Class: Io::Flow::V0::Clients::Invitations

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ Invitations

Returns a new instance of Invitations.



3616
3617
3618
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3616

def initialize(client)
  @client = HttpClient::Preconditions.assert_class('client', client, ::Io::Flow::V0::Client)
end

Instance Method Details

#delete_by_id(id) ⇒ Object



3655
3656
3657
3658
3659
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3655

def delete_by_id(id)
  HttpClient::Preconditions.assert_class('id', id, String)
  r = @client.request("/invitations/#{CGI.escape(id)}").delete
  nil
end

#get(incoming = {}) ⇒ Object

Search invitations. Always paginated.



3621
3622
3623
3624
3625
3626
3627
3628
3629
3630
3631
3632
3633
3634
3635
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3621

def get(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  query = {
    :id => (x = opts.delete(:id); x.nil? ? nil : HttpClient::Preconditions.assert_class('id', x, Array).map { |v| HttpClient::Preconditions.assert_class('id', v, String) }),
    :organization => (x = opts.delete(:organization); x.nil? ? nil : HttpClient::Preconditions.assert_class('organization', x, String)),
    :email => (x = opts.delete(:email); x.nil? ? nil : HttpClient::Preconditions.assert_class('email', x, String)),
    :token => (x = opts.delete(:token); x.nil? ? nil : HttpClient::Preconditions.assert_class('token', x, String)),
    :limit => HttpClient::Preconditions.assert_class('limit', (x = opts.delete(:limit); x.nil? ? 25 : x), Integer),
    :offset => HttpClient::Preconditions.assert_class('offset', (x = opts.delete(:offset); x.nil? ? 0 : x), Integer),
    :sort => HttpClient::Preconditions.assert_class('sort', (x = opts.delete(:sort); x.nil? ? "-created_at" : x), String),
    :expand => (x = opts.delete(:expand); x.nil? ? nil : HttpClient::Preconditions.assert_class('expand', x, Array).map { |v| HttpClient::Preconditions.assert_class('expand', v, String) })
  }.delete_if { |k, v| v.nil? }
  r = @client.request("/invitations").with_query(query).get
  r.map { |x| ::Io::Flow::V0::Models::Invitation.new(x) }
end

#get_by_id(id, incoming = {}) ⇒ Object

Returns information about a specific invitation.



3645
3646
3647
3648
3649
3650
3651
3652
3653
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3645

def get_by_id(id, incoming={})
  HttpClient::Preconditions.assert_class('id', id, String)
  opts = HttpClient::Helper.symbolize_keys(incoming)
  query = {
    :expand => (x = opts.delete(:expand); x.nil? ? nil : HttpClient::Preconditions.assert_class('expand', x, Array).map { |v| HttpClient::Preconditions.assert_class('expand', v, String) })
  }.delete_if { |k, v| v.nil? }
  r = @client.request("/invitations/#{CGI.escape(id)}").with_query(query).get
  ::Io::Flow::V0::Models::Invitation.new(r)
end

#get_tokens_by_token(token, incoming = {}) ⇒ Object

Lookup an invitation by its token.



3662
3663
3664
3665
3666
3667
3668
3669
3670
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3662

def get_tokens_by_token(token, incoming={})
  HttpClient::Preconditions.assert_class('token', token, String)
  opts = HttpClient::Helper.symbolize_keys(incoming)
  query = {
    :expand => (x = opts.delete(:expand); x.nil? ? nil : HttpClient::Preconditions.assert_class('expand', x, Array).map { |v| HttpClient::Preconditions.assert_class('expand', v, String) })
  }.delete_if { |k, v| v.nil? }
  r = @client.request("/invitations/tokens/#{CGI.escape(token)}").with_query(query).get
  ::Io::Flow::V0::Models::Invitation.new(r)
end

#get_versions(incoming = {}) ⇒ Object



3684
3685
3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3684

def get_versions(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  query = {
    :id => (x = opts.delete(:id); x.nil? ? nil : HttpClient::Preconditions.assert_class('id', x, Array).map { |v| HttpClient::Preconditions.assert_class('id', v, String) }),
    :invitation => (x = opts.delete(:invitation); x.nil? ? nil : HttpClient::Preconditions.assert_class('invitation', x, Array).map { |v| HttpClient::Preconditions.assert_class('invitation', v, String) }),
    :limit => HttpClient::Preconditions.assert_class('limit', (x = opts.delete(:limit); x.nil? ? 25 : x), Integer),
    :offset => HttpClient::Preconditions.assert_class('offset', (x = opts.delete(:offset); x.nil? ? 0 : x), Integer),
    :sort => HttpClient::Preconditions.assert_class('sort', (x = opts.delete(:sort); x.nil? ? "journal_timestamp" : x), String)
  }.delete_if { |k, v| v.nil? }
  r = @client.request("/invitations/versions").with_query(query).get
  r.map { |x| ::Io::Flow::V0::Models::InvitationVersion.new(x) }
end

#post(invitation_form) ⇒ Object

Create a new invitation.



3638
3639
3640
3641
3642
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3638

def post(invitation_form)
  HttpClient::Preconditions.assert_class('invitation_form', invitation_form, ::Io::Flow::V0::Models::InvitationForm)
  r = @client.request("/invitations").with_json(invitation_form.to_json).post
  ::Io::Flow::V0::Models::Invitation.new(r)
end

#put_tokens_by_token(token, hash) ⇒ Object

Accepts the invitation w/ the specified token and the authenticated user. Creating a membership record for this user within this organization. Invitations are one time use only - you will get a validation error if the invitation has previously been accepted or if the user's email addresses do not match the email on the invite.



3677
3678
3679
3680
3681
3682
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3677

def put_tokens_by_token(token, hash)
  HttpClient::Preconditions.assert_class('token', token, String)
  HttpClient::Preconditions.assert_class('hash', hash, Hash)
  r = @client.request("/invitations/tokens/#{CGI.escape(token)}").with_json(hash.to_json).put
  ::Io::Flow::V0::Models::Membership.new(r)
end