Class: Io::Flow::V0::Clients::Refunds
- Inherits:
-
Object
- Object
- Io::Flow::V0::Clients::Refunds
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Method Summary collapse
- #delete_identifiers_by_key_and_identifier(organization, key, identifier) ⇒ Object
- #get(organization, incoming = {}) ⇒ Object
-
#get_by_key(organization, key) ⇒ Object
Returns information about a specific refund.
- #get_identifiers_by_key(organization, key, incoming = {}) ⇒ Object
-
#get_summary_by_order_number(organization, order_number) ⇒ Object
Returns a refund order summary for the specified order.
-
#get_versions(organization, incoming = {}) ⇒ Object
Provides visibility into recent changes of each object, including deletion.
-
#initialize(client) ⇒ Refunds
constructor
A new instance of Refunds.
-
#post(organization, refund_form) ⇒ Object
Create a new refund.
-
#put_identifiers_by_key_and_identifier(organization, key, identifier, identifier_form) ⇒ Object
Create a new identifier for this refund.
Constructor Details
#initialize(client) ⇒ Refunds
Returns a new instance of Refunds.
3414 3415 3416 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3414 def initialize(client) @client = HttpClient::Preconditions.assert_class('client', client, ::Io::Flow::V0::Client) end |
Instance Method Details
#delete_identifiers_by_key_and_identifier(organization, key, identifier) ⇒ Object
3501 3502 3503 3504 3505 3506 3507 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3501 def delete_identifiers_by_key_and_identifier(organization, key, identifier) HttpClient::Preconditions.assert_class('organization', organization, String) HttpClient::Preconditions.assert_class('key', key, String) HttpClient::Preconditions.assert_class('identifier', identifier, String) r = @client.request("/#{CGI.escape(organization)}/refunds/#{CGI.escape(key)}/identifiers/#{CGI.escape(identifier)}").delete nil end |
#get(organization, incoming = {}) ⇒ Object
3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3418 def get(organization, incoming={}) HttpClient::Preconditions.assert_class('organization', organization, String) opts = HttpClient::Helper.symbolize_keys(incoming) query = { :id => (x = opts.delete(:id); x.nil? ? nil : HttpClient::Preconditions.assert_class('id', x, Array).map { |v| HttpClient::Preconditions.assert_class('id', v, String) }), :key => (x = opts.delete(:key); x.nil? ? nil : HttpClient::Preconditions.assert_class('key', x, Array).map { |v| HttpClient::Preconditions.assert_class('key', v, String) }), :identifier => (x = opts.delete(:identifier); x.nil? ? nil : HttpClient::Preconditions.assert_class('identifier', x, String)), :authorization_id => (x = opts.delete(:authorization_id); x.nil? ? nil : HttpClient::Preconditions.assert_class('authorization_id', x, String)), :authorization_key => (x = opts.delete(:authorization_key); x.nil? ? nil : HttpClient::Preconditions.assert_class('authorization_key', x, String)), :capture_id => (x = opts.delete(:capture_id); x.nil? ? nil : HttpClient::Preconditions.assert_class('capture_id', x, String)), :capture_key => (x = opts.delete(:capture_key); x.nil? ? nil : HttpClient::Preconditions.assert_class('capture_key', x, String)), :limit => HttpClient::Preconditions.assert_class('limit', (x = opts.delete(:limit); x.nil? ? 25 : x), Integer), :offset => HttpClient::Preconditions.assert_class('offset', (x = opts.delete(:offset); x.nil? ? 0 : x), Integer), :sort => HttpClient::Preconditions.assert_class('sort', (x = opts.delete(:sort); x.nil? ? "-created_at" : x), String) }.delete_if { |k, v| v.nil? } r = @client.request("/#{CGI.escape(organization)}/refunds").with_query(query).get r.map { |x| ::Io::Flow::V0::Models::Refund.new(x) } end |
#get_by_key(organization, key) ⇒ Object
Returns information about a specific refund.
3469 3470 3471 3472 3473 3474 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3469 def get_by_key(organization, key) HttpClient::Preconditions.assert_class('organization', organization, String) HttpClient::Preconditions.assert_class('key', key, String) r = @client.request("/#{CGI.escape(organization)}/refunds/#{CGI.escape(key)}").get ::Io::Flow::V0::Models::Refund.new(r) end |
#get_identifiers_by_key(organization, key, incoming = {}) ⇒ Object
3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 3489 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3476 def get_identifiers_by_key(organization, key, incoming={}) HttpClient::Preconditions.assert_class('organization', organization, String) HttpClient::Preconditions.assert_class('key', key, String) opts = HttpClient::Helper.symbolize_keys(incoming) query = { :id => (x = opts.delete(:id); x.nil? ? nil : HttpClient::Preconditions.assert_class('id', x, Array).map { |v| HttpClient::Preconditions.assert_class('id', v, String) }), :identifier => (x = opts.delete(:identifier); x.nil? ? nil : HttpClient::Preconditions.assert_class('identifier', x, String)), :limit => HttpClient::Preconditions.assert_class('limit', (x = opts.delete(:limit); x.nil? ? 25 : x), Integer), :offset => HttpClient::Preconditions.assert_class('offset', (x = opts.delete(:offset); x.nil? ? 0 : x), Integer), :sort => HttpClient::Preconditions.assert_class('sort', (x = opts.delete(:sort); x.nil? ? "-created_at" : x), String) }.delete_if { |k, v| v.nil? } r = @client.request("/#{CGI.escape(organization)}/refunds/#{CGI.escape(key)}/identifiers").with_query(query).get r.map { |x| ::Io::Flow::V0::Models::RefundIdentifier.new(x) } end |
#get_summary_by_order_number(organization, order_number) ⇒ Object
Returns a refund order summary for the specified order.
3446 3447 3448 3449 3450 3451 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3446 def get_summary_by_order_number(organization, order_number) HttpClient::Preconditions.assert_class('organization', organization, String) HttpClient::Preconditions.assert_class('order_number', order_number, String) r = @client.request("/#{CGI.escape(organization)}/refunds/summary/#{CGI.escape(order_number)}").get ::Io::Flow::V0::Models::RefundOrderSummary.new(r) end |
#get_versions(organization, incoming = {}) ⇒ Object
Provides visibility into recent changes of each object, including deletion
3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3454 def get_versions(organization, incoming={}) HttpClient::Preconditions.assert_class('organization', organization, String) opts = HttpClient::Helper.symbolize_keys(incoming) query = { :id => (x = opts.delete(:id); x.nil? ? nil : HttpClient::Preconditions.assert_class('id', x, Array).map { |v| HttpClient::Preconditions.assert_class('id', v, Integer) }), :refund_id => (x = opts.delete(:refund_id); x.nil? ? nil : HttpClient::Preconditions.assert_class('refund_id', x, Array).map { |v| HttpClient::Preconditions.assert_class('refund_id', v, String) }), :limit => HttpClient::Preconditions.assert_class('limit', (x = opts.delete(:limit); x.nil? ? 25 : x), Integer), :offset => HttpClient::Preconditions.assert_class('offset', (x = opts.delete(:offset); x.nil? ? 0 : x), Integer), :sort => HttpClient::Preconditions.assert_class('sort', (x = opts.delete(:sort); x.nil? ? "journal_timestamp" : x), String) }.delete_if { |k, v| v.nil? } r = @client.request("/#{CGI.escape(organization)}/refunds/versions").with_query(query).get r.map { |x| ::Io::Flow::V0::Models::RefundVersion.new(x) } end |
#post(organization, refund_form) ⇒ Object
Create a new refund.
3438 3439 3440 3441 3442 3443 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3438 def post(organization, refund_form) HttpClient::Preconditions.assert_class('organization', organization, String) (x = refund_form; x.is_a?(::Io::Flow::V0::Models::RefundForm) ? x : ::Io::Flow::V0::Models::RefundForm.new(x)) r = @client.request("/#{CGI.escape(organization)}/refunds").with_json(refund_form.to_json).post ::Io::Flow::V0::Models::Refund.new(r) end |
#put_identifiers_by_key_and_identifier(organization, key, identifier, identifier_form) ⇒ Object
Create a new identifier for this refund
3492 3493 3494 3495 3496 3497 3498 3499 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 3492 def put_identifiers_by_key_and_identifier(organization, key, identifier, identifier_form) HttpClient::Preconditions.assert_class('organization', organization, String) HttpClient::Preconditions.assert_class('key', key, String) HttpClient::Preconditions.assert_class('identifier', identifier, String) (x = identifier_form; x.is_a?(::Io::Flow::V0::Models::IdentifierForm) ? x : ::Io::Flow::V0::Models::IdentifierForm.new(x)) r = @client.request("/#{CGI.escape(organization)}/refunds/#{CGI.escape(key)}/identifiers/#{CGI.escape(identifier)}").with_json(identifier_form.to_json).put ::Io::Flow::V0::Models::RefundIdentifier.new(r) end |