Class: Io::Flow::V0::Models::Address
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::Address
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
Defines structured fields for address to be used in user/form input. Either text or the structured input needs to be present.
Instance Attribute Summary collapse
-
#city ⇒ Object
readonly
Returns the value of attribute city.
-
#country ⇒ Object
readonly
Returns the value of attribute country.
-
#latitude ⇒ Object
readonly
Returns the value of attribute latitude.
-
#longitude ⇒ Object
readonly
Returns the value of attribute longitude.
-
#postal ⇒ Object
readonly
Returns the value of attribute postal.
-
#province ⇒ Object
readonly
Returns the value of attribute province.
-
#street_number ⇒ Object
readonly
Returns the value of attribute street_number.
-
#streets ⇒ Object
readonly
Returns the value of attribute streets.
-
#text ⇒ Object
readonly
Returns the value of attribute text.
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ Address
constructor
A new instance of Address.
- #to_hash ⇒ Object
- #to_json ⇒ Object
Constructor Details
#initialize(incoming = {}) ⇒ Address
20428 20429 20430 20431 20432 20433 20434 20435 20436 20437 20438 20439 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20428 def initialize(incoming={}) opts = HttpClient::Helper.symbolize_keys(incoming) @text = (x = opts.delete(:text); x.nil? ? nil : HttpClient::Preconditions.assert_class('text', x, String)) @streets = (x = opts.delete(:streets); x.nil? ? nil : HttpClient::Preconditions.assert_class('streets', x, Array).map { |v| HttpClient::Preconditions.assert_class('streets', v, String) }) @street_number = (x = opts.delete(:street_number); x.nil? ? nil : HttpClient::Preconditions.assert_class('street_number', x, String)) @city = (x = opts.delete(:city); x.nil? ? nil : HttpClient::Preconditions.assert_class('city', x, String)) @province = (x = opts.delete(:province); x.nil? ? nil : HttpClient::Preconditions.assert_class('province', x, String)) @postal = (x = opts.delete(:postal); x.nil? ? nil : HttpClient::Preconditions.assert_class('postal', x, String)) @country = (x = opts.delete(:country); x.nil? ? nil : HttpClient::Preconditions.assert_class('country', x, String)) @latitude = (x = opts.delete(:latitude); x.nil? ? nil : HttpClient::Preconditions.assert_class('latitude', x, String)) @longitude = (x = opts.delete(:longitude); x.nil? ? nil : HttpClient::Preconditions.assert_class('longitude', x, String)) end |
Instance Attribute Details
#city ⇒ Object (readonly)
Returns the value of attribute city.
20426 20427 20428 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20426 def city @city end |
#country ⇒ Object (readonly)
Returns the value of attribute country.
20426 20427 20428 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20426 def country @country end |
#latitude ⇒ Object (readonly)
Returns the value of attribute latitude.
20426 20427 20428 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20426 def latitude @latitude end |
#longitude ⇒ Object (readonly)
Returns the value of attribute longitude.
20426 20427 20428 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20426 def longitude @longitude end |
#postal ⇒ Object (readonly)
Returns the value of attribute postal.
20426 20427 20428 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20426 def postal @postal end |
#province ⇒ Object (readonly)
Returns the value of attribute province.
20426 20427 20428 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20426 def province @province end |
#street_number ⇒ Object (readonly)
Returns the value of attribute street_number.
20426 20427 20428 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20426 def street_number @street_number end |
#streets ⇒ Object (readonly)
Returns the value of attribute streets.
20426 20427 20428 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20426 def streets @streets end |
#text ⇒ Object (readonly)
Returns the value of attribute text.
20426 20427 20428 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20426 def text @text end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
20445 20446 20447 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20445 def copy(incoming={}) Address.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#to_hash ⇒ Object
20449 20450 20451 20452 20453 20454 20455 20456 20457 20458 20459 20460 20461 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20449 def to_hash { :text => text, :streets => streets.nil? ? nil : streets, :street_number => street_number, :city => city, :province => province, :postal => postal, :country => country, :latitude => latitude, :longitude => longitude } end |
#to_json ⇒ Object
20441 20442 20443 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20441 def to_json JSON.dump(to_hash) end |