Class: Io::Flow::V0::Models::AddressVerification
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::AddressVerification
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
Address verification returns information on whether or not an address is valid and deliverable - meaning carriers will accept this address. Also returns suggestions for address correction, including data to highlight specific fields to correct.
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
Returns the value of attribute address.
-
#suggestions ⇒ Object
readonly
Returns the value of attribute suggestions.
-
#valid ⇒ Object
readonly
Returns the value of attribute valid.
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ AddressVerification
constructor
A new instance of AddressVerification.
- #to_hash ⇒ Object
- #to_json ⇒ Object
Constructor Details
#initialize(incoming = {}) ⇒ AddressVerification
Returns a new instance of AddressVerification.
20669 20670 20671 20672 20673 20674 20675 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20669 def initialize(incoming={}) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:address, :valid], 'AddressVerification') @address = (x = opts.delete(:address); x.is_a?(::Io::Flow::V0::Models::Address) ? x : ::Io::Flow::V0::Models::Address.new(x)) @valid = HttpClient::Preconditions.assert_boolean('valid', opts.delete(:valid)) @suggestions = HttpClient::Preconditions.assert_class('suggestions', (x = opts.delete(:suggestions); x.nil? ? [] : x), Array).map { |v| (x = v; x.is_a?(::Io::Flow::V0::Models::AddressSuggestion) ? x : ::Io::Flow::V0::Models::AddressSuggestion.new(x)) } end |
Instance Attribute Details
#address ⇒ Object (readonly)
Returns the value of attribute address.
20667 20668 20669 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20667 def address @address end |
#suggestions ⇒ Object (readonly)
Returns the value of attribute suggestions.
20667 20668 20669 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20667 def suggestions @suggestions end |
#valid ⇒ Object (readonly)
Returns the value of attribute valid.
20667 20668 20669 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20667 def valid @valid end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
20681 20682 20683 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20681 def copy(incoming={}) AddressVerification.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#to_hash ⇒ Object
20685 20686 20687 20688 20689 20690 20691 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20685 def to_hash { :address => address.to_hash, :valid => valid, :suggestions => suggestions.map { |o| o.to_hash } } end |
#to_json ⇒ Object
20677 20678 20679 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20677 def to_json JSON.dump(to_hash) end |