Class: Io::Flow::V0::Models::AdjustmentReasonKey

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ AdjustmentReasonKey



6146
6147
6148
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 6146

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



6144
6145
6146
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 6144

def value
  @value
end

Class Method Details

.ALLObject



6166
6167
6168
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 6166

def AdjustmentReasonKey.ALL
  @@all ||= [AdjustmentReasonKey.duty_deminimis, AdjustmentReasonKey.vat_deminimis]
end

.apply(value) ⇒ Object

Returns the instance of AdjustmentReasonKey for this value, creating a new instance for an unknown value



6151
6152
6153
6154
6155
6156
6157
6158
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 6151

def AdjustmentReasonKey.apply(value)
  if value.instance_of?(AdjustmentReasonKey)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || AdjustmentReasonKey.new(value))
  end
end

.duty_deminimisObject

If the duty de minimis value has not been met, an adjustment may be made to offset any previously calculated duty.



6172
6173
6174
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 6172

def AdjustmentReasonKey.duty_deminimis
  @@_duty_deminimis ||= AdjustmentReasonKey.new('duty_deminimis')
end

.from_string(value) ⇒ Object

Returns the instance of AdjustmentReasonKey for this value, or nil if not found



6161
6162
6163
6164
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 6161

def AdjustmentReasonKey.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  AdjustmentReasonKey.ALL.find { |v| v.value == value }
end

.vat_deminimisObject

If the VAT de minimis value has not been met, an adjustment may be made to offset any previously calculated VAT.



6178
6179
6180
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 6178

def AdjustmentReasonKey.vat_deminimis
  @@_vat_deminimis ||= AdjustmentReasonKey.new('vat_deminimis')
end

Instance Method Details

#to_hashObject



6182
6183
6184
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 6182

def to_hash
  value
end