Class: Io::Flow::V0::Models::AdyenV3FingerprintToken

Inherits:
SdkAdyenV3AuthenticationToken show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

This will load a hidden script from the card issuer that gathers browser metrics to inform the authorization decision. Used to initiate Checkout.create using the threeDS2DeviceFingerprint operation.

Instance Attribute Summary collapse

Attributes inherited from SdkAdyenV3AuthenticationToken

#type

Instance Method Summary collapse

Methods inherited from SdkAdyenV3AuthenticationToken

from_json, #to_hash

Constructor Details

#initialize(incoming = {}) ⇒ AdyenV3FingerprintToken

Returns a new instance of AdyenV3FingerprintToken.



30007
30008
30009
30010
30011
30012
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 30007

def initialize(incoming={})
  super(:type => SdkAdyenV3AuthenticationToken::Types::ADYEN_V3_FINGERPRINT_TOKEN)
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:fingerprint_token], 'AdyenV3FingerprintToken')
  @fingerprint_token = HttpClient::Preconditions.assert_class('fingerprint_token', opts.delete(:fingerprint_token), String)
end

Instance Attribute Details

#fingerprint_token ⇒ Object (readonly)

Returns the value of attribute fingerprint_token.



30005
30006
30007
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 30005

def fingerprint_token
  @fingerprint_token
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



30018
30019
30020
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 30018

def copy(incoming={})
  AdyenV3FingerprintToken.new(subtype_to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#subtype_to_hash ⇒ Object



30022
30023
30024
30025
30026
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 30022

def subtype_to_hash
  {
    :fingerprint_token => fingerprint_token
  }
end

#to_json ⇒ Object



30014
30015
30016
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 30014

def to_json
  JSON.dump(to_hash)
end