Class: Io::Flow::V0::Models::Aggregate

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ Aggregate

Returns a new instance of Aggregate.



11901
11902
11903
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11901

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



11899
11900
11901
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11899

def value
  @value
end

Class Method Details

.ALLObject



11921
11922
11923
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11921

def Aggregate.ALL
  @@all ||= [Aggregate.maximum, Aggregate.minimum]
end

.apply(value) ⇒ Object

Returns the instance of Aggregate for this value, creating a new instance for an unknown value



11906
11907
11908
11909
11910
11911
11912
11913
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11906

def Aggregate.apply(value)
  if value.instance_of?(Aggregate)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || Aggregate.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of Aggregate for this value, or nil if not found



11916
11917
11918
11919
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11916

def Aggregate.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  Aggregate.ALL.find { |v| v.value == value }
end

.maximumObject



11925
11926
11927
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11925

def Aggregate.maximum
  @@_maximum ||= Aggregate.new('maximum')
end

.minimumObject



11929
11930
11931
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11929

def Aggregate.minimum
  @@_minimum ||= Aggregate.new('minimum')
end

Instance Method Details

#to_hashObject



11933
11934
11935
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11933

def to_hash
  value
end