Class: Io::Flow::V0::Models::Attribute

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

An attribute can be configured to be used in different ways throughout Flow. A common example is to identify a meaningful attribute (e.g. brand) that can then be displayed throughout the Flow console.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ Attribute

Returns a new instance of Attribute.



21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21263

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:id, :key, :options], 'Attribute')
  @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String)
  @key = HttpClient::Preconditions.assert_class('key', opts.delete(:key), String)
  @options = (x = opts.delete(:options); x.is_a?(::Io::Flow::V0::Models::Options) ? x : ::Io::Flow::V0::Models::Options.new(x))
  @label = (x = opts.delete(:label); x.nil? ? nil : HttpClient::Preconditions.assert_class('label', x, String))
  @intent = (x = opts.delete(:intent); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::AttributeIntent) ? x : ::Io::Flow::V0::Models::AttributeIntent.apply(x)))
  @type = (x = opts.delete(:type); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::AttributeDataType) ? x : ::Io::Flow::V0::Models::AttributeDataType.apply(x)))
  @position = (x = opts.delete(:position); x.nil? ? nil : HttpClient::Preconditions.assert_class('position', x, Integer))
end

Instance Attribute Details

#idObject (readonly)

Returns the value of attribute id.



21261
21262
21263
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21261

def id
  @id
end

#intentObject (readonly)

Returns the value of attribute intent.



21261
21262
21263
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21261

def intent
  @intent
end

#keyObject (readonly)

Returns the value of attribute key.



21261
21262
21263
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21261

def key
  @key
end

#labelObject (readonly)

Returns the value of attribute label.



21261
21262
21263
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21261

def label
  @label
end

#optionsObject (readonly)

Returns the value of attribute options.



21261
21262
21263
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21261

def options
  @options
end

#positionObject (readonly)

Returns the value of attribute position.



21261
21262
21263
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21261

def position
  @position
end

#typeObject (readonly)

Returns the value of attribute type.



21261
21262
21263
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21261

def type
  @type
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



21279
21280
21281
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21279

def copy(incoming={})
  Attribute.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hashObject



21283
21284
21285
21286
21287
21288
21289
21290
21291
21292
21293
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21283

def to_hash
  {
    :id => id,
    :key => key,
    :options => options.to_hash,
    :label => label,
    :intent => intent.nil? ? nil : intent.value,
    :type => type.nil? ? nil : type.value,
    :position => position
  }
end

#to_jsonObject



21275
21276
21277
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21275

def to_json
  JSON.dump(to_hash)
end