Class: Io::Flow::V0::Models::AttributeDataType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::AttributeDataType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of AttributeDataType for this value, creating a new instance for an unknown value.
-
.boolean ⇒ Object
Boolean true/false data type.
-
.decimal ⇒ Object
Decimal datatype without size or precision restrictions.
-
.from_string(value) ⇒ Object
Returns the instance of AttributeDataType for this value, or nil if not found.
-
.integer ⇒ Object
Value of the attribute must be an integer.
-
.json_array ⇒ Object
An example [“Cotton”, “Wool”].
-
.string ⇒ Object
Unvalidated string of characters.
Instance Method Summary collapse
-
#initialize(value) ⇒ AttributeDataType
constructor
A new instance of AttributeDataType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ AttributeDataType
Returns a new instance of AttributeDataType.
15392 15393 15394 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15392 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
15390 15391 15392 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15390 def value @value end |
Class Method Details
.ALL ⇒ Object
15412 15413 15414 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15412 def AttributeDataType.ALL @@all ||= [AttributeDataType.boolean, AttributeDataType.integer, AttributeDataType.decimal, AttributeDataType.string, AttributeDataType.json_array] end |
.apply(value) ⇒ Object
Returns the instance of AttributeDataType for this value, creating a new instance for an unknown value
15397 15398 15399 15400 15401 15402 15403 15404 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15397 def AttributeDataType.apply(value) if value.instance_of?(AttributeDataType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || AttributeDataType.new(value)) end end |
.boolean ⇒ Object
Boolean true/false data type
15417 15418 15419 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15417 def AttributeDataType.boolean @@_boolean ||= AttributeDataType.new('boolean') end |
.decimal ⇒ Object
Decimal datatype without size or precision restrictions. Commonly used for currency values.
15428 15429 15430 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15428 def AttributeDataType.decimal @@_decimal ||= AttributeDataType.new('decimal') end |
.from_string(value) ⇒ Object
Returns the instance of AttributeDataType for this value, or nil if not found
15407 15408 15409 15410 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15407 def AttributeDataType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) AttributeDataType.ALL.find { |v| v.value == value } end |
.integer ⇒ Object
Value of the attribute must be an integer
15422 15423 15424 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15422 def AttributeDataType.integer @@_integer ||= AttributeDataType.new('integer') end |
.json_array ⇒ Object
An example [“Cotton”, “Wool”]
15438 15439 15440 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15438 def AttributeDataType.json_array @@_json_array ||= AttributeDataType.new('json_array') end |
.string ⇒ Object
Unvalidated string of characters.
15433 15434 15435 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15433 def AttributeDataType.string @@_string ||= AttributeDataType.new('string') end |
Instance Method Details
#to_hash ⇒ Object
15442 15443 15444 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15442 def to_hash value end |