Class: Io::Flow::V0::Models::AuthorizationOption

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ AuthorizationOption

Returns a new instance of AuthorizationOption.



15075
15076
15077
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15075

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



15073
15074
15075
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15073

def value
  @value
end

Class Method Details

.ALLObject



15095
15096
15097
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15095

def AuthorizationOption.ALL
  @@all ||= [AuthorizationOption.store_card]
end

.apply(value) ⇒ Object

Returns the instance of AuthorizationOption for this value, creating a new instance for an unknown value



15080
15081
15082
15083
15084
15085
15086
15087
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15080

def AuthorizationOption.apply(value)
  if value.instance_of?(AuthorizationOption)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || AuthorizationOption.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of AuthorizationOption for this value, or nil if not found



15090
15091
15092
15093
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15090

def AuthorizationOption.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  AuthorizationOption.ALL.find { |v| v.value == value }
end

.store_cardObject

If set, and the authorization is created using a one time nonce, we automatically tokenize and store the card. In these cases you will want to store the new card token in the authorization response (card object)



15102
15103
15104
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15102

def AuthorizationOption.store_card
  @@_store_card ||= AuthorizationOption.new('store_card')
end

Instance Method Details

#to_hashObject



15106
15107
15108
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15106

def to_hash
  value
end