Class: Io::Flow::V0::Models::AuthorizationResultActionPost

Inherits:
AuthorizationResultAction show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Provides details for how to acquire additional information from the customer using POST (e.g. redirecting to the issuer for online payment method or 3D Secure).

Instance Attribute Summary collapse

Attributes inherited from AuthorizationResultAction

#discriminator

Instance Method Summary collapse

Methods inherited from AuthorizationResultAction

from_json, #to_hash

Constructor Details

#initialize(incoming = {}) ⇒ AuthorizationResultActionPost

Returns a new instance of AuthorizationResultActionPost.



21833
21834
21835
21836
21837
21838
21839
21840
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21833

def initialize(incoming={})
  super(:discriminator => AuthorizationResultAction::Types::AUTHORIZATION_RESULT_ACTION_POST)
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:type, :url, :parameters], 'AuthorizationResultActionPost')
  @type = (x = opts.delete(:type); x.is_a?(::Io::Flow::V0::Models::AuthorizationResultActionType) ? x : ::Io::Flow::V0::Models::AuthorizationResultActionType.apply(x))
  @url = HttpClient::Preconditions.assert_class('url', opts.delete(:url), String)
  @parameters = HttpClient::Preconditions.assert_class('parameters', HttpClient::Helper.to_object(opts.delete(:parameters)), Hash)
end

Instance Attribute Details

#parametersObject (readonly)

Returns the value of attribute parameters.



21831
21832
21833
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21831

def parameters
  @parameters
end

#typeObject (readonly)

Returns the value of attribute type.



21831
21832
21833
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21831

def type
  @type
end

#urlObject (readonly)

Returns the value of attribute url.



21831
21832
21833
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21831

def url
  @url
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



21846
21847
21848
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21846

def copy(incoming={})
  AuthorizationResultActionPost.new(subtype_to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#subtype_to_hashObject



21850
21851
21852
21853
21854
21855
21856
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21850

def subtype_to_hash
  {
    :type => type.value,
    :url => url,
    :parameters => parameters
  }
end

#to_jsonObject



21842
21843
21844
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21842

def to_json
  JSON.dump(to_hash)
end