Class: Io::Flow::V0::Models::AvailabilityStatus
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::AvailabilityStatus
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of AvailabilityStatus for this value, creating a new instance for an unknown value.
- .disabled ⇒ Object
- .enabled ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of AvailabilityStatus for this value, or nil if not found.
Instance Method Summary collapse
-
#initialize(value) ⇒ AvailabilityStatus
constructor
A new instance of AvailabilityStatus.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ AvailabilityStatus
Returns a new instance of AvailabilityStatus.
12442 12443 12444 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12442 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
12440 12441 12442 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12440 def value @value end |
Class Method Details
.ALL ⇒ Object
12462 12463 12464 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12462 def AvailabilityStatus.ALL @@all ||= [AvailabilityStatus.enabled, AvailabilityStatus.disabled] end |
.apply(value) ⇒ Object
Returns the instance of AvailabilityStatus for this value, creating a new instance for an unknown value
12447 12448 12449 12450 12451 12452 12453 12454 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12447 def AvailabilityStatus.apply(value) if value.instance_of?(AvailabilityStatus) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || AvailabilityStatus.new(value)) end end |
.disabled ⇒ Object
12470 12471 12472 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12470 def AvailabilityStatus.disabled @@_disabled ||= AvailabilityStatus.new('disabled') end |
.enabled ⇒ Object
12466 12467 12468 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12466 def AvailabilityStatus.enabled @@_enabled ||= AvailabilityStatus.new('enabled') end |
.from_string(value) ⇒ Object
Returns the instance of AvailabilityStatus for this value, or nil if not found
12457 12458 12459 12460 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12457 def AvailabilityStatus.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) AvailabilityStatus.ALL.find { |v| v.value == value } end |
Instance Method Details
#to_hash ⇒ Object
12474 12475 12476 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12474 def to_hash value end |