Class: Io::Flow::V0::Models::Calendar

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ Calendar

Returns a new instance of Calendar.



12602
12603
12604
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12602

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



12600
12601
12602
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12600

def value
  @value
end

Class Method Details

.ALLObject



12622
12623
12624
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12622

def Calendar.ALL
  @@all ||= [Calendar.weekdays, Calendar.everyday]
end

.apply(value) ⇒ Object

Returns the instance of Calendar for this value, creating a new instance for an unknown value



12607
12608
12609
12610
12611
12612
12613
12614
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12607

def Calendar.apply(value)
  if value.instance_of?(Calendar)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || Calendar.new(value))
  end
end

.everydayObject

7 days per week



12632
12633
12634
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12632

def Calendar.everyday
  @@_everyday ||= Calendar.new('everyday')
end

.from_string(value) ⇒ Object

Returns the instance of Calendar for this value, or nil if not found



12617
12618
12619
12620
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12617

def Calendar.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  Calendar.ALL.find { |v| v.value == value }
end

.weekdaysObject

Mon - Fri



12627
12628
12629
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12627

def Calendar.weekdays
  @@_weekdays ||= Calendar.new('weekdays')
end

Instance Method Details

#to_hashObject



12636
12637
12638
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12636

def to_hash
  value
end