Class: Io::Flow::V0::Models::CancelReason

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ CancelReason

Returns a new instance of CancelReason.



12646
12647
12648
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12646

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



12644
12645
12646
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12644

def value
  @value
end

Class Method Details

.ALLObject



12666
12667
12668
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12666

def CancelReason.ALL
  @@all ||= [CancelReason.out_of_stock, CancelReason.consumer_requested, CancelReason.flow_cancel]
end

.apply(value) ⇒ Object

Returns the instance of CancelReason for this value, creating a new instance for an unknown value



12651
12652
12653
12654
12655
12656
12657
12658
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12651

def CancelReason.apply(value)
  if value.instance_of?(CancelReason)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || CancelReason.new(value))
  end
end

.consumer_requestedObject

A consumer requested cancellation of an item qty and the fulfillment party has acknowledged that the qty will not be shipped. This is a cancel of the ordered quantity and will reduce or refund the consumer's payment



12680
12681
12682
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12680

def CancelReason.consumer_requested
  @@_consumer_requested ||= CancelReason.new('consumer_requested')
end

.flow_cancelObject

Flow has had to cancel an order, possibly due to fraud activity or inability to collect payment. This will cancel the ordered quantity. All known parties will be notified.



12687
12688
12689
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12687

def CancelReason.flow_cancel
  @@_flow_cancel ||= CancelReason.new('flow_cancel')
end

.from_string(value) ⇒ Object

Returns the instance of CancelReason for this value, or nil if not found



12661
12662
12663
12664
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12661

def CancelReason.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  CancelReason.ALL.find { |v| v.value == value }
end

.out_of_stockObject

Out of stock is a permanent cancel of the fulfillment of an item qty. If no other fulfillment parties exist, this will cancel the ordered quantity and reduce or refund the consumer's payment.



12673
12674
12675
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12673

def CancelReason.out_of_stock
  @@_out_of_stock ||= CancelReason.new('out_of_stock')
end

Instance Method Details

#to_hashObject



12691
12692
12693
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12691

def to_hash
  value
end