Class: Io::Flow::V0::Models::CardErrorCode
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::CardErrorCode
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of CardErrorCode for this value, creating a new instance for an unknown value.
-
.avs ⇒ Object
Declined due to avs mismatch.
-
.cvv ⇒ Object
Declined due to cvv mismatch.
-
.fraud ⇒ Object
Declined due to suspected fraud.
-
.from_string(value) ⇒ Object
Returns the instance of CardErrorCode for this value, or nil if not found.
-
.invalid_address ⇒ Object
Invalid billing address.
-
.invalid_currency ⇒ Object
Invalid requested currency.
-
.invalid_expiration ⇒ Object
Invalid expiration date.
-
.invalid_name ⇒ Object
Invalid cardholder name.
-
.invalid_number ⇒ Object
Invalid payment number.
-
.invalid_token_type ⇒ Object
Cannot create a permanent card via an unauthorized request.
-
.unknown ⇒ Object
Declined due to another reason (details not known).
Instance Method Summary collapse
-
#initialize(value) ⇒ CardErrorCode
constructor
A new instance of CardErrorCode.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ CardErrorCode
Returns a new instance of CardErrorCode.
16405 16406 16407 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16405 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
16403 16404 16405 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16403 def value @value end |
Class Method Details
.ALL ⇒ Object
16425 16426 16427 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16425 def CardErrorCode.ALL @@all ||= [CardErrorCode.invalid_address, CardErrorCode.invalid_currency, CardErrorCode.invalid_name, CardErrorCode.invalid_number, CardErrorCode.invalid_expiration, CardErrorCode.invalid_token_type, CardErrorCode.avs, CardErrorCode.cvv, CardErrorCode.fraud, CardErrorCode.unknown] end |
.apply(value) ⇒ Object
Returns the instance of CardErrorCode for this value, creating a new instance for an unknown value
16410 16411 16412 16413 16414 16415 16416 16417 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16410 def CardErrorCode.apply(value) if value.instance_of?(CardErrorCode) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || CardErrorCode.new(value)) end end |
.avs ⇒ Object
Declined due to avs mismatch
16460 16461 16462 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16460 def CardErrorCode.avs @@_avs ||= CardErrorCode.new('avs') end |
.cvv ⇒ Object
Declined due to cvv mismatch
16465 16466 16467 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16465 def CardErrorCode.cvv @@_cvv ||= CardErrorCode.new('cvv') end |
.fraud ⇒ Object
Declined due to suspected fraud
16470 16471 16472 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16470 def CardErrorCode.fraud @@_fraud ||= CardErrorCode.new('fraud') end |
.from_string(value) ⇒ Object
Returns the instance of CardErrorCode for this value, or nil if not found
16420 16421 16422 16423 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16420 def CardErrorCode.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) CardErrorCode.ALL.find { |v| v.value == value } end |
.invalid_address ⇒ Object
Invalid billing address
16430 16431 16432 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16430 def CardErrorCode.invalid_address @@_invalid_address ||= CardErrorCode.new('invalid_address') end |
.invalid_currency ⇒ Object
Invalid requested currency
16435 16436 16437 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16435 def CardErrorCode.invalid_currency @@_invalid_currency ||= CardErrorCode.new('invalid_currency') end |
.invalid_expiration ⇒ Object
Invalid expiration date
16450 16451 16452 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16450 def CardErrorCode.invalid_expiration @@_invalid_expiration ||= CardErrorCode.new('invalid_expiration') end |
.invalid_name ⇒ Object
Invalid cardholder name
16440 16441 16442 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16440 def CardErrorCode.invalid_name @@_invalid_name ||= CardErrorCode.new('invalid_name') end |
.invalid_number ⇒ Object
Invalid payment number
16445 16446 16447 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16445 def CardErrorCode.invalid_number @@_invalid_number ||= CardErrorCode.new('invalid_number') end |
.invalid_token_type ⇒ Object
Cannot create a permanent card via an unauthorized request
16455 16456 16457 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16455 def CardErrorCode.invalid_token_type @@_invalid_token_type ||= CardErrorCode.new('invalid_token_type') end |
.unknown ⇒ Object
Declined due to another reason (details not known)
16475 16476 16477 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16475 def CardErrorCode.unknown @@_unknown ||= CardErrorCode.new('unknown') end |
Instance Method Details
#to_hash ⇒ Object
16479 16480 16481 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16479 def to_hash value end |