Class: Io::Flow::V0::Models::ConsumerInvoiceCustomerType

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ ConsumerInvoiceCustomerType

Returns a new instance of ConsumerInvoiceCustomerType.



16659
16660
16661
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16659

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



16657
16658
16659
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16657

def value
  @value
end

Class Method Details

.ALLObject



16679
16680
16681
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16679

def ConsumerInvoiceCustomerType.ALL
  @@all ||= [ConsumerInvoiceCustomerType.business_eu_verified, ConsumerInvoiceCustomerType.business_non_verified, ConsumerInvoiceCustomerType.individual]
end

.apply(value) ⇒ Object

Returns the instance of ConsumerInvoiceCustomerType for this value, creating a new instance for an unknown value



16664
16665
16666
16667
16668
16669
16670
16671
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16664

def ConsumerInvoiceCustomerType.apply(value)
  if value.instance_of?(ConsumerInvoiceCustomerType)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || ConsumerInvoiceCustomerType.new(value))
  end
end

.business_eu_verifiedObject

A business that have been verified in the European Union



16684
16685
16686
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16684

def ConsumerInvoiceCustomerType.business_eu_verified
  @@_business_eu_verified ||= ConsumerInvoiceCustomerType.new('business_eu_verified')
end

.business_non_verifiedObject

A business, but with no additional verification



16689
16690
16691
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16689

def ConsumerInvoiceCustomerType.business_non_verified
  @@_business_non_verified ||= ConsumerInvoiceCustomerType.new('business_non_verified')
end

.from_string(value) ⇒ Object

Returns the instance of ConsumerInvoiceCustomerType for this value, or nil if not found



16674
16675
16676
16677
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16674

def ConsumerInvoiceCustomerType.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  ConsumerInvoiceCustomerType.ALL.find { |v| v.value == value }
end

.individualObject



16693
16694
16695
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16693

def ConsumerInvoiceCustomerType.individual
  @@_individual ||= ConsumerInvoiceCustomerType.new('individual')
end

Instance Method Details

#to_hashObject



16697
16698
16699
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16697

def to_hash
  value
end