Class: Io::Flow::V0::Models::ConsumerInvoiceStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ ConsumerInvoiceStatus



13177
13178
13179
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13177

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



13175
13176
13177
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13175

def value
  @value
end

Class Method Details

.ALLObject



13197
13198
13199
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13197

def ConsumerInvoiceStatus.ALL
  @@all ||= [ConsumerInvoiceStatus.pending, ConsumerInvoiceStatus.available, ConsumerInvoiceStatus.invalid]
end

.apply(value) ⇒ Object

Returns the instance of ConsumerInvoiceStatus for this value, creating a new instance for an unknown value



13182
13183
13184
13185
13186
13187
13188
13189
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13182

def ConsumerInvoiceStatus.apply(value)
  if value.instance_of?(ConsumerInvoiceStatus)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || ConsumerInvoiceStatus.new(value))
  end
end

.availableObject

Indicates that the credit memo is fully validated and available for the end consumer



13209
13210
13211
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13209

def ConsumerInvoiceStatus.available
  @@_available ||= ConsumerInvoiceStatus.new('available')
end

.from_string(value) ⇒ Object

Returns the instance of ConsumerInvoiceStatus for this value, or nil if not found



13192
13193
13194
13195
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13192

def ConsumerInvoiceStatus.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  ConsumerInvoiceStatus.ALL.find { |v| v.value == value }
end

.invalidObject

Indicates that the credit memo failed to validate after multiple attempts and time



13215
13216
13217
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13215

def ConsumerInvoiceStatus.invalid
  @@_invalid ||= ConsumerInvoiceStatus.new('invalid')
end

.pendingObject

Indicates that the credit memo has been created but validation is pending (e.g. waiting for the associated refund to be confirmed)



13203
13204
13205
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13203

def ConsumerInvoiceStatus.pending
  @@_pending ||= ConsumerInvoiceStatus.new('pending')
end

Instance Method Details

#to_hashObject



13219
13220
13221
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13219

def to_hash
  value
end