Class: Io::Flow::V0::Models::CurrencyLabelFormatter

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ CurrencyLabelFormatter

Returns a new instance of CurrencyLabelFormatter.



13304
13305
13306
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13304

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



13302
13303
13304
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13302

def value
  @value
end

Class Method Details

.ALLObject



13324
13325
13326
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13324

def CurrencyLabelFormatter.ALL
  @@all ||= [CurrencyLabelFormatter.strip_trailing_zeros]
end

.apply(value) ⇒ Object

Returns the instance of CurrencyLabelFormatter for this value, creating a new instance for an unknown value



13309
13310
13311
13312
13313
13314
13315
13316
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13309

def CurrencyLabelFormatter.apply(value)
  if value.instance_of?(CurrencyLabelFormatter)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || CurrencyLabelFormatter.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of CurrencyLabelFormatter for this value, or nil if not found



13319
13320
13321
13322
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13319

def CurrencyLabelFormatter.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  CurrencyLabelFormatter.ALL.find { |v| v.value == value }
end

.strip_trailing_zerosObject

If a price ends in '.00' or ',00', we remove the cents and just display the price as a whole number. e.g. 'A$100.00' becomes 'A$100'



13330
13331
13332
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13330

def CurrencyLabelFormatter.strip_trailing_zeros
  @@_strip_trailing_zeros ||= CurrencyLabelFormatter.new('strip_trailing_zeros')
end

Instance Method Details

#to_hashObject



13334
13335
13336
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13334

def to_hash
  value
end