Class: Io::Flow::V0::Models::CustomerAddressPreference

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Represents a customer address preference. Only a single address book contact can be associated per type. If contact is created or updated with a preference, existing preferences of the same type will be removed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ CustomerAddressPreference

Returns a new instance of CustomerAddressPreference.



35135
35136
35137
35138
35139
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 35135

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:type], 'CustomerAddressPreference')
  @type = (x = opts.delete(:type); x.is_a?(::Io::Flow::V0::Models::CustomerAddressType) ? x : ::Io::Flow::V0::Models::CustomerAddressType.apply(x))
end

Instance Attribute Details

#typeObject (readonly)

Returns the value of attribute type.



35133
35134
35135
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 35133

def type
  @type
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



35145
35146
35147
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 35145

def copy(incoming={})
  CustomerAddressPreference.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hashObject



35149
35150
35151
35152
35153
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 35149

def to_hash
  {
    :type => type.value
  }
end

#to_jsonObject



35141
35142
35143
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 35141

def to_json
  JSON.dump(to_hash)
end