Class: Io::Flow::V0::Models::CustomerAddressType

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ CustomerAddressType

Returns a new instance of CustomerAddressType.



13390
13391
13392
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13390

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



13388
13389
13390
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13388

def value
  @value
end

Class Method Details

.ALLObject



13410
13411
13412
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13410

def CustomerAddressType.ALL
  @@all ||= [CustomerAddressType.billing, CustomerAddressType.invoice, CustomerAddressType.shipping]
end

.apply(value) ⇒ Object

Returns the instance of CustomerAddressType for this value, creating a new instance for an unknown value



13395
13396
13397
13398
13399
13400
13401
13402
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13395

def CustomerAddressType.apply(value)
  if value.instance_of?(CustomerAddressType)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || CustomerAddressType.new(value))
  end
end

.billingObject



13414
13415
13416
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13414

def CustomerAddressType.billing
  @@_billing ||= CustomerAddressType.new('billing')
end

.from_string(value) ⇒ Object

Returns the instance of CustomerAddressType for this value, or nil if not found



13405
13406
13407
13408
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13405

def CustomerAddressType.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  CustomerAddressType.ALL.find { |v| v.value == value }
end

.invoiceObject



13418
13419
13420
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13418

def CustomerAddressType.invoice
  @@_invoice ||= CustomerAddressType.new('invoice')
end

.shippingObject



13422
13423
13424
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13422

def CustomerAddressType.shipping
  @@_shipping ||= CustomerAddressType.new('shipping')
end

Instance Method Details

#to_hashObject



13426
13427
13428
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13426

def to_hash
  value
end