Class: Io::Flow::V0::Models::DeliveryWindow

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Flow’s estimate of when a shipment for this delivery will actually arrive at the final destination, taking into account a shipment estimate, center schedules, and carrier transit windows.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ DeliveryWindow

Returns a new instance of DeliveryWindow.



22772
22773
22774
22775
22776
22777
22778
22779
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22772

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:from, :to], 'DeliveryWindow')
  @from = HttpClient::Preconditions.assert_class('from', HttpClient::Helper.to_date_time_iso8601(opts.delete(:from)), DateTime)
  @to = HttpClient::Preconditions.assert_class('to', HttpClient::Helper.to_date_time_iso8601(opts.delete(:to)), DateTime)
  @timezone = (x = opts.delete(:timezone); x.nil? ? nil : HttpClient::Preconditions.assert_class('timezone', x, String))
  @label = (x = opts.delete(:label); x.nil? ? nil : HttpClient::Preconditions.assert_class('label', x, String))
end

Instance Attribute Details

#fromObject (readonly)

Returns the value of attribute from.



22770
22771
22772
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22770

def from
  @from
end

#labelObject (readonly)

Returns the value of attribute label.



22770
22771
22772
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22770

def label
  @label
end

#timezoneObject (readonly)

Returns the value of attribute timezone.



22770
22771
22772
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22770

def timezone
  @timezone
end

#toObject (readonly)

Returns the value of attribute to.



22770
22771
22772
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22770

def to
  @to
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



22785
22786
22787
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22785

def copy(incoming={})
  DeliveryWindow.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hashObject



22789
22790
22791
22792
22793
22794
22795
22796
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22789

def to_hash
  {
    :from => from,
    :to => to,
    :timezone => timezone,
    :label => label
  }
end

#to_jsonObject



22781
22782
22783
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22781

def to_json
  JSON.dump(to_hash)
end