Class: Io::Flow::V0::Models::DeliveryWindowComponentSource
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::DeliveryWindowComponentSource
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of DeliveryWindowComponentSource for this value, creating a new instance for an unknown value.
- .carrier ⇒ Object
- .center ⇒ Object
- .flow ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of DeliveryWindowComponentSource for this value, or nil if not found.
-
.mixed ⇒ Object
A delivery estimate may be a combination of multiple sources.
- .organization ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ DeliveryWindowComponentSource
constructor
A new instance of DeliveryWindowComponentSource.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ DeliveryWindowComponentSource
Returns a new instance of DeliveryWindowComponentSource.
17389 17390 17391 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17389 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
17387 17388 17389 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17387 def value @value end |
Class Method Details
.ALL ⇒ Object
17409 17410 17411 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17409 def DeliveryWindowComponentSource.ALL @@all ||= [DeliveryWindowComponentSource.flow, DeliveryWindowComponentSource.organization, DeliveryWindowComponentSource.carrier, DeliveryWindowComponentSource.center, DeliveryWindowComponentSource.mixed] end |
.apply(value) ⇒ Object
Returns the instance of DeliveryWindowComponentSource for this value, creating a new instance for an unknown value
17394 17395 17396 17397 17398 17399 17400 17401 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17394 def DeliveryWindowComponentSource.apply(value) if value.instance_of?(DeliveryWindowComponentSource) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || DeliveryWindowComponentSource.new(value)) end end |
.carrier ⇒ Object
17421 17422 17423 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17421 def DeliveryWindowComponentSource.carrier @@_carrier ||= DeliveryWindowComponentSource.new('carrier') end |
.center ⇒ Object
17425 17426 17427 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17425 def DeliveryWindowComponentSource.center @@_center ||= DeliveryWindowComponentSource.new('center') end |
.flow ⇒ Object
17413 17414 17415 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17413 def DeliveryWindowComponentSource.flow @@_flow ||= DeliveryWindowComponentSource.new('flow') end |
.from_string(value) ⇒ Object
Returns the instance of DeliveryWindowComponentSource for this value, or nil if not found
17404 17405 17406 17407 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17404 def DeliveryWindowComponentSource.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) DeliveryWindowComponentSource.ALL.find { |v| v.value == value } end |
.mixed ⇒ Object
A delivery estimate may be a combination of multiple sources
17430 17431 17432 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17430 def DeliveryWindowComponentSource.mixed @@_mixed ||= DeliveryWindowComponentSource.new('mixed') end |
.organization ⇒ Object
17417 17418 17419 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17417 def DeliveryWindowComponentSource.organization @@_organization ||= DeliveryWindowComponentSource.new('organization') end |
Instance Method Details
#to_hash ⇒ Object
17434 17435 17436 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17434 def to_hash value end |