Class: Io::Flow::V0::Models::DeliveryWindowLocation

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ DeliveryWindowLocation

Returns a new instance of DeliveryWindowLocation.



13806
13807
13808
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13806

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



13804
13805
13806
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13804

def value
  @value
end

Class Method Details

.ALLObject



13826
13827
13828
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13826

def DeliveryWindowLocation.ALL
  @@all ||= [DeliveryWindowLocation.center, DeliveryWindowLocation.crossdock, DeliveryWindowLocation.customer]
end

.apply(value) ⇒ Object

Returns the instance of DeliveryWindowLocation for this value, creating a new instance for an unknown value



13811
13812
13813
13814
13815
13816
13817
13818
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13811

def DeliveryWindowLocation.apply(value)
  if value.instance_of?(DeliveryWindowLocation)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || DeliveryWindowLocation.new(value))
  end
end

.centerObject



13830
13831
13832
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13830

def DeliveryWindowLocation.center
  @@_center ||= DeliveryWindowLocation.new('center')
end

.crossdockObject



13834
13835
13836
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13834

def DeliveryWindowLocation.crossdock
  @@_crossdock ||= DeliveryWindowLocation.new('crossdock')
end

.customerObject



13838
13839
13840
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13838

def DeliveryWindowLocation.customer
  @@_customer ||= DeliveryWindowLocation.new('customer')
end

.from_string(value) ⇒ Object

Returns the instance of DeliveryWindowLocation for this value, or nil if not found



13821
13822
13823
13824
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13821

def DeliveryWindowLocation.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  DeliveryWindowLocation.ALL.find { |v| v.value == value }
end

Instance Method Details

#to_hashObject



13842
13843
13844
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13842

def to_hash
  value
end