Class: Io::Flow::V0::Models::DeminimisSimple
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
De Minimis for most common example which includes a value threshold and rules on what components are used in the duty calculation
Instance Attribute Summary collapse
-
#components ⇒ Object
readonly
Returns the value of attribute components.
-
#currency ⇒ Object
readonly
Returns the value of attribute currency.
-
#minimum ⇒ Object
readonly
Returns the value of attribute minimum.
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Attributes inherited from Deminimis
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ DeminimisSimple
constructor
A new instance of DeminimisSimple.
- #subtype_to_hash ⇒ Object
- #to_json ⇒ Object
Methods inherited from Deminimis
Constructor Details
#initialize(incoming = {}) ⇒ DeminimisSimple
Returns a new instance of DeminimisSimple.
11822 11823 11824 11825 11826 11827 11828 11829 11830 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11822 def initialize(incoming={}) super(:discriminator => Deminimis::Types::DEMINIMIS_SIMPLE) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:currency, :components], 'DeminimisSimple') @value = (x = opts.delete(:value); x.nil? ? nil : HttpClient::Preconditions.assert_class('value', HttpClient::Helper.to_big_decimal(x), BigDecimal)) @currency = HttpClient::Preconditions.assert_class('currency', opts.delete(:currency), String) @components = HttpClient::Preconditions.assert_class('components', opts.delete(:components), Array).map { |v| (x = v; x.is_a?(::Io::Flow::V0::Models::LevyComponent) ? x : ::Io::Flow::V0::Models::LevyComponent.apply(x)) } @minimum = (x = opts.delete(:minimum); x.nil? ? nil : HttpClient::Preconditions.assert_class('minimum', HttpClient::Helper.to_big_decimal(x), BigDecimal)) end |
Instance Attribute Details
#components ⇒ Object (readonly)
Returns the value of attribute components.
11820 11821 11822 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11820 def components @components end |
#currency ⇒ Object (readonly)
Returns the value of attribute currency.
11820 11821 11822 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11820 def currency @currency end |
#minimum ⇒ Object (readonly)
Returns the value of attribute minimum.
11820 11821 11822 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11820 def minimum @minimum end |
#value ⇒ Object (readonly)
Returns the value of attribute value.
11820 11821 11822 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11820 def value @value end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
11836 11837 11838 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11836 def copy(incoming={}) DeminimisSimple.new(subtype_to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#subtype_to_hash ⇒ Object
11840 11841 11842 11843 11844 11845 11846 11847 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11840 def subtype_to_hash { :value => value, :currency => currency, :components => components.map { |o| o.value }, :minimum => minimum } end |
#to_json ⇒ Object
11832 11833 11834 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11832 def to_json JSON.dump(to_hash) end |