Class: Io::Flow::V0::Models::DiscountRuleStatus
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::DiscountRuleStatus
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .active ⇒ Object
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of DiscountRuleStatus for this value, creating a new instance for an unknown value.
- .expired ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of DiscountRuleStatus for this value, or nil if not found.
- .scheduled ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ DiscountRuleStatus
constructor
A new instance of DiscountRuleStatus.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ DiscountRuleStatus
Returns a new instance of DiscountRuleStatus.
17534 17535 17536 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17534 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
17532 17533 17534 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17532 def value @value end |
Class Method Details
.active ⇒ Object
17558 17559 17560 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17558 def DiscountRuleStatus.active @@_active ||= DiscountRuleStatus.new('active') end |
.ALL ⇒ Object
17554 17555 17556 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17554 def DiscountRuleStatus.ALL @@all ||= [DiscountRuleStatus.active, DiscountRuleStatus.scheduled, DiscountRuleStatus.expired] end |
.apply(value) ⇒ Object
Returns the instance of DiscountRuleStatus for this value, creating a new instance for an unknown value
17539 17540 17541 17542 17543 17544 17545 17546 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17539 def DiscountRuleStatus.apply(value) if value.instance_of?(DiscountRuleStatus) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || DiscountRuleStatus.new(value)) end end |
.expired ⇒ Object
17566 17567 17568 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17566 def DiscountRuleStatus.expired @@_expired ||= DiscountRuleStatus.new('expired') end |
.from_string(value) ⇒ Object
Returns the instance of DiscountRuleStatus for this value, or nil if not found
17549 17550 17551 17552 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17549 def DiscountRuleStatus.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) DiscountRuleStatus.ALL.find { |v| v.value == value } end |
.scheduled ⇒ Object
17562 17563 17564 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17562 def DiscountRuleStatus.scheduled @@_scheduled ||= DiscountRuleStatus.new('scheduled') end |
Instance Method Details
#to_hash ⇒ Object
17570 17571 17572 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17570 def to_hash value end |