Class: Io::Flow::V0::Models::EmailVerification

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Represents the successful response of an email verification token. We return the email address in this case to allow the UI to display which email address was verified.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ EmailVerification

Returns a new instance of EmailVerification.



28719
28720
28721
28722
28723
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 28719

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:email], 'EmailVerification')
  @email = HttpClient::Preconditions.assert_class('email', opts.delete(:email), String)
end

Instance Attribute Details

#emailObject (readonly)

Returns the value of attribute email.



28717
28718
28719
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 28717

def email
  @email
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



28729
28730
28731
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 28729

def copy(incoming={})
  EmailVerification.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hashObject



28733
28734
28735
28736
28737
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 28733

def to_hash
  {
    :email => email
  }
end

#to_jsonObject



28725
28726
28727
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 28725

def to_json
  JSON.dump(to_hash)
end