Class: Io::Flow::V0::Models::Environment

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ Environment

Returns a new instance of Environment.



14052
14053
14054
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14052

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



14050
14051
14052
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14050

def value
  @value
end

Class Method Details

.ALLObject



14072
14073
14074
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14072

def Environment.ALL
  @@all ||= [Environment.sandbox, Environment.production]
end

.apply(value) ⇒ Object

Returns the instance of Environment for this value, creating a new instance for an unknown value



14057
14058
14059
14060
14061
14062
14063
14064
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14057

def Environment.apply(value)
  if value.instance_of?(Environment)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || Environment.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of Environment for this value, or nil if not found



14067
14068
14069
14070
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14067

def Environment.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  Environment.ALL.find { |v| v.value == value }
end

.productionObject

In production, all external services are live and will generate real transactions



14084
14085
14086
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14084

def Environment.production
  @@_production ||= Environment.new('production')
end

.sandboxObject

In sandbox, no external services (e.g. orders, payments, logistics) will generate real transactions



14078
14079
14080
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14078

def Environment.sandbox
  @@_sandbox ||= Environment.new('sandbox')
end

Instance Method Details

#to_hashObject



14088
14089
14090
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14088

def to_hash
  value
end