Class: Io::Flow::V0::Models::ExceptionType

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ ExceptionType

Returns a new instance of ExceptionType.



14784
14785
14786
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14784

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



14782
14783
14784
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14782

def value
  @value
end

Class Method Details

.ALLObject



14804
14805
14806
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14804

def ExceptionType.ALL
  @@all ||= [ExceptionType.open, ExceptionType.closed]
end

.apply(value) ⇒ Object

Returns the instance of ExceptionType for this value, creating a new instance for an unknown value



14789
14790
14791
14792
14793
14794
14795
14796
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14789

def ExceptionType.apply(value)
  if value.instance_of?(ExceptionType)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || ExceptionType.new(value))
  end
end

.closedObject



14812
14813
14814
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14812

def ExceptionType.closed
  @@_closed ||= ExceptionType.new('closed')
end

.from_string(value) ⇒ Object

Returns the instance of ExceptionType for this value, or nil if not found



14799
14800
14801
14802
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14799

def ExceptionType.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  ExceptionType.ALL.find { |v| v.value == value }
end

.openObject



14808
14809
14810
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14808

def ExceptionType.open
  @@_open ||= ExceptionType.new('open')
end

Instance Method Details

#to_hashObject



14816
14817
14818
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14816

def to_hash
  value
end