Class: Io::Flow::V0::Models::ExperienceCloneStatus
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::ExperienceCloneStatus
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of ExperienceCloneStatus for this value, creating a new instance for an unknown value.
- .completed ⇒ Object
- .failed ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of ExperienceCloneStatus for this value, or nil if not found.
- .pending ⇒ Object
- .updating ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ ExperienceCloneStatus
constructor
A new instance of ExperienceCloneStatus.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ ExperienceCloneStatus
Returns a new instance of ExperienceCloneStatus.
14872 14873 14874 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14872 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
14870 14871 14872 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14870 def value @value end |
Class Method Details
.ALL ⇒ Object
14892 14893 14894 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14892 def ExperienceCloneStatus.ALL @@all ||= [ExperienceCloneStatus.pending, ExperienceCloneStatus.updating, ExperienceCloneStatus.completed, ExperienceCloneStatus.failed] end |
.apply(value) ⇒ Object
Returns the instance of ExperienceCloneStatus for this value, creating a new instance for an unknown value
14877 14878 14879 14880 14881 14882 14883 14884 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14877 def ExperienceCloneStatus.apply(value) if value.instance_of?(ExperienceCloneStatus) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || ExperienceCloneStatus.new(value)) end end |
.completed ⇒ Object
14904 14905 14906 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14904 def ExperienceCloneStatus.completed @@_completed ||= ExperienceCloneStatus.new('completed') end |
.failed ⇒ Object
14908 14909 14910 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14908 def ExperienceCloneStatus.failed @@_failed ||= ExperienceCloneStatus.new('failed') end |
.from_string(value) ⇒ Object
Returns the instance of ExperienceCloneStatus for this value, or nil if not found
14887 14888 14889 14890 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14887 def ExperienceCloneStatus.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) ExperienceCloneStatus.ALL.find { |v| v.value == value } end |
.pending ⇒ Object
14896 14897 14898 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14896 def ExperienceCloneStatus.pending @@_pending ||= ExperienceCloneStatus.new('pending') end |
.updating ⇒ Object
14900 14901 14902 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14900 def ExperienceCloneStatus.updating @@_updating ||= ExperienceCloneStatus.new('updating') end |
Instance Method Details
#to_hash ⇒ Object
14912 14913 14914 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14912 def to_hash value end |