Class: Io::Flow::V0::Models::ExperiencePaymentMethodTag

Inherits:
PaymentMethodTag show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Attributes inherited from PaymentMethodTag

#discriminator

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from PaymentMethodTag

from_json, #to_hash

Constructor Details

#initialize(value) ⇒ ExperiencePaymentMethodTag

Returns a new instance of ExperiencePaymentMethodTag.



14922
14923
14924
14925
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14922

def initialize(value)
  super(:name => PaymentMethodTag::Types::EXPERIENCE_PAYMENT_METHOD_TAG, :discriminator => 'experience_payment_method_tag')
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



14920
14921
14922
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14920

def value
  @value
end

Class Method Details

.ALLObject



14943
14944
14945
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14943

def ExperiencePaymentMethodTag.ALL
  @@all ||= [ExperiencePaymentMethodTag.display]
end

.apply(value) ⇒ Object

Returns the instance of ExperiencePaymentMethodTag for this value, creating a new instance for an unknown value



14928
14929
14930
14931
14932
14933
14934
14935
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14928

def ExperiencePaymentMethodTag.apply(value)
  if value.instance_of?(ExperiencePaymentMethodTag)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || ExperiencePaymentMethodTag.new(value))
  end
end

.displayObject

A displayed payment method will be highlighted during the checkout process for an experience.



14949
14950
14951
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14949

def ExperiencePaymentMethodTag.display
  @@_display ||= ExperiencePaymentMethodTag.new('display')
end

.from_string(value) ⇒ Object

Returns the instance of ExperiencePaymentMethodTag for this value, or nil if not found



14938
14939
14940
14941
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14938

def ExperiencePaymentMethodTag.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  ExperiencePaymentMethodTag.ALL.find { |v| v.value == value }
end

Instance Method Details

#subtype_to_hashObject



14953
14954
14955
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14953

def subtype_to_hash
  value
end