Class: Io::Flow::V0::Models::ExportDelivery

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Export deliveries represent actions to take once a requested export has completed. A common pattern would be to request delivery of the export via email - you will then receive an email notification once the requested export is ready

Defined Under Namespace

Modules: Types

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ ExportDelivery

Returns a new instance of ExportDelivery.



4872
4873
4874
4875
4876
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 4872

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:discriminator], 'ExportDelivery')
  @discriminator = HttpClient::Preconditions.assert_class('discriminator', opts.delete(:discriminator), String)
end

Instance Attribute Details

#discriminator ⇒ Object (readonly)

Returns the value of attribute discriminator.



4870
4871
4872
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 4870

def discriminator
  @discriminator
end

Instance Method Details

#subtype_to_hash ⇒ Object



4878
4879
4880
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 4878

def subtype_to_hash
  raise 'Cannot serialize an instance of export_delivery directly - must use one of the specific types: export_delivery_email'
end

#to_hash ⇒ Object



4882
4883
4884
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 4882

def to_hash
  subtype_to_hash.merge(:discriminator => @discriminator)
end