Class: Io::Flow::V0::Models::ExportStatus
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::ExportStatus
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of ExportStatus for this value, creating a new instance for an unknown value.
- .completed ⇒ Object
- .created ⇒ Object
- .failed ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of ExportStatus for this value, or nil if not found.
- .processing ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ ExportStatus
constructor
A new instance of ExportStatus.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ ExportStatus
Returns a new instance of ExportStatus.
15015 15016 15017 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15015 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
15013 15014 15015 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15013 def value @value end |
Class Method Details
.ALL ⇒ Object
15035 15036 15037 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15035 def ExportStatus.ALL @@all ||= [ExportStatus.created, ExportStatus.processing, ExportStatus.completed, ExportStatus.failed] end |
.apply(value) ⇒ Object
Returns the instance of ExportStatus for this value, creating a new instance for an unknown value
15020 15021 15022 15023 15024 15025 15026 15027 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15020 def ExportStatus.apply(value) if value.instance_of?(ExportStatus) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || ExportStatus.new(value)) end end |
.completed ⇒ Object
15047 15048 15049 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15047 def ExportStatus.completed @@_completed ||= ExportStatus.new('completed') end |
.created ⇒ Object
15039 15040 15041 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15039 def ExportStatus.created @@_created ||= ExportStatus.new('created') end |
.failed ⇒ Object
15051 15052 15053 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15051 def ExportStatus.failed @@_failed ||= ExportStatus.new('failed') end |
.from_string(value) ⇒ Object
Returns the instance of ExportStatus for this value, or nil if not found
15030 15031 15032 15033 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15030 def ExportStatus.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) ExportStatus.ALL.find { |v| v.value == value } end |
.processing ⇒ Object
15043 15044 15045 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15043 def ExportStatus.processing @@_processing ||= ExportStatus.new('processing') end |
Instance Method Details
#to_hash ⇒ Object
15055 15056 15057 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15055 def to_hash value end |