Class: Io::Flow::V0::Models::FlowBehavior

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ FlowBehavior

Returns a new instance of FlowBehavior.



19062
19063
19064
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19062

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



19060
19061
19062
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19060

def value
  @value
end

Class Method Details

.ALLObject



19082
19083
19084
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19082

def FlowBehavior.ALL
  @@all ||= [FlowBehavior.view_consumer_data]
end

.apply(value) ⇒ Object

Returns the instance of FlowBehavior for this value, creating a new instance for an unknown value



19067
19068
19069
19070
19071
19072
19073
19074
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19067

def FlowBehavior.apply(value)
  if value.instance_of?(FlowBehavior)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || FlowBehavior.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of FlowBehavior for this value, or nil if not found



19077
19078
19079
19080
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19077

def FlowBehavior.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  FlowBehavior.ALL.find { |v| v.value == value }
end

.view_consumer_dataObject

Allows user to view consumers’ personal data.



19087
19088
19089
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19087

def FlowBehavior.view_consumer_data
  @@_view_consumer_data ||= FlowBehavior.new('view_consumer_data')
end

Instance Method Details

#to_hashObject



19091
19092
19093
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19091

def to_hash
  value
end