Class: Io::Flow::V0::Models::FlowUserRole
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Attributes inherited from FlowRole
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of FlowUserRole for this value, creating a new instance for an unknown value.
-
.flow_operations ⇒ Object
Can access Flow internal functions.
-
.from_string(value) ⇒ Object
Returns the instance of FlowUserRole for this value, or nil if not found.
-
.organization_admin ⇒ Object
Can fully administrate a merchant organization.
-
.organization_finance ⇒ Object
Can access billing and reconcilliation functions and retreive relevant data.
-
.organization_fulfillment ⇒ Object
Can access fulfillment functions and retreive relevant data.
-
.organization_marketing ⇒ Object
Can access marketing functions and retreive relevant data.
-
.organization_merchant ⇒ Object
Can access merchant functions such as analytics, billing, experiences.
-
.organization_operations ⇒ Object
Can access customer service functions and retreive relevant data.
Instance Method Summary collapse
-
#initialize(value) ⇒ FlowUserRole
constructor
A new instance of FlowUserRole.
- #subtype_to_hash ⇒ Object
Methods inherited from FlowRole
Constructor Details
#initialize(value) ⇒ FlowUserRole
Returns a new instance of FlowUserRole.
15149 15150 15151 15152 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15149 def initialize(value) super(:name => FlowRole::Types::FLOW_USER_ROLE, :__discriminator__ => 'flow_user_role') @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
15147 15148 15149 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15147 def value @value end |
Class Method Details
.ALL ⇒ Object
15170 15171 15172 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15170 def FlowUserRole.ALL @@all ||= [FlowUserRole.organization_admin, FlowUserRole.organization_merchant, FlowUserRole.organization_operations, FlowUserRole.organization_fulfillment, FlowUserRole.organization_marketing, FlowUserRole.organization_finance, FlowUserRole.flow_operations] end |
.apply(value) ⇒ Object
Returns the instance of FlowUserRole for this value, creating a new instance for an unknown value
15155 15156 15157 15158 15159 15160 15161 15162 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15155 def FlowUserRole.apply(value) if value.instance_of?(FlowUserRole) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || FlowUserRole.new(value)) end end |
.flow_operations ⇒ Object
Can access Flow internal functions.
15205 15206 15207 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15205 def FlowUserRole.flow_operations @@_flow_operations ||= FlowUserRole.new('flow_operations') end |
.from_string(value) ⇒ Object
Returns the instance of FlowUserRole for this value, or nil if not found
15165 15166 15167 15168 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15165 def FlowUserRole.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) FlowUserRole.ALL.find { |v| v.value == value } end |
.organization_admin ⇒ Object
Can fully administrate a merchant organization.
15175 15176 15177 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15175 def FlowUserRole.organization_admin @@_organization_admin ||= FlowUserRole.new('organization_admin') end |
.organization_finance ⇒ Object
Can access billing and reconcilliation functions and retreive relevant data.
15200 15201 15202 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15200 def FlowUserRole.organization_finance @@_organization_finance ||= FlowUserRole.new('organization_finance') end |
.organization_fulfillment ⇒ Object
Can access fulfillment functions and retreive relevant data.
15190 15191 15192 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15190 def FlowUserRole.organization_fulfillment @@_organization_fulfillment ||= FlowUserRole.new('organization_fulfillment') end |
.organization_marketing ⇒ Object
Can access marketing functions and retreive relevant data.
15195 15196 15197 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15195 def FlowUserRole.organization_marketing @@_organization_marketing ||= FlowUserRole.new('organization_marketing') end |
.organization_merchant ⇒ Object
Can access merchant functions such as analytics, billing, experiences.
15180 15181 15182 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15180 def FlowUserRole.organization_merchant @@_organization_merchant ||= FlowUserRole.new('organization_merchant') end |
.organization_operations ⇒ Object
Can access customer service functions and retreive relevant data.
15185 15186 15187 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15185 def FlowUserRole.organization_operations @@_organization_operations ||= FlowUserRole.new('organization_operations') end |
Instance Method Details
#subtype_to_hash ⇒ Object
15209 15210 15211 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15209 def subtype_to_hash value end |