Class: Io::Flow::V0::Models::FraudLiability

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ FraudLiability

Returns a new instance of FraudLiability.



15263
15264
15265
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15263

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



15261
15262
15263
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15261

def value
  @value
end

Class Method Details

.ALLObject



15283
15284
15285
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15283

def FraudLiability.ALL
  @@all ||= [FraudLiability.flow, FraudLiability.organization]
end

.apply(value) ⇒ Object

Returns the instance of FraudLiability for this value, creating a new instance for an unknown value



15268
15269
15270
15271
15272
15273
15274
15275
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15268

def FraudLiability.apply(value)
  if value.instance_of?(FraudLiability)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || FraudLiability.new(value))
  end
end

.flowObject

Flow takes any fraud liability for the order.



15288
15289
15290
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15288

def FraudLiability.flow
  @@_flow ||= FraudLiability.new('flow')
end

.from_string(value) ⇒ Object

Returns the instance of FraudLiability for this value, or nil if not found



15278
15279
15280
15281
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15278

def FraudLiability.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  FraudLiability.ALL.find { |v| v.value == value }
end

.organizationObject

The merchant takes any fraud liability for the order.



15293
15294
15295
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15293

def FraudLiability.organization
  @@_organization ||= FraudLiability.new('organization')
end

Instance Method Details

#to_hashObject



15297
15298
15299
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15297

def to_hash
  value
end