Class: Io::Flow::V0::Models::FtpFileSource
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::FtpFileSource
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of FtpFileSource for this value, creating a new instance for an unknown value.
-
.flow ⇒ Object
Indicates flow created this file.
-
.from_string(value) ⇒ Object
Returns the instance of FtpFileSource for this value, or nil if not found.
-
.organization ⇒ Object
Indicates the organization created this file.
Instance Method Summary collapse
-
#initialize(value) ⇒ FtpFileSource
constructor
A new instance of FtpFileSource.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ FtpFileSource
Returns a new instance of FtpFileSource.
19372 19373 19374 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19372 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
19370 19371 19372 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19370 def value @value end |
Class Method Details
.ALL ⇒ Object
19392 19393 19394 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19392 def FtpFileSource.ALL @@all ||= [FtpFileSource.flow, FtpFileSource.organization] end |
.apply(value) ⇒ Object
Returns the instance of FtpFileSource for this value, creating a new instance for an unknown value
19377 19378 19379 19380 19381 19382 19383 19384 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19377 def FtpFileSource.apply(value) if value.instance_of?(FtpFileSource) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || FtpFileSource.new(value)) end end |
.flow ⇒ Object
Indicates flow created this file
19397 19398 19399 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19397 def FtpFileSource.flow @@_flow ||= FtpFileSource.new('flow') end |
.from_string(value) ⇒ Object
Returns the instance of FtpFileSource for this value, or nil if not found
19387 19388 19389 19390 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19387 def FtpFileSource.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) FtpFileSource.ALL.find { |v| v.value == value } end |
.organization ⇒ Object
Indicates the organization created this file
19402 19403 19404 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19402 def FtpFileSource.organization @@_organization ||= FtpFileSource.new('organization') end |
Instance Method Details
#to_hash ⇒ Object
19406 19407 19408 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19406 def to_hash value end |