Class: Io::Flow::V0::Models::FulfillmentCompleteCancellationForm

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Changing an order for the purpose of completely cancelling all remaining uncancelled, unshipped lines of an order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ FulfillmentCompleteCancellationForm

Returns a new instance of FulfillmentCompleteCancellationForm.



31159
31160
31161
31162
31163
31164
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 31159

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:reason], 'FulfillmentCompleteCancellationForm')
  @change_source = (x = (x = opts.delete(:change_source); x.nil? ? "fulfillment" : x); x.is_a?(::Io::Flow::V0::Models::OrderChangeSource) ? x : ::Io::Flow::V0::Models::OrderChangeSource.apply(x))
  @reason = (x = opts.delete(:reason); x.is_a?(::Io::Flow::V0::Models::CancelReason) ? x : ::Io::Flow::V0::Models::CancelReason.apply(x))
end

Instance Attribute Details

#change_sourceObject (readonly)

Returns the value of attribute change_source.



31157
31158
31159
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 31157

def change_source
  @change_source
end

#reasonObject (readonly)

Returns the value of attribute reason.



31157
31158
31159
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 31157

def reason
  @reason
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



31170
31171
31172
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 31170

def copy(incoming={})
  FulfillmentCompleteCancellationForm.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hashObject



31174
31175
31176
31177
31178
31179
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 31174

def to_hash
  {
    :change_source => change_source.value,
    :reason => reason.value
  }
end

#to_jsonObject



31166
31167
31168
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 31166

def to_json
  JSON.dump(to_hash)
end