Class: Io::Flow::V0::Models::FulfillmentMethodType

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ FulfillmentMethodType

Returns a new instance of FulfillmentMethodType.



15455
15456
15457
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15455

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



15453
15454
15455
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15453

def value
  @value
end

Class Method Details

.ALLObject



15475
15476
15477
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15475

def FulfillmentMethodType.ALL
  @@all ||= [FulfillmentMethodType.fulfillment_method]
end

.apply(value) ⇒ Object

Returns the instance of FulfillmentMethodType for this value, creating a new instance for an unknown value



15460
15461
15462
15463
15464
15465
15466
15467
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15460

def FulfillmentMethodType.apply(value)
  if value.instance_of?(FulfillmentMethodType)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || FulfillmentMethodType.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of FulfillmentMethodType for this value, or nil if not found



15470
15471
15472
15473
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15470

def FulfillmentMethodType.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  FulfillmentMethodType.ALL.find { |v| v.value == value }
end

.fulfillment_methodObject

Indicates how an item will be shipped or fulfilled. Acceptable values are defined by the 'fulfillment_method_value' enum.



15481
15482
15483
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15481

def FulfillmentMethodType.fulfillment_method
  @@_fulfillment_method ||= FulfillmentMethodType.new('fulfillment_method')
end

Instance Method Details

#to_hashObject



15485
15486
15487
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15485

def to_hash
  value
end