Class: Io::Flow::V0::Models::FulfillmentMethodValue

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ FulfillmentMethodValue

Returns a new instance of FulfillmentMethodValue.



15495
15496
15497
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15495

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



15493
15494
15495
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15493

def value
  @value
end

Class Method Details

.ALLObject



15515
15516
15517
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15515

def FulfillmentMethodValue.ALL
  @@all ||= [FulfillmentMethodValue.digital, FulfillmentMethodValue.physical]
end

.apply(value) ⇒ Object

Returns the instance of FulfillmentMethodValue for this value, creating a new instance for an unknown value



15500
15501
15502
15503
15504
15505
15506
15507
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15500

def FulfillmentMethodValue.apply(value)
  if value.instance_of?(FulfillmentMethodValue)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || FulfillmentMethodValue.new(value))
  end
end

.digitalObject

Indicates item will be fulfilled digitally and no shipment is required (e.g. Gift Card).



15521
15522
15523
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15521

def FulfillmentMethodValue.digital
  @@_digital ||= FulfillmentMethodValue.new('digital')
end

.from_string(value) ⇒ Object

Returns the instance of FulfillmentMethodValue for this value, or nil if not found



15510
15511
15512
15513
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15510

def FulfillmentMethodValue.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  FulfillmentMethodValue.ALL.find { |v| v.value == value }
end

.physicalObject

Indicates item will be shipped in a physical package.



15526
15527
15528
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15526

def FulfillmentMethodValue.physical
  @@_physical ||= FulfillmentMethodValue.new('physical')
end

Instance Method Details

#to_hashObject



15530
15531
15532
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15530

def to_hash
  value
end