Class: Io::Flow::V0::Models::GoodsSupply
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::GoodsSupply
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of GoodsSupply for this value, creating a new instance for an unknown value.
-
.export ⇒ Object
Goods will be supplied from a DC from outside the national and customs boundaries of the destination.
-
.from_string(value) ⇒ Object
Returns the instance of GoodsSupply for this value, or nil if not found.
-
.intra_community ⇒ Object
Goods will be supplied from a DC outside the national boundries of the destination, but within the same customs union.
-
.local ⇒ Object
Goods will be supplied from a DC within the same country as the destination.
Instance Method Summary collapse
-
#initialize(value) ⇒ GoodsSupply
constructor
A new instance of GoodsSupply.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ GoodsSupply
Returns a new instance of GoodsSupply.
15591 15592 15593 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15591 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
15589 15590 15591 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15589 def value @value end |
Class Method Details
.ALL ⇒ Object
15611 15612 15613 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15611 def GoodsSupply.ALL @@all ||= [GoodsSupply.export, GoodsSupply.intra_community, GoodsSupply.local] end |
.apply(value) ⇒ Object
Returns the instance of GoodsSupply for this value, creating a new instance for an unknown value
15596 15597 15598 15599 15600 15601 15602 15603 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15596 def GoodsSupply.apply(value) if value.instance_of?(GoodsSupply) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || GoodsSupply.new(value)) end end |
.export ⇒ Object
Goods will be supplied from a DC from outside the national and customs boundaries of the destination.
15617 15618 15619 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15617 def GoodsSupply.export @@_export ||= GoodsSupply.new('export') end |
.from_string(value) ⇒ Object
Returns the instance of GoodsSupply for this value, or nil if not found
15606 15607 15608 15609 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15606 def GoodsSupply.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) GoodsSupply.ALL.find { |v| v.value == value } end |
.intra_community ⇒ Object
Goods will be supplied from a DC outside the national boundries of the destination, but within the same customs union.
15623 15624 15625 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15623 def GoodsSupply.intra_community @@_intra_community ||= GoodsSupply.new('intra_community') end |
.local ⇒ Object
Goods will be supplied from a DC within the same country as the destination.
15628 15629 15630 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15628 def GoodsSupply.local @@_local ||= GoodsSupply.new('local') end |
Instance Method Details
#to_hash ⇒ Object
15632 15633 15634 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15632 def to_hash value end |