Class: Io::Flow::V0::Models::HarmonizedItem
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::HarmonizedItem
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
A harmonized item stores explicit information about this item for the purposes of harmonization / classification. The harmonization process begins by creating a harmonized item; this kicks off the internal processes. Once assigned, codes will be available via the hs6 and hs10 resources
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#categories ⇒ Object
readonly
Returns the value of attribute categories.
-
#description ⇒ Object
readonly
Returns the value of attribute description.
-
#id ⇒ Object
readonly
Returns the value of attribute id.
-
#name ⇒ Object
readonly
Returns the value of attribute name.
-
#number ⇒ Object
readonly
Returns the value of attribute number.
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ HarmonizedItem
constructor
A new instance of HarmonizedItem.
- #to_hash ⇒ Object
- #to_json ⇒ Object
Constructor Details
#initialize(incoming = {}) ⇒ HarmonizedItem
Returns a new instance of HarmonizedItem.
13022 13023 13024 13025 13026 13027 13028 13029 13030 13031 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13022 def initialize(incoming={}) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:id, :number, :name], 'HarmonizedItem') @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String) @number = HttpClient::Preconditions.assert_class('number', opts.delete(:number), String) @name = HttpClient::Preconditions.assert_class('name', opts.delete(:name), String) @categories = HttpClient::Preconditions.assert_class('categories', (x = opts.delete(:categories); x.nil? ? [] : x), Array).map { |v| HttpClient::Preconditions.assert_class('categories', v, String) } @attributes = HttpClient::Preconditions.assert_class('attributes', (x = opts.delete(:attributes); x.nil? ? {} : x), Hash).inject({}) { |h, d| h[d[0]] = HttpClient::Preconditions.assert_class('attributes', d[1], String); h } @description = (x = opts.delete(:description); x.nil? ? nil : HttpClient::Preconditions.assert_class('description', x, String)) end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
13020 13021 13022 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13020 def attributes @attributes end |
#categories ⇒ Object (readonly)
Returns the value of attribute categories.
13020 13021 13022 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13020 def categories @categories end |
#description ⇒ Object (readonly)
Returns the value of attribute description.
13020 13021 13022 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13020 def description @description end |
#id ⇒ Object (readonly)
Returns the value of attribute id.
13020 13021 13022 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13020 def id @id end |
#name ⇒ Object (readonly)
Returns the value of attribute name.
13020 13021 13022 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13020 def name @name end |
#number ⇒ Object (readonly)
Returns the value of attribute number.
13020 13021 13022 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13020 def number @number end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
13037 13038 13039 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13037 def copy(incoming={}) HarmonizedItem.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#to_hash ⇒ Object
13041 13042 13043 13044 13045 13046 13047 13048 13049 13050 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13041 def to_hash { :id => id, :number => number, :name => name, :categories => categories, :attributes => attributes, :description => description } end |
#to_json ⇒ Object
13033 13034 13035 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13033 def to_json JSON.dump(to_hash) end |