Class: Io::Flow::V0::Models::HarmonizedLandedCostForm

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Allows calculation of duty and tax for multiple items in one API call for items going to a specific destination country

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ HarmonizedLandedCostForm

Returns a new instance of HarmonizedLandedCostForm.



13390
13391
13392
13393
13394
13395
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13390

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:address, :item_numbers], 'HarmonizedLandedCostForm')
  @address = (x = opts.delete(:address); x.is_a?(::Io::Flow::V0::Models::Address) ? x : ::Io::Flow::V0::Models::Address.new(x))
  @item_numbers = HttpClient::Preconditions.assert_class('item_numbers', opts.delete(:item_numbers), Array).map { |v| HttpClient::Preconditions.assert_class('item_numbers', v, String) }
end

Instance Attribute Details

#address ⇒ Object (readonly)

Returns the value of attribute address.



13388
13389
13390
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13388

def address
  @address
end

#item_numbers ⇒ Object (readonly)

Returns the value of attribute item_numbers.



13388
13389
13390
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13388

def item_numbers
  @item_numbers
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



13401
13402
13403
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13401

def copy(incoming={})
  HarmonizedLandedCostForm.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hash ⇒ Object



13405
13406
13407
13408
13409
13410
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13405

def to_hash
  {
    :address => address.to_hash,
    :item_numbers => item_numbers
  }
end

#to_json ⇒ Object



13397
13398
13399
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13397

def to_json
  JSON.dump(to_hash)
end