Class: Io::Flow::V0::Models::ImageTag

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ ImageTag

Returns a new instance of ImageTag.



15684
15685
15686
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15684

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



15682
15683
15684
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15682

def value
  @value
end

Class Method Details

.ALLObject



15704
15705
15706
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15704

def ImageTag.ALL
  @@all ||= [ImageTag.thumbnail, ImageTag.checkout]
end

.apply(value) ⇒ Object

Returns the instance of ImageTag for this value, creating a new instance for an unknown value



15689
15690
15691
15692
15693
15694
15695
15696
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15689

def ImageTag.apply(value)
  if value.instance_of?(ImageTag)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || ImageTag.new(value))
  end
end

.checkoutObject

Checkout images identify the item image to use when displaying the item in the context of a consumer checkout (e.g. cart, checkout page).



15716
15717
15718
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15716

def ImageTag.checkout
  @@_checkout ||= ImageTag.new('checkout')
end

.from_string(value) ⇒ Object

Returns the instance of ImageTag for this value, or nil if not found



15699
15700
15701
15702
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15699

def ImageTag.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  ImageTag.ALL.find { |v| v.value == value }
end

.thumbnailObject

Thumbnail images identify the image to use when displaying products in the Flow Console.



15710
15711
15712
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15710

def ImageTag.thumbnail
  @@_thumbnail ||= ImageTag.new('thumbnail')
end

Instance Method Details

#to_hashObject



15720
15721
15722
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15720

def to_hash
  value
end