Class: Io::Flow::V0::Models::Import

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Imports allow you to upload data to Flow via files in batch. Each import fetches data from a given URL. The type of the import determines which file format to expect and what data to update

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ Import

Returns a new instance of Import.



13876
13877
13878
13879
13880
13881
13882
13883
13884
13885
13886
13887
13888
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13876

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:id, :type, :source_url, :status, :created_at, :deliveries], 'Import')
  @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String)
  @type = (x = opts.delete(:type); x.is_a?(::Io::Flow::V0::Models::ImportType) ? x : ::Io::Flow::V0::Models::ImportType.apply(x))
  @source_url = HttpClient::Preconditions.assert_class('source_url', opts.delete(:source_url), String)
  @status = (x = opts.delete(:status); x.is_a?(::Io::Flow::V0::Models::ExportStatus) ? x : ::Io::Flow::V0::Models::ExportStatus.apply(x))
  @created_at = HttpClient::Preconditions.assert_class('created_at', HttpClient::Helper.to_date_time_iso8601(opts.delete(:created_at)), DateTime)
  @started_at = (x = opts.delete(:started_at); x.nil? ? nil : HttpClient::Preconditions.assert_class('started_at', HttpClient::Helper.to_date_time_iso8601(x), DateTime))
  @completed_at = (x = opts.delete(:completed_at); x.nil? ? nil : HttpClient::Preconditions.assert_class('completed_at', HttpClient::Helper.to_date_time_iso8601(x), DateTime))
  @results = (x = opts.delete(:results); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::ImportResults) ? x : ::Io::Flow::V0::Models::ImportResults.new(x)))
  @deliveries = HttpClient::Preconditions.assert_class('deliveries', opts.delete(:deliveries), Array).map { |v| (x = v; x.is_a?(::Io::Flow::V0::Models::ExportDelivery) ? x : ::Io::Flow::V0::Models::ExportDelivery.from_json(x)) }
end

Instance Attribute Details

#completed_at ⇒ Object (readonly)

Returns the value of attribute completed_at.



13874
13875
13876
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13874

def completed_at
  @completed_at
end

#created_at ⇒ Object (readonly)

Returns the value of attribute created_at.



13874
13875
13876
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13874

def created_at
  @created_at
end

#deliveries ⇒ Object (readonly)

Returns the value of attribute deliveries.



13874
13875
13876
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13874

def deliveries
  @deliveries
end

#id ⇒ Object (readonly)

Returns the value of attribute id.



13874
13875
13876
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13874

def id
  @id
end

#results ⇒ Object (readonly)

Returns the value of attribute results.



13874
13875
13876
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13874

def results
  @results
end

#source_url ⇒ Object (readonly)

Returns the value of attribute source_url.



13874
13875
13876
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13874

def source_url
  @source_url
end

#started_at ⇒ Object (readonly)

Returns the value of attribute started_at.



13874
13875
13876
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13874

def started_at
  @started_at
end

#status ⇒ Object (readonly)

Returns the value of attribute status.



13874
13875
13876
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13874

def status
  @status
end

#type ⇒ Object (readonly)

Returns the value of attribute type.



13874
13875
13876
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13874

def type
  @type
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



13894
13895
13896
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13894

def copy(incoming={})
  Import.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hash ⇒ Object



13898
13899
13900
13901
13902
13903
13904
13905
13906
13907
13908
13909
13910
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13898

def to_hash
  {
    :id => id,
    :type => type.value,
    :source_url => source_url,
    :status => status.value,
    :created_at => created_at,
    :started_at => started_at,
    :completed_at => completed_at,
    :results => results.nil? ? nil : results.to_hash,
    :deliveries => deliveries.map { |o| o.to_hash }
  }
end

#to_json ⇒ Object



13890
13891
13892
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13890

def to_json
  JSON.dump(to_hash)
end