Class: Io::Flow::V0::Models::Incoterm

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ Incoterm

Returns a new instance of Incoterm.



15871
15872
15873
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15871

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



15869
15870
15871
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15869

def value
  @value
end

Class Method Details

.ALLObject



15891
15892
15893
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15891

def Incoterm.ALL
  @@all ||= [Incoterm.exw, Incoterm.fca, Incoterm.cpt, Incoterm.cip, Incoterm.dat, Incoterm.dap, Incoterm.ddp, Incoterm.fas, Incoterm.fob, Incoterm.cfr, Incoterm.cif, Incoterm.daf, Incoterm.des, Incoterm.deq, Incoterm.ddu]
end

.apply(value) ⇒ Object

Returns the instance of Incoterm for this value, creating a new instance for an unknown value



15876
15877
15878
15879
15880
15881
15882
15883
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15876

def Incoterm.apply(value)
  if value.instance_of?(Incoterm)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || Incoterm.new(value))
  end
end

.cfrObject

Cost and Freight (named port of destination)



15941
15942
15943
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15941

def Incoterm.cfr
  @@_cfr ||= Incoterm.new('CFR')
end

.cifObject

Cost, Insurance & Freight (named port of destination)



15946
15947
15948
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15946

def Incoterm.cif
  @@_cif ||= Incoterm.new('CIF')
end

.cipObject

Carriage and Insurance Paid to (named place of destination)



15911
15912
15913
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15911

def Incoterm.cip
  @@_cip ||= Incoterm.new('CIP')
end

.cptObject

Carriage Paid To (named place of destination)



15906
15907
15908
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15906

def Incoterm.cpt
  @@_cpt ||= Incoterm.new('CPT')
end

.dafObject

Delivered at Frontier (named place of delivery)



15951
15952
15953
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15951

def Incoterm.daf
  @@_daf ||= Incoterm.new('DAF')
end

.dapObject

Delivered At Place (named place of destination)



15921
15922
15923
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15921

def Incoterm.dap
  @@_dap ||= Incoterm.new('DAP')
end

.datObject

Delivered At Terminal (named terminal at port or place of destination)



15916
15917
15918
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15916

def Incoterm.dat
  @@_dat ||= Incoterm.new('DAT')
end

.ddpObject

Delivered Duty Paid (named place of destination)



15926
15927
15928
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15926

def Incoterm.ddp
  @@_ddp ||= Incoterm.new('DDP')
end

.dduObject

Delivered Duty Unpaid (named place of destination)



15966
15967
15968
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15966

def Incoterm.ddu
  @@_ddu ||= Incoterm.new('DDU')
end

.deqObject

Delivered Ex Quay (named port of delivery)



15961
15962
15963
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15961

def Incoterm.deq
  @@_deq ||= Incoterm.new('DEQ')
end

.desObject

Delivered Ex Ship



15956
15957
15958
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15956

def Incoterm.des
  @@_des ||= Incoterm.new('DES')
end

.exwObject

Ex Works (named place of delivery)



15896
15897
15898
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15896

def Incoterm.exw
  @@_exw ||= Incoterm.new('EXW')
end

.fasObject

Free Alongside Ship (named port of shipment)



15931
15932
15933
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15931

def Incoterm.fas
  @@_fas ||= Incoterm.new('FAS')
end

.fcaObject

Free Carrier (named place of delivery)



15901
15902
15903
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15901

def Incoterm.fca
  @@_fca ||= Incoterm.new('FCA')
end

.fobObject

Free on Board (named port of shipment)



15936
15937
15938
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15936

def Incoterm.fob
  @@_fob ||= Incoterm.new('FOB')
end

.from_string(value) ⇒ Object

Returns the instance of Incoterm for this value, or nil if not found



15886
15887
15888
15889
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15886

def Incoterm.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  Incoterm.ALL.find { |v| v.value == value }
end

Instance Method Details

#to_hashObject



15970
15971
15972
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15970

def to_hash
  value
end