Class: Io::Flow::V0::Models::InstallmentPlanPaymentForm

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

The installment payment form is used to create an installment plan for an order, associating the plan immediately with this order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ InstallmentPlanPaymentForm

Returns a new instance of InstallmentPlanPaymentForm.



32986
32987
32988
32989
32990
32991
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 32986

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:installment_program_id, :authorization_key], 'InstallmentPlanPaymentForm')
  @installment_program_id = HttpClient::Preconditions.assert_class('installment_program_id', opts.delete(:installment_program_id), String)
  @authorization_key = HttpClient::Preconditions.assert_class('authorization_key', opts.delete(:authorization_key), String)
end

Instance Attribute Details

#authorization_keyObject (readonly)

Returns the value of attribute authorization_key.



32984
32985
32986
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 32984

def authorization_key
  @authorization_key
end

#installment_program_idObject (readonly)

Returns the value of attribute installment_program_id.



32984
32985
32986
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 32984

def installment_program_id
  @installment_program_id
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



32997
32998
32999
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 32997

def copy(incoming={})
  InstallmentPlanPaymentForm.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hashObject



33001
33002
33003
33004
33005
33006
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 33001

def to_hash
  {
    :installment_program_id => installment_program_id,
    :authorization_key => authorization_key
  }
end

#to_jsonObject



32993
32994
32995
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 32993

def to_json
  JSON.dump(to_hash)
end