Class: Io::Flow::V0::Models::InvitationErrorCode
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::InvitationErrorCode
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of InvitationErrorCode for this value, creating a new instance for an unknown value.
- .expired ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of InvitationErrorCode for this value, or nil if not found.
- .invalid_email ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ InvitationErrorCode
constructor
A new instance of InvitationErrorCode.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ InvitationErrorCode
Returns a new instance of InvitationErrorCode.
16114 16115 16116 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16114 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
16112 16113 16114 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16112 def value @value end |
Class Method Details
.ALL ⇒ Object
16134 16135 16136 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16134 def InvitationErrorCode.ALL @@all ||= [InvitationErrorCode.expired, InvitationErrorCode.invalid_email] end |
.apply(value) ⇒ Object
Returns the instance of InvitationErrorCode for this value, creating a new instance for an unknown value
16119 16120 16121 16122 16123 16124 16125 16126 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16119 def InvitationErrorCode.apply(value) if value.instance_of?(InvitationErrorCode) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || InvitationErrorCode.new(value)) end end |
.expired ⇒ Object
16138 16139 16140 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16138 def InvitationErrorCode.expired @@_expired ||= InvitationErrorCode.new('expired') end |
.from_string(value) ⇒ Object
Returns the instance of InvitationErrorCode for this value, or nil if not found
16129 16130 16131 16132 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16129 def InvitationErrorCode.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) InvitationErrorCode.ALL.find { |v| v.value == value } end |
.invalid_email ⇒ Object
16142 16143 16144 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16142 def InvitationErrorCode.invalid_email @@_invalid_email ||= InvitationErrorCode.new('invalid_email') end |
Instance Method Details
#to_hash ⇒ Object
16146 16147 16148 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16146 def to_hash value end |