Class: Io::Flow::V0::Models::Item

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

The Flow item defines a specific item that can be purchased by a consumer. For many clients, this will map to a Sku.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ Item

Returns a new instance of Item.



14589
14590
14591
14592
14593
14594
14595
14596
14597
14598
14599
14600
14601
14602
14603
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14589

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:id, :number, :locale, :name, :price, :dimensions], 'Item')
  @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String)
  @number = HttpClient::Preconditions.assert_class('number', opts.delete(:number), String)
  @locale = HttpClient::Preconditions.assert_class('locale', opts.delete(:locale), String)
  @name = HttpClient::Preconditions.assert_class('name', opts.delete(:name), String)
  @price = (x = opts.delete(:price); x.is_a?(::Io::Flow::V0::Models::Price) ? x : ::Io::Flow::V0::Models::Price.new(x))
  @categories = HttpClient::Preconditions.assert_class('categories', (x = opts.delete(:categories); x.nil? ? [] : x), Array).map { |v| HttpClient::Preconditions.assert_class('categories', v, String) }
  @description = (x = opts.delete(:description); x.nil? ? nil : HttpClient::Preconditions.assert_class('description', x, String))
  @attributes = HttpClient::Preconditions.assert_class('attributes', (x = opts.delete(:attributes); x.nil? ? {} : x), Hash).inject({}) { |h, d| h[d[0]] = HttpClient::Preconditions.assert_class('attributes', d[1], String); h }
  @dimensions = (x = opts.delete(:dimensions); x.is_a?(::Io::Flow::V0::Models::Dimensions) ? x : ::Io::Flow::V0::Models::Dimensions.new(x))
  @images = HttpClient::Preconditions.assert_class('images', (x = opts.delete(:images); x.nil? ? [] : x), Array).map { |v| (x = v; x.is_a?(::Io::Flow::V0::Models::Image) ? x : ::Io::Flow::V0::Models::Image.new(x)) }
  @local = (x = opts.delete(:local); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::Local) ? x : ::Io::Flow::V0::Models::Local.new(x)))
end

Instance Attribute Details

#attributes ⇒ Object (readonly)

Returns the value of attribute attributes.



14587
14588
14589
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14587

def attributes
  @attributes
end

#categories ⇒ Object (readonly)

Returns the value of attribute categories.



14587
14588
14589
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14587

def categories
  @categories
end

#description ⇒ Object (readonly)

Returns the value of attribute description.



14587
14588
14589
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14587

def description
  @description
end

#dimensions ⇒ Object (readonly)

Returns the value of attribute dimensions.



14587
14588
14589
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14587

def dimensions
  @dimensions
end

#id ⇒ Object (readonly)

Returns the value of attribute id.



14587
14588
14589
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14587

def id
  @id
end

#images ⇒ Object (readonly)

Returns the value of attribute images.



14587
14588
14589
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14587

def images
  @images
end

#local ⇒ Object (readonly)

Returns the value of attribute local.



14587
14588
14589
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14587

def local
  @local
end

#locale ⇒ Object (readonly)

Returns the value of attribute locale.



14587
14588
14589
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14587

def locale
  @locale
end

#name ⇒ Object (readonly)

Returns the value of attribute name.



14587
14588
14589
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14587

def name
  @name
end

#number ⇒ Object (readonly)

Returns the value of attribute number.



14587
14588
14589
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14587

def number
  @number
end

#price ⇒ Object (readonly)

Returns the value of attribute price.



14587
14588
14589
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14587

def price
  @price
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



14609
14610
14611
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14609

def copy(incoming={})
  Item.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hash ⇒ Object



14613
14614
14615
14616
14617
14618
14619
14620
14621
14622
14623
14624
14625
14626
14627
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14613

def to_hash
  {
    :id => id,
    :number => number,
    :locale => locale,
    :name => name,
    :price => price.to_hash,
    :categories => categories,
    :description => description,
    :attributes => attributes,
    :dimensions => dimensions.to_hash,
    :images => images.map { |o| o.to_hash },
    :local => local.nil? ? nil : local.to_hash
  }
end

#to_json ⇒ Object



14605
14606
14607
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14605

def to_json
  JSON.dump(to_hash)
end