Class: Io::Flow::V0::Models::ItemOriginUpserted
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
Event raised whenever an item is assigned a country of origin. Note that one item may have multiple countries of origin.
Instance Attribute Summary collapse
-
#event_id ⇒ Object
readonly
Returns the value of attribute event_id.
-
#number ⇒ Object
readonly
Returns the value of attribute number.
-
#organization ⇒ Object
readonly
Returns the value of attribute organization.
-
#origin ⇒ Object
readonly
Returns the value of attribute origin.
-
#timestamp ⇒ Object
readonly
Returns the value of attribute timestamp.
Attributes inherited from Event
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ ItemOriginUpserted
constructor
A new instance of ItemOriginUpserted.
- #subtype_to_hash ⇒ Object
- #to_json ⇒ Object
Methods inherited from Event
Constructor Details
#initialize(incoming = {}) ⇒ ItemOriginUpserted
34339 34340 34341 34342 34343 34344 34345 34346 34347 34348 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 34339 def initialize(incoming={}) super(:discriminator => Event::Types::ITEM_ORIGIN_UPSERTED) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:event_id, :timestamp, :organization, :number, :origin], 'ItemOriginUpserted') @event_id = HttpClient::Preconditions.assert_class('event_id', opts.delete(:event_id), String) @timestamp = HttpClient::Preconditions.assert_class('timestamp', HttpClient::Helper.to_date_time_iso8601(opts.delete(:timestamp)), DateTime) @organization = HttpClient::Preconditions.assert_class('organization', opts.delete(:organization), String) @number = HttpClient::Preconditions.assert_class('number', opts.delete(:number), String) @origin = HttpClient::Preconditions.assert_class('origin', opts.delete(:origin), String) end |
Instance Attribute Details
#event_id ⇒ Object (readonly)
Returns the value of attribute event_id.
34337 34338 34339 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 34337 def event_id @event_id end |
#number ⇒ Object (readonly)
Returns the value of attribute number.
34337 34338 34339 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 34337 def number @number end |
#organization ⇒ Object (readonly)
Returns the value of attribute organization.
34337 34338 34339 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 34337 def organization @organization end |
#origin ⇒ Object (readonly)
Returns the value of attribute origin.
34337 34338 34339 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 34337 def origin @origin end |
#timestamp ⇒ Object (readonly)
Returns the value of attribute timestamp.
34337 34338 34339 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 34337 def @timestamp end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
34354 34355 34356 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 34354 def copy(incoming={}) ItemOriginUpserted.new(subtype_to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#subtype_to_hash ⇒ Object
34358 34359 34360 34361 34362 34363 34364 34365 34366 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 34358 def subtype_to_hash { :event_id => event_id, :timestamp => , :organization => organization, :number => number, :origin => origin } end |
#to_json ⇒ Object
34350 34351 34352 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 34350 def to_json JSON.dump(to_hash) end |