Class: Io::Flow::V0::Models::LaneStrategy

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ LaneStrategy



16295
16296
16297
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16295

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



16293
16294
16295
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16293

def value
  @value
end

Class Method Details

.ALLObject



16315
16316
16317
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16315

def LaneStrategy.ALL
  @@all ||= [LaneStrategy.oldest, LaneStrategy.fastest, LaneStrategy.lowest_cost, LaneStrategy.highest_priority]
end

.apply(value) ⇒ Object

Returns the instance of LaneStrategy for this value, creating a new instance for an unknown value



16300
16301
16302
16303
16304
16305
16306
16307
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16300

def LaneStrategy.apply(value)
  if value.instance_of?(LaneStrategy)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || LaneStrategy.new(value))
  end
end

.fastestObject

Optimize for fastest average time in transit across all tiers from the center on the lane



16326
16327
16328
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16326

def LaneStrategy.fastest
  @@_fastest ||= LaneStrategy.new('fastest')
end

.from_string(value) ⇒ Object

Returns the instance of LaneStrategy for this value, or nil if not found



16310
16311
16312
16313
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16310

def LaneStrategy.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  LaneStrategy.ALL.find { |v| v.value == value }
end

.highest_priorityObject

Get the highest priority center for the shipping lane



16336
16337
16338
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16336

def LaneStrategy.highest_priority
  @@_highest_priority ||= LaneStrategy.new('highest_priority')
end

.lowest_costObject

Optimize for lowest average cost across all tiers from the center on the lane



16331
16332
16333
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16331

def LaneStrategy.lowest_cost
  @@_lowest_cost ||= LaneStrategy.new('lowest_cost')
end

.oldestObject

Use the oldest center by creation date.



16320
16321
16322
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16320

def LaneStrategy.oldest
  @@_oldest ||= LaneStrategy.new('oldest')
end

Instance Method Details

#to_hashObject



16340
16341
16342
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16340

def to_hash
  value
end