Class: Io::Flow::V0::Models::LocationErrorCode
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::LocationErrorCode
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
-
.address_required ⇒ Object
Indicates that a non empty address was not specified when required.
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of LocationErrorCode for this value, creating a new instance for an unknown value.
-
.from_string(value) ⇒ Object
Returns the instance of LocationErrorCode for this value, or nil if not found.
-
.ip_invalid ⇒ Object
Indicates the specified IP Address is invalid.
-
.ip_required ⇒ Object
Indicates that a non empty IP Address was not specified when required.
-
.timezone_unavailable ⇒ Object
Indicates that there is no timezone information available for the specified IP Address.
Instance Method Summary collapse
-
#initialize(value) ⇒ LocationErrorCode
constructor
A new instance of LocationErrorCode.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ LocationErrorCode
Returns a new instance of LocationErrorCode.
16452 16453 16454 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16452 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
16450 16451 16452 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16450 def value @value end |
Class Method Details
.address_required ⇒ Object
Indicates that a non empty address was not specified when required
16477 16478 16479 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16477 def LocationErrorCode.address_required @@_address_required ||= LocationErrorCode.new('address_required') end |
.ALL ⇒ Object
16472 16473 16474 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16472 def LocationErrorCode.ALL @@all ||= [LocationErrorCode.address_required, LocationErrorCode.ip_invalid, LocationErrorCode.ip_required, LocationErrorCode.timezone_unavailable] end |
.apply(value) ⇒ Object
Returns the instance of LocationErrorCode for this value, creating a new instance for an unknown value
16457 16458 16459 16460 16461 16462 16463 16464 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16457 def LocationErrorCode.apply(value) if value.instance_of?(LocationErrorCode) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || LocationErrorCode.new(value)) end end |
.from_string(value) ⇒ Object
Returns the instance of LocationErrorCode for this value, or nil if not found
16467 16468 16469 16470 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16467 def LocationErrorCode.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) LocationErrorCode.ALL.find { |v| v.value == value } end |
.ip_invalid ⇒ Object
Indicates the specified IP Address is invalid
16482 16483 16484 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16482 def LocationErrorCode.ip_invalid @@_ip_invalid ||= LocationErrorCode.new('ip_invalid') end |
.ip_required ⇒ Object
Indicates that a non empty IP Address was not specified when required
16487 16488 16489 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16487 def LocationErrorCode.ip_required @@_ip_required ||= LocationErrorCode.new('ip_required') end |
.timezone_unavailable ⇒ Object
Indicates that there is no timezone information available for the specified IP Address
16493 16494 16495 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16493 def LocationErrorCode.timezone_unavailable @@_timezone_unavailable ||= LocationErrorCode.new('timezone_unavailable') end |
Instance Method Details
#to_hash ⇒ Object
16497 16498 16499 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16497 def to_hash value end |