Class: Io::Flow::V0::Models::MeasurementSystem
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::MeasurementSystem
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of MeasurementSystem for this value, creating a new instance for an unknown value.
-
.from_string(value) ⇒ Object
Returns the instance of MeasurementSystem for this value, or nil if not found.
- .imperial ⇒ Object
- .metric ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ MeasurementSystem
constructor
A new instance of MeasurementSystem.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ MeasurementSystem
Returns a new instance of MeasurementSystem.
16552 16553 16554 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16552 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
16550 16551 16552 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16550 def value @value end |
Class Method Details
.ALL ⇒ Object
16572 16573 16574 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16572 def MeasurementSystem.ALL @@all ||= [MeasurementSystem.imperial, MeasurementSystem.metric] end |
.apply(value) ⇒ Object
Returns the instance of MeasurementSystem for this value, creating a new instance for an unknown value
16557 16558 16559 16560 16561 16562 16563 16564 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16557 def MeasurementSystem.apply(value) if value.instance_of?(MeasurementSystem) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || MeasurementSystem.new(value)) end end |
.from_string(value) ⇒ Object
Returns the instance of MeasurementSystem for this value, or nil if not found
16567 16568 16569 16570 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16567 def MeasurementSystem.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) MeasurementSystem.ALL.find { |v| v.value == value } end |
.imperial ⇒ Object
16576 16577 16578 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16576 def MeasurementSystem.imperial @@_imperial ||= MeasurementSystem.new('imperial') end |
.metric ⇒ Object
16580 16581 16582 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16580 def MeasurementSystem.metric @@_metric ||= MeasurementSystem.new('metric') end |
Instance Method Details
#to_hash ⇒ Object
16584 16585 16586 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16584 def to_hash value end |