Class: Io::Flow::V0::Models::Method

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ Method

Returns a new instance of Method.



16694
16695
16696
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16694

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



16692
16693
16694
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16692

def value
  @value
end

Class Method Details

.ALLObject



16714
16715
16716
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16714

def Method.ALL
  @@all ||= [Method.post]
end

.apply(value) ⇒ Object

Returns the instance of Method for this value, creating a new instance for an unknown value



16699
16700
16701
16702
16703
16704
16705
16706
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16699

def Method.apply(value)
  if value.instance_of?(Method)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || Method.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of Method for this value, or nil if not found



16709
16710
16711
16712
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16709

def Method.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  Method.ALL.find { |v| v.value == value }
end

.postObject



16718
16719
16720
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16718

def Method.post
  @@_post ||= Method.new('post')
end

Instance Method Details

#to_hashObject



16722
16723
16724
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16722

def to_hash
  value
end