Class: Io::Flow::V0::Models::OptinResponseType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::OptinResponseType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of OptinResponseType for this value, creating a new instance for an unknown value.
-
.from_string(value) ⇒ Object
Returns the instance of OptinResponseType for this value, or nil if not found.
- .not_shown ⇒ Object
- .opted_in ⇒ Object
- .opted_out ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ OptinResponseType
constructor
A new instance of OptinResponseType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ OptinResponseType
Returns a new instance of OptinResponseType.
16732 16733 16734 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16732 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
16730 16731 16732 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16730 def value @value end |
Class Method Details
.ALL ⇒ Object
16752 16753 16754 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16752 def OptinResponseType.ALL @@all ||= [OptinResponseType.not_shown, OptinResponseType.opted_in, OptinResponseType.opted_out] end |
.apply(value) ⇒ Object
Returns the instance of OptinResponseType for this value, creating a new instance for an unknown value
16737 16738 16739 16740 16741 16742 16743 16744 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16737 def OptinResponseType.apply(value) if value.instance_of?(OptinResponseType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || OptinResponseType.new(value)) end end |
.from_string(value) ⇒ Object
Returns the instance of OptinResponseType for this value, or nil if not found
16747 16748 16749 16750 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16747 def OptinResponseType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) OptinResponseType.ALL.find { |v| v.value == value } end |
.not_shown ⇒ Object
16756 16757 16758 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16756 def OptinResponseType.not_shown @@_not_shown ||= OptinResponseType.new('not_shown') end |
.opted_in ⇒ Object
16760 16761 16762 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16760 def OptinResponseType.opted_in @@_opted_in ||= OptinResponseType.new('opted_in') end |
.opted_out ⇒ Object
16764 16765 16766 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16764 def OptinResponseType.opted_out @@_opted_out ||= OptinResponseType.new('opted_out') end |
Instance Method Details
#to_hash ⇒ Object
16768 16769 16770 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16768 def to_hash value end |