Class: Io::Flow::V0::Models::OrderChangeSource

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ OrderChangeSource

Returns a new instance of OrderChangeSource.



16778
16779
16780
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16778

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



16776
16777
16778
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16776

def value
  @value
end

Class Method Details

.ALLObject



16798
16799
16800
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16798

def OrderChangeSource.ALL
  @@all ||= [OrderChangeSource.consumer, OrderChangeSource.retailer, OrderChangeSource.fulfillment, OrderChangeSource.flow, OrderChangeSource.carrier]
end

.apply(value) ⇒ Object

Returns the instance of OrderChangeSource for this value, creating a new instance for an unknown value



16783
16784
16785
16786
16787
16788
16789
16790
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16783

def OrderChangeSource.apply(value)
  if value.instance_of?(OrderChangeSource)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || OrderChangeSource.new(value))
  end
end

.carrierObject

A party providing carriage for an order



16823
16824
16825
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16823

def OrderChangeSource.carrier
  @@_carrier ||= OrderChangeSource.new('carrier')
end

.consumerObject

The party that placed an order



16803
16804
16805
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16803

def OrderChangeSource.consumer
  @@_consumer ||= OrderChangeSource.new('consumer')
end

.flowObject

Flow may provide anti-fraud or payment services for an order



16818
16819
16820
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16818

def OrderChangeSource.flow
  @@_flow ||= OrderChangeSource.new('flow')
end

.from_string(value) ⇒ Object

Returns the instance of OrderChangeSource for this value, or nil if not found



16793
16794
16795
16796
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16793

def OrderChangeSource.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  OrderChangeSource.ALL.find { |v| v.value == value }
end

.fulfillmentObject

A party providing fulfillment for an order



16813
16814
16815
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16813

def OrderChangeSource.fulfillment
  @@_fulfillment ||= OrderChangeSource.new('fulfillment')
end

.retailerObject

The party that owns the processing of the order



16808
16809
16810
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16808

def OrderChangeSource.retailer
  @@_retailer ||= OrderChangeSource.new('retailer')
end

Instance Method Details

#to_hashObject



16827
16828
16829
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16827

def to_hash
  value
end