Class: Io::Flow::V0::Models::OrderErrorCode

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ OrderErrorCode

Returns a new instance of OrderErrorCode.



16837
16838
16839
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16837

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



16835
16836
16837
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16835

def value
  @value
end

Class Method Details

.ALLObject



16857
16858
16859
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16857

def OrderErrorCode.ALL
  @@all ||= [OrderErrorCode.generic_error, OrderErrorCode.order_item_not_available, OrderErrorCode.order_identifier_error, OrderErrorCode.authorization_invalid, OrderErrorCode.domestic_shipping_unavailable, OrderErrorCode.shipping_unavailable, OrderErrorCode.value_threshold_exceeded, OrderErrorCode.invalid_currency, OrderErrorCode.invalid_country, OrderErrorCode.invalid_region, OrderErrorCode.invalid_language, OrderErrorCode.item_out_of_stock, OrderErrorCode.gift_card_not_accepted, OrderErrorCode.total_changed]
end

.apply(value) ⇒ Object

Returns the instance of OrderErrorCode for this value, creating a new instance for an unknown value



16842
16843
16844
16845
16846
16847
16848
16849
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16842

def OrderErrorCode.apply(value)
  if value.instance_of?(OrderErrorCode)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || OrderErrorCode.new(value))
  end
end

.authorization_invalidObject

The authorization key specified is invalid - either because it does not exist or is not associated with this order



16881
16882
16883
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16881

def OrderErrorCode.authorization_invalid
  @@_authorization_invalid ||= OrderErrorCode.new('authorization_invalid')
end

.domestic_shipping_unavailableObject

Indicates that an order was created for a country for one of your domicile countries and you have asked Flow not to accept orders for this country.



16887
16888
16889
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16887

def OrderErrorCode.domestic_shipping_unavailable
  @@_domestic_shipping_unavailable ||= OrderErrorCode.new('domestic_shipping_unavailable')
end

.from_string(value) ⇒ Object

Returns the instance of OrderErrorCode for this value, or nil if not found



16852
16853
16854
16855
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16852

def OrderErrorCode.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  OrderErrorCode.ALL.find { |v| v.value == value }
end

.generic_errorObject



16861
16862
16863
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16861

def OrderErrorCode.generic_error
  @@_generic_error ||= OrderErrorCode.new('generic_error')
end

.gift_card_not_acceptedObject

Indicates a failure to charge a gift card. Error message will indicate when retries are possible.



16933
16934
16935
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16933

def OrderErrorCode.gift_card_not_accepted
  @@_gift_card_not_accepted ||= OrderErrorCode.new('gift_card_not_accepted')
end

.invalid_countryObject

Indicates that the specified country code is not valid



16910
16911
16912
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16910

def OrderErrorCode.invalid_country
  @@_invalid_country ||= OrderErrorCode.new('invalid_country')
end

.invalid_currencyObject

Indicates that the specified currency code is not valid



16905
16906
16907
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16905

def OrderErrorCode.invalid_currency
  @@_invalid_currency ||= OrderErrorCode.new('invalid_currency')
end

.invalid_languageObject

Indicates that the specified language code is not valid



16920
16921
16922
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16920

def OrderErrorCode.invalid_language
  @@_invalid_language ||= OrderErrorCode.new('invalid_language')
end

.invalid_regionObject

Indicates that the specified region code is not valid



16915
16916
16917
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16915

def OrderErrorCode.invalid_region
  @@_invalid_region ||= OrderErrorCode.new('invalid_region')
end

.item_out_of_stockObject

Indicates that one or more ordered items is marked as out-of-stock or otherwise cannot be reserved. We will list the specific out-of-stock items in the numbers field



16927
16928
16929
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16927

def OrderErrorCode.item_out_of_stock
  @@_item_out_of_stock ||= OrderErrorCode.new('item_out_of_stock')
end

.order_identifier_errorObject

Indicates that there is no order with the specified number (nor an order for which an order identifier with that number has been created)



16875
16876
16877
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16875

def OrderErrorCode.order_identifier_error
  @@_order_identifier_error ||= OrderErrorCode.new('order_identifier_error')
end

.order_item_not_availableObject

When creating an order, if a particular item is not available in the country / destination (either because it was restricted or excluded from that country), we return this error code and list the specific item numbers which are not available in the 'numbers' field.



16869
16870
16871
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16869

def OrderErrorCode.order_item_not_available
  @@_order_item_not_available ||= OrderErrorCode.new('order_item_not_available')
end

.shipping_unavailableObject

Indicates that an order was created for a country to which you have asked Flow not to ship.



16893
16894
16895
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16893

def OrderErrorCode.shipping_unavailable
  @@_shipping_unavailable ||= OrderErrorCode.new('shipping_unavailable')
end

.total_changedObject

Indicates that the order total has changed, likely due to pricebook update or rate change. This is not an error but the consumer should be shown the new price before continuing checkout.



16940
16941
16942
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16940

def OrderErrorCode.total_changed
  @@_total_changed ||= OrderErrorCode.new('total_changed')
end

.value_threshold_exceededObject

Indicates the order value exceeds the value threshold for destination and cannot be shipped. When specified, the order will also populate the threshold attribute.



16900
16901
16902
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16900

def OrderErrorCode.value_threshold_exceeded
  @@_value_threshold_exceeded ||= OrderErrorCode.new('value_threshold_exceeded')
end

Instance Method Details

#to_hashObject



16944
16945
16946
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16944

def to_hash
  value
end