Class: Io::Flow::V0::Models::OrderForm
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::OrderForm
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
The order form is used to create an open order, providing the details on pricing and delivery options for destination and items/quantities specified
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#authorization_keys ⇒ Object
readonly
Returns the value of attribute authorization_keys.
-
#customer ⇒ Object
readonly
Returns the value of attribute customer.
-
#delivered_duty ⇒ Object
readonly
Returns the value of attribute delivered_duty.
-
#destination ⇒ Object
readonly
Returns the value of attribute destination.
-
#discount ⇒ Object
readonly
Returns the value of attribute discount.
-
#discounts ⇒ Object
readonly
Returns the value of attribute discounts.
-
#items ⇒ Object
readonly
Returns the value of attribute items.
-
#number ⇒ Object
readonly
Returns the value of attribute number.
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ OrderForm
constructor
A new instance of OrderForm.
- #to_hash ⇒ Object
- #to_json ⇒ Object
Constructor Details
#initialize(incoming = {}) ⇒ OrderForm
Returns a new instance of OrderForm.
37753 37754 37755 37756 37757 37758 37759 37760 37761 37762 37763 37764 37765 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 37753 def initialize(incoming={}) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:items], 'OrderForm') @customer = (x = opts.delete(:customer); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::OrderCustomerForm) ? x : ::Io::Flow::V0::Models::OrderCustomerForm.new(x))) @items = HttpClient::Preconditions.assert_class('items', opts.delete(:items), Array).map { |v| (x = v; x.is_a?(::Io::Flow::V0::Models::LineItemForm) ? x : ::Io::Flow::V0::Models::LineItemForm.new(x)) } @delivered_duty = (x = opts.delete(:delivered_duty); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::DeliveredDuty) ? x : ::Io::Flow::V0::Models::DeliveredDuty.apply(x))) @number = (x = opts.delete(:number); x.nil? ? nil : HttpClient::Preconditions.assert_class('number', x, String)) @destination = (x = opts.delete(:destination); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::OrderAddress) ? x : ::Io::Flow::V0::Models::OrderAddress.new(x))) @discount = (x = opts.delete(:discount); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::Money) ? x : ::Io::Flow::V0::Models::Money.new(x))) @discounts = (x = opts.delete(:discounts); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::DiscountsForm) ? x : ::Io::Flow::V0::Models::DiscountsForm.new(x))) @attributes = (x = opts.delete(:attributes); x.nil? ? nil : HttpClient::Preconditions.assert_class('attributes', x, Hash).inject({}) { |h, d| h[d[0]] = HttpClient::Preconditions.assert_class('attributes', d[1], String); h }) = (x = opts.delete(:authorization_keys); x.nil? ? nil : HttpClient::Preconditions.assert_class('authorization_keys', x, Array).map { |v| HttpClient::Preconditions.assert_class('authorization_keys', v, String) }) end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
37751 37752 37753 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 37751 def attributes @attributes end |
#authorization_keys ⇒ Object (readonly)
Returns the value of attribute authorization_keys.
37751 37752 37753 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 37751 def end |
#customer ⇒ Object (readonly)
Returns the value of attribute customer.
37751 37752 37753 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 37751 def customer @customer end |
#delivered_duty ⇒ Object (readonly)
Returns the value of attribute delivered_duty.
37751 37752 37753 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 37751 def delivered_duty @delivered_duty end |
#destination ⇒ Object (readonly)
Returns the value of attribute destination.
37751 37752 37753 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 37751 def destination @destination end |
#discount ⇒ Object (readonly)
Returns the value of attribute discount.
37751 37752 37753 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 37751 def discount @discount end |
#discounts ⇒ Object (readonly)
Returns the value of attribute discounts.
37751 37752 37753 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 37751 def discounts @discounts end |
#items ⇒ Object (readonly)
Returns the value of attribute items.
37751 37752 37753 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 37751 def items @items end |
#number ⇒ Object (readonly)
Returns the value of attribute number.
37751 37752 37753 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 37751 def number @number end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
37771 37772 37773 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 37771 def copy(incoming={}) OrderForm.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#to_hash ⇒ Object
37775 37776 37777 37778 37779 37780 37781 37782 37783 37784 37785 37786 37787 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 37775 def to_hash { :customer => customer.nil? ? nil : customer.to_hash, :items => items.map { |o| o.to_hash }, :delivered_duty => delivered_duty.nil? ? nil : delivered_duty.value, :number => number, :destination => destination.nil? ? nil : destination.to_hash, :discount => discount.nil? ? nil : discount.to_hash, :discounts => discounts.nil? ? nil : discounts.to_hash, :attributes => attributes.nil? ? nil : attributes, :authorization_keys => .nil? ? nil : } end |
#to_json ⇒ Object
37767 37768 37769 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 37767 def to_json JSON.dump(to_hash) end |