Class: Io::Flow::V0::Models::OrderPaymentType

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ OrderPaymentType



17000
17001
17002
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17000

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



16998
16999
17000
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16998

def value
  @value
end

Class Method Details

.ALLObject



17020
17021
17022
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17020

def OrderPaymentType.ALL
  @@all ||= [OrderPaymentType.card, OrderPaymentType.online, OrderPaymentType.credit, OrderPaymentType.installment_plan, OrderPaymentType.cash_on_delivery]
end

.apply(value) ⇒ Object

Returns the instance of OrderPaymentType for this value, creating a new instance for an unknown value



17005
17006
17007
17008
17009
17010
17011
17012
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17005

def OrderPaymentType.apply(value)
  if value.instance_of?(OrderPaymentType)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || OrderPaymentType.new(value))
  end
end

.cardObject

Represents a payment in the form of a credit or debit card



17025
17026
17027
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17025

def OrderPaymentType.card
  @@_card ||= OrderPaymentType.new('card')
end

.cash_on_deliveryObject

Request to pay the balance with cash on delivery. Offered only when the final mile carriers support cash on delivery.



17050
17051
17052
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17050

def OrderPaymentType.cash_on_delivery
  @@_cash_on_delivery ||= OrderPaymentType.new('cash_on_delivery')
end

.creditObject

A payment in the form of a credit of some type (e.g. a store credit, gift card) applied to an order



17036
17037
17038
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17036

def OrderPaymentType.credit
  @@_credit ||= OrderPaymentType.new('credit')
end

.from_string(value) ⇒ Object

Returns the instance of OrderPaymentType for this value, or nil if not found



17015
17016
17017
17018
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17015

def OrderPaymentType.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  OrderPaymentType.ALL.find { |v| v.value == value }
end

.installment_planObject

An installment plan payment represents that the user has elected an installment plan to pay for this order. For the purposes of the order, the balance will reflect fully paid for the total value of the installment plan, even though individual installments may be created in the future.



17044
17045
17046
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17044

def OrderPaymentType.installment_plan
  @@_installment_plan ||= OrderPaymentType.new('installment_plan')
end

.onlineObject

Represents an online payment (e.g. paypal, alipay, etc)



17030
17031
17032
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17030

def OrderPaymentType.online
  @@_online ||= OrderPaymentType.new('online')
end

Instance Method Details

#to_hashObject



17054
17055
17056
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17054

def to_hash
  value
end