Class: Io::Flow::V0::Models::OrderPlaced
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
Sent when an order is submitted, allocations are generated and the total value of the order is accounted for by discounts, subsidies, credits and authorized payments -- but may not ready to fulfill (e.g. pending assignment of a DC or fraud review). Intended to fuel customer feedback and alert merchants that an order is coming.
Instance Attribute Summary collapse
-
#allocation ⇒ Object
readonly
Returns the value of attribute allocation.
-
#event_id ⇒ Object
readonly
Returns the value of attribute event_id.
-
#order ⇒ Object
readonly
Returns the value of attribute order.
-
#order_number ⇒ Object
readonly
Returns the value of attribute order_number.
-
#organization ⇒ Object
readonly
Returns the value of attribute organization.
-
#timestamp ⇒ Object
readonly
Returns the value of attribute timestamp.
Attributes inherited from Event
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ OrderPlaced
constructor
A new instance of OrderPlaced.
- #subtype_to_hash ⇒ Object
- #to_json ⇒ Object
Methods inherited from Event
Constructor Details
#initialize(incoming = {}) ⇒ OrderPlaced
Returns a new instance of OrderPlaced.
38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38383 def initialize(incoming={}) super(:discriminator => Event::Types::ORDER_PLACED) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:event_id, :timestamp, :organization, :order_number, :order, :allocation], 'OrderPlaced') @event_id = HttpClient::Preconditions.assert_class('event_id', opts.delete(:event_id), String) @timestamp = HttpClient::Preconditions.assert_class('timestamp', HttpClient::Helper.to_date_time_iso8601(opts.delete(:timestamp)), DateTime) @organization = HttpClient::Preconditions.assert_class('organization', opts.delete(:organization), String) @order_number = HttpClient::Preconditions.assert_class('order_number', opts.delete(:order_number), String) @order = (x = opts.delete(:order); x.is_a?(::Io::Flow::V0::Models::Order) ? x : ::Io::Flow::V0::Models::Order.new(x)) @allocation = (x = opts.delete(:allocation); x.is_a?(::Io::Flow::V0::Models::AllocationV2) ? x : ::Io::Flow::V0::Models::AllocationV2.new(x)) end |
Instance Attribute Details
#allocation ⇒ Object (readonly)
Returns the value of attribute allocation.
38381 38382 38383 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38381 def allocation @allocation end |
#event_id ⇒ Object (readonly)
Returns the value of attribute event_id.
38381 38382 38383 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38381 def event_id @event_id end |
#order ⇒ Object (readonly)
Returns the value of attribute order.
38381 38382 38383 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38381 def order @order end |
#order_number ⇒ Object (readonly)
Returns the value of attribute order_number.
38381 38382 38383 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38381 def order_number @order_number end |
#organization ⇒ Object (readonly)
Returns the value of attribute organization.
38381 38382 38383 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38381 def organization @organization end |
#timestamp ⇒ Object (readonly)
Returns the value of attribute timestamp.
38381 38382 38383 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38381 def @timestamp end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
38399 38400 38401 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38399 def copy(incoming={}) OrderPlaced.new(subtype_to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#subtype_to_hash ⇒ Object
38403 38404 38405 38406 38407 38408 38409 38410 38411 38412 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38403 def subtype_to_hash { :event_id => event_id, :timestamp => , :organization => organization, :order_number => order_number, :order => order.to_hash, :allocation => allocation.to_hash } end |
#to_json ⇒ Object
38395 38396 38397 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38395 def to_json JSON.dump(to_hash) end |