Class: Io::Flow::V0::Models::OrderPlacedDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Order is submitted, allocations are generated and the total value of the order is accounted for by discounts, subsidies, credits and authorized payments -- but may not ready to fulfill (e.g. pending assignment of a DC or fraud review).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ OrderPlacedDetails



38424
38425
38426
38427
38428
38429
38430
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38424

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:id, :order, :allocation], 'OrderPlacedDetails')
  @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String)
  @order = (x = opts.delete(:order); x.is_a?(::Io::Flow::V0::Models::Order) ? x : ::Io::Flow::V0::Models::Order.new(x))
  @allocation = (x = opts.delete(:allocation); x.is_a?(::Io::Flow::V0::Models::AllocationV2) ? x : ::Io::Flow::V0::Models::AllocationV2.new(x))
end

Instance Attribute Details

#allocationObject (readonly)

Returns the value of attribute allocation.



38422
38423
38424
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38422

def allocation
  @allocation
end

#idObject (readonly)

Returns the value of attribute id.



38422
38423
38424
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38422

def id
  @id
end

#orderObject (readonly)

Returns the value of attribute order.



38422
38423
38424
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38422

def order
  @order
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



38436
38437
38438
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38436

def copy(incoming={})
  OrderPlacedDetails.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hashObject



38440
38441
38442
38443
38444
38445
38446
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38440

def to_hash
  {
    :id => id,
    :order => order.to_hash,
    :allocation => allocation.to_hash
  }
end

#to_jsonObject



38432
38433
38434
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38432

def to_json
  JSON.dump(to_hash)
end