Class: Io::Flow::V0::Models::OrderPriceDetailComponentKey

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ OrderPriceDetailComponentKey

Returns a new instance of OrderPriceDetailComponentKey.



17064
17065
17066
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17064

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



17062
17063
17064
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17062

def value
  @value
end

Class Method Details

.adjustmentObject

A general purpose adjustment applied to the order.



17089
17090
17091
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17089

def OrderPriceDetailComponentKey.adjustment
  @@_adjustment ||= OrderPriceDetailComponentKey.new('adjustment')
end

.ALLObject



17084
17085
17086
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17084

def OrderPriceDetailComponentKey.ALL
  @@all ||= [OrderPriceDetailComponentKey.adjustment, OrderPriceDetailComponentKey.vat_deminimis, OrderPriceDetailComponentKey.duty_deminimis, OrderPriceDetailComponentKey.duties_item_price, OrderPriceDetailComponentKey.duties_freight, OrderPriceDetailComponentKey.duties_insurance, OrderPriceDetailComponentKey.vat_item_price, OrderPriceDetailComponentKey.vat_freight, OrderPriceDetailComponentKey.vat_insurance, OrderPriceDetailComponentKey.vat_duties_item_price, OrderPriceDetailComponentKey.vat_duties_freight, OrderPriceDetailComponentKey.vat_duties_insurance, OrderPriceDetailComponentKey.item_price, OrderPriceDetailComponentKey.item_discount, OrderPriceDetailComponentKey.rounding, OrderPriceDetailComponentKey.insurance, OrderPriceDetailComponentKey.shipping, OrderPriceDetailComponentKey.order_discount, OrderPriceDetailComponentKey.subtotal_percent_sales_margin, OrderPriceDetailComponentKey.subtotal_vat_percent_sales_margin, OrderPriceDetailComponentKey.subtotal_duty_percent_sales_margin, OrderPriceDetailComponentKey.vat_subsidy, OrderPriceDetailComponentKey.duty_subsidy, OrderPriceDetailComponentKey.remote_area_surcharge, OrderPriceDetailComponentKey.fuel_surcharge]
end

.apply(value) ⇒ Object

Returns the instance of OrderPriceDetailComponentKey for this value, creating a new instance for an unknown value



17069
17070
17071
17072
17073
17074
17075
17076
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17069

def OrderPriceDetailComponentKey.apply(value)
  if value.instance_of?(OrderPriceDetailComponentKey)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || OrderPriceDetailComponentKey.new(value))
  end
end

.duties_freightObject

The duty owed on the freight cost of the order.



17110
17111
17112
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17110

def OrderPriceDetailComponentKey.duties_freight
  @@_duties_freight ||= OrderPriceDetailComponentKey.new('duties_freight')
end

.duties_insuranceObject

The duty owed on the insurance cost of the order.



17115
17116
17117
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17115

def OrderPriceDetailComponentKey.duties_insurance
  @@_duties_insurance ||= OrderPriceDetailComponentKey.new('duties_insurance')
end

.duties_item_priceObject

The duty owed on the price of the order's items, including any added margins and rounding.



17105
17106
17107
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17105

def OrderPriceDetailComponentKey.duties_item_price
  @@_duties_item_price ||= OrderPriceDetailComponentKey.new('duties_item_price')
end

.duty_deminimisObject

An adjustment based on whether the duty de minimis applies to the order.



17099
17100
17101
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17099

def OrderPriceDetailComponentKey.duty_deminimis
  @@_duty_deminimis ||= OrderPriceDetailComponentKey.new('duty_deminimis')
end

.duty_subsidyObject

An offset to account for any duty subsidized by the organization. For example, if duty is included in an item price and changes at the order level (due to passing de minimis threshold, or the destination having a more specific duty rate), the difference will be represented here.



17210
17211
17212
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17210

def OrderPriceDetailComponentKey.duty_subsidy
  @@_duty_subsidy ||= OrderPriceDetailComponentKey.new('duty_subsidy')
end

.from_string(value) ⇒ Object

Returns the instance of OrderPriceDetailComponentKey for this value, or nil if not found



17079
17080
17081
17082
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17079

def OrderPriceDetailComponentKey.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  OrderPriceDetailComponentKey.ALL.find { |v| v.value == value }
end

.fuel_surchargeObject

Surcharge applied to a shipment for fuel consumption by the carrier.



17221
17222
17223
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17221

def OrderPriceDetailComponentKey.fuel_surcharge
  @@_fuel_surcharge ||= OrderPriceDetailComponentKey.new('fuel_surcharge')
end

.insuranceObject

The insurance cost for the order.



17168
17169
17170
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17168

def OrderPriceDetailComponentKey.insurance
  @@_insurance ||= OrderPriceDetailComponentKey.new('insurance')
end

.item_discountObject

The sum of all discounts applied to the order's items.



17158
17159
17160
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17158

def OrderPriceDetailComponentKey.item_discount
  @@_item_discount ||= OrderPriceDetailComponentKey.new('item_discount')
end

.item_priceObject

The sum of the price of the order's items with their currency margins, percent margins, and fixed margins included.



17153
17154
17155
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17153

def OrderPriceDetailComponentKey.item_price
  @@_item_price ||= OrderPriceDetailComponentKey.new('item_price')
end

.order_discountObject

A discount applied to the entire order.



17178
17179
17180
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17178

def OrderPriceDetailComponentKey.order_discount
  @@_order_discount ||= OrderPriceDetailComponentKey.new('order_discount')
end

.remote_area_surchargeObject

Surcharge applied to a shipment for delivery to a remote area determined by the carrier.



17216
17217
17218
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17216

def OrderPriceDetailComponentKey.remote_area_surcharge
  @@_remote_area_surcharge ||= OrderPriceDetailComponentKey.new('remote_area_surcharge')
end

.roundingObject

The sum of any rounding applied to the order's items.



17163
17164
17165
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17163

def OrderPriceDetailComponentKey.rounding
  @@_rounding ||= OrderPriceDetailComponentKey.new('rounding')
end

.shippingObject

The shipping cost for the order.



17173
17174
17175
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17173

def OrderPriceDetailComponentKey.shipping
  @@_shipping ||= OrderPriceDetailComponentKey.new('shipping')
end

.subtotal_duty_percent_sales_marginObject

The sum of adjustments to duty owed made due to percentage sales margins.



17194
17195
17196
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17194

def OrderPriceDetailComponentKey.subtotal_duty_percent_sales_margin
  @@_subtotal_duty_percent_sales_margin ||= OrderPriceDetailComponentKey.new('subtotal_duty_percent_sales_margin')
end

.subtotal_percent_sales_marginObject

The sum of adjustments to item price, margin and rounding made due to percentage sales margins.



17184
17185
17186
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17184

def OrderPriceDetailComponentKey.subtotal_percent_sales_margin
  @@_subtotal_percent_sales_margin ||= OrderPriceDetailComponentKey.new('subtotal_percent_sales_margin')
end

.subtotal_vat_percent_sales_marginObject

The sum of adjustments to VAT owed made due to percentage sales margins.



17189
17190
17191
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17189

def OrderPriceDetailComponentKey.subtotal_vat_percent_sales_margin
  @@_subtotal_vat_percent_sales_margin ||= OrderPriceDetailComponentKey.new('subtotal_vat_percent_sales_margin')
end

.vat_deminimisObject

An adjustment based on whether the VAT de minimis applies to the order.



17094
17095
17096
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17094

def OrderPriceDetailComponentKey.vat_deminimis
  @@_vat_deminimis ||= OrderPriceDetailComponentKey.new('vat_deminimis')
end

.vat_duties_freightObject

The VAT owed on the duties on the freight cost of the order.



17142
17143
17144
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17142

def OrderPriceDetailComponentKey.vat_duties_freight
  @@_vat_duties_freight ||= OrderPriceDetailComponentKey.new('vat_duties_freight')
end

.vat_duties_insuranceObject

The VAT owed on the duties on the insurance cost of the order.



17147
17148
17149
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17147

def OrderPriceDetailComponentKey.vat_duties_insurance
  @@_vat_duties_insurance ||= OrderPriceDetailComponentKey.new('vat_duties_insurance')
end

.vat_duties_item_priceObject

The VAT owed on the duties on the price of the order's items, including any added margins and rounding.



17137
17138
17139
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17137

def OrderPriceDetailComponentKey.vat_duties_item_price
  @@_vat_duties_item_price ||= OrderPriceDetailComponentKey.new('vat_duties_item_price')
end

.vat_freightObject

The VAT owed on the freight cost of the order.



17126
17127
17128
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17126

def OrderPriceDetailComponentKey.vat_freight
  @@_vat_freight ||= OrderPriceDetailComponentKey.new('vat_freight')
end

.vat_insuranceObject

The VAT owed on the insurance cost of the order.



17131
17132
17133
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17131

def OrderPriceDetailComponentKey.vat_insurance
  @@_vat_insurance ||= OrderPriceDetailComponentKey.new('vat_insurance')
end

.vat_item_priceObject

The VAT owed on the price of the order's items, including any added margins and rounding.



17121
17122
17123
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17121

def OrderPriceDetailComponentKey.vat_item_price
  @@_vat_item_price ||= OrderPriceDetailComponentKey.new('vat_item_price')
end

.vat_subsidyObject

An offset to account for any VAT subsidized by the organization. For example, if VAT is included in an item price and changes at the order level (due to passing de minimis threshold, or the destination having a more specific VAT rate), the difference will be represented here.



17202
17203
17204
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17202

def OrderPriceDetailComponentKey.vat_subsidy
  @@_vat_subsidy ||= OrderPriceDetailComponentKey.new('vat_subsidy')
end

Instance Method Details

#to_hashObject



17225
17226
17227
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17225

def to_hash
  value
end