Class: Io::Flow::V0::Models::OrderPriceDetailKey

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ OrderPriceDetailKey



21582
21583
21584
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21582

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



21580
21581
21582
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21580

def value
  @value
end

Class Method Details

.adjustmentObject

The details of any adjustments made to the order.



21607
21608
21609
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21607

def OrderPriceDetailKey.adjustment
  @@_adjustment ||= OrderPriceDetailKey.new('adjustment')
end

.ALLObject



21602
21603
21604
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21602

def OrderPriceDetailKey.ALL
  @@all ||= [OrderPriceDetailKey.adjustment, OrderPriceDetailKey.subtotal, OrderPriceDetailKey.vat, OrderPriceDetailKey.duty, OrderPriceDetailKey.shipping, OrderPriceDetailKey.insurance, OrderPriceDetailKey.discount, OrderPriceDetailKey.surcharges]
end

.apply(value) ⇒ Object

Returns the instance of OrderPriceDetailKey for this value, creating a new instance for an unknown value



21587
21588
21589
21590
21591
21592
21593
21594
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21587

def OrderPriceDetailKey.apply(value)
  if value.instance_of?(OrderPriceDetailKey)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || OrderPriceDetailKey.new(value))
  end
end

.discountObject

The details of any discount applied to the order.



21638
21639
21640
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21638

def OrderPriceDetailKey.discount
  @@_discount ||= OrderPriceDetailKey.new('discount')
end

.dutyObject

The details of any duties owed on the order.



21623
21624
21625
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21623

def OrderPriceDetailKey.duty
  @@_duty ||= OrderPriceDetailKey.new('duty')
end

.from_string(value) ⇒ Object

Returns the instance of OrderPriceDetailKey for this value, or nil if not found



21597
21598
21599
21600
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21597

def OrderPriceDetailKey.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  OrderPriceDetailKey.ALL.find { |v| v.value == value }
end

.insuranceObject

The details of insurance costs for the order.



21633
21634
21635
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21633

def OrderPriceDetailKey.insurance
  @@_insurance ||= OrderPriceDetailKey.new('insurance')
end

.shippingObject

The details of shipping costs for the order.



21628
21629
21630
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21628

def OrderPriceDetailKey.shipping
  @@_shipping ||= OrderPriceDetailKey.new('shipping')
end

.subtotalObject

The details of the subtotal for the order, including item prices, margins, and rounding.



21613
21614
21615
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21613

def OrderPriceDetailKey.subtotal
  @@_subtotal ||= OrderPriceDetailKey.new('subtotal')
end

.surchargesObject

Additional fees and levies applied to the order



21643
21644
21645
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21643

def OrderPriceDetailKey.surcharges
  @@_surcharges ||= OrderPriceDetailKey.new('surcharges')
end

.vatObject

The details of any VAT owed on the order.



21618
21619
21620
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21618

def OrderPriceDetailKey.vat
  @@_vat ||= OrderPriceDetailKey.new('vat')
end

Instance Method Details

#to_hashObject



21647
21648
21649
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21647

def to_hash
  value
end