Class: Io::Flow::V0::Models::OrderQuoteErrorCode
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::OrderQuoteErrorCode
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of OrderQuoteErrorCode for this value, creating a new instance for an unknown value.
- .contact_email_invalid ⇒ Object
- .contact_email_required ⇒ Object
- .contact_phone_invalid ⇒ Object
- .contact_phone_required ⇒ Object
- .country_not_supported ⇒ Object
- .currency_invalid ⇒ Object
- .first_name_invalid ⇒ Object
- .first_name_required ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of OrderQuoteErrorCode for this value, or nil if not found.
- .geo_required_when_no_session ⇒ Object
- .language_invalid ⇒ Object
- .last_name_invalid ⇒ Object
- .last_name_required ⇒ Object
- .line_item_number_invalid ⇒ Object
- .line_item_number_not_available ⇒ Object
- .line_not_found ⇒ Object
- .line_quantity_invalid ⇒ Object
- .line_value_threshold_exceeded ⇒ Object
- .name_missing_first_or_last ⇒ Object
- .name_required ⇒ Object
- .order_quote_requires_at_least_one_line ⇒ Object
- .session_not_found ⇒ Object
- .session_organization_mismatch ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ OrderQuoteErrorCode
constructor
A new instance of OrderQuoteErrorCode.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ OrderQuoteErrorCode
Returns a new instance of OrderQuoteErrorCode.
21695 21696 21697 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21695 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
21693 21694 21695 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21693 def value @value end |
Class Method Details
.ALL ⇒ Object
.apply(value) ⇒ Object
Returns the instance of OrderQuoteErrorCode for this value, creating a new instance for an unknown value
21700 21701 21702 21703 21704 21705 21706 21707 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21700 def OrderQuoteErrorCode.apply(value) if value.instance_of?(OrderQuoteErrorCode) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || OrderQuoteErrorCode.new(value)) end end |
.contact_email_invalid ⇒ Object
21719 21720 21721 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21719 def OrderQuoteErrorCode.contact_email_invalid @@_contact_email_invalid ||= OrderQuoteErrorCode.new('contact_email_invalid') end |
.contact_email_required ⇒ Object
21723 21724 21725 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21723 def OrderQuoteErrorCode.contact_email_required @@_contact_email_required ||= OrderQuoteErrorCode.new('contact_email_required') end |
.contact_phone_invalid ⇒ Object
21727 21728 21729 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21727 def OrderQuoteErrorCode.contact_phone_invalid @@_contact_phone_invalid ||= OrderQuoteErrorCode.new('contact_phone_invalid') end |
.contact_phone_required ⇒ Object
21731 21732 21733 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21731 def OrderQuoteErrorCode.contact_phone_required @@_contact_phone_required ||= OrderQuoteErrorCode.new('contact_phone_required') end |
.country_not_supported ⇒ Object
21735 21736 21737 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21735 def OrderQuoteErrorCode.country_not_supported @@_country_not_supported ||= OrderQuoteErrorCode.new('country_not_supported') end |
.currency_invalid ⇒ Object
21739 21740 21741 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21739 def OrderQuoteErrorCode.currency_invalid @@_currency_invalid ||= OrderQuoteErrorCode.new('currency_invalid') end |
.first_name_invalid ⇒ Object
21743 21744 21745 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21743 def OrderQuoteErrorCode.first_name_invalid @@_first_name_invalid ||= OrderQuoteErrorCode.new('first_name_invalid') end |
.first_name_required ⇒ Object
21747 21748 21749 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21747 def OrderQuoteErrorCode.first_name_required @@_first_name_required ||= OrderQuoteErrorCode.new('first_name_required') end |
.from_string(value) ⇒ Object
Returns the instance of OrderQuoteErrorCode for this value, or nil if not found
21710 21711 21712 21713 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21710 def OrderQuoteErrorCode.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) OrderQuoteErrorCode.ALL.find { |v| v.value == value } end |
.geo_required_when_no_session ⇒ Object
21751 21752 21753 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21751 def OrderQuoteErrorCode.geo_required_when_no_session @@_geo_required_when_no_session ||= OrderQuoteErrorCode.new('geo_required_when_no_session') end |
.language_invalid ⇒ Object
21755 21756 21757 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21755 def OrderQuoteErrorCode.language_invalid @@_language_invalid ||= OrderQuoteErrorCode.new('language_invalid') end |
.last_name_invalid ⇒ Object
21759 21760 21761 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21759 def OrderQuoteErrorCode.last_name_invalid @@_last_name_invalid ||= OrderQuoteErrorCode.new('last_name_invalid') end |
.last_name_required ⇒ Object
21763 21764 21765 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21763 def OrderQuoteErrorCode.last_name_required @@_last_name_required ||= OrderQuoteErrorCode.new('last_name_required') end |
.line_item_number_invalid ⇒ Object
21767 21768 21769 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21767 def OrderQuoteErrorCode.line_item_number_invalid @@_line_item_number_invalid ||= OrderQuoteErrorCode.new('line_item_number_invalid') end |
.line_item_number_not_available ⇒ Object
21771 21772 21773 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21771 def OrderQuoteErrorCode.line_item_number_not_available @@_line_item_number_not_available ||= OrderQuoteErrorCode.new('line_item_number_not_available') end |
.line_not_found ⇒ Object
21775 21776 21777 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21775 def OrderQuoteErrorCode.line_not_found @@_line_not_found ||= OrderQuoteErrorCode.new('line_not_found') end |
.line_quantity_invalid ⇒ Object
21779 21780 21781 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21779 def OrderQuoteErrorCode.line_quantity_invalid @@_line_quantity_invalid ||= OrderQuoteErrorCode.new('line_quantity_invalid') end |
.line_value_threshold_exceeded ⇒ Object
21783 21784 21785 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21783 def OrderQuoteErrorCode.line_value_threshold_exceeded @@_line_value_threshold_exceeded ||= OrderQuoteErrorCode.new('line_value_threshold_exceeded') end |
.name_missing_first_or_last ⇒ Object
21787 21788 21789 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21787 def OrderQuoteErrorCode.name_missing_first_or_last @@_name_missing_first_or_last ||= OrderQuoteErrorCode.new('name_missing_first_or_last') end |
.name_required ⇒ Object
21791 21792 21793 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21791 def OrderQuoteErrorCode.name_required @@_name_required ||= OrderQuoteErrorCode.new('name_required') end |
.order_quote_requires_at_least_one_line ⇒ Object
21795 21796 21797 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21795 def OrderQuoteErrorCode.order_quote_requires_at_least_one_line @@_order_quote_requires_at_least_one_line ||= OrderQuoteErrorCode.new('order_quote_requires_at_least_one_line') end |
.session_not_found ⇒ Object
21799 21800 21801 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21799 def OrderQuoteErrorCode.session_not_found @@_session_not_found ||= OrderQuoteErrorCode.new('session_not_found') end |
.session_organization_mismatch ⇒ Object
21803 21804 21805 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21803 def OrderQuoteErrorCode.session_organization_mismatch @@_session_organization_mismatch ||= OrderQuoteErrorCode.new('session_organization_mismatch') end |
Instance Method Details
#to_hash ⇒ Object
21807 21808 21809 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21807 def to_hash value end |