Class: Io::Flow::V0::Models::OrderServiceChangeForm

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Manual change for a shipping method used for an order. Currently only available to orders with a single calculated delivery. To help with orders with multiple deliveries, we will require verification of both the current service level (from) and the new service level (to).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ OrderServiceChangeForm

Returns a new instance of OrderServiceChangeForm.



50188
50189
50190
50191
50192
50193
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 50188

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:from_service_id, :to_service_id], 'OrderServiceChangeForm')
  @from_service_id = HttpClient::Preconditions.assert_class('from_service_id', opts.delete(:from_service_id), String)
  @to_service_id = HttpClient::Preconditions.assert_class('to_service_id', opts.delete(:to_service_id), String)
end

Instance Attribute Details

#from_service_idObject (readonly)

Returns the value of attribute from_service_id.



50186
50187
50188
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 50186

def from_service_id
  @from_service_id
end

#to_service_idObject (readonly)

Returns the value of attribute to_service_id.



50186
50187
50188
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 50186

def to_service_id
  @to_service_id
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



50199
50200
50201
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 50199

def copy(incoming={})
  OrderServiceChangeForm.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hashObject



50203
50204
50205
50206
50207
50208
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 50203

def to_hash
  {
    :from_service_id => from_service_id,
    :to_service_id => to_service_id
  }
end

#to_jsonObject



50195
50196
50197
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 50195

def to_json
  JSON.dump(to_hash)
end