Class: Io::Flow::V0::Models::OrderStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ OrderStatus

Returns a new instance of OrderStatus.



21963
21964
21965
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21963

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



21961
21962
21963
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21961

def value
  @value
end

Class Method Details

.ALLObject



21983
21984
21985
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21983

def OrderStatus.ALL
  @@all ||= [OrderStatus.open, OrderStatus.]
end

.apply(value) ⇒ Object

Returns the instance of OrderStatus for this value, creating a new instance for an unknown value



21968
21969
21970
21971
21972
21973
21974
21975
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21968

def OrderStatus.apply(value)
  if value.instance_of?(OrderStatus)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || OrderStatus.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of OrderStatus for this value, or nil if not found



21978
21979
21980
21981
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21978

def OrderStatus.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  OrderStatus.ALL.find { |v| v.value == value }
end

.openObject



21987
21988
21989
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21987

def OrderStatus.open
  @@_open ||= OrderStatus.new('open')
end

.submittedObject



21991
21992
21993
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21991

def OrderStatus.
   ||= OrderStatus.new('submitted')
end

Instance Method Details

#to_hashObject



21995
21996
21997
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21995

def to_hash
  value
end