Class: Io::Flow::V0::Models::OrderSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

The order summary is a view of the order summary object with the order prices flattened to keys.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ OrderSummary

Returns a new instance of OrderSummary.



38911
38912
38913
38914
38915
38916
38917
38918
38919
38920
38921
38922
38923
38924
38925
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38911

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:number, :subtotal, :total, :lines], 'OrderSummary')
  @number = HttpClient::Preconditions.assert_class('number', opts.delete(:number), String)
  @subtotal = (x = opts.delete(:subtotal); x.is_a?(::Io::Flow::V0::Models::OrderSummaryPriceDetail) ? x : ::Io::Flow::V0::Models::OrderSummaryPriceDetail.new(x))
  @shipping = (x = opts.delete(:shipping); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::OrderSummaryPriceDetail) ? x : ::Io::Flow::V0::Models::OrderSummaryPriceDetail.new(x)))
  @tax = (x = opts.delete(:tax); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::OrderSummaryPriceDetail) ? x : ::Io::Flow::V0::Models::OrderSummaryPriceDetail.new(x)))
  @duty = (x = opts.delete(:duty); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::OrderSummaryPriceDetail) ? x : ::Io::Flow::V0::Models::OrderSummaryPriceDetail.new(x)))
  @insurance = (x = opts.delete(:insurance); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::OrderSummaryPriceDetail) ? x : ::Io::Flow::V0::Models::OrderSummaryPriceDetail.new(x)))
  @discount = (x = opts.delete(:discount); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::OrderSummaryPriceDetail) ? x : ::Io::Flow::V0::Models::OrderSummaryPriceDetail.new(x)))
  @surcharges = (x = opts.delete(:surcharges); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::OrderSummaryPriceDetail) ? x : ::Io::Flow::V0::Models::OrderSummaryPriceDetail.new(x)))
  @adjustment = (x = opts.delete(:adjustment); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::OrderSummaryPriceDetail) ? x : ::Io::Flow::V0::Models::OrderSummaryPriceDetail.new(x)))
  @total = (x = opts.delete(:total); x.is_a?(::Io::Flow::V0::Models::OrderSummaryPriceDetail) ? x : ::Io::Flow::V0::Models::OrderSummaryPriceDetail.new(x))
  @lines = HttpClient::Preconditions.assert_class('lines', opts.delete(:lines), Array).map { |v| (x = v; x.is_a?(::Io::Flow::V0::Models::OrderSummaryLineItem) ? x : ::Io::Flow::V0::Models::OrderSummaryLineItem.new(x)) }
end

Instance Attribute Details

#adjustmentObject (readonly)

Returns the value of attribute adjustment.



38909
38910
38911
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38909

def adjustment
  @adjustment
end

#discountObject (readonly)

Returns the value of attribute discount.



38909
38910
38911
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38909

def discount
  @discount
end

#dutyObject (readonly)

Returns the value of attribute duty.



38909
38910
38911
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38909

def duty
  @duty
end

#insuranceObject (readonly)

Returns the value of attribute insurance.



38909
38910
38911
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38909

def insurance
  @insurance
end

#linesObject (readonly)

Returns the value of attribute lines.



38909
38910
38911
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38909

def lines
  @lines
end

#numberObject (readonly)

Returns the value of attribute number.



38909
38910
38911
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38909

def number
  @number
end

#shippingObject (readonly)

Returns the value of attribute shipping.



38909
38910
38911
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38909

def shipping
  @shipping
end

#subtotalObject (readonly)

Returns the value of attribute subtotal.



38909
38910
38911
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38909

def subtotal
  @subtotal
end

#surchargesObject (readonly)

Returns the value of attribute surcharges.



38909
38910
38911
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38909

def surcharges
  @surcharges
end

#taxObject (readonly)

Returns the value of attribute tax.



38909
38910
38911
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38909

def tax
  @tax
end

#totalObject (readonly)

Returns the value of attribute total.



38909
38910
38911
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38909

def total
  @total
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



38931
38932
38933
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38931

def copy(incoming={})
  OrderSummary.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hashObject



38935
38936
38937
38938
38939
38940
38941
38942
38943
38944
38945
38946
38947
38948
38949
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38935

def to_hash
  {
    :number => number,
    :subtotal => subtotal.to_hash,
    :shipping => shipping.nil? ? nil : shipping.to_hash,
    :tax => tax.nil? ? nil : tax.to_hash,
    :duty => duty.nil? ? nil : duty.to_hash,
    :insurance => insurance.nil? ? nil : insurance.to_hash,
    :discount => discount.nil? ? nil : discount.to_hash,
    :surcharges => surcharges.nil? ? nil : surcharges.to_hash,
    :adjustment => adjustment.nil? ? nil : adjustment.to_hash,
    :total => total.to_hash,
    :lines => lines.map { |o| o.to_hash }
  }
end

#to_jsonObject



38927
38928
38929
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38927

def to_json
  JSON.dump(to_hash)
end