Class: Io::Flow::V0::Models::OrganizationPaymentMethodTag

Inherits:
PaymentMethodTag show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Attributes inherited from PaymentMethodTag

#discriminator

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from PaymentMethodTag

from_json, #to_hash

Constructor Details

#initialize(value) ⇒ OrganizationPaymentMethodTag

Returns a new instance of OrganizationPaymentMethodTag.



17352
17353
17354
17355
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17352

def initialize(value)
  super(:name => PaymentMethodTag::Types::ORGANIZATION_PAYMENT_METHOD_TAG, :discriminator => 'organization_payment_method_tag')
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



17350
17351
17352
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17350

def value
  @value
end

Class Method Details

.ALLObject



17373
17374
17375
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17373

def OrganizationPaymentMethodTag.ALL
  @@all ||= [OrganizationPaymentMethodTag.deny]
end

.apply(value) ⇒ Object

Returns the instance of OrganizationPaymentMethodTag for this value, creating a new instance for an unknown value



17358
17359
17360
17361
17362
17363
17364
17365
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17358

def OrganizationPaymentMethodTag.apply(value)
  if value.instance_of?(OrganizationPaymentMethodTag)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || OrganizationPaymentMethodTag.new(value))
  end
end

.denyObject

A denied payment method cannot be used for an organization in any experience.



17378
17379
17380
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17378

def OrganizationPaymentMethodTag.deny
  @@_deny ||= OrganizationPaymentMethodTag.new('deny')
end

.from_string(value) ⇒ Object

Returns the instance of OrganizationPaymentMethodTag for this value, or nil if not found



17368
17369
17370
17371
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17368

def OrganizationPaymentMethodTag.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  OrganizationPaymentMethodTag.ALL.find { |v| v.value == value }
end

Instance Method Details

#subtype_to_hashObject



17382
17383
17384
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17382

def subtype_to_hash
  value
end