Class: Io::Flow::V0::Models::PaymentMethodDataOptionType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::PaymentMethodDataOptionType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of PaymentMethodDataOptionType for this value, creating a new instance for an unknown value.
-
.from_string(value) ⇒ Object
Returns the instance of PaymentMethodDataOptionType for this value, or nil if not found.
-
.ideal_issuer_option ⇒ Object
Describes the process of selecting ideal issuers options.
Instance Method Summary collapse
-
#initialize(value) ⇒ PaymentMethodDataOptionType
constructor
A new instance of PaymentMethodDataOptionType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ PaymentMethodDataOptionType
Returns a new instance of PaymentMethodDataOptionType.
22504 22505 22506 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22504 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
22502 22503 22504 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22502 def value @value end |
Class Method Details
.ALL ⇒ Object
22524 22525 22526 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22524 def PaymentMethodDataOptionType.ALL @@all ||= [PaymentMethodDataOptionType.ideal_issuer_option] end |
.apply(value) ⇒ Object
Returns the instance of PaymentMethodDataOptionType for this value, creating a new instance for an unknown value
22509 22510 22511 22512 22513 22514 22515 22516 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22509 def PaymentMethodDataOptionType.apply(value) if value.instance_of?(PaymentMethodDataOptionType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || PaymentMethodDataOptionType.new(value)) end end |
.from_string(value) ⇒ Object
Returns the instance of PaymentMethodDataOptionType for this value, or nil if not found
22519 22520 22521 22522 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22519 def PaymentMethodDataOptionType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) PaymentMethodDataOptionType.ALL.find { |v| v.value == value } end |
.ideal_issuer_option ⇒ Object
Describes the process of selecting ideal issuers options
22529 22530 22531 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22529 def PaymentMethodDataOptionType.ideal_issuer_option @@_ideal_issuer_option ||= PaymentMethodDataOptionType.new('ideal_issuer_option') end |
Instance Method Details
#to_hash ⇒ Object
22533 22534 22535 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22533 def to_hash value end |