Module: Io::Flow::V0::Models::PaymentOrderReference::Types

Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Constant Summary collapse

AUTHORIZATION_ORDER_REFERENCE =

Use this option if you are integrated with Flow orders.

'flow_order'
PAYMENT_PAYMENT_REQUEST_REFERENCE =

Use this option if you are integrated with Flow Payment Gateway.

'payment_request'