Class: Io::Flow::V0::Models::PaymentSourceConfirmationActionType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::PaymentSourceConfirmationActionType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of PaymentSourceConfirmationActionType for this value, creating a new instance for an unknown value.
- .billing_address ⇒ Object
- .cvv ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of PaymentSourceConfirmationActionType for this value, or nil if not found.
- .number ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ PaymentSourceConfirmationActionType
constructor
A new instance of PaymentSourceConfirmationActionType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ PaymentSourceConfirmationActionType
17557 17558 17559 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17557 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
17555 17556 17557 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17555 def value @value end |
Class Method Details
.ALL ⇒ Object
17577 17578 17579 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17577 def PaymentSourceConfirmationActionType.ALL @@all ||= [PaymentSourceConfirmationActionType.cvv, PaymentSourceConfirmationActionType.billing_address, PaymentSourceConfirmationActionType.number] end |
.apply(value) ⇒ Object
Returns the instance of PaymentSourceConfirmationActionType for this value, creating a new instance for an unknown value
17562 17563 17564 17565 17566 17567 17568 17569 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17562 def PaymentSourceConfirmationActionType.apply(value) if value.instance_of?(PaymentSourceConfirmationActionType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || PaymentSourceConfirmationActionType.new(value)) end end |
.billing_address ⇒ Object
17585 17586 17587 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17585 def PaymentSourceConfirmationActionType.billing_address @@_billing_address ||= PaymentSourceConfirmationActionType.new('billing_address') end |
.cvv ⇒ Object
17581 17582 17583 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17581 def PaymentSourceConfirmationActionType.cvv @@_cvv ||= PaymentSourceConfirmationActionType.new('cvv') end |
.from_string(value) ⇒ Object
Returns the instance of PaymentSourceConfirmationActionType for this value, or nil if not found
17572 17573 17574 17575 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17572 def PaymentSourceConfirmationActionType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) PaymentSourceConfirmationActionType.ALL.find { |v| v.value == value } end |
.number ⇒ Object
17589 17590 17591 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17589 def PaymentSourceConfirmationActionType.number @@_number ||= PaymentSourceConfirmationActionType.new('number') end |
Instance Method Details
#to_hash ⇒ Object
17593 17594 17595 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17593 def to_hash value end |