Class: Io::Flow::V0::Models::PriceDetailComponentKey
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::PriceDetailComponentKey
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of PriceDetailComponentKey for this value, creating a new instance for an unknown value.
-
.base_price ⇒ Object
The base price of the item.
-
.currency_margin ⇒ Object
The amount added to the post-discount item price due to FX markup, as configured in the organization's currency settings.
-
.discount ⇒ Object
A discount applied to the base price of the item.
-
.duties_added_margin ⇒ Object
The duty owed on the sum of the currency margin, percent item margin, and fixed item margin.
-
.duties_deminimis ⇒ Object
An adjustment made if the item does not meet the duty de minimis rule.
-
.duties_item_price ⇒ Object
The duty owed on the post-discount base item price.
-
.duties_rounding ⇒ Object
The duty owed on any rounding applied to the total item price.
-
.duty_percent_sales_margin ⇒ Object
An adjustment made to duty owed as a result of a percent sales margin.
-
.fixed_item_margin ⇒ Object
The amount added to the post-discount item price from a fixed item margin.
-
.from_string(value) ⇒ Object
Returns the instance of PriceDetailComponentKey for this value, or nil if not found.
-
.item_price_percent_sales_margin ⇒ Object
An adjustment made to the item price as a result of a percent sales margin.
-
.margins_percent_sales_margin ⇒ Object
An adjustment made to the item margins as a result of a percent sales margin.
-
.percent_item_margin ⇒ Object
The amount added to the post-discount item price from a percent item margin.
-
.rounding_percent_sales_margin ⇒ Object
An adjustment made to rounding as a result of a percent sales margin.
-
.vat_added_margin ⇒ Object
The VAT owed on the sum of the currency margin, percent item margin, and fixed item margin.
-
.vat_deminimis ⇒ Object
An adjustment made if the item does not meet the VAT de minimis rule.
-
.vat_duties_added_margin ⇒ Object
The VAT owed on the duty owed on the sum of the currency margin, percent item margin, and fixed item margin.
-
.vat_duties_item_price ⇒ Object
The VAT owed on the duty owed on the post-discount base item price.
-
.vat_duties_rounding ⇒ Object
The VAT owed on the duty owed on any rounding applied to the total item price.
-
.vat_duty_percent_sales_margin ⇒ Object
An adjustment made to VAT on duties (e.g. VAT on duties on item price) owed as a result of a percent sales margin.
-
.vat_item_price ⇒ Object
The VAT owed on the post-discount base item price.
-
.vat_percent_sales_margin ⇒ Object
An adjustment made to VAT owed as a result of a percent sales margin.
-
.vat_rounding ⇒ Object
The VAT owed on any rounding applied to the total item price.
Instance Method Summary collapse
-
#initialize(value) ⇒ PriceDetailComponentKey
constructor
A new instance of PriceDetailComponentKey.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ PriceDetailComponentKey
Returns a new instance of PriceDetailComponentKey.
17795 17796 17797 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17795 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
17793 17794 17795 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17793 def value @value end |
Class Method Details
.ALL ⇒ Object
.apply(value) ⇒ Object
Returns the instance of PriceDetailComponentKey for this value, creating a new instance for an unknown value
17800 17801 17802 17803 17804 17805 17806 17807 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17800 def PriceDetailComponentKey.apply(value) if value.instance_of?(PriceDetailComponentKey) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || PriceDetailComponentKey.new(value)) end end |
.base_price ⇒ Object
The base price of the item.
17820 17821 17822 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17820 def PriceDetailComponentKey.base_price @@_base_price ||= PriceDetailComponentKey.new('base_price') end |
.currency_margin ⇒ Object
The amount added to the post-discount item price due to FX markup, as configured in the organization's currency settings.
17831 17832 17833 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17831 def PriceDetailComponentKey.currency_margin @@_currency_margin ||= PriceDetailComponentKey.new('currency_margin') end |
.discount ⇒ Object
A discount applied to the base price of the item.
17825 17826 17827 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17825 def PriceDetailComponentKey.discount @@_discount ||= PriceDetailComponentKey.new('discount') end |
.duties_added_margin ⇒ Object
The duty owed on the sum of the currency margin, percent item margin, and fixed item margin.
17854 17855 17856 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17854 def PriceDetailComponentKey.duties_added_margin @@_duties_added_margin ||= PriceDetailComponentKey.new('duties_added_margin') end |
.duties_deminimis ⇒ Object
An adjustment made if the item does not meet the duty de minimis rule.
17864 17865 17866 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17864 def PriceDetailComponentKey.duties_deminimis @@_duties_deminimis ||= PriceDetailComponentKey.new('duties_deminimis') end |
.duties_item_price ⇒ Object
The duty owed on the post-discount base item price.
17848 17849 17850 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17848 def PriceDetailComponentKey.duties_item_price @@_duties_item_price ||= PriceDetailComponentKey.new('duties_item_price') end |
.duties_rounding ⇒ Object
The duty owed on any rounding applied to the total item price.
17859 17860 17861 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17859 def PriceDetailComponentKey.duties_rounding @@_duties_rounding ||= PriceDetailComponentKey.new('duties_rounding') end |
.duty_percent_sales_margin ⇒ Object
An adjustment made to duty owed as a result of a percent sales margin.
17932 17933 17934 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17932 def PriceDetailComponentKey.duty_percent_sales_margin @@_duty_percent_sales_margin ||= PriceDetailComponentKey.new('duty_percent_sales_margin') end |
.fixed_item_margin ⇒ Object
The amount added to the post-discount item price from a fixed item margin. Negative amounts represent discounts.
17843 17844 17845 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17843 def PriceDetailComponentKey.fixed_item_margin @@_fixed_item_margin ||= PriceDetailComponentKey.new('fixed_item_margin') end |
.from_string(value) ⇒ Object
Returns the instance of PriceDetailComponentKey for this value, or nil if not found
17810 17811 17812 17813 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17810 def PriceDetailComponentKey.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) PriceDetailComponentKey.ALL.find { |v| v.value == value } end |
.item_price_percent_sales_margin ⇒ Object
An adjustment made to the item price as a result of a percent sales margin.
17906 17907 17908 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17906 def PriceDetailComponentKey.item_price_percent_sales_margin @@_item_price_percent_sales_margin ||= PriceDetailComponentKey.new('item_price_percent_sales_margin') end |
.margins_percent_sales_margin ⇒ Object
An adjustment made to the item margins as a result of a percent sales margin.
17911 17912 17913 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17911 def PriceDetailComponentKey.margins_percent_sales_margin @@_margins_percent_sales_margin ||= PriceDetailComponentKey.new('margins_percent_sales_margin') end |
.percent_item_margin ⇒ Object
The amount added to the post-discount item price from a percent item margin. Negative amounts represent discounts.
17837 17838 17839 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17837 def PriceDetailComponentKey.percent_item_margin @@_percent_item_margin ||= PriceDetailComponentKey.new('percent_item_margin') end |
.rounding_percent_sales_margin ⇒ Object
An adjustment made to rounding as a result of a percent sales margin.
17916 17917 17918 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17916 def PriceDetailComponentKey.rounding_percent_sales_margin @@_rounding_percent_sales_margin ||= PriceDetailComponentKey.new('rounding_percent_sales_margin') end |
.vat_added_margin ⇒ Object
The VAT owed on the sum of the currency margin, percent item margin, and fixed item margin.
17875 17876 17877 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17875 def PriceDetailComponentKey.vat_added_margin @@_vat_added_margin ||= PriceDetailComponentKey.new('vat_added_margin') end |
.vat_deminimis ⇒ Object
An adjustment made if the item does not meet the VAT de minimis rule.
17901 17902 17903 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17901 def PriceDetailComponentKey.vat_deminimis @@_vat_deminimis ||= PriceDetailComponentKey.new('vat_deminimis') end |
.vat_duties_added_margin ⇒ Object
The VAT owed on the duty owed on the sum of the currency margin, percent item margin, and fixed item margin.
17891 17892 17893 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17891 def PriceDetailComponentKey.vat_duties_added_margin @@_vat_duties_added_margin ||= PriceDetailComponentKey.new('vat_duties_added_margin') end |
.vat_duties_item_price ⇒ Object
The VAT owed on the duty owed on the post-discount base item price.
17885 17886 17887 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17885 def PriceDetailComponentKey.vat_duties_item_price @@_vat_duties_item_price ||= PriceDetailComponentKey.new('vat_duties_item_price') end |
.vat_duties_rounding ⇒ Object
The VAT owed on the duty owed on any rounding applied to the total item price.
17896 17897 17898 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17896 def PriceDetailComponentKey.vat_duties_rounding @@_vat_duties_rounding ||= PriceDetailComponentKey.new('vat_duties_rounding') end |
.vat_duty_percent_sales_margin ⇒ Object
An adjustment made to VAT on duties (e.g. VAT on duties on item price) owed as a result of a percent sales margin.
17927 17928 17929 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17927 def PriceDetailComponentKey.vat_duty_percent_sales_margin @@_vat_duty_percent_sales_margin ||= PriceDetailComponentKey.new('vat_duty_percent_sales_margin') end |
.vat_item_price ⇒ Object
The VAT owed on the post-discount base item price.
17869 17870 17871 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17869 def PriceDetailComponentKey.vat_item_price @@_vat_item_price ||= PriceDetailComponentKey.new('vat_item_price') end |
.vat_percent_sales_margin ⇒ Object
An adjustment made to VAT owed as a result of a percent sales margin.
17921 17922 17923 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17921 def PriceDetailComponentKey.vat_percent_sales_margin @@_vat_percent_sales_margin ||= PriceDetailComponentKey.new('vat_percent_sales_margin') end |
.vat_rounding ⇒ Object
The VAT owed on any rounding applied to the total item price.
17880 17881 17882 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17880 def PriceDetailComponentKey.vat_rounding @@_vat_rounding ||= PriceDetailComponentKey.new('vat_rounding') end |
Instance Method Details
#to_hash ⇒ Object
17936 17937 17938 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17936 def to_hash value end |