Class: Io::Flow::V0::Models::PriceDetailKey
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::PriceDetailKey
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
-
.adjustment ⇒ Object
The details of any price adjustments due to sales margins.
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of PriceDetailKey for this value, creating a new instance for an unknown value.
-
.duty ⇒ Object
The details of any duties owed on the item.
-
.from_string(value) ⇒ Object
Returns the instance of PriceDetailKey for this value, or nil if not found.
-
.item_price ⇒ Object
The details of the item price.
-
.margins ⇒ Object
The details of any margins added to the item price.
-
.rounding ⇒ Object
The details of any rounding added to the item.
-
.vat ⇒ Object
The details of any VAT owed on the item.
Instance Method Summary collapse
-
#initialize(value) ⇒ PriceDetailKey
constructor
A new instance of PriceDetailKey.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ PriceDetailKey
Returns a new instance of PriceDetailKey.
17946 17947 17948 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17946 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
17944 17945 17946 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17944 def value @value end |
Class Method Details
.adjustment ⇒ Object
The details of any price adjustments due to sales margins. A negative value indicates a discount.
17997 17998 17999 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17997 def PriceDetailKey.adjustment @@_adjustment ||= PriceDetailKey.new('adjustment') end |
.ALL ⇒ Object
17966 17967 17968 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17966 def PriceDetailKey.ALL @@all ||= [PriceDetailKey.item_price, PriceDetailKey.margins, PriceDetailKey.vat, PriceDetailKey.duty, PriceDetailKey.rounding, PriceDetailKey.adjustment] end |
.apply(value) ⇒ Object
Returns the instance of PriceDetailKey for this value, creating a new instance for an unknown value
17951 17952 17953 17954 17955 17956 17957 17958 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17951 def PriceDetailKey.apply(value) if value.instance_of?(PriceDetailKey) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || PriceDetailKey.new(value)) end end |
.duty ⇒ Object
The details of any duties owed on the item.
17986 17987 17988 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17986 def PriceDetailKey.duty @@_duty ||= PriceDetailKey.new('duty') end |
.from_string(value) ⇒ Object
Returns the instance of PriceDetailKey for this value, or nil if not found
17961 17962 17963 17964 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17961 def PriceDetailKey.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) PriceDetailKey.ALL.find { |v| v.value == value } end |
.item_price ⇒ Object
The details of the item price.
17971 17972 17973 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17971 def PriceDetailKey.item_price @@_item_price ||= PriceDetailKey.new('item_price') end |
.margins ⇒ Object
The details of any margins added to the item price.
17976 17977 17978 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17976 def PriceDetailKey.margins @@_margins ||= PriceDetailKey.new('margins') end |
.rounding ⇒ Object
The details of any rounding added to the item.
17991 17992 17993 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17991 def PriceDetailKey.rounding @@_rounding ||= PriceDetailKey.new('rounding') end |
.vat ⇒ Object
The details of any VAT owed on the item.
17981 17982 17983 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17981 def PriceDetailKey.vat @@_vat ||= PriceDetailKey.new('vat') end |
Instance Method Details
#to_hash ⇒ Object
18001 18002 18003 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18001 def to_hash value end |