Class: Io::Flow::V0::Models::PriceForm

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Amount-currency paid for a basic price to be used in model forms, before a price label is created. Label in the main price model is created by the implementing api.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ PriceForm

Returns a new instance of PriceForm.



18352
18353
18354
18355
18356
18357
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18352

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:amount, :currency], 'PriceForm')
  @amount = HttpClient::Preconditions.assert_class('amount', opts.delete(:amount), Numeric)
  @currency = HttpClient::Preconditions.assert_class('currency', opts.delete(:currency), String)
end

Instance Attribute Details

#amount ⇒ Object (readonly)

Returns the value of attribute amount.



18350
18351
18352
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18350

def amount
  @amount
end

#currency ⇒ Object (readonly)

Returns the value of attribute currency.



18350
18351
18352
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18350

def currency
  @currency
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



18363
18364
18365
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18363

def copy(incoming={})
  PriceForm.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hash ⇒ Object



18367
18368
18369
18370
18371
18372
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18367

def to_hash
  {
    :amount => amount,
    :currency => currency
  }
end

#to_json ⇒ Object



18359
18360
18361
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18359

def to_json
  JSON.dump(to_hash)
end