Class: Io::Flow::V0::Models::PricingLevySetting
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::PricingLevySetting
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of PricingLevySetting for this value, creating a new instance for an unknown value.
- .displayed ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of PricingLevySetting for this value, or nil if not found.
- .ignored ⇒ Object
- .included ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ PricingLevySetting
constructor
A new instance of PricingLevySetting.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ PricingLevySetting
Returns a new instance of PricingLevySetting.
18011 18012 18013 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18011 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
18009 18010 18011 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18009 def value @value end |
Class Method Details
.ALL ⇒ Object
18031 18032 18033 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18031 def PricingLevySetting.ALL @@all ||= [PricingLevySetting.included, PricingLevySetting.displayed, PricingLevySetting.ignored] end |
.apply(value) ⇒ Object
Returns the instance of PricingLevySetting for this value, creating a new instance for an unknown value
18016 18017 18018 18019 18020 18021 18022 18023 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18016 def PricingLevySetting.apply(value) if value.instance_of?(PricingLevySetting) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || PricingLevySetting.new(value)) end end |
.displayed ⇒ Object
18039 18040 18041 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18039 def PricingLevySetting.displayed @@_displayed ||= PricingLevySetting.new('displayed') end |
.from_string(value) ⇒ Object
Returns the instance of PricingLevySetting for this value, or nil if not found
18026 18027 18028 18029 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18026 def PricingLevySetting.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) PricingLevySetting.ALL.find { |v| v.value == value } end |
.ignored ⇒ Object
18043 18044 18045 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18043 def PricingLevySetting.ignored @@_ignored ||= PricingLevySetting.new('ignored') end |
.included ⇒ Object
18035 18036 18037 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18035 def PricingLevySetting.included @@_included ||= PricingLevySetting.new('included') end |
Instance Method Details
#to_hash ⇒ Object
18047 18048 18049 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18047 def to_hash value end |