Class: Io::Flow::V0::Models::QueryType

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ QueryType

Returns a new instance of QueryType.



18186
18187
18188
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18186

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



18184
18185
18186
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18184

def value
  @value
end

Class Method Details

.ALLObject



18206
18207
18208
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18206

def QueryType.ALL
  @@all ||= [QueryType.exclusion, QueryType.inclusion]
end

.apply(value) ⇒ Object

Returns the instance of QueryType for this value, creating a new instance for an unknown value



18191
18192
18193
18194
18195
18196
18197
18198
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18191

def QueryType.apply(value)
  if value.instance_of?(QueryType)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || QueryType.new(value))
  end
end

.exclusionObject

Exclude items satisfied by the associated query



18211
18212
18213
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18211

def QueryType.exclusion
  @@_exclusion ||= QueryType.new('exclusion')
end

.from_string(value) ⇒ Object

Returns the instance of QueryType for this value, or nil if not found



18201
18202
18203
18204
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18201

def QueryType.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  QueryType.ALL.find { |v| v.value == value }
end

.inclusionObject

Include items satisfied by the associated query



18216
18217
18218
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18216

def QueryType.inclusion
  @@_inclusion ||= QueryType.new('inclusion')
end

Instance Method Details

#to_hashObject



18220
18221
18222
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18220

def to_hash
  value
end