Class: Io::Flow::V0::Models::QuoteErrorCode

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ QuoteErrorCode

Returns a new instance of QuoteErrorCode.



23622
23623
23624
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23622

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



23620
23621
23622
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23620

def value
  @value
end

Class Method Details

.ALLObject



23642
23643
23644
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23642

def QuoteErrorCode.ALL
  @@all ||= [QuoteErrorCode.generic_error, QuoteErrorCode.items_not_available, QuoteErrorCode.shipping_unavailable]
end

.apply(value) ⇒ Object

Returns the instance of QuoteErrorCode for this value, creating a new instance for an unknown value



23627
23628
23629
23630
23631
23632
23633
23634
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23627

def QuoteErrorCode.apply(value)
  if value.instance_of?(QuoteErrorCode)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || QuoteErrorCode.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of QuoteErrorCode for this value, or nil if not found



23637
23638
23639
23640
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23637

def QuoteErrorCode.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  QuoteErrorCode.ALL.find { |v| v.value == value }
end

.generic_errorObject



23646
23647
23648
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23646

def QuoteErrorCode.generic_error
  @@_generic_error ||= QuoteErrorCode.new('generic_error')
end

.items_not_availableObject

Item numbers are not available in inventory



23651
23652
23653
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23651

def QuoteErrorCode.items_not_available
  @@_items_not_available ||= QuoteErrorCode.new('items_not_available')
end

.shipping_unavailableObject

Indicates that an order was created for a destination country to which you have no shipping lanes.



23657
23658
23659
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23657

def QuoteErrorCode.shipping_unavailable
  @@_shipping_unavailable ||= QuoteErrorCode.new('shipping_unavailable')
end

Instance Method Details

#to_hashObject



23661
23662
23663
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23661

def to_hash
  value
end