Class: Io::Flow::V0::Models::RatecardRate

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Specific line item in a ratecard lane with information on a weight threshold and corresponding amount to charge

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ RatecardRate

Returns a new instance of RatecardRate.



43949
43950
43951
43952
43953
43954
43955
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 43949

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:id, :amount, :weight], 'RatecardRate')
  @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String)
  @amount = HttpClient::Preconditions.assert_class('amount', opts.delete(:amount), Numeric)
  @weight = HttpClient::Preconditions.assert_class('weight', opts.delete(:weight), Numeric)
end

Instance Attribute Details

#amountObject (readonly)

Returns the value of attribute amount.



43947
43948
43949
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 43947

def amount
  @amount
end

#idObject (readonly)

Returns the value of attribute id.



43947
43948
43949
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 43947

def id
  @id
end

#weightObject (readonly)

Returns the value of attribute weight.



43947
43948
43949
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 43947

def weight
  @weight
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



43961
43962
43963
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 43961

def copy(incoming={})
  RatecardRate.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hashObject



43965
43966
43967
43968
43969
43970
43971
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 43965

def to_hash
  {
    :id => id,
    :amount => amount,
    :weight => weight
  }
end

#to_jsonObject



43957
43958
43959
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 43957

def to_json
  JSON.dump(to_hash)
end