Class: Io::Flow::V0::Models::RedirectAuthorizationDetails

Inherits:
OnlineAuthorizationDetails show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Represents an online payment that requires the user to redirect to another site before entering their payment information.

Instance Attribute Summary collapse

Attributes inherited from OnlineAuthorizationDetails

#discriminator

Instance Method Summary collapse

Methods inherited from OnlineAuthorizationDetails

from_json, #to_hash

Constructor Details

#initialize(incoming = {}) ⇒ RedirectAuthorizationDetails



44203
44204
44205
44206
44207
44208
44209
44210
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44203

def initialize(incoming={})
  super(:discriminator => OnlineAuthorizationDetails::Types::REDIRECT_AUTHORIZATION_DETAILS)
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:id, :payment_redirect_url], 'RedirectAuthorizationDetails')
  @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String)
  @payment_redirect_url = HttpClient::Preconditions.assert_class('payment_redirect_url', opts.delete(:payment_redirect_url), String)
  @confirmation_details = (x = opts.delete(:confirmation_details); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::ConfirmationDetails) ? x : ::Io::Flow::V0::Models::ConfirmationDetails.from_json(x)))
end

Instance Attribute Details

#confirmation_detailsObject (readonly)

Returns the value of attribute confirmation_details.



44201
44202
44203
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44201

def confirmation_details
  @confirmation_details
end

#idObject (readonly)

Returns the value of attribute id.



44201
44202
44203
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44201

def id
  @id
end

#payment_redirect_urlObject (readonly)

Returns the value of attribute payment_redirect_url.



44201
44202
44203
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44201

def payment_redirect_url
  @payment_redirect_url
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



44216
44217
44218
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44216

def copy(incoming={})
  RedirectAuthorizationDetails.new(subtype_to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#subtype_to_hashObject



44220
44221
44222
44223
44224
44225
44226
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44220

def subtype_to_hash
  {
    :id => id,
    :payment_redirect_url => payment_redirect_url,
    :confirmation_details => confirmation_details.nil? ? nil : confirmation_details.to_hash
  }
end

#to_jsonObject



44212
44213
44214
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44212

def to_json
  JSON.dump(to_hash)
end