Class: Io::Flow::V0::Models::Refund

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Refunds can be created against either a specific capture or an authorization (in which case we will select 1 or more specific captures against which to execute the refund).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ Refund



44281
44282
44283
44284
44285
44286
44287
44288
44289
44290
44291
44292
44293
44294
44295
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44281

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:id, :key, :authorization, :amount, :currency, :captures, :created_at], 'Refund')
  @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String)
  @key = HttpClient::Preconditions.assert_class('key', opts.delete(:key), String)
  @authorization = (x = opts.delete(:authorization); x.is_a?(::Io::Flow::V0::Models::AuthorizationReference) ? x : ::Io::Flow::V0::Models::AuthorizationReference.new(x))
  @amount = HttpClient::Preconditions.assert_class('amount', HttpClient::Helper.to_big_decimal(opts.delete(:amount)), BigDecimal)
  @currency = HttpClient::Preconditions.assert_class('currency', opts.delete(:currency), String)
  @requested = (x = opts.delete(:requested); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::Money) ? x : ::Io::Flow::V0::Models::Money.new(x)))
  @captures = HttpClient::Preconditions.assert_class('captures', opts.delete(:captures), Array).map { |v| (x = v; x.is_a?(::Io::Flow::V0::Models::RefundCaptureSummary) ? x : ::Io::Flow::V0::Models::RefundCaptureSummary.new(x)) }
  @created_at = HttpClient::Preconditions.assert_class('created_at', HttpClient::Helper.to_date_time_iso8601(opts.delete(:created_at)), DateTime)
  @attributes = (x = opts.delete(:attributes); x.nil? ? nil : HttpClient::Preconditions.assert_class('attributes', x, Hash).inject({}) { |h, d| h[d[0]] = HttpClient::Preconditions.assert_class('attributes', d[1], String); h })
  @status = (x = (x = opts.delete(:status); x.nil? ? "succeeded" : x); x.is_a?(::Io::Flow::V0::Models::RefundStatus) ? x : ::Io::Flow::V0::Models::RefundStatus.apply(x))
  @base = (x = opts.delete(:base); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::Money) ? x : ::Io::Flow::V0::Models::Money.new(x)))
end

Instance Attribute Details

#amountObject (readonly)

Returns the value of attribute amount.



44279
44280
44281
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44279

def amount
  @amount
end

#attributesObject (readonly)

Returns the value of attribute attributes.



44279
44280
44281
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44279

def attributes
  @attributes
end

#authorizationObject (readonly)

Returns the value of attribute authorization.



44279
44280
44281
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44279

def authorization
  @authorization
end

#baseObject (readonly)

Returns the value of attribute base.



44279
44280
44281
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44279

def base
  @base
end

#capturesObject (readonly)

Returns the value of attribute captures.



44279
44280
44281
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44279

def captures
  @captures
end

#created_atObject (readonly)

Returns the value of attribute created_at.



44279
44280
44281
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44279

def created_at
  @created_at
end

#currencyObject (readonly)

Returns the value of attribute currency.



44279
44280
44281
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44279

def currency
  @currency
end

#idObject (readonly)

Returns the value of attribute id.



44279
44280
44281
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44279

def id
  @id
end

#keyObject (readonly)

Returns the value of attribute key.



44279
44280
44281
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44279

def key
  @key
end

#requestedObject (readonly)

Returns the value of attribute requested.



44279
44280
44281
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44279

def requested
  @requested
end

#statusObject (readonly)

Returns the value of attribute status.



44279
44280
44281
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44279

def status
  @status
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



44301
44302
44303
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44301

def copy(incoming={})
  Refund.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hashObject



44305
44306
44307
44308
44309
44310
44311
44312
44313
44314
44315
44316
44317
44318
44319
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44305

def to_hash
  {
    :id => id,
    :key => key,
    :authorization => authorization.to_hash,
    :amount => amount.to_f.to_s,
    :currency => currency,
    :requested => requested.nil? ? nil : requested.to_hash,
    :captures => captures.map { |o| o.to_hash },
    :created_at => created_at,
    :attributes => attributes.nil? ? nil : attributes,
    :status => status.value,
    :base => base.nil? ? nil : base.to_hash
  }
end

#to_jsonObject



44297
44298
44299
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44297

def to_json
  JSON.dump(to_hash)
end