Class: Io::Flow::V0::Models::RefundDeclineCode

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ RefundDeclineCode

Returns a new instance of RefundDeclineCode.



23713
23714
23715
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23713

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



23711
23712
23713
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23711

def value
  @value
end

Class Method Details

.ALLObject



23733
23734
23735
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23733

def RefundDeclineCode.ALL
  @@all ||= [RefundDeclineCode.expired, RefundDeclineCode.insufficient_funds, RefundDeclineCode.unknown]
end

.apply(value) ⇒ Object

Returns the instance of RefundDeclineCode for this value, creating a new instance for an unknown value



23718
23719
23720
23721
23722
23723
23724
23725
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23718

def RefundDeclineCode.apply(value)
  if value.instance_of?(RefundDeclineCode)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || RefundDeclineCode.new(value))
  end
end

.expiredObject

All associated payment captures have expired; refunds can no longer be issued



23738
23739
23740
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23738

def RefundDeclineCode.expired
  @@_expired ||= RefundDeclineCode.new('expired')
end

.from_string(value) ⇒ Object

Returns the instance of RefundDeclineCode for this value, or nil if not found



23728
23729
23730
23731
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23728

def RefundDeclineCode.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  RefundDeclineCode.ALL.find { |v| v.value == value }
end

.insufficient_fundsObject

The requested refund amount exceeded the amount of remaining unrefunded funds



23743
23744
23745
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23743

def RefundDeclineCode.insufficient_funds
  @@_insufficient_funds ||= RefundDeclineCode.new('insufficient_funds')
end

.unknownObject

Failed due to another reason (details not known)



23748
23749
23750
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23748

def RefundDeclineCode.unknown
  @@_unknown ||= RefundDeclineCode.new('unknown')
end

Instance Method Details

#to_hashObject



23752
23753
23754
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 23752

def to_hash
  value
end