Class: Io::Flow::V0::Models::RefundOrderSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

For merchant of record authorizations, we provide a summary of refund information primarily to support customer service workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ RefundOrderSummary

Returns a new instance of RefundOrderSummary.



44638
44639
44640
44641
44642
44643
44644
44645
44646
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44638

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:order_number, :currency, :captured, :refunded, :amounts], 'RefundOrderSummary')
  @order_number = HttpClient::Preconditions.assert_class('order_number', opts.delete(:order_number), String)
  @currency = HttpClient::Preconditions.assert_class('currency', opts.delete(:currency), String)
  @captured = HttpClient::Preconditions.assert_class('captured', HttpClient::Helper.to_big_decimal(opts.delete(:captured)), BigDecimal)
  @refunded = HttpClient::Preconditions.assert_class('refunded', HttpClient::Helper.to_big_decimal(opts.delete(:refunded)), BigDecimal)
  @amounts = (x = opts.delete(:amounts); x.is_a?(::Io::Flow::V0::Models::RefundOrderSummaryAmounts) ? x : ::Io::Flow::V0::Models::RefundOrderSummaryAmounts.new(x))
end

Instance Attribute Details

#amountsObject (readonly)

Returns the value of attribute amounts.



44636
44637
44638
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44636

def amounts
  @amounts
end

#capturedObject (readonly)

Returns the value of attribute captured.



44636
44637
44638
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44636

def captured
  @captured
end

#currencyObject (readonly)

Returns the value of attribute currency.



44636
44637
44638
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44636

def currency
  @currency
end

#order_numberObject (readonly)

Returns the value of attribute order_number.



44636
44637
44638
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44636

def order_number
  @order_number
end

#refundedObject (readonly)

Returns the value of attribute refunded.



44636
44637
44638
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44636

def refunded
  @refunded
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



44652
44653
44654
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44652

def copy(incoming={})
  RefundOrderSummary.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hashObject



44656
44657
44658
44659
44660
44661
44662
44663
44664
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44656

def to_hash
  {
    :order_number => order_number,
    :currency => currency,
    :captured => captured.to_f.to_s,
    :refunded => refunded.to_f.to_s,
    :amounts => amounts.to_hash
  }
end

#to_jsonObject



44648
44649
44650
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 44648

def to_json
  JSON.dump(to_hash)
end