Class: Io::Flow::V0::Models::RefundStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ RefundStatus

Returns a new instance of RefundStatus.



18414
18415
18416
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18414

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



18412
18413
18414
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18412

def value
  @value
end

Class Method Details

.ALLObject



18434
18435
18436
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18434

def RefundStatus.ALL
  @@all ||= [RefundStatus.pending, RefundStatus.succeeded, RefundStatus.failed, RefundStatus.canceled]
end

.apply(value) ⇒ Object

Returns the instance of RefundStatus for this value, creating a new instance for an unknown value



18419
18420
18421
18422
18423
18424
18425
18426
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18419

def RefundStatus.apply(value)
  if value.instance_of?(RefundStatus)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || RefundStatus.new(value))
  end
end

.canceledObject

The refund was canceled.



18454
18455
18456
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18454

def RefundStatus.canceled
  @@_canceled ||= RefundStatus.new('canceled')
end

.failedObject

The refund failed to process.



18449
18450
18451
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18449

def RefundStatus.failed
  @@_failed ||= RefundStatus.new('failed')
end

.from_string(value) ⇒ Object

Returns the instance of RefundStatus for this value, or nil if not found



18429
18430
18431
18432
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18429

def RefundStatus.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  RefundStatus.ALL.find { |v| v.value == value }
end

.pendingObject

The refund has been initiated and requires time to complete.



18439
18440
18441
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18439

def RefundStatus.pending
  @@_pending ||= RefundStatus.new('pending')
end

.succeededObject

The refund has been processed successfully.



18444
18445
18446
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18444

def RefundStatus.succeeded
  @@_succeeded ||= RefundStatus.new('succeeded')
end

Instance Method Details

#to_hashObject



18458
18459
18460
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18458

def to_hash
  value
end