Class: Io::Flow::V0::Models::ReturnStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ ReturnStatus

Returns a new instance of ReturnStatus.



18962
18963
18964
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18962

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



18960
18961
18962
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18960

def value
  @value
end

Class Method Details

.ALLObject



18982
18983
18984
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18982

def ReturnStatus.ALL
  @@all ||= [ReturnStatus.open, ReturnStatus.refunded]
end

.apply(value) ⇒ Object

Returns the instance of ReturnStatus for this value, creating a new instance for an unknown value



18967
18968
18969
18970
18971
18972
18973
18974
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18967

def ReturnStatus.apply(value)
  if value.instance_of?(ReturnStatus)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || ReturnStatus.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of ReturnStatus for this value, or nil if not found



18977
18978
18979
18980
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18977

def ReturnStatus.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  ReturnStatus.ALL.find { |v| v.value == value }
end

.openObject



18986
18987
18988
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18986

def ReturnStatus.open
  @@_open ||= ReturnStatus.new('open')
end

.refundedObject



18990
18991
18992
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18990

def ReturnStatus.refunded
  @@_refunded ||= ReturnStatus.new('refunded')
end

Instance Method Details

#to_hashObject



18994
18995
18996
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18994

def to_hash
  value
end