Class: Io::Flow::V0::Models::ReversalStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ ReversalStatus



18596
18597
18598
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18596

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



18594
18595
18596
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18594

def value
  @value
end

Class Method Details

.ALLObject



18616
18617
18618
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18616

def ReversalStatus.ALL
  @@all ||= [ReversalStatus.pending, ReversalStatus.processed, ReversalStatus.failed]
end

.apply(value) ⇒ Object

Returns the instance of ReversalStatus for this value, creating a new instance for an unknown value



18601
18602
18603
18604
18605
18606
18607
18608
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18601

def ReversalStatus.apply(value)
  if value.instance_of?(ReversalStatus)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || ReversalStatus.new(value))
  end
end

.failedObject

Reversal failed to process.



18631
18632
18633
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18631

def ReversalStatus.failed
  @@_failed ||= ReversalStatus.new('failed')
end

.from_string(value) ⇒ Object

Returns the instance of ReversalStatus for this value, or nil if not found



18611
18612
18613
18614
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18611

def ReversalStatus.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  ReversalStatus.ALL.find { |v| v.value == value }
end

.pendingObject

Reversal is pending processing.



18621
18622
18623
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18621

def ReversalStatus.pending
  @@_pending ||= ReversalStatus.new('pending')
end

.processedObject

Reversal has been processed successfully.



18626
18627
18628
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18626

def ReversalStatus.processed
  @@_processed ||= ReversalStatus.new('processed')
end

Instance Method Details

#to_hashObject



18635
18636
18637
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18635

def to_hash
  value
end