Class: Io::Flow::V0::Models::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ Role



18645
18646
18647
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18645

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



18643
18644
18645
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18643

def value
  @value
end

Class Method Details

.adminObject



18669
18670
18671
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18669

def Role.admin
  @@_admin ||= Role.new('admin')
end

.ALLObject



18665
18666
18667
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18665

def Role.ALL
  @@all ||= [Role.admin, Role.member]
end

.apply(value) ⇒ Object

Returns the instance of Role for this value, creating a new instance for an unknown value



18650
18651
18652
18653
18654
18655
18656
18657
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18650

def Role.apply(value)
  if value.instance_of?(Role)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || Role.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of Role for this value, or nil if not found



18660
18661
18662
18663
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18660

def Role.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  Role.ALL.find { |v| v.value == value }
end

.memberObject



18673
18674
18675
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18673

def Role.member
  @@_member ||= Role.new('member')
end

Instance Method Details

#to_hashObject



18677
18678
18679
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18677

def to_hash
  value
end