Class: Io::Flow::V0::Models::RoundingMethod

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ RoundingMethod

Returns a new instance of RoundingMethod.



24277
24278
24279
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24277

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



24275
24276
24277
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24275

def value
  @value
end

Class Method Details

.ALLObject



24297
24298
24299
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24297

def RoundingMethod.ALL
  @@all ||= [RoundingMethod.up, RoundingMethod.down, RoundingMethod.nearest]
end

.apply(value) ⇒ Object

Returns the instance of RoundingMethod for this value, creating a new instance for an unknown value



24282
24283
24284
24285
24286
24287
24288
24289
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24282

def RoundingMethod.apply(value)
  if value.instance_of?(RoundingMethod)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || RoundingMethod.new(value))
  end
end

.downObject

Round down to the specified rounding.value



24307
24308
24309
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24307

def RoundingMethod.down
  @@_down ||= RoundingMethod.new('down')
end

.from_string(value) ⇒ Object

Returns the instance of RoundingMethod for this value, or nil if not found



24292
24293
24294
24295
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24292

def RoundingMethod.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  RoundingMethod.ALL.find { |v| v.value == value }
end

.nearestObject

Round to the nearest specified rounding.value. If equidistant, will round up.



24312
24313
24314
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24312

def RoundingMethod.nearest
  @@_nearest ||= RoundingMethod.new('nearest')
end

.upObject

Round up to the specified rounding.value



24302
24303
24304
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24302

def RoundingMethod.up
  @@_up ||= RoundingMethod.new('up')
end

Instance Method Details

#to_hashObject



24316
24317
24318
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24316

def to_hash
  value
end