Class: Io::Flow::V0::Models::ScheduleExceptionStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ ScheduleExceptionStatus

Returns a new instance of ScheduleExceptionStatus.



18782
18783
18784
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18782

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



18780
18781
18782
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18780

def value
  @value
end

Class Method Details

.ALLObject



18802
18803
18804
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18802

def ScheduleExceptionStatus.ALL
  @@all ||= [ScheduleExceptionStatus.open, ScheduleExceptionStatus.closed]
end

.apply(value) ⇒ Object

Returns the instance of ScheduleExceptionStatus for this value, creating a new instance for an unknown value



18787
18788
18789
18790
18791
18792
18793
18794
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18787

def ScheduleExceptionStatus.apply(value)
  if value.instance_of?(ScheduleExceptionStatus)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || ScheduleExceptionStatus.new(value))
  end
end

.closedObject



18810
18811
18812
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18810

def ScheduleExceptionStatus.closed
  @@_closed ||= ScheduleExceptionStatus.new('Closed')
end

.from_string(value) ⇒ Object

Returns the instance of ScheduleExceptionStatus for this value, or nil if not found



18797
18798
18799
18800
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18797

def ScheduleExceptionStatus.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  ScheduleExceptionStatus.ALL.find { |v| v.value == value }
end

.openObject



18806
18807
18808
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18806

def ScheduleExceptionStatus.open
  @@_open ||= ScheduleExceptionStatus.new('Open')
end

Instance Method Details

#to_hashObject



18814
18815
18816
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18814

def to_hash
  value
end