Class: Io::Flow::V0::Models::SessionVisitor

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

A session visitor is a unique identifier for our best guess as to who the individual user is interacting with Flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ SessionVisitor

Returns a new instance of SessionVisitor.



46773
46774
46775
46776
46777
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 46773

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:id], 'SessionVisitor')
  @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String)
end

Instance Attribute Details

#idObject (readonly)

Returns the value of attribute id.



46771
46772
46773
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 46771

def id
  @id
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



46783
46784
46785
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 46783

def copy(incoming={})
  SessionVisitor.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hashObject



46787
46788
46789
46790
46791
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 46787

def to_hash
  {
    :id => id
  }
end

#to_jsonObject



46779
46780
46781
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 46779

def to_json
  JSON.dump(to_hash)
end