Class: Io::Flow::V0::Models::ShipmentIntegrationType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::ShipmentIntegrationType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of ShipmentIntegrationType for this value, creating a new instance for an unknown value.
-
.direct ⇒ Object
Always generate a label for the chosen delivery option.
-
.from_string(value) ⇒ Object
Returns the instance of ShipmentIntegrationType for this value, or nil if not found.
-
.information ⇒ Object
Booking and label generation is not available.
-
.preadvice ⇒ Object
A generic label will be provided by the client organization when available as pre-advice shipment notification to carrier partner.
Instance Method Summary collapse
-
#initialize(value) ⇒ ShipmentIntegrationType
constructor
A new instance of ShipmentIntegrationType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ ShipmentIntegrationType
Returns a new instance of ShipmentIntegrationType.
18870 18871 18872 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18870 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
18868 18869 18870 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18868 def value @value end |
Class Method Details
.ALL ⇒ Object
18890 18891 18892 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18890 def ShipmentIntegrationType.ALL @@all ||= [ShipmentIntegrationType.direct, ShipmentIntegrationType.information, ShipmentIntegrationType.preadvice] end |
.apply(value) ⇒ Object
Returns the instance of ShipmentIntegrationType for this value, creating a new instance for an unknown value
18875 18876 18877 18878 18879 18880 18881 18882 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18875 def ShipmentIntegrationType.apply(value) if value.instance_of?(ShipmentIntegrationType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || ShipmentIntegrationType.new(value)) end end |
.direct ⇒ Object
Always generate a label for the chosen delivery option.
18895 18896 18897 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18895 def ShipmentIntegrationType.direct @@_direct ||= ShipmentIntegrationType.new('direct') end |
.from_string(value) ⇒ Object
Returns the instance of ShipmentIntegrationType for this value, or nil if not found
18885 18886 18887 18888 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18885 def ShipmentIntegrationType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) ShipmentIntegrationType.ALL.find { |v| v.value == value } end |
.information ⇒ Object
Booking and label generation is not available. Just use Flow to calculate delivery window estimates and shipment prices to display.
18901 18902 18903 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18901 def ShipmentIntegrationType.information @@_information ||= ShipmentIntegrationType.new('information') end |
.preadvice ⇒ Object
A generic label will be provided by the client organization when available as pre-advice shipment notification to carrier partner.
18907 18908 18909 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18907 def ShipmentIntegrationType.preadvice @@_preadvice ||= ShipmentIntegrationType.new('preadvice') end |
Instance Method Details
#to_hash ⇒ Object
18911 18912 18913 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18911 def to_hash value end |