Class: Io::Flow::V0::Models::ShipmentRecipient

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ ShipmentRecipient

Returns a new instance of ShipmentRecipient.



18921
18922
18923
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18921

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



18919
18920
18921
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18919

def value
  @value
end

Class Method Details

.ALLObject



18941
18942
18943
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18941

def ShipmentRecipient.ALL
  @@all ||= [ShipmentRecipient.customer, ShipmentRecipient.return, ShipmentRecipient.crossdock]
end

.apply(value) ⇒ Object

Returns the instance of ShipmentRecipient for this value, creating a new instance for an unknown value



18926
18927
18928
18929
18930
18931
18932
18933
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18926

def ShipmentRecipient.apply(value)
  if value.instance_of?(ShipmentRecipient)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || ShipmentRecipient.new(value))
  end
end

.crossdockObject

Outbound shipment to a crossdock



18956
18957
18958
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18956

def ShipmentRecipient.crossdock
  @@_crossdock ||= ShipmentRecipient.new('crossdock')
end

.customerObject

Outbound shipment to the customer



18946
18947
18948
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18946

def ShipmentRecipient.customer
  @@_customer ||= ShipmentRecipient.new('customer')
end

.from_string(value) ⇒ Object

Returns the instance of ShipmentRecipient for this value, or nil if not found



18936
18937
18938
18939
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18936

def ShipmentRecipient.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  ShipmentRecipient.ALL.find { |v| v.value == value }
end

.returnObject

Inbound or return shipment



18951
18952
18953
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18951

def ShipmentRecipient.return
  @@_return ||= ShipmentRecipient.new('return')
end

Instance Method Details

#to_hashObject



18960
18961
18962
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18960

def to_hash
  value
end