Class: Io::Flow::V0::Models::ShippingConfigurationType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::ShippingConfigurationType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of ShippingConfigurationType for this value, creating a new instance for an unknown value.
- .default ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of ShippingConfigurationType for this value, or nil if not found.
- .variant ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ ShippingConfigurationType
constructor
A new instance of ShippingConfigurationType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ ShippingConfigurationType
Returns a new instance of ShippingConfigurationType.
24514 24515 24516 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24514 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
24512 24513 24514 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24512 def value @value end |
Class Method Details
.ALL ⇒ Object
24534 24535 24536 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24534 def ShippingConfigurationType.ALL @@all ||= [ShippingConfigurationType.default, ShippingConfigurationType.variant] end |
.apply(value) ⇒ Object
Returns the instance of ShippingConfigurationType for this value, creating a new instance for an unknown value
24519 24520 24521 24522 24523 24524 24525 24526 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24519 def ShippingConfigurationType.apply(value) if value.instance_of?(ShippingConfigurationType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || ShippingConfigurationType.new(value)) end end |
.default ⇒ Object
24538 24539 24540 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24538 def ShippingConfigurationType.default @@_default ||= ShippingConfigurationType.new('default') end |
.from_string(value) ⇒ Object
Returns the instance of ShippingConfigurationType for this value, or nil if not found
24529 24530 24531 24532 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24529 def ShippingConfigurationType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) ShippingConfigurationType.ALL.find { |v| v.value == value } end |
.variant ⇒ Object
24542 24543 24544 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24542 def ShippingConfigurationType.variant @@_variant ||= ShippingConfigurationType.new('variant') end |
Instance Method Details
#to_hash ⇒ Object
24546 24547 24548 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24546 def to_hash value end |