Class: Io::Flow::V0::Models::ShippingNotification

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Represents information about a client-facilitated shipment where the shipping label and fulfillment was not handled by Flow. For merchant-of-record and tracking purposes, clients doing their own shipping will need to notify Flow of shipped packages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ ShippingNotification

Returns a new instance of ShippingNotification.



20256
20257
20258
20259
20260
20261
20262
20263
20264
20265
20266
20267
20268
20269
20270
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20256

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:id, :key, :carrier_tracking_number, :destination, :flow_tracking_number, :origin, :package, :service, :window], 'ShippingNotification')
  @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String)
  @key = HttpClient::Preconditions.assert_class('key', opts.delete(:key), String)
  @attributes = HttpClient::Preconditions.assert_class('attributes', (x = opts.delete(:attributes); x.nil? ? {} : x), Hash).inject({}) { |h, d| h[d[0]] = HttpClient::Preconditions.assert_class('attributes', d[1], String); h }
  @carrier_tracking_number = HttpClient::Preconditions.assert_class('carrier_tracking_number', opts.delete(:carrier_tracking_number), String)
  @destination = (x = opts.delete(:destination); x.is_a?(::Io::Flow::V0::Models::ShippingAddress) ? x : ::Io::Flow::V0::Models::ShippingAddress.new(x))
  @flow_tracking_number = HttpClient::Preconditions.assert_class('flow_tracking_number', opts.delete(:flow_tracking_number), String)
  @origin = (x = opts.delete(:origin); x.is_a?(::Io::Flow::V0::Models::ShippingAddress) ? x : ::Io::Flow::V0::Models::ShippingAddress.new(x))
  @package = (x = opts.delete(:package); x.is_a?(::Io::Flow::V0::Models::ShippingLabelPackage) ? x : ::Io::Flow::V0::Models::ShippingLabelPackage.new(x))
  @service = (x = opts.delete(:service); x.is_a?(::Io::Flow::V0::Models::ServiceSummary) ? x : ::Io::Flow::V0::Models::ServiceSummary.new(x))
  @window = (x = opts.delete(:window); x.is_a?(::Io::Flow::V0::Models::DatetimeRange) ? x : ::Io::Flow::V0::Models::DatetimeRange.new(x))
  @order = (x = opts.delete(:order); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::LabelOrderSummary) ? x : ::Io::Flow::V0::Models::LabelOrderSummary.new(x)))
end

Instance Attribute Details

#attributes ⇒ Object (readonly)

Returns the value of attribute attributes.



20254
20255
20256
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20254

def attributes
  @attributes
end

#carrier_tracking_number ⇒ Object (readonly)

Returns the value of attribute carrier_tracking_number.



20254
20255
20256
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20254

def carrier_tracking_number
  @carrier_tracking_number
end

#destination ⇒ Object (readonly)

Returns the value of attribute destination.



20254
20255
20256
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20254

def destination
  @destination
end

#flow_tracking_number ⇒ Object (readonly)

Returns the value of attribute flow_tracking_number.



20254
20255
20256
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20254

def flow_tracking_number
  @flow_tracking_number
end

#id ⇒ Object (readonly)

Returns the value of attribute id.



20254
20255
20256
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20254

def id
  @id
end

#key ⇒ Object (readonly)

Returns the value of attribute key.



20254
20255
20256
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20254

def key
  @key
end

#order ⇒ Object (readonly)

Returns the value of attribute order.



20254
20255
20256
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20254

def order
  @order
end

#origin ⇒ Object (readonly)

Returns the value of attribute origin.



20254
20255
20256
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20254

def origin
  @origin
end

#package ⇒ Object (readonly)

Returns the value of attribute package.



20254
20255
20256
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20254

def package
  @package
end

#service ⇒ Object (readonly)

Returns the value of attribute service.



20254
20255
20256
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20254

def service
  @service
end

#window ⇒ Object (readonly)

Returns the value of attribute window.



20254
20255
20256
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20254

def window
  @window
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



20276
20277
20278
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20276

def copy(incoming={})
  ShippingNotification.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hash ⇒ Object



20280
20281
20282
20283
20284
20285
20286
20287
20288
20289
20290
20291
20292
20293
20294
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20280

def to_hash
  {
    :id => id,
    :key => key,
    :attributes => attributes,
    :carrier_tracking_number => carrier_tracking_number,
    :destination => destination.to_hash,
    :flow_tracking_number => flow_tracking_number,
    :origin => origin.to_hash,
    :package => package.to_hash,
    :service => service.to_hash,
    :window => window.to_hash,
    :order => order.nil? ? nil : order.to_hash
  }
end

#to_json ⇒ Object



20272
20273
20274
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20272

def to_json
  JSON.dump(to_hash)
end