Class: Io::Flow::V0::Models::ShippingNotificationForm

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Form for information about a client-facilitated shipment where the shipping label and fulfillment was not handled by Flow. For merchant-of-record and tracking purposes, clients doing their own shipping will need to notify Flow of shipped packages.

Defined Under Namespace

Modules: Types

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ ShippingNotificationForm

Returns a new instance of ShippingNotificationForm.



11358
11359
11360
11361
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11358

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  @discriminator = HttpClient::Preconditions.assert_class('discriminator', opts.delete(:discriminator) || 'detailed_shipping_notification_form', String)
end

Instance Attribute Details

#discriminatorObject (readonly)

Returns the value of attribute discriminator.



11356
11357
11358
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11356

def discriminator
  @discriminator
end

Class Method Details

.from_json(hash) ⇒ Object



11371
11372
11373
11374
11375
11376
11377
11378
11379
11380
11381
11382
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11371

def ShippingNotificationForm.from_json(hash)
  HttpClient::Preconditions.assert_class('hash', hash, Hash)
  discriminator = HttpClient::Helper.symbolize_keys(hash)[:discriminator].to_s.strip
  if discriminator.empty?
    raise "Union type[shipping_notification_form] requires a field named 'discriminator'"
  end
  case discriminator
    when Types::DETAILED_SHIPPING_NOTIFICATION_FORM; DetailedShippingNotificationForm.new(hash)
    when Types::SINGLE_PACKAGE_SHIPPING_NOTIFICATION_FORM; SinglePackageShippingNotificationForm.new(hash)
    else ShippingNotificationFormUndefinedType.new(:discriminator => discriminator)
  end
end

Instance Method Details

#subtype_to_hashObject



11363
11364
11365
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11363

def subtype_to_hash
  raise 'Cannot serialize an instance of shipping_notification_form directly - must use one of the specific types: detailed_shipping_notification_form, single_package_shipping_notification_form'
end

#to_hashObject



11367
11368
11369
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11367

def to_hash
  subtype_to_hash.merge(:discriminator => @discriminator)
end