Class: Io::Flow::V0::Models::ShopifySyncCheck
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::ShopifySyncCheck
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of ShopifySyncCheck for this value, creating a new instance for an unknown value.
-
.flow_variant_metafields ⇒ Object
Provides status check of Flow variant metafields sync to Shopify.
-
.from_string(value) ⇒ Object
Returns the instance of ShopifySyncCheck for this value, or nil if not found.
-
.localized_variants ⇒ Object
Provides status check of localized variant metafields sync to Shopify.
Instance Method Summary collapse
-
#initialize(value) ⇒ ShopifySyncCheck
constructor
A new instance of ShopifySyncCheck.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ ShopifySyncCheck
Returns a new instance of ShopifySyncCheck.
24660 24661 24662 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24660 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
24658 24659 24660 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24658 def value @value end |
Class Method Details
.ALL ⇒ Object
24680 24681 24682 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24680 def ShopifySyncCheck.ALL @@all ||= [ShopifySyncCheck.localized_variants, ShopifySyncCheck.] end |
.apply(value) ⇒ Object
Returns the instance of ShopifySyncCheck for this value, creating a new instance for an unknown value
24665 24666 24667 24668 24669 24670 24671 24672 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24665 def ShopifySyncCheck.apply(value) if value.instance_of?(ShopifySyncCheck) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || ShopifySyncCheck.new(value)) end end |
.flow_variant_metafields ⇒ Object
Provides status check of Flow variant metafields sync to Shopify
24690 24691 24692 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24690 def ShopifySyncCheck. ||= ShopifySyncCheck.new('flow_variant_metafields') end |
.from_string(value) ⇒ Object
Returns the instance of ShopifySyncCheck for this value, or nil if not found
24675 24676 24677 24678 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24675 def ShopifySyncCheck.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) ShopifySyncCheck.ALL.find { |v| v.value == value } end |
.localized_variants ⇒ Object
Provides status check of localized variant metafields sync to Shopify
24685 24686 24687 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24685 def ShopifySyncCheck.localized_variants @@_localized_variants ||= ShopifySyncCheck.new('localized_variants') end |
Instance Method Details
#to_hash ⇒ Object
24694 24695 24696 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 24694 def to_hash value end |