Class: Io::Flow::V0::Models::ShopifyVariantInventoryMetafield
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::ShopifyVariantInventoryMetafield
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
For enabled organizations, this indicates the total number of available units of inventory for customers in this experience.
Instance Attribute Summary collapse
-
#experience ⇒ Object
readonly
Returns the value of attribute experience.
-
#status ⇒ Object
readonly
Returns the value of attribute status.
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ ShopifyVariantInventoryMetafield
constructor
A new instance of ShopifyVariantInventoryMetafield.
- #to_hash ⇒ Object
- #to_json ⇒ Object
Constructor Details
#initialize(incoming = {}) ⇒ ShopifyVariantInventoryMetafield
Returns a new instance of ShopifyVariantInventoryMetafield.
49017 49018 49019 49020 49021 49022 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 49017 def initialize(incoming={}) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:experience, :status], 'ShopifyVariantInventoryMetafield') @experience = (x = opts.delete(:experience); x.is_a?(::Io::Flow::V0::Models::ExperienceReference) ? x : ::Io::Flow::V0::Models::ExperienceReference.new(x)) @status = (x = opts.delete(:status); x.is_a?(::Io::Flow::V0::Models::ItemAvailabilityStatus) ? x : ::Io::Flow::V0::Models::ItemAvailabilityStatus.apply(x)) end |
Instance Attribute Details
#experience ⇒ Object (readonly)
Returns the value of attribute experience.
49015 49016 49017 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 49015 def experience @experience end |
#status ⇒ Object (readonly)
Returns the value of attribute status.
49015 49016 49017 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 49015 def status @status end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
49028 49029 49030 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 49028 def copy(incoming={}) ShopifyVariantInventoryMetafield.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#to_hash ⇒ Object
49032 49033 49034 49035 49036 49037 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 49032 def to_hash { :experience => experience.to_hash, :status => status.value } end |
#to_json ⇒ Object
49024 49025 49026 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 49024 def to_json JSON.dump(to_hash) end |