Class: Io::Flow::V0::Models::SortDirection
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::SortDirection
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of SortDirection for this value, creating a new instance for an unknown value.
- .ascending ⇒ Object
- .descending ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of SortDirection for this value, or nil if not found.
Instance Method Summary collapse
-
#initialize(value) ⇒ SortDirection
constructor
A new instance of SortDirection.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ SortDirection
Returns a new instance of SortDirection.
19160 19161 19162 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19160 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
19158 19159 19160 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19158 def value @value end |
Class Method Details
.ALL ⇒ Object
19180 19181 19182 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19180 def SortDirection.ALL @@all ||= [SortDirection.ascending, SortDirection.descending] end |
.apply(value) ⇒ Object
Returns the instance of SortDirection for this value, creating a new instance for an unknown value
19165 19166 19167 19168 19169 19170 19171 19172 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19165 def SortDirection.apply(value) if value.instance_of?(SortDirection) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || SortDirection.new(value)) end end |
.ascending ⇒ Object
19184 19185 19186 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19184 def SortDirection.ascending @@_ascending ||= SortDirection.new('ascending') end |
.descending ⇒ Object
19188 19189 19190 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19188 def SortDirection.descending @@_descending ||= SortDirection.new('descending') end |
.from_string(value) ⇒ Object
Returns the instance of SortDirection for this value, or nil if not found
19175 19176 19177 19178 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19175 def SortDirection.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) SortDirection.ALL.find { |v| v.value == value } end |
Instance Method Details
#to_hash ⇒ Object
19192 19193 19194 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19192 def to_hash value end |