Class: Io::Flow::V0::Models::TaxVerificationResult
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::TaxVerificationResult
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of TaxVerificationResult for this value, creating a new instance for an unknown value.
-
.from_string(value) ⇒ Object
Returns the instance of TaxVerificationResult for this value, or nil if not found.
- .invalid ⇒ Object
- .unable_to_validate ⇒ Object
- .valid ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ TaxVerificationResult
constructor
A new instance of TaxVerificationResult.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ TaxVerificationResult
Returns a new instance of TaxVerificationResult.
19389 19390 19391 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19389 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
19387 19388 19389 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19387 def value @value end |
Class Method Details
.ALL ⇒ Object
19409 19410 19411 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19409 def TaxVerificationResult.ALL @@all ||= [TaxVerificationResult.valid, TaxVerificationResult.invalid, TaxVerificationResult.unable_to_validate] end |
.apply(value) ⇒ Object
Returns the instance of TaxVerificationResult for this value, creating a new instance for an unknown value
19394 19395 19396 19397 19398 19399 19400 19401 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19394 def TaxVerificationResult.apply(value) if value.instance_of?(TaxVerificationResult) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || TaxVerificationResult.new(value)) end end |
.from_string(value) ⇒ Object
Returns the instance of TaxVerificationResult for this value, or nil if not found
19404 19405 19406 19407 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19404 def TaxVerificationResult.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) TaxVerificationResult.ALL.find { |v| v.value == value } end |
.invalid ⇒ Object
19417 19418 19419 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19417 def TaxVerificationResult.invalid @@_invalid ||= TaxVerificationResult.new('invalid') end |
.unable_to_validate ⇒ Object
19421 19422 19423 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19421 def TaxVerificationResult.unable_to_validate @@_unable_to_validate ||= TaxVerificationResult.new('unable_to_validate') end |
.valid ⇒ Object
19413 19414 19415 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19413 def TaxVerificationResult.valid @@_valid ||= TaxVerificationResult.new('valid') end |
Instance Method Details
#to_hash ⇒ Object
19425 19426 19427 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19425 def to_hash value end |