Class: Io::Flow::V0::Models::TaxabilityType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::TaxabilityType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of TaxabilityType for this value, creating a new instance for an unknown value.
-
.from_string(value) ⇒ Object
Returns the instance of TaxabilityType for this value, or nil if not found.
-
.tax_rule ⇒ Object
Rule indicating how taxes should be applied.
Instance Method Summary collapse
-
#initialize(value) ⇒ TaxabilityType
constructor
A new instance of TaxabilityType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ TaxabilityType
19435 19436 19437 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19435 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
19433 19434 19435 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19433 def value @value end |
Class Method Details
.ALL ⇒ Object
19455 19456 19457 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19455 def TaxabilityType.ALL @@all ||= [TaxabilityType.tax_rule] end |
.apply(value) ⇒ Object
Returns the instance of TaxabilityType for this value, creating a new instance for an unknown value
19440 19441 19442 19443 19444 19445 19446 19447 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19440 def TaxabilityType.apply(value) if value.instance_of?(TaxabilityType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || TaxabilityType.new(value)) end end |
.from_string(value) ⇒ Object
Returns the instance of TaxabilityType for this value, or nil if not found
19450 19451 19452 19453 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19450 def TaxabilityType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) TaxabilityType.ALL.find { |v| v.value == value } end |
.tax_rule ⇒ Object
Rule indicating how taxes should be applied. Acceptable values are defined by the 'taxability_value' enum.
19461 19462 19463 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19461 def TaxabilityType.tax_rule @@_tax_rule ||= TaxabilityType.new('tax_rule') end |
Instance Method Details
#to_hash ⇒ Object
19465 19466 19467 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19465 def to_hash value end |