Class: Io::Flow::V0::Models::TaxabilityValue
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::TaxabilityValue
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of TaxabilityValue for this value, creating a new instance for an unknown value.
-
.exempt ⇒ Object
An item with this value is exempt from being taxed.
-
.from_string(value) ⇒ Object
Returns the instance of TaxabilityValue for this value, or nil if not found.
Instance Method Summary collapse
-
#initialize(value) ⇒ TaxabilityValue
constructor
A new instance of TaxabilityValue.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ TaxabilityValue
Returns a new instance of TaxabilityValue.
19475 19476 19477 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19475 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
19473 19474 19475 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19473 def value @value end |
Class Method Details
.ALL ⇒ Object
19495 19496 19497 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19495 def TaxabilityValue.ALL @@all ||= [TaxabilityValue.exempt] end |
.apply(value) ⇒ Object
Returns the instance of TaxabilityValue for this value, creating a new instance for an unknown value
19480 19481 19482 19483 19484 19485 19486 19487 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19480 def TaxabilityValue.apply(value) if value.instance_of?(TaxabilityValue) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || TaxabilityValue.new(value)) end end |
.exempt ⇒ Object
An item with this value is exempt from being taxed.
19500 19501 19502 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19500 def TaxabilityValue.exempt @@_exempt ||= TaxabilityValue.new('exempt') end |
.from_string(value) ⇒ Object
Returns the instance of TaxabilityValue for this value, or nil if not found
19490 19491 19492 19493 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19490 def TaxabilityValue.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) TaxabilityValue.ALL.find { |v| v.value == value } end |
Instance Method Details
#to_hash ⇒ Object
19504 19505 19506 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19504 def to_hash value end |