Class: Io::Flow::V0::Models::TierStrategy
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::TierStrategy
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of TierStrategy for this value, creating a new instance for an unknown value.
-
.fastest ⇒ Object
Optimize for fastest first, then cheapest.
-
.from_string(value) ⇒ Object
Returns the instance of TierStrategy for this value, or nil if not found.
-
.lowest_cost ⇒ Object
Optimize for lowest cost first, then fastest.
Instance Method Summary collapse
-
#initialize(value) ⇒ TierStrategy
constructor
A new instance of TierStrategy.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ TierStrategy
Returns a new instance of TierStrategy.
19606 19607 19608 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19606 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
19604 19605 19606 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19604 def value @value end |
Class Method Details
.ALL ⇒ Object
19626 19627 19628 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19626 def TierStrategy.ALL @@all ||= [TierStrategy.fastest, TierStrategy.lowest_cost] end |
.apply(value) ⇒ Object
Returns the instance of TierStrategy for this value, creating a new instance for an unknown value
19611 19612 19613 19614 19615 19616 19617 19618 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19611 def TierStrategy.apply(value) if value.instance_of?(TierStrategy) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || TierStrategy.new(value)) end end |
.fastest ⇒ Object
Optimize for fastest first, then cheapest
19631 19632 19633 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19631 def TierStrategy.fastest @@_fastest ||= TierStrategy.new('fastest') end |
.from_string(value) ⇒ Object
Returns the instance of TierStrategy for this value, or nil if not found
19621 19622 19623 19624 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19621 def TierStrategy.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) TierStrategy.ALL.find { |v| v.value == value } end |
.lowest_cost ⇒ Object
Optimize for lowest cost first, then fastest
19636 19637 19638 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19636 def TierStrategy.lowest_cost @@_lowest_cost ||= TierStrategy.new('lowest_cost') end |
Instance Method Details
#to_hash ⇒ Object
19640 19641 19642 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19640 def to_hash value end |