Class: Io::Flow::V0::Models::TokenType

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ TokenType

Returns a new instance of TokenType.



16786
16787
16788
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16786

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



16784
16785
16786
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16784

def value
  @value
end

Class Method Details

.ALLObject



16806
16807
16808
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16806

def TokenType.ALL
  @@all ||= [TokenType.permanent, TokenType.one_time]
end

.apply(value) ⇒ Object

Returns the instance of TokenType for this value, creating a new instance for an unknown value



16791
16792
16793
16794
16795
16796
16797
16798
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16791

def TokenType.apply(value)
  if value.instance_of?(TokenType)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || TokenType.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of TokenType for this value, or nil if not found



16801
16802
16803
16804
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16801

def TokenType.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  TokenType.ALL.find { |v| v.value == value }
end

.one_timeObject

Create a one time token for the card. This token can be used to either authorized payment or later exchange for a permanent token. Once used, this token cannot be used for future activity.



16818
16819
16820
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16818

def TokenType.one_time
  @@_one_time ||= TokenType.new('one_time')
end

.permanentObject

Create a permanent token for the card (stored up until normal purge interval)



16811
16812
16813
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16811

def TokenType.permanent
  @@_permanent ||= TokenType.new('permanent')
end

Instance Method Details

#to_hashObject



16822
16823
16824
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16822

def to_hash
  value
end