Class: Io::Flow::V0::Models::TokenValidationForm

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Defines the payload of a request to validate a token, with primary goal of preventing the token from being included in an HTTP GET.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ TokenValidationForm

Returns a new instance of TokenValidationForm.



21986
21987
21988
21989
21990
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21986

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:token], 'TokenValidationForm')
  @token = HttpClient::Preconditions.assert_class('token', opts.delete(:token), String)
end

Instance Attribute Details

#token ⇒ Object (readonly)

Returns the value of attribute token.



21984
21985
21986
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21984

def token
  @token
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



21996
21997
21998
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21996

def copy(incoming={})
  TokenValidationForm.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hash ⇒ Object



22000
22001
22002
22003
22004
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 22000

def to_hash
  {
    :token => token
  }
end

#to_json ⇒ Object



21992
21993
21994
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 21992

def to_json
  JSON.dump(to_hash)
end