Class: Io::Flow::V0::Models::TrackingNumberType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::TrackingNumberType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of TrackingNumberType for this value, creating a new instance for an unknown value.
- .carrier ⇒ Object
- .flow ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of TrackingNumberType for this value, or nil if not found.
Instance Method Summary collapse
-
#initialize(value) ⇒ TrackingNumberType
constructor
A new instance of TrackingNumberType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ TrackingNumberType
Returns a new instance of TrackingNumberType.
25681 25682 25683 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 25681 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
25679 25680 25681 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 25679 def value @value end |
Class Method Details
.ALL ⇒ Object
25701 25702 25703 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 25701 def TrackingNumberType.ALL @@all ||= [TrackingNumberType.flow, TrackingNumberType.carrier] end |
.apply(value) ⇒ Object
Returns the instance of TrackingNumberType for this value, creating a new instance for an unknown value
25686 25687 25688 25689 25690 25691 25692 25693 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 25686 def TrackingNumberType.apply(value) if value.instance_of?(TrackingNumberType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || TrackingNumberType.new(value)) end end |
.carrier ⇒ Object
25709 25710 25711 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 25709 def TrackingNumberType.carrier @@_carrier ||= TrackingNumberType.new('carrier') end |
.flow ⇒ Object
25705 25706 25707 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 25705 def TrackingNumberType.flow @@_flow ||= TrackingNumberType.new('flow') end |
.from_string(value) ⇒ Object
Returns the instance of TrackingNumberType for this value, or nil if not found
25696 25697 25698 25699 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 25696 def TrackingNumberType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) TrackingNumberType.ALL.find { |v| v.value == value } end |
Instance Method Details
#to_hash ⇒ Object
25713 25714 25715 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 25713 def to_hash value end |