Class: Io::Flow::V0::Models::TrackingStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ TrackingStatus

Returns a new instance of TrackingStatus.



19738
19739
19740
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19738

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



19736
19737
19738
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19736

def value
  @value
end

Class Method Details

.ALLObject



19758
19759
19760
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19758

def TrackingStatus.ALL
  @@all ||= [TrackingStatus.label_created, TrackingStatus.pending, TrackingStatus.info_received, TrackingStatus.picked_up, TrackingStatus.in_transit, TrackingStatus.out_for_delivery, TrackingStatus.attempt_fail, TrackingStatus.delivered, TrackingStatus.exception, TrackingStatus.returned, TrackingStatus.expired]
end

.apply(value) ⇒ Object

Returns the instance of TrackingStatus for this value, creating a new instance for an unknown value



19743
19744
19745
19746
19747
19748
19749
19750
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19743

def TrackingStatus.apply(value)
  if value.instance_of?(TrackingStatus)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || TrackingStatus.new(value))
  end
end

.attempt_failObject



19786
19787
19788
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19786

def TrackingStatus.attempt_fail
  @@_attempt_fail ||= TrackingStatus.new('attempt_fail')
end

.deliveredObject



19790
19791
19792
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19790

def TrackingStatus.delivered
  @@_delivered ||= TrackingStatus.new('delivered')
end

.exceptionObject



19794
19795
19796
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19794

def TrackingStatus.exception
  @@_exception ||= TrackingStatus.new('exception')
end

.expiredObject



19802
19803
19804
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19802

def TrackingStatus.expired
  @@_expired ||= TrackingStatus.new('expired')
end

.from_string(value) ⇒ Object

Returns the instance of TrackingStatus for this value, or nil if not found



19753
19754
19755
19756
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19753

def TrackingStatus.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  TrackingStatus.ALL.find { |v| v.value == value }
end

.in_transitObject



19778
19779
19780
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19778

def TrackingStatus.in_transit
  @@_in_transit ||= TrackingStatus.new('in_transit')
end

.info_receivedObject



19770
19771
19772
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19770

def TrackingStatus.info_received
  @@_info_received ||= TrackingStatus.new('info_received')
end

.label_createdObject



19762
19763
19764
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19762

def TrackingStatus.label_created
  @@_label_created ||= TrackingStatus.new('label_created')
end

.out_for_deliveryObject



19782
19783
19784
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19782

def TrackingStatus.out_for_delivery
  @@_out_for_delivery ||= TrackingStatus.new('out_for_delivery')
end

.pendingObject



19766
19767
19768
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19766

def TrackingStatus.pending
  @@_pending ||= TrackingStatus.new('pending')
end

.picked_upObject



19774
19775
19776
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19774

def TrackingStatus.picked_up
  @@_picked_up ||= TrackingStatus.new('picked_up')
end

.returnedObject



19798
19799
19800
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19798

def TrackingStatus.returned
  @@_returned ||= TrackingStatus.new('returned')
end

Instance Method Details

#to_hashObject



19806
19807
19808
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19806

def to_hash
  value
end