Class: Io::Flow::V0::Models::UpdateType

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ UpdateType

Returns a new instance of UpdateType.



26145
26146
26147
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 26145

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



26143
26144
26145
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 26143

def value
  @value
end

Class Method Details

.ALLObject



26165
26166
26167
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 26165

def UpdateType.ALL
  @@all ||= [UpdateType.change, UpdateType.set]
end

.apply(value) ⇒ Object

Returns the instance of UpdateType for this value, creating a new instance for an unknown value



26150
26151
26152
26153
26154
26155
26156
26157
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 26150

def UpdateType.apply(value)
  if value.instance_of?(UpdateType)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || UpdateType.new(value))
  end
end

.changeObject

Long value to increment or decrement. Positive quantities are added to inventory while negative quantities are decrement from inventory.



26171
26172
26173
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 26171

def UpdateType.change
  @@_change ||= UpdateType.new('change')
end

.from_string(value) ⇒ Object

Returns the instance of UpdateType for this value, or nil if not found



26160
26161
26162
26163
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 26160

def UpdateType.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  UpdateType.ALL.find { |v| v.value == value }
end

.setObject

Set absolute quantity to new value with no regard for previous updates



26176
26177
26178
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 26176

def UpdateType.set
  @@_set ||= UpdateType.new('set')
end

Instance Method Details

#to_hashObject



26180
26181
26182
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 26180

def to_hash
  value
end