Class: Io::Flow::V0::Clients::Refunds
- Inherits:
-
Object
- Object
- Io::Flow::V0::Clients::Refunds
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Method Summary collapse
- #get(organization, incoming = {}) ⇒ Object
-
#get_by_key(organization, key) ⇒ Object
Returns information about a specific refund.
-
#get_summary_by_order_number(organization, order_number) ⇒ Object
Returns a refund order summary for the specified order.
-
#get_versions(organization, incoming = {}) ⇒ Object
Provides visibility into recent changes of each object, including deletion.
-
#initialize(client) ⇒ Refunds
constructor
A new instance of Refunds.
-
#post(organization, refund_form) ⇒ Object
Create a new refund.
Constructor Details
#initialize(client) ⇒ Refunds
Returns a new instance of Refunds.
2274 2275 2276 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 2274 def initialize(client) @client = HttpClient::Preconditions.assert_class('client', client, ::Io::Flow::V0::Client) end |
Instance Method Details
#get(organization, incoming = {}) ⇒ Object
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 2278 def get(organization, incoming={}) HttpClient::Preconditions.assert_class('organization', organization, String) opts = HttpClient::Helper.symbolize_keys(incoming) query = { :id => (x = opts.delete(:id); x.nil? ? nil : HttpClient::Preconditions.assert_class('id', x, Array).map { |v| HttpClient::Preconditions.assert_class('id', v, String) }), :key => (x = opts.delete(:key); x.nil? ? nil : HttpClient::Preconditions.assert_class('key', x, Array).map { |v| HttpClient::Preconditions.assert_class('key', v, String) }), :authorization_id => (x = opts.delete(:authorization_id); x.nil? ? nil : HttpClient::Preconditions.assert_class('authorization_id', x, String)), :authorization_key => (x = opts.delete(:authorization_key); x.nil? ? nil : HttpClient::Preconditions.assert_class('authorization_key', x, String)), :capture_id => (x = opts.delete(:capture_id); x.nil? ? nil : HttpClient::Preconditions.assert_class('capture_id', x, String)), :capture_key => (x = opts.delete(:capture_key); x.nil? ? nil : HttpClient::Preconditions.assert_class('capture_key', x, String)), :limit => HttpClient::Preconditions.assert_class('limit', (x = opts.delete(:limit); x.nil? ? 25 : x), Integer), :offset => HttpClient::Preconditions.assert_class('offset', (x = opts.delete(:offset); x.nil? ? 0 : x), Integer), :sort => HttpClient::Preconditions.assert_class('sort', (x = opts.delete(:sort); x.nil? ? "-created_at" : x), String) }.delete_if { |k, v| v.nil? } r = @client.request("/#{CGI.escape(organization)}/refunds").with_query(query).get r.map { |x| ::Io::Flow::V0::Models::Refund.new(x) } end |
#get_by_key(organization, key) ⇒ Object
Returns information about a specific refund.
2305 2306 2307 2308 2309 2310 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 2305 def get_by_key(organization, key) HttpClient::Preconditions.assert_class('organization', organization, String) HttpClient::Preconditions.assert_class('key', key, String) r = @client.request("/#{CGI.escape(organization)}/refunds/#{CGI.escape(key)}").get ::Io::Flow::V0::Models::Refund.new(r) end |
#get_summary_by_order_number(organization, order_number) ⇒ Object
Returns a refund order summary for the specified order.
2313 2314 2315 2316 2317 2318 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 2313 def get_summary_by_order_number(organization, order_number) HttpClient::Preconditions.assert_class('organization', organization, String) HttpClient::Preconditions.assert_class('order_number', order_number, String) r = @client.request("/#{CGI.escape(organization)}/refunds/summary/#{CGI.escape(order_number)}").get ::Io::Flow::V0::Models::RefundOrderSummary.new(r) end |
#get_versions(organization, incoming = {}) ⇒ Object
Provides visibility into recent changes of each object, including deletion
2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 2321 def get_versions(organization, incoming={}) HttpClient::Preconditions.assert_class('organization', organization, String) opts = HttpClient::Helper.symbolize_keys(incoming) query = { :id => (x = opts.delete(:id); x.nil? ? nil : HttpClient::Preconditions.assert_class('id', x, Array).map { |v| HttpClient::Preconditions.assert_class('id', v, String) }), :refund_id => (x = opts.delete(:refund_id); x.nil? ? nil : HttpClient::Preconditions.assert_class('refund_id', x, Array).map { |v| HttpClient::Preconditions.assert_class('refund_id', v, String) }), :limit => HttpClient::Preconditions.assert_class('limit', (x = opts.delete(:limit); x.nil? ? 25 : x), Integer), :offset => HttpClient::Preconditions.assert_class('offset', (x = opts.delete(:offset); x.nil? ? 0 : x), Integer), :sort => HttpClient::Preconditions.assert_class('sort', (x = opts.delete(:sort); x.nil? ? "journal_timestamp" : x), String) }.delete_if { |k, v| v.nil? } r = @client.request("/#{CGI.escape(organization)}/refunds/versions").with_query(query).get r.map { |x| ::Io::Flow::V0::Models::RefundVersion.new(x) } end |
#post(organization, refund_form) ⇒ Object
Create a new refund.
2297 2298 2299 2300 2301 2302 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 2297 def post(organization, refund_form) HttpClient::Preconditions.assert_class('organization', organization, String) HttpClient::Preconditions.assert_class('refund_form', refund_form, ::Io::Flow::V0::Models::RefundForm) r = @client.request("/#{CGI.escape(organization)}/refunds").with_json(refund_form.to_json).post ::Io::Flow::V0::Models::Refund.new(r) end |