Class: Io::Flow::V0::Models::Address

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Defines structured fields for address to be used in user/form input. Either text or the structured input needs to be present.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ Address

Returns a new instance of Address.



9100
9101
9102
9103
9104
9105
9106
9107
9108
9109
9110
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9100

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  @text = (x = opts.delete(:text); x.nil? ? nil : HttpClient::Preconditions.assert_class('text', x, String))
  @streets = (x = opts.delete(:streets); x.nil? ? nil : HttpClient::Preconditions.assert_class('streets', x, Array).map { |v| HttpClient::Preconditions.assert_class('streets', v, String) })
  @city = (x = opts.delete(:city); x.nil? ? nil : HttpClient::Preconditions.assert_class('city', x, String))
  @province = (x = opts.delete(:province); x.nil? ? nil : HttpClient::Preconditions.assert_class('province', x, String))
  @postal = (x = opts.delete(:postal); x.nil? ? nil : HttpClient::Preconditions.assert_class('postal', x, String))
  @country = (x = opts.delete(:country); x.nil? ? nil : HttpClient::Preconditions.assert_class('country', x, String))
  @latitude = (x = opts.delete(:latitude); x.nil? ? nil : HttpClient::Preconditions.assert_class('latitude', x, String))
  @longitude = (x = opts.delete(:longitude); x.nil? ? nil : HttpClient::Preconditions.assert_class('longitude', x, String))
end

Instance Attribute Details

#city ⇒ Object (readonly)

Returns the value of attribute city.



9098
9099
9100
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9098

def city
  @city
end

#country ⇒ Object (readonly)

Returns the value of attribute country.



9098
9099
9100
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9098

def country
  @country
end

#latitude ⇒ Object (readonly)

Returns the value of attribute latitude.



9098
9099
9100
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9098

def latitude
  @latitude
end

#longitude ⇒ Object (readonly)

Returns the value of attribute longitude.



9098
9099
9100
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9098

def longitude
  @longitude
end

#postal ⇒ Object (readonly)

Returns the value of attribute postal.



9098
9099
9100
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9098

def postal
  @postal
end

#province ⇒ Object (readonly)

Returns the value of attribute province.



9098
9099
9100
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9098

def province
  @province
end

#streets ⇒ Object (readonly)

Returns the value of attribute streets.



9098
9099
9100
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9098

def streets
  @streets
end

#text ⇒ Object (readonly)

Returns the value of attribute text.



9098
9099
9100
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9098

def text
  @text
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



9116
9117
9118
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9116

def copy(incoming={})
  Address.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hash ⇒ Object



9120
9121
9122
9123
9124
9125
9126
9127
9128
9129
9130
9131
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9120

def to_hash
  {
    :text => text,
    :streets => streets.nil? ? nil : streets,
    :city => city,
    :province => province,
    :postal => postal,
    :country => country,
    :latitude => latitude,
    :longitude => longitude
  }
end

#to_json ⇒ Object



9112
9113
9114
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9112

def to_json
  JSON.dump(to_hash)
end