Class: Io::Flow::V0::Models::AddressVerification

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Address verification returns information on whether or not an address is valid and deliverable - meaning carriers will accept this address. Also returns suggestions for address correction, including data to highlight specific fields to correct.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ AddressVerification

Returns a new instance of AddressVerification.



9182
9183
9184
9185
9186
9187
9188
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9182

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:address, :valid], 'AddressVerification')
  @address = (x = opts.delete(:address); x.is_a?(::Io::Flow::V0::Models::Address) ? x : ::Io::Flow::V0::Models::Address.new(x))
  @valid = HttpClient::Preconditions.assert_boolean('valid', opts.delete(:valid))
  @suggestions = HttpClient::Preconditions.assert_class('suggestions', (x = opts.delete(:suggestions); x.nil? ? [] : x), Array).map { |v| (x = v; x.is_a?(::Io::Flow::V0::Models::AddressSuggestion) ? x : ::Io::Flow::V0::Models::AddressSuggestion.new(x)) }
end

Instance Attribute Details

#address ⇒ Object (readonly)

Returns the value of attribute address.



9180
9181
9182
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9180

def address
  @address
end

#suggestions ⇒ Object (readonly)

Returns the value of attribute suggestions.



9180
9181
9182
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9180

def suggestions
  @suggestions
end

#valid ⇒ Object (readonly)

Returns the value of attribute valid.



9180
9181
9182
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9180

def valid
  @valid
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



9194
9195
9196
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9194

def copy(incoming={})
  AddressVerification.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hash ⇒ Object



9198
9199
9200
9201
9202
9203
9204
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9198

def to_hash
  {
    :address => address.to_hash,
    :valid => valid,
    :suggestions => suggestions.map { |o| o.to_hash }
  }
end

#to_json ⇒ Object



9190
9191
9192
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9190

def to_json
  JSON.dump(to_hash)
end