Class: Io::Flow::V0::Models::AttributeDataType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::AttributeDataType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of AttributeDataType for this value, creating a new instance for an unknown value.
-
.boolean ⇒ Object
Boolean true/false data type.
-
.decimal ⇒ Object
Decimal datatype without size or precision restrictions.
-
.from_string(value) ⇒ Object
Returns the instance of AttributeDataType for this value, or nil if not found.
-
.json_array ⇒ Object
An example ["Cotton", "Wool"].
-
.string ⇒ Object
Unvalidated string of characters.
Instance Method Summary collapse
-
#initialize(value) ⇒ AttributeDataType
constructor
A new instance of AttributeDataType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ AttributeDataType
Returns a new instance of AttributeDataType.
11943 11944 11945 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11943 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
11941 11942 11943 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11941 def value @value end |
Class Method Details
.ALL ⇒ Object
11963 11964 11965 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11963 def AttributeDataType.ALL @@all ||= [AttributeDataType.boolean, AttributeDataType.decimal, AttributeDataType.string, AttributeDataType.json_array] end |
.apply(value) ⇒ Object
Returns the instance of AttributeDataType for this value, creating a new instance for an unknown value
11948 11949 11950 11951 11952 11953 11954 11955 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11948 def AttributeDataType.apply(value) if value.instance_of?(AttributeDataType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || AttributeDataType.new(value)) end end |
.boolean ⇒ Object
Boolean true/false data type
11968 11969 11970 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11968 def AttributeDataType.boolean @@_boolean ||= AttributeDataType.new('boolean') end |
.decimal ⇒ Object
Decimal datatype without size or precision restrictions. Commonly used for currency values.
11974 11975 11976 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11974 def AttributeDataType.decimal @@_decimal ||= AttributeDataType.new('decimal') end |
.from_string(value) ⇒ Object
Returns the instance of AttributeDataType for this value, or nil if not found
11958 11959 11960 11961 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11958 def AttributeDataType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) AttributeDataType.ALL.find { |v| v.value == value } end |
.json_array ⇒ Object
An example ["Cotton", "Wool"]
11984 11985 11986 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11984 def AttributeDataType.json_array @@_json_array ||= AttributeDataType.new('json_array') end |
.string ⇒ Object
Unvalidated string of characters.
11979 11980 11981 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11979 def AttributeDataType.string @@_string ||= AttributeDataType.new('string') end |
Instance Method Details
#to_hash ⇒ Object
11988 11989 11990 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11988 def to_hash value end |