Class: Io::Flow::V0::Models::AttributeIntent
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::AttributeIntent
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of AttributeIntent for this value, creating a new instance for an unknown value.
-
.brand ⇒ Object
A brand name of the item (for retailers that sell multiple brands).
-
.color ⇒ Object
The color of the item.
-
.consumer_url ⇒ Object
A URL of the product detail page of the item.
-
.countries_of_origin ⇒ Object
A space separated list of the countries of origin for this item.
-
.excluded_regions ⇒ Object
A space separated list of the regions (as defined in https://api.flow.io/reference/regions) where the item must be excluded.
-
.facet ⇒ Object
Identifies a facet.
-
.from_string(value) ⇒ Object
Returns the instance of AttributeIntent for this value, or nil if not found.
-
.fulfillment_method ⇒ Object
Identifies whether the item is a physical or digital good.
-
.gtin ⇒ Object
The Global Trade Item Number of this item.
-
.hazardous ⇒ Object
Identifies whether this item may contain hazardous materials.
-
.mpn ⇒ Object
The Manufacturer Part Number of this item.
-
.price ⇒ Object
A price for the item in the organization's base currency (will be localized based on each Experience's pricing policy).
-
.product_id ⇒ Object
An identifier used to group items that are variations of the same product, such as different sizes or colors of the same shirt.
-
.size ⇒ Object
A size label of the item.
-
.sku ⇒ Object
An SKU for the item.
-
.taxability ⇒ Object
Identifies whether taxes are applicable to an item.
Instance Method Summary collapse
-
#initialize(value) ⇒ AttributeIntent
constructor
A new instance of AttributeIntent.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ AttributeIntent
Returns a new instance of AttributeIntent.
11998 11999 12000 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11998 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
11996 11997 11998 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 11996 def value @value end |
Class Method Details
.ALL ⇒ Object
12018 12019 12020 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12018 def AttributeIntent.ALL @@all ||= [AttributeIntent.brand, AttributeIntent.color, AttributeIntent.countries_of_origin, AttributeIntent.product_id, AttributeIntent.fulfillment_method, AttributeIntent.hazardous, AttributeIntent.price, AttributeIntent.size, AttributeIntent.sku, AttributeIntent.taxability, AttributeIntent.consumer_url, AttributeIntent.gtin, AttributeIntent.mpn, AttributeIntent.excluded_regions, AttributeIntent.facet] end |
.apply(value) ⇒ Object
Returns the instance of AttributeIntent for this value, creating a new instance for an unknown value
12003 12004 12005 12006 12007 12008 12009 12010 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12003 def AttributeIntent.apply(value) if value.instance_of?(AttributeIntent) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || AttributeIntent.new(value)) end end |
.brand ⇒ Object
A brand name of the item (for retailers that sell multiple brands)
12023 12024 12025 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12023 def AttributeIntent.brand @@_brand ||= AttributeIntent.new('brand') end |
.color ⇒ Object
The color of the item
12028 12029 12030 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12028 def AttributeIntent.color @@_color ||= AttributeIntent.new('color') end |
.consumer_url ⇒ Object
A URL of the product detail page of the item
12075 12076 12077 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12075 def AttributeIntent.consumer_url @@_consumer_url ||= AttributeIntent.new('consumer_url') end |
.countries_of_origin ⇒ Object
A space separated list of the countries of origin for this item
12033 12034 12035 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12033 def AttributeIntent.countries_of_origin @@_countries_of_origin ||= AttributeIntent.new('countries_of_origin') end |
.excluded_regions ⇒ Object
A space separated list of the regions (as defined in https://api.flow.io/reference/regions) where the item must be excluded.
12091 12092 12093 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12091 def AttributeIntent.excluded_regions @@_excluded_regions ||= AttributeIntent.new('excluded_regions') end |
.facet ⇒ Object
Identifies a facet.
12096 12097 12098 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12096 def AttributeIntent.facet @@_facet ||= AttributeIntent.new('facet') end |
.from_string(value) ⇒ Object
Returns the instance of AttributeIntent for this value, or nil if not found
12013 12014 12015 12016 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12013 def AttributeIntent.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) AttributeIntent.ALL.find { |v| v.value == value } end |
.fulfillment_method ⇒ Object
Identifies whether the item is a physical or digital good
12044 12045 12046 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12044 def AttributeIntent.fulfillment_method @@_fulfillment_method ||= AttributeIntent.new('fulfillment_method') end |
.gtin ⇒ Object
The Global Trade Item Number of this item.
12080 12081 12082 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12080 def AttributeIntent.gtin @@_gtin ||= AttributeIntent.new('gtin') end |
.hazardous ⇒ Object
Identifies whether this item may contain hazardous materials
12049 12050 12051 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12049 def AttributeIntent.hazardous @@_hazardous ||= AttributeIntent.new('hazardous') end |
.mpn ⇒ Object
The Manufacturer Part Number of this item.
12085 12086 12087 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12085 def AttributeIntent.mpn @@_mpn ||= AttributeIntent.new('mpn') end |
.price ⇒ Object
A price for the item in the organization's base currency (will be localized based on each Experience's pricing policy)
12055 12056 12057 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12055 def AttributeIntent.price @@_price ||= AttributeIntent.new('price') end |
.product_id ⇒ Object
An identifier used to group items that are variations of the same product, such as different sizes or colors of the same shirt
12039 12040 12041 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12039 def AttributeIntent.product_id @@_product_id ||= AttributeIntent.new('product_id') end |
.size ⇒ Object
A size label of the item
12060 12061 12062 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12060 def AttributeIntent.size @@_size ||= AttributeIntent.new('size') end |
.sku ⇒ Object
An SKU for the item
12065 12066 12067 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12065 def AttributeIntent.sku @@_sku ||= AttributeIntent.new('sku') end |
.taxability ⇒ Object
Identifies whether taxes are applicable to an item
12070 12071 12072 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12070 def AttributeIntent.taxability @@_taxability ||= AttributeIntent.new('taxability') end |
Instance Method Details
#to_hash ⇒ Object
12100 12101 12102 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12100 def to_hash value end |