Class: Io::Flow::V0::Models::AuthorizationOption
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::AuthorizationOption
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of AuthorizationOption for this value, creating a new instance for an unknown value.
-
.from_string(value) ⇒ Object
Returns the instance of AuthorizationOption for this value, or nil if not found.
-
.store_card ⇒ Object
If set, and the authorization is created using a one time nonce, we automatically tokenize and store the card.
Instance Method Summary collapse
-
#initialize(value) ⇒ AuthorizationOption
constructor
A new instance of AuthorizationOption.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ AuthorizationOption
Returns a new instance of AuthorizationOption.
12277 12278 12279 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12277 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
12275 12276 12277 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12275 def value @value end |
Class Method Details
.ALL ⇒ Object
12297 12298 12299 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12297 def AuthorizationOption.ALL @@all ||= [AuthorizationOption.store_card] end |
.apply(value) ⇒ Object
Returns the instance of AuthorizationOption for this value, creating a new instance for an unknown value
12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12282 def AuthorizationOption.apply(value) if value.instance_of?(AuthorizationOption) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || AuthorizationOption.new(value)) end end |
.from_string(value) ⇒ Object
Returns the instance of AuthorizationOption for this value, or nil if not found
12292 12293 12294 12295 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12292 def AuthorizationOption.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) AuthorizationOption.ALL.find { |v| v.value == value } end |
.store_card ⇒ Object
If set, and the authorization is created using a one time nonce, we automatically tokenize and store the card. In these cases you will want to store the new card token in the authorization response (card object)
12304 12305 12306 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12304 def AuthorizationOption.store_card @@_store_card ||= AuthorizationOption.new('store_card') end |
Instance Method Details
#to_hash ⇒ Object
12308 12309 12310 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12308 def to_hash value end |