Class: Io::Flow::V0::Models::AvsCode

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ AvsCode

Returns a new instance of AvsCode.



12547
12548
12549
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12547

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



12545
12546
12547
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12545

def value
  @value
end

Class Method Details

.ALLObject



12567
12568
12569
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12567

def AvsCode.ALL
  @@all ||= [AvsCode.match, AvsCode.partial, AvsCode.unsupported, AvsCode.no_match]
end

.apply(value) ⇒ Object

Returns the instance of AvsCode for this value, creating a new instance for an unknown value



12552
12553
12554
12555
12556
12557
12558
12559
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12552

def AvsCode.apply(value)
  if value.instance_of?(AvsCode)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || AvsCode.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of AvsCode for this value, or nil if not found



12562
12563
12564
12565
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12562

def AvsCode.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  AvsCode.ALL.find { |v| v.value == value }
end

.matchObject

Full match



12572
12573
12574
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12572

def AvsCode.match
  @@_match ||= AvsCode.new('match')
end

.no_matchObject

Address does not match expected card values



12588
12589
12590
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12588

def AvsCode.no_match
  @@_no_match ||= AvsCode.new('no_match')
end

.partialObject

Partial match; see details in 'avs' model to understand which components matched



12578
12579
12580
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12578

def AvsCode.partial
  @@_partial ||= AvsCode.new('partial')
end

.unsupportedObject

Issuer does not support address verification



12583
12584
12585
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12583

def AvsCode.unsupported
  @@_unsupported ||= AvsCode.new('unsupported')
end

Instance Method Details

#to_hashObject



12592
12593
12594
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12592

def to_hash
  value
end