Class: Io::Flow::V0::Models::Capture
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::Capture
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
Capture actually transfers funds. You can capture as many times as you'd like up until the total amount of the authorization has been captured or the authorization otherwise becomes unavailable (e.g. expires).
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Returns the value of attribute amount.
-
#authorization ⇒ Object
readonly
Returns the value of attribute authorization.
-
#created_at ⇒ Object
readonly
Returns the value of attribute created_at.
-
#currency ⇒ Object
readonly
Returns the value of attribute currency.
-
#id ⇒ Object
readonly
Returns the value of attribute id.
-
#key ⇒ Object
readonly
Returns the value of attribute key.
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ Capture
constructor
A new instance of Capture.
- #to_hash ⇒ Object
- #to_json ⇒ Object
Constructor Details
#initialize(incoming = {}) ⇒ Capture
Returns a new instance of Capture.
10093 10094 10095 10096 10097 10098 10099 10100 10101 10102 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 10093 def initialize(incoming={}) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:id, :key, :authorization, :amount, :currency, :created_at], 'Capture') @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String) @key = HttpClient::Preconditions.assert_class('key', opts.delete(:key), String) = (x = opts.delete(:authorization); x.is_a?(::Io::Flow::V0::Models::AuthorizationReference) ? x : ::Io::Flow::V0::Models::AuthorizationReference.new(x)) @amount = HttpClient::Preconditions.assert_class('amount', HttpClient::Helper.to_big_decimal(opts.delete(:amount)), BigDecimal) @currency = HttpClient::Preconditions.assert_class('currency', opts.delete(:currency), String) @created_at = HttpClient::Preconditions.assert_class('created_at', HttpClient::Helper.to_date_time_iso8601(opts.delete(:created_at)), DateTime) end |
Instance Attribute Details
#amount ⇒ Object (readonly)
Returns the value of attribute amount.
10091 10092 10093 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 10091 def amount @amount end |
#authorization ⇒ Object (readonly)
Returns the value of attribute authorization.
10091 10092 10093 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 10091 def end |
#created_at ⇒ Object (readonly)
Returns the value of attribute created_at.
10091 10092 10093 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 10091 def created_at @created_at end |
#currency ⇒ Object (readonly)
Returns the value of attribute currency.
10091 10092 10093 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 10091 def currency @currency end |
#id ⇒ Object (readonly)
Returns the value of attribute id.
10091 10092 10093 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 10091 def id @id end |
#key ⇒ Object (readonly)
Returns the value of attribute key.
10091 10092 10093 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 10091 def key @key end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
10108 10109 10110 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 10108 def copy(incoming={}) Capture.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#to_hash ⇒ Object
10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 10112 def to_hash { :id => id, :key => key, :authorization => .to_hash, :amount => amount, :currency => currency, :created_at => created_at } end |
#to_json ⇒ Object
10104 10105 10106 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 10104 def to_json JSON.dump(to_hash) end |