Class: Io::Flow::V0::Models::CaptureStatus
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::CaptureStatus
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of CaptureStatus for this value, creating a new instance for an unknown value.
-
.canceled ⇒ Object
The capture was canceled.
-
.failed ⇒ Object
The capture failed to process.
-
.from_string(value) ⇒ Object
Returns the instance of CaptureStatus for this value, or nil if not found.
-
.pending ⇒ Object
The capture has been initiated and requires time to complete.
-
.succeeded ⇒ Object
The capture has been processed successfully.
Instance Method Summary collapse
-
#initialize(value) ⇒ CaptureStatus
constructor
A new instance of CaptureStatus.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ CaptureStatus
Returns a new instance of CaptureStatus.
12788 12789 12790 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12788 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
12786 12787 12788 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12786 def value @value end |
Class Method Details
.ALL ⇒ Object
12808 12809 12810 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12808 def CaptureStatus.ALL @@all ||= [CaptureStatus.pending, CaptureStatus.succeeded, CaptureStatus.failed, CaptureStatus.canceled] end |
.apply(value) ⇒ Object
Returns the instance of CaptureStatus for this value, creating a new instance for an unknown value
12793 12794 12795 12796 12797 12798 12799 12800 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12793 def CaptureStatus.apply(value) if value.instance_of?(CaptureStatus) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || CaptureStatus.new(value)) end end |
.canceled ⇒ Object
The capture was canceled.
12828 12829 12830 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12828 def CaptureStatus.canceled @@_canceled ||= CaptureStatus.new('canceled') end |
.failed ⇒ Object
The capture failed to process.
12823 12824 12825 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12823 def CaptureStatus.failed @@_failed ||= CaptureStatus.new('failed') end |
.from_string(value) ⇒ Object
Returns the instance of CaptureStatus for this value, or nil if not found
12803 12804 12805 12806 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12803 def CaptureStatus.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) CaptureStatus.ALL.find { |v| v.value == value } end |
.pending ⇒ Object
The capture has been initiated and requires time to complete.
12813 12814 12815 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12813 def CaptureStatus.pending @@_pending ||= CaptureStatus.new('pending') end |
.succeeded ⇒ Object
The capture has been processed successfully.
12818 12819 12820 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12818 def CaptureStatus.succeeded @@_succeeded ||= CaptureStatus.new('succeeded') end |
Instance Method Details
#to_hash ⇒ Object
12832 12833 12834 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12832 def to_hash value end |