Class: Io::Flow::V0::Models::ConsumerInvoiceCustomerType

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ ConsumerInvoiceCustomerType

Returns a new instance of ConsumerInvoiceCustomerType.



13189
13190
13191
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13189

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



13187
13188
13189
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13187

def value
  @value
end

Class Method Details

.ALLObject



13209
13210
13211
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13209

def ConsumerInvoiceCustomerType.ALL
  @@all ||= [ConsumerInvoiceCustomerType.business_eu_verified, ConsumerInvoiceCustomerType.business_non_verified, ConsumerInvoiceCustomerType.individual]
end

.apply(value) ⇒ Object

Returns the instance of ConsumerInvoiceCustomerType for this value, creating a new instance for an unknown value



13194
13195
13196
13197
13198
13199
13200
13201
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13194

def ConsumerInvoiceCustomerType.apply(value)
  if value.instance_of?(ConsumerInvoiceCustomerType)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || ConsumerInvoiceCustomerType.new(value))
  end
end

.business_eu_verifiedObject

A business that have been verified in the European Union



13214
13215
13216
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13214

def ConsumerInvoiceCustomerType.business_eu_verified
  @@_business_eu_verified ||= ConsumerInvoiceCustomerType.new('business_eu_verified')
end

.business_non_verifiedObject

A business, but with no additional verification



13219
13220
13221
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13219

def ConsumerInvoiceCustomerType.business_non_verified
  @@_business_non_verified ||= ConsumerInvoiceCustomerType.new('business_non_verified')
end

.from_string(value) ⇒ Object

Returns the instance of ConsumerInvoiceCustomerType for this value, or nil if not found



13204
13205
13206
13207
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13204

def ConsumerInvoiceCustomerType.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  ConsumerInvoiceCustomerType.ALL.find { |v| v.value == value }
end

.individualObject



13223
13224
13225
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13223

def ConsumerInvoiceCustomerType.individual
  @@_individual ||= ConsumerInvoiceCustomerType.new('individual')
end

Instance Method Details

#to_hashObject



13227
13228
13229
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13227

def to_hash
  value
end