Class: Io::Flow::V0::Models::ConsumerInvoiceDocumentType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::ConsumerInvoiceDocumentType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of ConsumerInvoiceDocumentType for this value, creating a new instance for an unknown value.
-
.from_string(value) ⇒ Object
Returns the instance of ConsumerInvoiceDocumentType for this value, or nil if not found.
- .pdf ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ ConsumerInvoiceDocumentType
constructor
A new instance of ConsumerInvoiceDocumentType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ ConsumerInvoiceDocumentType
Returns a new instance of ConsumerInvoiceDocumentType.
13139 13140 13141 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13139 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
13137 13138 13139 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13137 def value @value end |
Class Method Details
.ALL ⇒ Object
13159 13160 13161 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13159 def ConsumerInvoiceDocumentType.ALL @@all ||= [ConsumerInvoiceDocumentType.pdf] end |
.apply(value) ⇒ Object
Returns the instance of ConsumerInvoiceDocumentType for this value, creating a new instance for an unknown value
13144 13145 13146 13147 13148 13149 13150 13151 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13144 def ConsumerInvoiceDocumentType.apply(value) if value.instance_of?(ConsumerInvoiceDocumentType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || ConsumerInvoiceDocumentType.new(value)) end end |
.from_string(value) ⇒ Object
Returns the instance of ConsumerInvoiceDocumentType for this value, or nil if not found
13154 13155 13156 13157 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13154 def ConsumerInvoiceDocumentType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) ConsumerInvoiceDocumentType.ALL.find { |v| v.value == value } end |
.pdf ⇒ Object
13163 13164 13165 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13163 def ConsumerInvoiceDocumentType.pdf @@_pdf ||= ConsumerInvoiceDocumentType.new('pdf') end |
Instance Method Details
#to_hash ⇒ Object
13167 13168 13169 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13167 def to_hash value end |