Class: Io::Flow::V0::Models::CreditPaymentErrorCode
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::CreditPaymentErrorCode
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.amount_exceeds_balance ⇒ Object
Indicates the provided credit amount exceeds the remaining balance on the order.
-
.amount_must_be_positive ⇒ Object
Indicates the provided credit amount was <= 0.
-
.apply(value) ⇒ Object
Returns the instance of CreditPaymentErrorCode for this value, creating a new instance for an unknown value.
-
.duplicate ⇒ Object
Indicates that a credit payment with the specified key already exists.
-
.from_string(value) ⇒ Object
Returns the instance of CreditPaymentErrorCode for this value, or nil if not found.
- .generic_error ⇒ Object
-
.insufficient_amount ⇒ Object
Indicates the provided credit amount exceeds the maximum amount of applicable credit.
-
.invalid_currency ⇒ Object
Indicates that the specified currency code is not valid.
-
.invalid_description ⇒ Object
Indicates that the description is invalid (must be non-empty).
-
.invalid_order_number ⇒ Object
Indicates the specified order does not exist.
Instance Method Summary collapse
-
#initialize(value) ⇒ CreditPaymentErrorCode
constructor
A new instance of CreditPaymentErrorCode.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ CreditPaymentErrorCode
Returns a new instance of CreditPaymentErrorCode.
13229 13230 13231 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13229 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
13227 13228 13229 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13227 def value @value end |
Class Method Details
.ALL ⇒ Object
13249 13250 13251 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13249 def CreditPaymentErrorCode.ALL @@all ||= [CreditPaymentErrorCode.generic_error, CreditPaymentErrorCode.invalid_order_number, CreditPaymentErrorCode.invalid_currency, CreditPaymentErrorCode.invalid_description, CreditPaymentErrorCode.duplicate, CreditPaymentErrorCode.amount_must_be_positive, CreditPaymentErrorCode.amount_exceeds_balance, CreditPaymentErrorCode.insufficient_amount] end |
.amount_exceeds_balance ⇒ Object
Indicates the provided credit amount exceeds the remaining balance on the order
13284 13285 13286 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13284 def CreditPaymentErrorCode.amount_exceeds_balance @@_amount_exceeds_balance ||= CreditPaymentErrorCode.new('amount_exceeds_balance') end |
.amount_must_be_positive ⇒ Object
Indicates the provided credit amount was <= 0
13278 13279 13280 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13278 def CreditPaymentErrorCode.amount_must_be_positive @@_amount_must_be_positive ||= CreditPaymentErrorCode.new('amount_must_be_positive') end |
.apply(value) ⇒ Object
Returns the instance of CreditPaymentErrorCode for this value, creating a new instance for an unknown value
13234 13235 13236 13237 13238 13239 13240 13241 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13234 def CreditPaymentErrorCode.apply(value) if value.instance_of?(CreditPaymentErrorCode) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || CreditPaymentErrorCode.new(value)) end end |
.duplicate ⇒ Object
Indicates that a credit payment with the specified key already exists
13273 13274 13275 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13273 def CreditPaymentErrorCode.duplicate @@_duplicate ||= CreditPaymentErrorCode.new('duplicate') end |
.from_string(value) ⇒ Object
Returns the instance of CreditPaymentErrorCode for this value, or nil if not found
13244 13245 13246 13247 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13244 def CreditPaymentErrorCode.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) CreditPaymentErrorCode.ALL.find { |v| v.value == value } end |
.generic_error ⇒ Object
13253 13254 13255 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13253 def CreditPaymentErrorCode.generic_error @@_generic_error ||= CreditPaymentErrorCode.new('generic_error') end |
.insufficient_amount ⇒ Object
Indicates the provided credit amount exceeds the maximum amount of applicable credit
13290 13291 13292 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13290 def CreditPaymentErrorCode.insufficient_amount @@_insufficient_amount ||= CreditPaymentErrorCode.new('insufficient_amount') end |
.invalid_currency ⇒ Object
Indicates that the specified currency code is not valid
13263 13264 13265 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13263 def CreditPaymentErrorCode.invalid_currency @@_invalid_currency ||= CreditPaymentErrorCode.new('invalid_currency') end |
.invalid_description ⇒ Object
Indicates that the description is invalid (must be non-empty)
13268 13269 13270 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13268 def CreditPaymentErrorCode.invalid_description @@_invalid_description ||= CreditPaymentErrorCode.new('invalid_description') end |
.invalid_order_number ⇒ Object
Indicates the specified order does not exist
13258 13259 13260 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13258 def CreditPaymentErrorCode.invalid_order_number @@_invalid_order_number ||= CreditPaymentErrorCode.new('invalid_order_number') end |
Instance Method Details
#to_hash ⇒ Object
13294 13295 13296 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13294 def to_hash value end |