Class: Io::Flow::V0::Models::CustomerAddressPreference

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Represents a customer address preference. Only a single address book contact can be associated per type. If contact is created or updated with a preference, existing preferences of the same type will be removed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ CustomerAddressPreference

Returns a new instance of CustomerAddressPreference.



26823
26824
26825
26826
26827
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 26823

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:type], 'CustomerAddressPreference')
  @type = (x = opts.delete(:type); x.is_a?(::Io::Flow::V0::Models::CustomerAddressType) ? x : ::Io::Flow::V0::Models::CustomerAddressType.apply(x))
end

Instance Attribute Details

#typeObject (readonly)

Returns the value of attribute type.



26821
26822
26823
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 26821

def type
  @type
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



26833
26834
26835
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 26833

def copy(incoming={})
  CustomerAddressPreference.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hashObject



26837
26838
26839
26840
26841
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 26837

def to_hash
  {
    :type => type.value
  }
end

#to_jsonObject



26829
26830
26831
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 26829

def to_json
  JSON.dump(to_hash)
end