Class: Io::Flow::V0::Models::CustomerAddressType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::CustomerAddressType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of CustomerAddressType for this value, creating a new instance for an unknown value.
- .billing ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of CustomerAddressType for this value, or nil if not found.
- .invoice ⇒ Object
- .shipping ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ CustomerAddressType
constructor
A new instance of CustomerAddressType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ CustomerAddressType
Returns a new instance of CustomerAddressType.
13390 13391 13392 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13390 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
13388 13389 13390 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13388 def value @value end |
Class Method Details
.ALL ⇒ Object
13410 13411 13412 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13410 def CustomerAddressType.ALL @@all ||= [CustomerAddressType.billing, CustomerAddressType.invoice, CustomerAddressType.shipping] end |
.apply(value) ⇒ Object
Returns the instance of CustomerAddressType for this value, creating a new instance for an unknown value
13395 13396 13397 13398 13399 13400 13401 13402 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13395 def CustomerAddressType.apply(value) if value.instance_of?(CustomerAddressType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || CustomerAddressType.new(value)) end end |
.billing ⇒ Object
13414 13415 13416 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13414 def CustomerAddressType.billing @@_billing ||= CustomerAddressType.new('billing') end |
.from_string(value) ⇒ Object
Returns the instance of CustomerAddressType for this value, or nil if not found
13405 13406 13407 13408 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13405 def CustomerAddressType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) CustomerAddressType.ALL.find { |v| v.value == value } end |
.invoice ⇒ Object
13418 13419 13420 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13418 def CustomerAddressType.invoice @@_invoice ||= CustomerAddressType.new('invoice') end |
.shipping ⇒ Object
13422 13423 13424 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13422 def CustomerAddressType.shipping @@_shipping ||= CustomerAddressType.new('shipping') end |
Instance Method Details
#to_hash ⇒ Object
13426 13427 13428 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13426 def to_hash value end |