Class: Io::Flow::V0::Models::CvvCode
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::CvvCode
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of CvvCode for this value, creating a new instance for an unknown value.
-
.from_string(value) ⇒ Object
Returns the instance of CvvCode for this value, or nil if not found.
-
.match ⇒ Object
CVV matches.
-
.no_match ⇒ Object
CVV did not match; Specific reason not available.
-
.suspicious ⇒ Object
CVV did not match; Transaction is possibly fraudulent.
-
.unsupported ⇒ Object
CVV did not match; Issuer does not support card verification numbers.
Instance Method Summary collapse
-
#initialize(value) ⇒ CvvCode
constructor
A new instance of CvvCode.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ CvvCode
Returns a new instance of CvvCode.
13436 13437 13438 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13436 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
13434 13435 13436 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13434 def value @value end |
Class Method Details
.ALL ⇒ Object
13456 13457 13458 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13456 def CvvCode.ALL @@all ||= [CvvCode.match, CvvCode.suspicious, CvvCode.unsupported, CvvCode.no_match] end |
.apply(value) ⇒ Object
Returns the instance of CvvCode for this value, creating a new instance for an unknown value
13441 13442 13443 13444 13445 13446 13447 13448 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13441 def CvvCode.apply(value) if value.instance_of?(CvvCode) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || CvvCode.new(value)) end end |
.from_string(value) ⇒ Object
Returns the instance of CvvCode for this value, or nil if not found
13451 13452 13453 13454 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13451 def CvvCode.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) CvvCode.ALL.find { |v| v.value == value } end |
.match ⇒ Object
CVV matches
13461 13462 13463 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13461 def CvvCode.match @@_match ||= CvvCode.new('match') end |
.no_match ⇒ Object
CVV did not match; Specific reason not available
13476 13477 13478 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13476 def CvvCode.no_match @@_no_match ||= CvvCode.new('no_match') end |
Instance Method Details
#to_hash ⇒ Object
13480 13481 13482 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13480 def to_hash value end |