Class: Io::Flow::V0::Models::DeliveryWindowComponentSource
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::DeliveryWindowComponentSource
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of DeliveryWindowComponentSource for this value, creating a new instance for an unknown value.
- .carrier ⇒ Object
- .center ⇒ Object
- .flow ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of DeliveryWindowComponentSource for this value, or nil if not found.
-
.mixed ⇒ Object
A delivery estimate may be a combination of multiple sources.
- .organization ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ DeliveryWindowComponentSource
constructor
A new instance of DeliveryWindowComponentSource.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ DeliveryWindowComponentSource
Returns a new instance of DeliveryWindowComponentSource.
13751 13752 13753 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13751 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
13749 13750 13751 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13749 def value @value end |
Class Method Details
.ALL ⇒ Object
13771 13772 13773 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13771 def DeliveryWindowComponentSource.ALL @@all ||= [DeliveryWindowComponentSource.flow, DeliveryWindowComponentSource.organization, DeliveryWindowComponentSource.carrier, DeliveryWindowComponentSource.center, DeliveryWindowComponentSource.mixed] end |
.apply(value) ⇒ Object
Returns the instance of DeliveryWindowComponentSource for this value, creating a new instance for an unknown value
13756 13757 13758 13759 13760 13761 13762 13763 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13756 def DeliveryWindowComponentSource.apply(value) if value.instance_of?(DeliveryWindowComponentSource) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || DeliveryWindowComponentSource.new(value)) end end |
.carrier ⇒ Object
13783 13784 13785 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13783 def DeliveryWindowComponentSource.carrier @@_carrier ||= DeliveryWindowComponentSource.new('carrier') end |
.center ⇒ Object
13787 13788 13789 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13787 def DeliveryWindowComponentSource.center @@_center ||= DeliveryWindowComponentSource.new('center') end |
.flow ⇒ Object
13775 13776 13777 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13775 def DeliveryWindowComponentSource.flow @@_flow ||= DeliveryWindowComponentSource.new('flow') end |
.from_string(value) ⇒ Object
Returns the instance of DeliveryWindowComponentSource for this value, or nil if not found
13766 13767 13768 13769 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13766 def DeliveryWindowComponentSource.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) DeliveryWindowComponentSource.ALL.find { |v| v.value == value } end |
.mixed ⇒ Object
A delivery estimate may be a combination of multiple sources
13792 13793 13794 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13792 def DeliveryWindowComponentSource.mixed @@_mixed ||= DeliveryWindowComponentSource.new('mixed') end |
.organization ⇒ Object
13779 13780 13781 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13779 def DeliveryWindowComponentSource.organization @@_organization ||= DeliveryWindowComponentSource.new('organization') end |
Instance Method Details
#to_hash ⇒ Object
13796 13797 13798 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13796 def to_hash value end |