Class: Io::Flow::V0::Models::Direction
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::Direction
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of Direction for this value, creating a new instance for an unknown value.
-
.from_string(value) ⇒ Object
Returns the instance of Direction for this value, or nil if not found.
-
.outbound ⇒ Object
Outbound shipment to typically fulfill a customer order.
-
.return ⇒ Object
Inbound or return shipment.
Instance Method Summary collapse
-
#initialize(value) ⇒ Direction
constructor
A new instance of Direction.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ Direction
Returns a new instance of Direction.
13852 13853 13854 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13852 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
13850 13851 13852 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13850 def value @value end |
Class Method Details
.ALL ⇒ Object
13872 13873 13874 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13872 def Direction.ALL @@all ||= [Direction.outbound, Direction.return] end |
.apply(value) ⇒ Object
Returns the instance of Direction for this value, creating a new instance for an unknown value
13857 13858 13859 13860 13861 13862 13863 13864 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13857 def Direction.apply(value) if value.instance_of?(Direction) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || Direction.new(value)) end end |
.from_string(value) ⇒ Object
Returns the instance of Direction for this value, or nil if not found
13867 13868 13869 13870 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13867 def Direction.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) Direction.ALL.find { |v| v.value == value } end |
.outbound ⇒ Object
Outbound shipment to typically fulfill a customer order
13877 13878 13879 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13877 def Direction.outbound @@_outbound ||= Direction.new('outbound') end |
.return ⇒ Object
Inbound or return shipment
13882 13883 13884 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13882 def Direction.return @@_return ||= Direction.new('return') end |
Instance Method Details
#to_hash ⇒ Object
13886 13887 13888 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13886 def to_hash value end |