Class: Io::Flow::V0::Models::EmailVerification
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::EmailVerification
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
Represents the successful response of an email verification token. We return the email address in this case to allow the UI to display which email address was verified.
Instance Attribute Summary collapse
-
#email ⇒ Object
readonly
Returns the value of attribute email.
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ EmailVerification
constructor
A new instance of EmailVerification.
- #to_hash ⇒ Object
- #to_json ⇒ Object
Constructor Details
#initialize(incoming = {}) ⇒ EmailVerification
Returns a new instance of EmailVerification.
12025 12026 12027 12028 12029 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12025 def initialize(incoming={}) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:email], 'EmailVerification') @email = HttpClient::Preconditions.assert_class('email', opts.delete(:email), String) end |
Instance Attribute Details
#email ⇒ Object (readonly)
Returns the value of attribute email.
12023 12024 12025 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12023 def email @email end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
12035 12036 12037 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12035 def copy(incoming={}) EmailVerification.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#to_hash ⇒ Object
12039 12040 12041 12042 12043 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12039 def to_hash { :email => email } end |
#to_json ⇒ Object
12031 12032 12033 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12031 def to_json JSON.dump(to_hash) end |