Class: Io::Flow::V0::Models::EventType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::EventType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
- .allocation_deleted_v2 ⇒ Object
- .allocation_upserted_v2 ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of EventType for this value, creating a new instance for an unknown value.
- .attribute_deleted ⇒ Object
- .attribute_deleted_v2 ⇒ Object
- .attribute_upserted ⇒ Object
- .attribute_upserted_v2 ⇒ Object
- .authorization_deleted_v2 ⇒ Object
- .authorization_status_changed ⇒ Object
- .available_promotions_deleted ⇒ Object
- .available_promotions_deleted_v2 ⇒ Object
- .available_promotions_upserted ⇒ Object
- .available_promotions_upserted_v2 ⇒ Object
- .b2b_credit_memo_deleted ⇒ Object
- .b2b_credit_memo_upserted ⇒ Object
- .b2b_invoice_deleted ⇒ Object
- .b2b_invoice_upserted ⇒ Object
- .browse_optin_responses_deleted ⇒ Object
- .browse_optin_responses_upserted ⇒ Object
- .capture_deleted ⇒ Object
- .capture_identifier_deleted ⇒ Object
- .capture_identifier_upserted ⇒ Object
- .capture_upserted_v2 ⇒ Object
- .card_authorization_deleted_v2 ⇒ Object
- .card_authorization_upserted_v2 ⇒ Object
- .card_deleted ⇒ Object
- .card_upserted_v2 ⇒ Object
- .catalog_deleted ⇒ Object
- .catalog_item_deleted ⇒ Object
- .catalog_item_deleted_v2 ⇒ Object
- .catalog_item_upserted ⇒ Object
- .catalog_item_upserted_v2 ⇒ Object
- .catalog_upserted ⇒ Object
- .center_deleted ⇒ Object
- .center_upserted ⇒ Object
- .channel_currency_deleted ⇒ Object
- .channel_currency_upserted ⇒ Object
- .channel_deleted ⇒ Object
- .channel_organization_deleted ⇒ Object
- .channel_organization_upserted ⇒ Object
- .channel_upserted ⇒ Object
- .checkout_optin_responses_deleted ⇒ Object
- .checkout_optin_responses_upserted ⇒ Object
- .consumer_invoice_deleted ⇒ Object
- .consumer_invoice_upserted ⇒ Object
- .country_status_deleted ⇒ Object
- .country_status_upserted ⇒ Object
- .credit_memo_deleted ⇒ Object
- .credit_memo_upserted ⇒ Object
- .crossdock_shipment_upserted ⇒ Object
- .currency_format_deleted ⇒ Object
- .currency_format_upserted ⇒ Object
- .customer_address_book_contact_deleted ⇒ Object
- .customer_address_book_contact_upserted ⇒ Object
- .customer_deleted ⇒ Object
- .customer_upserted ⇒ Object
- .ecommerce_platform_deleted ⇒ Object
- .ecommerce_platform_upserted ⇒ Object
- .email_notification_deleted ⇒ Object
- .email_notification_upserted ⇒ Object
- .experience_deleted ⇒ Object
- .experience_deleted_v2 ⇒ Object
- .experience_logistics_settings_deleted ⇒ Object
- .experience_logistics_settings_upserted ⇒ Object
- .experience_price_book_mapping_deleted ⇒ Object
- .experience_price_book_mapping_upserted ⇒ Object
- .experience_upserted ⇒ Object
- .experience_upserted_v2 ⇒ Object
- .fraud_status_changed ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of EventType for this value, or nil if not found.
- .fully_harmonized_item_upserted ⇒ Object
- .harmonized_landed_cost_upserted ⇒ Object
- .hs10_code_deleted ⇒ Object
- .hs10_code_upserted ⇒ Object
- .hs6_code_deleted ⇒ Object
- .hs6_code_upserted ⇒ Object
- .import_completed_v2 ⇒ Object
- .import_failed_v2 ⇒ Object
- .item_margin_deleted_v2 ⇒ Object
- .item_margin_upserted_v2 ⇒ Object
- .item_origin_deleted ⇒ Object
- .item_origin_upserted ⇒ Object
- .item_sales_margin_deleted ⇒ Object
- .item_sales_margin_upserted ⇒ Object
- .label_deleted_v2 ⇒ Object
- .label_format_deleted ⇒ Object
- .label_format_upserted ⇒ Object
- .label_upserted ⇒ Object
- .label_upserted_v2 ⇒ Object
- .local_item_deleted ⇒ Object
- .local_item_upserted ⇒ Object
- .manifested_label_deleted ⇒ Object
- .manifested_label_upserted ⇒ Object
- .membership_deleted_v2 ⇒ Object
- .membership_upserted_v2 ⇒ Object
- .notification_deleted_v2 ⇒ Object
- .notification_upserted_v2 ⇒ Object
- .online_authorization_deleted_v2 ⇒ Object
- .online_authorization_upserted_v2 ⇒ Object
- .order_deleted ⇒ Object
- .order_deleted_v2 ⇒ Object
- .order_identifier_deleted ⇒ Object
- .order_identifier_deleted_v2 ⇒ Object
- .order_identifier_upserted ⇒ Object
- .order_identifier_upserted_v2 ⇒ Object
- .order_identifier_upserted_v3 ⇒ Object
- .order_placed ⇒ Object
- .order_placed_v2 ⇒ Object
- .order_replacement_deleted ⇒ Object
- .order_replacement_upserted ⇒ Object
- .order_service_change_request ⇒ Object
- .order_upserted ⇒ Object
- .order_upserted_v2 ⇒ Object
- .organization_default_configurations_deleted ⇒ Object
- .organization_default_configurations_upserted ⇒ Object
- .organization_deleted ⇒ Object
- .organization_deleted_v2 ⇒ Object
- .organization_rates_published ⇒ Object
- .organization_upserted ⇒ Object
- .organization_upserted_v2 ⇒ Object
- .payment_deleted ⇒ Object
- .payment_request_upserted ⇒ Object
- .payment_upserted ⇒ Object
- .price_book_deleted ⇒ Object
- .price_book_item_deleted ⇒ Object
- .price_book_item_upserted ⇒ Object
- .price_book_upserted ⇒ Object
- .pricing_deleted ⇒ Object
- .pricing_upserted ⇒ Object
- .rate_deleted ⇒ Object
- .rate_deleted_v3 ⇒ Object
- .rate_upserted ⇒ Object
- .rate_upserted_v3 ⇒ Object
- .ratecard_deleted ⇒ Object
- .ratecard_lane_deleted ⇒ Object
- .ratecard_lane_upserted ⇒ Object
- .ratecard_upserted ⇒ Object
- .ready_to_fulfill ⇒ Object
- .ready_to_fulfill_v2 ⇒ Object
- .refund_capture_upserted_v2 ⇒ Object
- .refund_deleted_v2 ⇒ Object
- .refund_identifier_deleted ⇒ Object
- .refund_identifier_upserted ⇒ Object
- .refund_upserted_v2 ⇒ Object
- .return_deleted ⇒ Object
- .return_deleted_v2 ⇒ Object
- .return_upserted ⇒ Object
- .return_upserted_v2 ⇒ Object
- .reversal_deleted ⇒ Object
- .reversal_upserted ⇒ Object
- .rule_deleted ⇒ Object
- .rule_upserted ⇒ Object
- .shipping_configuration_deleted ⇒ Object
- .shipping_configuration_item_availability_deleted ⇒ Object
- .shipping_configuration_item_availability_upserted ⇒ Object
- .shipping_configuration_item_shipping_pricing_deleted ⇒ Object
- .shipping_configuration_item_shipping_pricing_upserted ⇒ Object
- .shipping_configuration_upserted ⇒ Object
- .shipping_lane_deleted ⇒ Object
- .shipping_lane_upserted ⇒ Object
- .shopify_localization_setting_deleted ⇒ Object
- .shopify_localization_setting_upserted ⇒ Object
- .snapshot_deleted ⇒ Object
- .snapshot_upserted ⇒ Object
- .subcatalog_deleted ⇒ Object
- .subcatalog_item_deleted ⇒ Object
- .subcatalog_item_upserted ⇒ Object
- .subcatalog_upserted ⇒ Object
- .tier_deleted_v2 ⇒ Object
- .tier_upserted_v2 ⇒ Object
- .tracking_label_event_upserted ⇒ Object
- .virtual_card_capture_deleted ⇒ Object
- .virtual_card_capture_upserted ⇒ Object
- .virtual_card_refund_deleted ⇒ Object
- .virtual_card_refund_upserted ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ EventType
constructor
A new instance of EventType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ EventType
Returns a new instance of EventType.
17929 17930 17931 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17929 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
17927 17928 17929 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17927 def value @value end |
Class Method Details
.ALL ⇒ Object
17949 17950 17951 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17949 def EventType.ALL @@all ||= [EventType.attribute_upserted, EventType.attribute_deleted, EventType.attribute_upserted_v2, EventType.attribute_deleted_v2, EventType.catalog_upserted, EventType.catalog_deleted, EventType.subcatalog_upserted, EventType.subcatalog_deleted, EventType.catalog_item_upserted, EventType.catalog_item_deleted, EventType.catalog_item_upserted_v2, EventType.catalog_item_deleted_v2, EventType.subcatalog_item_upserted, EventType.subcatalog_item_deleted, EventType.channel_upserted, EventType.channel_deleted, EventType.channel_currency_upserted, EventType.channel_currency_deleted, EventType.channel_organization_upserted, EventType.channel_organization_deleted, EventType.b2b_invoice_upserted, EventType.b2b_invoice_deleted, EventType.b2b_credit_memo_upserted, EventType.b2b_credit_memo_deleted, EventType.consumer_invoice_upserted, EventType.consumer_invoice_deleted, EventType.credit_memo_upserted, EventType.credit_memo_deleted, EventType.crossdock_shipment_upserted, EventType.rate_deleted, EventType.rate_upserted, EventType.rate_deleted_v3, EventType.rate_upserted_v3, EventType.customer_upserted, EventType.customer_deleted, EventType.customer_address_book_contact_upserted, EventType.customer_address_book_contact_deleted, EventType.email_notification_upserted, EventType.email_notification_deleted, EventType.available_promotions_upserted, EventType.available_promotions_deleted, EventType.available_promotions_upserted_v2, EventType.available_promotions_deleted_v2, EventType.allocation_deleted_v2, EventType.allocation_upserted_v2, EventType.currency_format_deleted, EventType.currency_format_upserted, EventType.experience_deleted, EventType.experience_upserted, EventType.experience_deleted_v2, EventType.experience_upserted_v2, EventType.country_status_upserted, EventType.country_status_deleted, EventType.experience_price_book_mapping_deleted, EventType.experience_price_book_mapping_upserted, EventType.experience_logistics_settings_upserted, EventType.experience_logistics_settings_deleted, EventType.item_margin_deleted_v2, EventType.item_margin_upserted_v2, EventType.item_sales_margin_deleted, EventType.item_sales_margin_upserted, EventType.label_format_deleted, EventType.label_format_upserted, EventType.order_deleted, EventType.order_upserted, EventType.order_deleted_v2, EventType.order_upserted_v2, EventType.order_identifier_deleted, EventType.order_identifier_upserted, EventType.order_identifier_deleted_v2, EventType.order_identifier_upserted_v2, EventType.order_identifier_upserted_v3, EventType.order_replacement_upserted, EventType.order_replacement_deleted, EventType.pricing_deleted, EventType.pricing_upserted, EventType.order_service_change_request, EventType.fraud_status_changed, EventType.center_upserted, EventType.center_deleted, EventType.shipping_configuration_upserted, EventType.shipping_configuration_deleted, EventType.tier_upserted_v2, EventType.tier_deleted_v2, EventType.shipping_lane_upserted, EventType.shipping_lane_deleted, EventType.shipping_configuration_item_availability_upserted, EventType.shipping_configuration_item_availability_deleted, EventType.shipping_configuration_item_shipping_pricing_upserted, EventType.shipping_configuration_item_shipping_pricing_deleted, EventType.hs6_code_upserted, EventType.hs6_code_deleted, EventType.hs10_code_upserted, EventType.hs10_code_deleted, EventType.item_origin_upserted, EventType.item_origin_deleted, EventType.harmonized_landed_cost_upserted, EventType.fully_harmonized_item_upserted, EventType.import_completed_v2, EventType.import_failed_v2, EventType.rule_upserted, EventType.rule_deleted, EventType.snapshot_upserted, EventType.snapshot_deleted, EventType.label_upserted, EventType.label_deleted_v2, EventType.label_upserted_v2, EventType.notification_upserted_v2, EventType.notification_deleted_v2, EventType.manifested_label_upserted, EventType.manifested_label_deleted, EventType.local_item_upserted, EventType.local_item_deleted, EventType.checkout_optin_responses_upserted, EventType.checkout_optin_responses_deleted, EventType.browse_optin_responses_upserted, EventType.browse_optin_responses_deleted, EventType.order_placed, EventType.order_placed_v2, EventType.ready_to_fulfill, EventType.ready_to_fulfill_v2, EventType.membership_upserted_v2, EventType.membership_deleted_v2, EventType.organization_upserted, EventType.organization_deleted, EventType.organization_upserted_v2, EventType.organization_deleted_v2, EventType.organization_default_configurations_upserted, EventType.organization_default_configurations_deleted, EventType.ecommerce_platform_upserted, EventType.ecommerce_platform_deleted, EventType., EventType., EventType., EventType., EventType., EventType., EventType.capture_upserted_v2, EventType.capture_deleted, EventType.card_upserted_v2, EventType.card_deleted, EventType.payment_upserted, EventType.payment_deleted, EventType.refund_upserted_v2, EventType.refund_deleted_v2, EventType.refund_capture_upserted_v2, EventType.reversal_upserted, EventType.reversal_deleted, EventType.capture_identifier_upserted, EventType.capture_identifier_deleted, EventType.refund_identifier_upserted, EventType.refund_identifier_deleted, EventType.virtual_card_capture_upserted, EventType.virtual_card_capture_deleted, EventType.virtual_card_refund_upserted, EventType.virtual_card_refund_deleted, EventType.payment_request_upserted, EventType.price_book_upserted, EventType.price_book_deleted, EventType.price_book_item_upserted, EventType.price_book_item_deleted, EventType.organization_rates_published, EventType.ratecard_lane_upserted, EventType.ratecard_lane_deleted, EventType.ratecard_upserted, EventType.ratecard_deleted, EventType.return_upserted, EventType.return_deleted, EventType.return_upserted_v2, EventType.return_deleted_v2, EventType.shopify_localization_setting_upserted, EventType.shopify_localization_setting_deleted, EventType.tracking_label_event_upserted] end |
.allocation_deleted_v2 ⇒ Object
18125 18126 18127 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18125 def EventType.allocation_deleted_v2 @@_allocation_deleted_v2 ||= EventType.new('allocation_deleted_v2') end |
.allocation_upserted_v2 ⇒ Object
18129 18130 18131 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18129 def EventType.allocation_upserted_v2 @@_allocation_upserted_v2 ||= EventType.new('allocation_upserted_v2') end |
.apply(value) ⇒ Object
Returns the instance of EventType for this value, creating a new instance for an unknown value
17934 17935 17936 17937 17938 17939 17940 17941 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17934 def EventType.apply(value) if value.instance_of?(EventType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || EventType.new(value)) end end |
.attribute_deleted ⇒ Object
17957 17958 17959 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17957 def EventType.attribute_deleted @@_attribute_deleted ||= EventType.new('attribute_deleted') end |
.attribute_deleted_v2 ⇒ Object
17965 17966 17967 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17965 def EventType.attribute_deleted_v2 @@_attribute_deleted_v2 ||= EventType.new('attribute_deleted_v2') end |
.attribute_upserted ⇒ Object
17953 17954 17955 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17953 def EventType.attribute_upserted @@_attribute_upserted ||= EventType.new('attribute_upserted') end |
.attribute_upserted_v2 ⇒ Object
17961 17962 17963 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17961 def EventType.attribute_upserted_v2 @@_attribute_upserted_v2 ||= EventType.new('attribute_upserted_v2') end |
.authorization_deleted_v2 ⇒ Object
18477 18478 18479 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18477 def EventType. ||= EventType.new('authorization_deleted_v2') end |
.authorization_status_changed ⇒ Object
18481 18482 18483 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18481 def EventType. ||= EventType.new('authorization_status_changed') end |
.available_promotions_deleted ⇒ Object
18113 18114 18115 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18113 def EventType.available_promotions_deleted @@_available_promotions_deleted ||= EventType.new('available_promotions_deleted') end |
.available_promotions_deleted_v2 ⇒ Object
18121 18122 18123 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18121 def EventType.available_promotions_deleted_v2 @@_available_promotions_deleted_v2 ||= EventType.new('available_promotions_deleted_v2') end |
.available_promotions_upserted ⇒ Object
18109 18110 18111 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18109 def EventType.available_promotions_upserted @@_available_promotions_upserted ||= EventType.new('available_promotions_upserted') end |
.available_promotions_upserted_v2 ⇒ Object
18117 18118 18119 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18117 def EventType.available_promotions_upserted_v2 @@_available_promotions_upserted_v2 ||= EventType.new('available_promotions_upserted_v2') end |
.b2b_credit_memo_deleted ⇒ Object
18045 18046 18047 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18045 def EventType.b2b_credit_memo_deleted @@_b2b_credit_memo_deleted ||= EventType.new('b2b_credit_memo_deleted') end |
.b2b_credit_memo_upserted ⇒ Object
18041 18042 18043 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18041 def EventType.b2b_credit_memo_upserted @@_b2b_credit_memo_upserted ||= EventType.new('b2b_credit_memo_upserted') end |
.b2b_invoice_deleted ⇒ Object
18037 18038 18039 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18037 def EventType.b2b_invoice_deleted @@_b2b_invoice_deleted ||= EventType.new('b2b_invoice_deleted') end |
.b2b_invoice_upserted ⇒ Object
18033 18034 18035 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18033 def EventType.b2b_invoice_upserted @@_b2b_invoice_upserted ||= EventType.new('b2b_invoice_upserted') end |
.browse_optin_responses_deleted ⇒ Object
18417 18418 18419 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18417 def EventType.browse_optin_responses_deleted @@_browse_optin_responses_deleted ||= EventType.new('browse_optin_responses_deleted') end |
.browse_optin_responses_upserted ⇒ Object
18413 18414 18415 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18413 def EventType.browse_optin_responses_upserted @@_browse_optin_responses_upserted ||= EventType.new('browse_optin_responses_upserted') end |
.capture_deleted ⇒ Object
18505 18506 18507 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18505 def EventType.capture_deleted @@_capture_deleted ||= EventType.new('capture_deleted') end |
.capture_identifier_deleted ⇒ Object
18549 18550 18551 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18549 def EventType.capture_identifier_deleted @@_capture_identifier_deleted ||= EventType.new('capture_identifier_deleted') end |
.capture_identifier_upserted ⇒ Object
18545 18546 18547 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18545 def EventType.capture_identifier_upserted @@_capture_identifier_upserted ||= EventType.new('capture_identifier_upserted') end |
.capture_upserted_v2 ⇒ Object
18501 18502 18503 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18501 def EventType.capture_upserted_v2 @@_capture_upserted_v2 ||= EventType.new('capture_upserted_v2') end |
.card_authorization_deleted_v2 ⇒ Object
18489 18490 18491 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18489 def EventType. ||= EventType.new('card_authorization_deleted_v2') end |
.card_authorization_upserted_v2 ⇒ Object
18485 18486 18487 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18485 def EventType. ||= EventType.new('card_authorization_upserted_v2') end |
.card_deleted ⇒ Object
18513 18514 18515 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18513 def EventType.card_deleted @@_card_deleted ||= EventType.new('card_deleted') end |
.card_upserted_v2 ⇒ Object
18509 18510 18511 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18509 def EventType.card_upserted_v2 @@_card_upserted_v2 ||= EventType.new('card_upserted_v2') end |
.catalog_deleted ⇒ Object
17973 17974 17975 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17973 def EventType.catalog_deleted @@_catalog_deleted ||= EventType.new('catalog_deleted') end |
.catalog_item_deleted ⇒ Object
17989 17990 17991 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17989 def EventType.catalog_item_deleted @@_catalog_item_deleted ||= EventType.new('catalog_item_deleted') end |
.catalog_item_deleted_v2 ⇒ Object
17997 17998 17999 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17997 def EventType.catalog_item_deleted_v2 @@_catalog_item_deleted_v2 ||= EventType.new('catalog_item_deleted_v2') end |
.catalog_item_upserted ⇒ Object
17985 17986 17987 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17985 def EventType.catalog_item_upserted @@_catalog_item_upserted ||= EventType.new('catalog_item_upserted') end |
.catalog_item_upserted_v2 ⇒ Object
17993 17994 17995 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17993 def EventType.catalog_item_upserted_v2 @@_catalog_item_upserted_v2 ||= EventType.new('catalog_item_upserted_v2') end |
.catalog_upserted ⇒ Object
17969 17970 17971 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17969 def EventType.catalog_upserted @@_catalog_upserted ||= EventType.new('catalog_upserted') end |
.center_deleted ⇒ Object
18269 18270 18271 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18269 def EventType.center_deleted @@_center_deleted ||= EventType.new('center_deleted') end |
.center_upserted ⇒ Object
18265 18266 18267 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18265 def EventType.center_upserted @@_center_upserted ||= EventType.new('center_upserted') end |
.channel_currency_deleted ⇒ Object
18021 18022 18023 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18021 def EventType.channel_currency_deleted @@_channel_currency_deleted ||= EventType.new('channel_currency_deleted') end |
.channel_currency_upserted ⇒ Object
18017 18018 18019 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18017 def EventType.channel_currency_upserted @@_channel_currency_upserted ||= EventType.new('channel_currency_upserted') end |
.channel_deleted ⇒ Object
18013 18014 18015 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18013 def EventType.channel_deleted @@_channel_deleted ||= EventType.new('channel_deleted') end |
.channel_organization_deleted ⇒ Object
18029 18030 18031 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18029 def EventType.channel_organization_deleted @@_channel_organization_deleted ||= EventType.new('channel_organization_deleted') end |
.channel_organization_upserted ⇒ Object
18025 18026 18027 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18025 def EventType.channel_organization_upserted @@_channel_organization_upserted ||= EventType.new('channel_organization_upserted') end |
.channel_upserted ⇒ Object
18009 18010 18011 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18009 def EventType.channel_upserted @@_channel_upserted ||= EventType.new('channel_upserted') end |
.checkout_optin_responses_deleted ⇒ Object
18409 18410 18411 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18409 def EventType.checkout_optin_responses_deleted @@_checkout_optin_responses_deleted ||= EventType.new('checkout_optin_responses_deleted') end |
.checkout_optin_responses_upserted ⇒ Object
18405 18406 18407 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18405 def EventType.checkout_optin_responses_upserted @@_checkout_optin_responses_upserted ||= EventType.new('checkout_optin_responses_upserted') end |
.consumer_invoice_deleted ⇒ Object
18053 18054 18055 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18053 def EventType.consumer_invoice_deleted @@_consumer_invoice_deleted ||= EventType.new('consumer_invoice_deleted') end |
.consumer_invoice_upserted ⇒ Object
18049 18050 18051 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18049 def EventType.consumer_invoice_upserted @@_consumer_invoice_upserted ||= EventType.new('consumer_invoice_upserted') end |
.country_status_deleted ⇒ Object
18161 18162 18163 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18161 def EventType.country_status_deleted @@_country_status_deleted ||= EventType.new('country_status_deleted') end |
.country_status_upserted ⇒ Object
18157 18158 18159 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18157 def EventType.country_status_upserted @@_country_status_upserted ||= EventType.new('country_status_upserted') end |
.credit_memo_deleted ⇒ Object
18061 18062 18063 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18061 def EventType.credit_memo_deleted @@_credit_memo_deleted ||= EventType.new('credit_memo_deleted') end |
.credit_memo_upserted ⇒ Object
18057 18058 18059 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18057 def EventType.credit_memo_upserted @@_credit_memo_upserted ||= EventType.new('credit_memo_upserted') end |
.crossdock_shipment_upserted ⇒ Object
18065 18066 18067 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18065 def EventType.crossdock_shipment_upserted @@_crossdock_shipment_upserted ||= EventType.new('crossdock_shipment_upserted') end |
.currency_format_deleted ⇒ Object
18133 18134 18135 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18133 def EventType.currency_format_deleted @@_currency_format_deleted ||= EventType.new('currency_format_deleted') end |
.currency_format_upserted ⇒ Object
18137 18138 18139 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18137 def EventType.currency_format_upserted @@_currency_format_upserted ||= EventType.new('currency_format_upserted') end |
.customer_address_book_contact_deleted ⇒ Object
18097 18098 18099 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18097 def EventType.customer_address_book_contact_deleted @@_customer_address_book_contact_deleted ||= EventType.new('customer_address_book_contact_deleted') end |
.customer_address_book_contact_upserted ⇒ Object
18093 18094 18095 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18093 def EventType.customer_address_book_contact_upserted @@_customer_address_book_contact_upserted ||= EventType.new('customer_address_book_contact_upserted') end |
.customer_deleted ⇒ Object
18089 18090 18091 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18089 def EventType.customer_deleted @@_customer_deleted ||= EventType.new('customer_deleted') end |
.customer_upserted ⇒ Object
18085 18086 18087 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18085 def EventType.customer_upserted @@_customer_upserted ||= EventType.new('customer_upserted') end |
.ecommerce_platform_deleted ⇒ Object
18473 18474 18475 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18473 def EventType.ecommerce_platform_deleted @@_ecommerce_platform_deleted ||= EventType.new('ecommerce_platform_deleted') end |
.ecommerce_platform_upserted ⇒ Object
18469 18470 18471 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18469 def EventType.ecommerce_platform_upserted @@_ecommerce_platform_upserted ||= EventType.new('ecommerce_platform_upserted') end |
.email_notification_deleted ⇒ Object
18105 18106 18107 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18105 def EventType.email_notification_deleted @@_email_notification_deleted ||= EventType.new('email_notification_deleted') end |
.email_notification_upserted ⇒ Object
18101 18102 18103 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18101 def EventType.email_notification_upserted @@_email_notification_upserted ||= EventType.new('email_notification_upserted') end |
.experience_deleted ⇒ Object
18141 18142 18143 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18141 def EventType.experience_deleted @@_experience_deleted ||= EventType.new('experience_deleted') end |
.experience_deleted_v2 ⇒ Object
18149 18150 18151 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18149 def EventType.experience_deleted_v2 @@_experience_deleted_v2 ||= EventType.new('experience_deleted_v2') end |
.experience_logistics_settings_deleted ⇒ Object
18177 18178 18179 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18177 def EventType.experience_logistics_settings_deleted @@_experience_logistics_settings_deleted ||= EventType.new('experience_logistics_settings_deleted') end |
.experience_logistics_settings_upserted ⇒ Object
18173 18174 18175 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18173 def EventType.experience_logistics_settings_upserted @@_experience_logistics_settings_upserted ||= EventType.new('experience_logistics_settings_upserted') end |
.experience_price_book_mapping_deleted ⇒ Object
18165 18166 18167 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18165 def EventType.experience_price_book_mapping_deleted @@_experience_price_book_mapping_deleted ||= EventType.new('experience_price_book_mapping_deleted') end |
.experience_price_book_mapping_upserted ⇒ Object
18169 18170 18171 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18169 def EventType.experience_price_book_mapping_upserted @@_experience_price_book_mapping_upserted ||= EventType.new('experience_price_book_mapping_upserted') end |
.experience_upserted ⇒ Object
18145 18146 18147 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18145 def EventType.experience_upserted @@_experience_upserted ||= EventType.new('experience_upserted') end |
.experience_upserted_v2 ⇒ Object
18153 18154 18155 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18153 def EventType.experience_upserted_v2 @@_experience_upserted_v2 ||= EventType.new('experience_upserted_v2') end |
.fraud_status_changed ⇒ Object
18261 18262 18263 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18261 def EventType.fraud_status_changed @@_fraud_status_changed ||= EventType.new('fraud_status_changed') end |
.from_string(value) ⇒ Object
Returns the instance of EventType for this value, or nil if not found
17944 17945 17946 17947 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17944 def EventType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) EventType.ALL.find { |v| v.value == value } end |
.fully_harmonized_item_upserted ⇒ Object
18341 18342 18343 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18341 def EventType.fully_harmonized_item_upserted @@_fully_harmonized_item_upserted ||= EventType.new('fully_harmonized_item_upserted') end |
.harmonized_landed_cost_upserted ⇒ Object
18337 18338 18339 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18337 def EventType.harmonized_landed_cost_upserted @@_harmonized_landed_cost_upserted ||= EventType.new('harmonized_landed_cost_upserted') end |
.hs10_code_deleted ⇒ Object
18325 18326 18327 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18325 def EventType.hs10_code_deleted @@_hs10_code_deleted ||= EventType.new('hs10_code_deleted') end |
.hs10_code_upserted ⇒ Object
18321 18322 18323 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18321 def EventType.hs10_code_upserted @@_hs10_code_upserted ||= EventType.new('hs10_code_upserted') end |
.hs6_code_deleted ⇒ Object
18317 18318 18319 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18317 def EventType.hs6_code_deleted @@_hs6_code_deleted ||= EventType.new('hs6_code_deleted') end |
.hs6_code_upserted ⇒ Object
18313 18314 18315 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18313 def EventType.hs6_code_upserted @@_hs6_code_upserted ||= EventType.new('hs6_code_upserted') end |
.import_completed_v2 ⇒ Object
18345 18346 18347 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18345 def EventType.import_completed_v2 @@_import_completed_v2 ||= EventType.new('import_completed_v2') end |
.import_failed_v2 ⇒ Object
18349 18350 18351 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18349 def EventType.import_failed_v2 @@_import_failed_v2 ||= EventType.new('import_failed_v2') end |
.item_margin_deleted_v2 ⇒ Object
18181 18182 18183 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18181 def EventType.item_margin_deleted_v2 @@_item_margin_deleted_v2 ||= EventType.new('item_margin_deleted_v2') end |
.item_margin_upserted_v2 ⇒ Object
18185 18186 18187 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18185 def EventType.item_margin_upserted_v2 @@_item_margin_upserted_v2 ||= EventType.new('item_margin_upserted_v2') end |
.item_origin_deleted ⇒ Object
18333 18334 18335 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18333 def EventType.item_origin_deleted @@_item_origin_deleted ||= EventType.new('item_origin_deleted') end |
.item_origin_upserted ⇒ Object
18329 18330 18331 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18329 def EventType.item_origin_upserted @@_item_origin_upserted ||= EventType.new('item_origin_upserted') end |
.item_sales_margin_deleted ⇒ Object
18189 18190 18191 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18189 def EventType.item_sales_margin_deleted @@_item_sales_margin_deleted ||= EventType.new('item_sales_margin_deleted') end |
.item_sales_margin_upserted ⇒ Object
18193 18194 18195 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18193 def EventType.item_sales_margin_upserted @@_item_sales_margin_upserted ||= EventType.new('item_sales_margin_upserted') end |
.label_deleted_v2 ⇒ Object
18373 18374 18375 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18373 def EventType.label_deleted_v2 @@_label_deleted_v2 ||= EventType.new('label_deleted_v2') end |
.label_format_deleted ⇒ Object
18197 18198 18199 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18197 def EventType.label_format_deleted @@_label_format_deleted ||= EventType.new('label_format_deleted') end |
.label_format_upserted ⇒ Object
18201 18202 18203 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18201 def EventType.label_format_upserted @@_label_format_upserted ||= EventType.new('label_format_upserted') end |
.label_upserted ⇒ Object
18369 18370 18371 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18369 def EventType.label_upserted @@_label_upserted ||= EventType.new('label_upserted') end |
.label_upserted_v2 ⇒ Object
18377 18378 18379 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18377 def EventType.label_upserted_v2 @@_label_upserted_v2 ||= EventType.new('label_upserted_v2') end |
.local_item_deleted ⇒ Object
18401 18402 18403 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18401 def EventType.local_item_deleted @@_local_item_deleted ||= EventType.new('local_item_deleted') end |
.local_item_upserted ⇒ Object
18397 18398 18399 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18397 def EventType.local_item_upserted @@_local_item_upserted ||= EventType.new('local_item_upserted') end |
.manifested_label_deleted ⇒ Object
18393 18394 18395 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18393 def EventType.manifested_label_deleted @@_manifested_label_deleted ||= EventType.new('manifested_label_deleted') end |
.manifested_label_upserted ⇒ Object
18389 18390 18391 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18389 def EventType.manifested_label_upserted @@_manifested_label_upserted ||= EventType.new('manifested_label_upserted') end |
.membership_deleted_v2 ⇒ Object
18441 18442 18443 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18441 def EventType.membership_deleted_v2 @@_membership_deleted_v2 ||= EventType.new('membership_deleted_v2') end |
.membership_upserted_v2 ⇒ Object
18437 18438 18439 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18437 def EventType.membership_upserted_v2 @@_membership_upserted_v2 ||= EventType.new('membership_upserted_v2') end |
.notification_deleted_v2 ⇒ Object
18385 18386 18387 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18385 def EventType.notification_deleted_v2 @@_notification_deleted_v2 ||= EventType.new('notification_deleted_v2') end |
.notification_upserted_v2 ⇒ Object
18381 18382 18383 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18381 def EventType.notification_upserted_v2 @@_notification_upserted_v2 ||= EventType.new('notification_upserted_v2') end |
.online_authorization_deleted_v2 ⇒ Object
18497 18498 18499 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18497 def EventType. ||= EventType.new('online_authorization_deleted_v2') end |
.online_authorization_upserted_v2 ⇒ Object
18493 18494 18495 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18493 def EventType. ||= EventType.new('online_authorization_upserted_v2') end |
.order_deleted ⇒ Object
18205 18206 18207 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18205 def EventType.order_deleted @@_order_deleted ||= EventType.new('order_deleted') end |
.order_deleted_v2 ⇒ Object
18213 18214 18215 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18213 def EventType.order_deleted_v2 @@_order_deleted_v2 ||= EventType.new('order_deleted_v2') end |
.order_identifier_deleted ⇒ Object
18221 18222 18223 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18221 def EventType.order_identifier_deleted @@_order_identifier_deleted ||= EventType.new('order_identifier_deleted') end |
.order_identifier_deleted_v2 ⇒ Object
18229 18230 18231 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18229 def EventType.order_identifier_deleted_v2 @@_order_identifier_deleted_v2 ||= EventType.new('order_identifier_deleted_v2') end |
.order_identifier_upserted ⇒ Object
18225 18226 18227 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18225 def EventType.order_identifier_upserted @@_order_identifier_upserted ||= EventType.new('order_identifier_upserted') end |
.order_identifier_upserted_v2 ⇒ Object
18233 18234 18235 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18233 def EventType.order_identifier_upserted_v2 @@_order_identifier_upserted_v2 ||= EventType.new('order_identifier_upserted_v2') end |
.order_identifier_upserted_v3 ⇒ Object
18237 18238 18239 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18237 def EventType.order_identifier_upserted_v3 @@_order_identifier_upserted_v3 ||= EventType.new('order_identifier_upserted_v3') end |
.order_placed ⇒ Object
18421 18422 18423 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18421 def EventType.order_placed @@_order_placed ||= EventType.new('order_placed') end |
.order_placed_v2 ⇒ Object
18425 18426 18427 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18425 def EventType.order_placed_v2 @@_order_placed_v2 ||= EventType.new('order_placed_v2') end |
.order_replacement_deleted ⇒ Object
18245 18246 18247 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18245 def EventType.order_replacement_deleted @@_order_replacement_deleted ||= EventType.new('order_replacement_deleted') end |
.order_replacement_upserted ⇒ Object
18241 18242 18243 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18241 def EventType.order_replacement_upserted @@_order_replacement_upserted ||= EventType.new('order_replacement_upserted') end |
.order_service_change_request ⇒ Object
18257 18258 18259 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18257 def EventType.order_service_change_request @@_order_service_change_request ||= EventType.new('order_service_change_request') end |
.order_upserted ⇒ Object
18209 18210 18211 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18209 def EventType.order_upserted @@_order_upserted ||= EventType.new('order_upserted') end |
.order_upserted_v2 ⇒ Object
18217 18218 18219 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18217 def EventType.order_upserted_v2 @@_order_upserted_v2 ||= EventType.new('order_upserted_v2') end |
.organization_default_configurations_deleted ⇒ Object
18465 18466 18467 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18465 def EventType.organization_default_configurations_deleted @@_organization_default_configurations_deleted ||= EventType.new('organization_default_configurations_deleted') end |
.organization_default_configurations_upserted ⇒ Object
18461 18462 18463 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18461 def EventType.organization_default_configurations_upserted @@_organization_default_configurations_upserted ||= EventType.new('organization_default_configurations_upserted') end |
.organization_deleted ⇒ Object
18449 18450 18451 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18449 def EventType.organization_deleted @@_organization_deleted ||= EventType.new('organization_deleted') end |
.organization_deleted_v2 ⇒ Object
18457 18458 18459 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18457 def EventType.organization_deleted_v2 @@_organization_deleted_v2 ||= EventType.new('organization_deleted_v2') end |
.organization_rates_published ⇒ Object
18597 18598 18599 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18597 def EventType.organization_rates_published @@_organization_rates_published ||= EventType.new('organization_rates_published') end |
.organization_upserted ⇒ Object
18445 18446 18447 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18445 def EventType.organization_upserted @@_organization_upserted ||= EventType.new('organization_upserted') end |
.organization_upserted_v2 ⇒ Object
18453 18454 18455 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18453 def EventType.organization_upserted_v2 @@_organization_upserted_v2 ||= EventType.new('organization_upserted_v2') end |
.payment_deleted ⇒ Object
18521 18522 18523 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18521 def EventType.payment_deleted @@_payment_deleted ||= EventType.new('payment_deleted') end |
.payment_request_upserted ⇒ Object
18577 18578 18579 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18577 def EventType.payment_request_upserted @@_payment_request_upserted ||= EventType.new('payment_request_upserted') end |
.payment_upserted ⇒ Object
18517 18518 18519 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18517 def EventType.payment_upserted @@_payment_upserted ||= EventType.new('payment_upserted') end |
.price_book_deleted ⇒ Object
18585 18586 18587 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18585 def EventType.price_book_deleted @@_price_book_deleted ||= EventType.new('price_book_deleted') end |
.price_book_item_deleted ⇒ Object
18593 18594 18595 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18593 def EventType.price_book_item_deleted @@_price_book_item_deleted ||= EventType.new('price_book_item_deleted') end |
.price_book_item_upserted ⇒ Object
18589 18590 18591 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18589 def EventType.price_book_item_upserted @@_price_book_item_upserted ||= EventType.new('price_book_item_upserted') end |
.price_book_upserted ⇒ Object
18581 18582 18583 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18581 def EventType.price_book_upserted @@_price_book_upserted ||= EventType.new('price_book_upserted') end |
.pricing_deleted ⇒ Object
18249 18250 18251 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18249 def EventType.pricing_deleted @@_pricing_deleted ||= EventType.new('pricing_deleted') end |
.pricing_upserted ⇒ Object
18253 18254 18255 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18253 def EventType.pricing_upserted @@_pricing_upserted ||= EventType.new('pricing_upserted') end |
.rate_deleted ⇒ Object
18069 18070 18071 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18069 def EventType.rate_deleted @@_rate_deleted ||= EventType.new('rate_deleted') end |
.rate_deleted_v3 ⇒ Object
18077 18078 18079 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18077 def EventType.rate_deleted_v3 @@_rate_deleted_v3 ||= EventType.new('rate_deleted_v3') end |
.rate_upserted ⇒ Object
18073 18074 18075 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18073 def EventType.rate_upserted @@_rate_upserted ||= EventType.new('rate_upserted') end |
.rate_upserted_v3 ⇒ Object
18081 18082 18083 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18081 def EventType.rate_upserted_v3 @@_rate_upserted_v3 ||= EventType.new('rate_upserted_v3') end |
.ratecard_deleted ⇒ Object
18613 18614 18615 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18613 def EventType.ratecard_deleted @@_ratecard_deleted ||= EventType.new('ratecard_deleted') end |
.ratecard_lane_deleted ⇒ Object
18605 18606 18607 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18605 def EventType.ratecard_lane_deleted @@_ratecard_lane_deleted ||= EventType.new('ratecard_lane_deleted') end |
.ratecard_lane_upserted ⇒ Object
18601 18602 18603 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18601 def EventType.ratecard_lane_upserted @@_ratecard_lane_upserted ||= EventType.new('ratecard_lane_upserted') end |
.ratecard_upserted ⇒ Object
18609 18610 18611 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18609 def EventType.ratecard_upserted @@_ratecard_upserted ||= EventType.new('ratecard_upserted') end |
.ready_to_fulfill ⇒ Object
18429 18430 18431 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18429 def EventType.ready_to_fulfill @@_ready_to_fulfill ||= EventType.new('ready_to_fulfill') end |
.ready_to_fulfill_v2 ⇒ Object
18433 18434 18435 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18433 def EventType.ready_to_fulfill_v2 @@_ready_to_fulfill_v2 ||= EventType.new('ready_to_fulfill_v2') end |
.refund_capture_upserted_v2 ⇒ Object
18533 18534 18535 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18533 def EventType.refund_capture_upserted_v2 @@_refund_capture_upserted_v2 ||= EventType.new('refund_capture_upserted_v2') end |
.refund_deleted_v2 ⇒ Object
18529 18530 18531 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18529 def EventType.refund_deleted_v2 @@_refund_deleted_v2 ||= EventType.new('refund_deleted_v2') end |
.refund_identifier_deleted ⇒ Object
18557 18558 18559 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18557 def EventType.refund_identifier_deleted @@_refund_identifier_deleted ||= EventType.new('refund_identifier_deleted') end |
.refund_identifier_upserted ⇒ Object
18553 18554 18555 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18553 def EventType.refund_identifier_upserted @@_refund_identifier_upserted ||= EventType.new('refund_identifier_upserted') end |
.refund_upserted_v2 ⇒ Object
18525 18526 18527 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18525 def EventType.refund_upserted_v2 @@_refund_upserted_v2 ||= EventType.new('refund_upserted_v2') end |
.return_deleted ⇒ Object
18621 18622 18623 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18621 def EventType.return_deleted @@_return_deleted ||= EventType.new('return_deleted') end |
.return_deleted_v2 ⇒ Object
18629 18630 18631 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18629 def EventType.return_deleted_v2 @@_return_deleted_v2 ||= EventType.new('return_deleted_v2') end |
.return_upserted ⇒ Object
18617 18618 18619 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18617 def EventType.return_upserted @@_return_upserted ||= EventType.new('return_upserted') end |
.return_upserted_v2 ⇒ Object
18625 18626 18627 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18625 def EventType.return_upserted_v2 @@_return_upserted_v2 ||= EventType.new('return_upserted_v2') end |
.reversal_deleted ⇒ Object
18541 18542 18543 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18541 def EventType.reversal_deleted @@_reversal_deleted ||= EventType.new('reversal_deleted') end |
.reversal_upserted ⇒ Object
18537 18538 18539 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18537 def EventType.reversal_upserted @@_reversal_upserted ||= EventType.new('reversal_upserted') end |
.rule_deleted ⇒ Object
18357 18358 18359 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18357 def EventType.rule_deleted @@_rule_deleted ||= EventType.new('rule_deleted') end |
.rule_upserted ⇒ Object
18353 18354 18355 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18353 def EventType.rule_upserted @@_rule_upserted ||= EventType.new('rule_upserted') end |
.shipping_configuration_deleted ⇒ Object
18277 18278 18279 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18277 def EventType.shipping_configuration_deleted @@_shipping_configuration_deleted ||= EventType.new('shipping_configuration_deleted') end |
.shipping_configuration_item_availability_deleted ⇒ Object
18301 18302 18303 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18301 def EventType.shipping_configuration_item_availability_deleted @@_shipping_configuration_item_availability_deleted ||= EventType.new('shipping_configuration_item_availability_deleted') end |
.shipping_configuration_item_availability_upserted ⇒ Object
18297 18298 18299 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18297 def EventType.shipping_configuration_item_availability_upserted @@_shipping_configuration_item_availability_upserted ||= EventType.new('shipping_configuration_item_availability_upserted') end |
.shipping_configuration_item_shipping_pricing_deleted ⇒ Object
18309 18310 18311 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18309 def EventType.shipping_configuration_item_shipping_pricing_deleted @@_shipping_configuration_item_shipping_pricing_deleted ||= EventType.new('shipping_configuration_item_shipping_pricing_deleted') end |
.shipping_configuration_item_shipping_pricing_upserted ⇒ Object
18305 18306 18307 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18305 def EventType.shipping_configuration_item_shipping_pricing_upserted @@_shipping_configuration_item_shipping_pricing_upserted ||= EventType.new('shipping_configuration_item_shipping_pricing_upserted') end |
.shipping_configuration_upserted ⇒ Object
18273 18274 18275 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18273 def EventType.shipping_configuration_upserted @@_shipping_configuration_upserted ||= EventType.new('shipping_configuration_upserted') end |
.shipping_lane_deleted ⇒ Object
18293 18294 18295 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18293 def EventType.shipping_lane_deleted @@_shipping_lane_deleted ||= EventType.new('shipping_lane_deleted') end |
.shipping_lane_upserted ⇒ Object
18289 18290 18291 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18289 def EventType.shipping_lane_upserted @@_shipping_lane_upserted ||= EventType.new('shipping_lane_upserted') end |
.shopify_localization_setting_deleted ⇒ Object
18637 18638 18639 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18637 def EventType.shopify_localization_setting_deleted @@_shopify_localization_setting_deleted ||= EventType.new('shopify_localization_setting_deleted') end |
.shopify_localization_setting_upserted ⇒ Object
18633 18634 18635 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18633 def EventType.shopify_localization_setting_upserted @@_shopify_localization_setting_upserted ||= EventType.new('shopify_localization_setting_upserted') end |
.snapshot_deleted ⇒ Object
18365 18366 18367 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18365 def EventType.snapshot_deleted @@_snapshot_deleted ||= EventType.new('snapshot_deleted') end |
.snapshot_upserted ⇒ Object
18361 18362 18363 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18361 def EventType.snapshot_upserted @@_snapshot_upserted ||= EventType.new('snapshot_upserted') end |
.subcatalog_deleted ⇒ Object
17981 17982 17983 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17981 def EventType.subcatalog_deleted @@_subcatalog_deleted ||= EventType.new('subcatalog_deleted') end |
.subcatalog_item_deleted ⇒ Object
18005 18006 18007 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18005 def EventType.subcatalog_item_deleted @@_subcatalog_item_deleted ||= EventType.new('subcatalog_item_deleted') end |
.subcatalog_item_upserted ⇒ Object
18001 18002 18003 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18001 def EventType.subcatalog_item_upserted @@_subcatalog_item_upserted ||= EventType.new('subcatalog_item_upserted') end |
.subcatalog_upserted ⇒ Object
17977 17978 17979 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17977 def EventType.subcatalog_upserted @@_subcatalog_upserted ||= EventType.new('subcatalog_upserted') end |
.tier_deleted_v2 ⇒ Object
18285 18286 18287 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18285 def EventType.tier_deleted_v2 @@_tier_deleted_v2 ||= EventType.new('tier_deleted_v2') end |
.tier_upserted_v2 ⇒ Object
18281 18282 18283 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18281 def EventType.tier_upserted_v2 @@_tier_upserted_v2 ||= EventType.new('tier_upserted_v2') end |
.tracking_label_event_upserted ⇒ Object
18641 18642 18643 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18641 def EventType.tracking_label_event_upserted @@_tracking_label_event_upserted ||= EventType.new('tracking_label_event_upserted') end |
.virtual_card_capture_deleted ⇒ Object
18565 18566 18567 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18565 def EventType.virtual_card_capture_deleted @@_virtual_card_capture_deleted ||= EventType.new('virtual_card_capture_deleted') end |
.virtual_card_capture_upserted ⇒ Object
18561 18562 18563 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18561 def EventType.virtual_card_capture_upserted @@_virtual_card_capture_upserted ||= EventType.new('virtual_card_capture_upserted') end |
.virtual_card_refund_deleted ⇒ Object
18573 18574 18575 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18573 def EventType.virtual_card_refund_deleted @@_virtual_card_refund_deleted ||= EventType.new('virtual_card_refund_deleted') end |
.virtual_card_refund_upserted ⇒ Object
18569 18570 18571 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18569 def EventType.virtual_card_refund_upserted @@_virtual_card_refund_upserted ||= EventType.new('virtual_card_refund_upserted') end |
Instance Method Details
#to_hash ⇒ Object
18645 18646 18647 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18645 def to_hash value end |