Class: Io::Flow::V0::Models::EventType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::EventType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
- .allocation_deleted_v2 ⇒ Object
- .allocation_upserted_v2 ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of EventType for this value, creating a new instance for an unknown value.
- .attribute_deleted ⇒ Object
- .attribute_deleted_v2 ⇒ Object
- .attribute_upserted ⇒ Object
- .attribute_upserted_v2 ⇒ Object
- .authorization_deleted_v2 ⇒ Object
- .authorization_status_changed ⇒ Object
- .available_promotions_deleted ⇒ Object
- .available_promotions_deleted_v2 ⇒ Object
- .available_promotions_upserted ⇒ Object
- .available_promotions_upserted_v2 ⇒ Object
- .b2b_credit_memo_deleted ⇒ Object
- .b2b_credit_memo_upserted ⇒ Object
- .b2b_invoice_deleted ⇒ Object
- .b2b_invoice_upserted ⇒ Object
- .browse_optin_responses_deleted ⇒ Object
- .browse_optin_responses_upserted ⇒ Object
- .capture_deleted ⇒ Object
- .capture_identifier_deleted ⇒ Object
- .capture_identifier_upserted ⇒ Object
- .capture_upserted_v2 ⇒ Object
- .card_authorization_deleted_v2 ⇒ Object
- .card_authorization_upserted_v2 ⇒ Object
- .card_deleted ⇒ Object
- .card_upserted_v2 ⇒ Object
- .catalog_deleted ⇒ Object
- .catalog_item_deleted ⇒ Object
- .catalog_item_deleted_v2 ⇒ Object
- .catalog_item_upserted ⇒ Object
- .catalog_item_upserted_v2 ⇒ Object
- .catalog_upserted ⇒ Object
- .center_deleted ⇒ Object
- .center_upserted ⇒ Object
- .checkout_optin_responses_deleted ⇒ Object
- .checkout_optin_responses_upserted ⇒ Object
- .consumer_invoice_deleted ⇒ Object
- .consumer_invoice_upserted ⇒ Object
- .credit_memo_deleted ⇒ Object
- .credit_memo_upserted ⇒ Object
- .crossdock_shipment_upserted ⇒ Object
- .currency_format_deleted ⇒ Object
- .currency_format_upserted ⇒ Object
- .customer_address_book_contact_deleted ⇒ Object
- .customer_address_book_contact_upserted ⇒ Object
- .customer_deleted ⇒ Object
- .customer_upserted ⇒ Object
- .ecommerce_platform_deleted ⇒ Object
- .ecommerce_platform_upserted ⇒ Object
- .email_notification_deleted ⇒ Object
- .email_notification_upserted ⇒ Object
- .experience_deleted ⇒ Object
- .experience_deleted_v2 ⇒ Object
- .experience_logistics_settings_deleted ⇒ Object
- .experience_logistics_settings_upserted ⇒ Object
- .experience_price_book_mapping_deleted ⇒ Object
- .experience_price_book_mapping_upserted ⇒ Object
- .experience_upserted ⇒ Object
- .experience_upserted_v2 ⇒ Object
- .fraud_status_changed ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of EventType for this value, or nil if not found.
- .fully_harmonized_item_upserted ⇒ Object
- .harmonized_landed_cost_upserted ⇒ Object
- .hs10_code_deleted ⇒ Object
- .hs10_code_upserted ⇒ Object
- .hs6_code_deleted ⇒ Object
- .hs6_code_upserted ⇒ Object
- .item_margin_deleted ⇒ Object
- .item_margin_upserted ⇒ Object
- .item_origin_deleted ⇒ Object
- .item_origin_upserted ⇒ Object
- .item_sales_margin_deleted ⇒ Object
- .item_sales_margin_upserted ⇒ Object
- .label_format_deleted ⇒ Object
- .label_format_upserted ⇒ Object
- .label_upserted ⇒ Object
- .local_item_deleted ⇒ Object
- .local_item_upserted ⇒ Object
- .manifested_label_deleted ⇒ Object
- .manifested_label_upserted ⇒ Object
- .membership_deleted_v2 ⇒ Object
- .membership_upserted_v2 ⇒ Object
- .notification_deleted ⇒ Object
- .notification_upserted ⇒ Object
- .online_authorization_deleted_v2 ⇒ Object
- .online_authorization_upserted_v2 ⇒ Object
- .order_deleted ⇒ Object
- .order_deleted_v2 ⇒ Object
- .order_identifier_deleted ⇒ Object
- .order_identifier_deleted_v2 ⇒ Object
- .order_identifier_upserted ⇒ Object
- .order_identifier_upserted_v2 ⇒ Object
- .order_identifier_upserted_v3 ⇒ Object
- .order_placed ⇒ Object
- .order_placed_v2 ⇒ Object
- .order_service_change_request ⇒ Object
- .order_upserted ⇒ Object
- .order_upserted_v2 ⇒ Object
- .organization_default_configurations_deleted ⇒ Object
- .organization_default_configurations_upserted ⇒ Object
- .organization_deleted ⇒ Object
- .organization_deleted_v2 ⇒ Object
- .organization_rates_published ⇒ Object
- .organization_short_id_deleted ⇒ Object
- .organization_short_id_upserted ⇒ Object
- .organization_upserted ⇒ Object
- .organization_upserted_v2 ⇒ Object
- .payment_deleted ⇒ Object
- .payment_upserted ⇒ Object
- .price_book_deleted ⇒ Object
- .price_book_item_deleted ⇒ Object
- .price_book_item_upserted ⇒ Object
- .price_book_upserted ⇒ Object
- .pricing_deleted ⇒ Object
- .pricing_upserted ⇒ Object
- .rate_deleted ⇒ Object
- .rate_deleted_v3 ⇒ Object
- .rate_upserted ⇒ Object
- .rate_upserted_v3 ⇒ Object
- .ratecard_deleted ⇒ Object
- .ratecard_lane_deleted ⇒ Object
- .ratecard_lane_upserted ⇒ Object
- .ratecard_upserted ⇒ Object
- .ready_to_fulfill ⇒ Object
- .refund_capture_upserted_v2 ⇒ Object
- .refund_deleted_v2 ⇒ Object
- .refund_identifier_deleted ⇒ Object
- .refund_identifier_upserted ⇒ Object
- .refund_upserted_v2 ⇒ Object
- .return_deleted ⇒ Object
- .return_upserted ⇒ Object
- .reversal_deleted ⇒ Object
- .reversal_upserted ⇒ Object
- .rule_deleted ⇒ Object
- .rule_upserted ⇒ Object
- .serial_deleted ⇒ Object
- .serial_upserted ⇒ Object
- .shipping_configuration_deleted ⇒ Object
- .shipping_configuration_item_availability_deleted ⇒ Object
- .shipping_configuration_item_availability_upserted ⇒ Object
- .shipping_configuration_item_shipping_pricing_deleted ⇒ Object
- .shipping_configuration_item_shipping_pricing_upserted ⇒ Object
- .shipping_configuration_upserted ⇒ Object
- .shipping_lane_deleted ⇒ Object
- .shipping_lane_upserted ⇒ Object
- .shopify_localization_setting_deleted ⇒ Object
- .shopify_localization_setting_upserted ⇒ Object
- .snapshot_deleted ⇒ Object
- .snapshot_upserted ⇒ Object
- .subcatalog_deleted ⇒ Object
- .subcatalog_item_deleted ⇒ Object
- .subcatalog_item_upserted ⇒ Object
- .subcatalog_upserted ⇒ Object
- .targeting_item_deleted ⇒ Object
- .targeting_item_deleted_v3 ⇒ Object
- .targeting_item_upserted ⇒ Object
- .targeting_item_upserted_v2 ⇒ Object
- .tier_deleted_v2 ⇒ Object
- .tier_upserted_v2 ⇒ Object
- .tracking_label_event_upserted ⇒ Object
- .virtual_card_capture_deleted ⇒ Object
- .virtual_card_capture_upserted ⇒ Object
- .virtual_card_refund_deleted ⇒ Object
- .virtual_card_refund_upserted ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ EventType
constructor
A new instance of EventType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ EventType
Returns a new instance of EventType.
14098 14099 14100 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14098 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
14096 14097 14098 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14096 def value @value end |
Class Method Details
.ALL ⇒ Object
14118 14119 14120 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14118 def EventType.ALL @@all ||= [EventType.attribute_upserted, EventType.attribute_deleted, EventType.attribute_upserted_v2, EventType.attribute_deleted_v2, EventType.catalog_upserted, EventType.catalog_deleted, EventType.subcatalog_upserted, EventType.subcatalog_deleted, EventType.catalog_item_upserted, EventType.catalog_item_deleted, EventType.catalog_item_upserted_v2, EventType.catalog_item_deleted_v2, EventType.subcatalog_item_upserted, EventType.subcatalog_item_deleted, EventType.b2b_invoice_upserted, EventType.b2b_invoice_deleted, EventType.b2b_credit_memo_upserted, EventType.b2b_credit_memo_deleted, EventType.consumer_invoice_upserted, EventType.consumer_invoice_deleted, EventType.credit_memo_upserted, EventType.credit_memo_deleted, EventType.crossdock_shipment_upserted, EventType.rate_deleted, EventType.rate_upserted, EventType.rate_deleted_v3, EventType.rate_upserted_v3, EventType.customer_upserted, EventType.customer_deleted, EventType.customer_address_book_contact_upserted, EventType.customer_address_book_contact_deleted, EventType.email_notification_upserted, EventType.email_notification_deleted, EventType.available_promotions_upserted, EventType.available_promotions_deleted, EventType.available_promotions_upserted_v2, EventType.available_promotions_deleted_v2, EventType.allocation_deleted_v2, EventType.allocation_upserted_v2, EventType.currency_format_deleted, EventType.currency_format_upserted, EventType.experience_deleted, EventType.experience_upserted, EventType.experience_deleted_v2, EventType.experience_upserted_v2, EventType.experience_price_book_mapping_deleted, EventType.experience_price_book_mapping_upserted, EventType.experience_logistics_settings_upserted, EventType.experience_logistics_settings_deleted, EventType.item_margin_deleted, EventType.item_margin_upserted, EventType.item_sales_margin_deleted, EventType.item_sales_margin_upserted, EventType.label_format_deleted, EventType.label_format_upserted, EventType.order_deleted, EventType.order_upserted, EventType.order_deleted_v2, EventType.order_upserted_v2, EventType.order_identifier_deleted, EventType.order_identifier_upserted, EventType.order_identifier_deleted_v2, EventType.order_identifier_upserted_v2, EventType.order_identifier_upserted_v3, EventType.pricing_deleted, EventType.pricing_upserted, EventType.order_service_change_request, EventType.fraud_status_changed, EventType.center_upserted, EventType.center_deleted, EventType.shipping_configuration_upserted, EventType.shipping_configuration_deleted, EventType.tier_upserted_v2, EventType.tier_deleted_v2, EventType.shipping_lane_upserted, EventType.shipping_lane_deleted, EventType.shipping_configuration_item_availability_upserted, EventType.shipping_configuration_item_availability_deleted, EventType.shipping_configuration_item_shipping_pricing_upserted, EventType.shipping_configuration_item_shipping_pricing_deleted, EventType.hs6_code_upserted, EventType.hs6_code_deleted, EventType.hs10_code_upserted, EventType.hs10_code_deleted, EventType.item_origin_upserted, EventType.item_origin_deleted, EventType.harmonized_landed_cost_upserted, EventType.fully_harmonized_item_upserted, EventType.rule_upserted, EventType.rule_deleted, EventType.serial_upserted, EventType.serial_deleted, EventType.snapshot_upserted, EventType.snapshot_deleted, EventType.label_upserted, EventType.notification_upserted, EventType.notification_deleted, EventType.manifested_label_upserted, EventType.manifested_label_deleted, EventType.local_item_upserted, EventType.local_item_deleted, EventType.checkout_optin_responses_upserted, EventType.checkout_optin_responses_deleted, EventType.browse_optin_responses_upserted, EventType.browse_optin_responses_deleted, EventType.order_placed, EventType.order_placed_v2, EventType.ready_to_fulfill, EventType.membership_upserted_v2, EventType.membership_deleted_v2, EventType.organization_upserted, EventType.organization_deleted, EventType.organization_upserted_v2, EventType.organization_deleted_v2, EventType.organization_short_id_upserted, EventType.organization_short_id_deleted, EventType.organization_default_configurations_upserted, EventType.organization_default_configurations_deleted, EventType.ecommerce_platform_upserted, EventType.ecommerce_platform_deleted, EventType., EventType., EventType., EventType., EventType., EventType., EventType.capture_upserted_v2, EventType.capture_deleted, EventType.card_upserted_v2, EventType.card_deleted, EventType.payment_upserted, EventType.payment_deleted, EventType.refund_upserted_v2, EventType.refund_deleted_v2, EventType.refund_capture_upserted_v2, EventType.reversal_upserted, EventType.reversal_deleted, EventType.capture_identifier_upserted, EventType.capture_identifier_deleted, EventType.refund_identifier_upserted, EventType.refund_identifier_deleted, EventType.virtual_card_capture_upserted, EventType.virtual_card_capture_deleted, EventType.virtual_card_refund_upserted, EventType.virtual_card_refund_deleted, EventType.price_book_upserted, EventType.price_book_deleted, EventType.price_book_item_upserted, EventType.price_book_item_deleted, EventType.organization_rates_published, EventType.ratecard_lane_upserted, EventType.ratecard_lane_deleted, EventType.ratecard_upserted, EventType.ratecard_deleted, EventType.return_upserted, EventType.return_deleted, EventType.shopify_localization_setting_upserted, EventType.shopify_localization_setting_deleted, EventType.targeting_item_upserted, EventType.targeting_item_upserted_v2, EventType.targeting_item_deleted, EventType.targeting_item_deleted_v3, EventType.tracking_label_event_upserted] end |
.allocation_deleted_v2 ⇒ Object
14270 14271 14272 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14270 def EventType.allocation_deleted_v2 @@_allocation_deleted_v2 ||= EventType.new('allocation_deleted_v2') end |
.allocation_upserted_v2 ⇒ Object
14274 14275 14276 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14274 def EventType.allocation_upserted_v2 @@_allocation_upserted_v2 ||= EventType.new('allocation_upserted_v2') end |
.apply(value) ⇒ Object
Returns the instance of EventType for this value, creating a new instance for an unknown value
14103 14104 14105 14106 14107 14108 14109 14110 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14103 def EventType.apply(value) if value.instance_of?(EventType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || EventType.new(value)) end end |
.attribute_deleted ⇒ Object
14126 14127 14128 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14126 def EventType.attribute_deleted @@_attribute_deleted ||= EventType.new('attribute_deleted') end |
.attribute_deleted_v2 ⇒ Object
14134 14135 14136 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14134 def EventType.attribute_deleted_v2 @@_attribute_deleted_v2 ||= EventType.new('attribute_deleted_v2') end |
.attribute_upserted ⇒ Object
14122 14123 14124 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14122 def EventType.attribute_upserted @@_attribute_upserted ||= EventType.new('attribute_upserted') end |
.attribute_upserted_v2 ⇒ Object
14130 14131 14132 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14130 def EventType.attribute_upserted_v2 @@_attribute_upserted_v2 ||= EventType.new('attribute_upserted_v2') end |
.authorization_deleted_v2 ⇒ Object
14602 14603 14604 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14602 def EventType. ||= EventType.new('authorization_deleted_v2') end |
.authorization_status_changed ⇒ Object
14606 14607 14608 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14606 def EventType. ||= EventType.new('authorization_status_changed') end |
.available_promotions_deleted ⇒ Object
14258 14259 14260 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14258 def EventType.available_promotions_deleted @@_available_promotions_deleted ||= EventType.new('available_promotions_deleted') end |
.available_promotions_deleted_v2 ⇒ Object
14266 14267 14268 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14266 def EventType.available_promotions_deleted_v2 @@_available_promotions_deleted_v2 ||= EventType.new('available_promotions_deleted_v2') end |
.available_promotions_upserted ⇒ Object
14254 14255 14256 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14254 def EventType.available_promotions_upserted @@_available_promotions_upserted ||= EventType.new('available_promotions_upserted') end |
.available_promotions_upserted_v2 ⇒ Object
14262 14263 14264 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14262 def EventType.available_promotions_upserted_v2 @@_available_promotions_upserted_v2 ||= EventType.new('available_promotions_upserted_v2') end |
.b2b_credit_memo_deleted ⇒ Object
14190 14191 14192 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14190 def EventType.b2b_credit_memo_deleted @@_b2b_credit_memo_deleted ||= EventType.new('b2b_credit_memo_deleted') end |
.b2b_credit_memo_upserted ⇒ Object
14186 14187 14188 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14186 def EventType.b2b_credit_memo_upserted @@_b2b_credit_memo_upserted ||= EventType.new('b2b_credit_memo_upserted') end |
.b2b_invoice_deleted ⇒ Object
14182 14183 14184 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14182 def EventType.b2b_invoice_deleted @@_b2b_invoice_deleted ||= EventType.new('b2b_invoice_deleted') end |
.b2b_invoice_upserted ⇒ Object
14178 14179 14180 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14178 def EventType.b2b_invoice_upserted @@_b2b_invoice_upserted ||= EventType.new('b2b_invoice_upserted') end |
.browse_optin_responses_deleted ⇒ Object
14538 14539 14540 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14538 def EventType.browse_optin_responses_deleted @@_browse_optin_responses_deleted ||= EventType.new('browse_optin_responses_deleted') end |
.browse_optin_responses_upserted ⇒ Object
14534 14535 14536 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14534 def EventType.browse_optin_responses_upserted @@_browse_optin_responses_upserted ||= EventType.new('browse_optin_responses_upserted') end |
.capture_deleted ⇒ Object
14630 14631 14632 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14630 def EventType.capture_deleted @@_capture_deleted ||= EventType.new('capture_deleted') end |
.capture_identifier_deleted ⇒ Object
14674 14675 14676 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14674 def EventType.capture_identifier_deleted @@_capture_identifier_deleted ||= EventType.new('capture_identifier_deleted') end |
.capture_identifier_upserted ⇒ Object
14670 14671 14672 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14670 def EventType.capture_identifier_upserted @@_capture_identifier_upserted ||= EventType.new('capture_identifier_upserted') end |
.capture_upserted_v2 ⇒ Object
14626 14627 14628 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14626 def EventType.capture_upserted_v2 @@_capture_upserted_v2 ||= EventType.new('capture_upserted_v2') end |
.card_authorization_deleted_v2 ⇒ Object
14614 14615 14616 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14614 def EventType. ||= EventType.new('card_authorization_deleted_v2') end |
.card_authorization_upserted_v2 ⇒ Object
14610 14611 14612 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14610 def EventType. ||= EventType.new('card_authorization_upserted_v2') end |
.card_deleted ⇒ Object
14638 14639 14640 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14638 def EventType.card_deleted @@_card_deleted ||= EventType.new('card_deleted') end |
.card_upserted_v2 ⇒ Object
14634 14635 14636 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14634 def EventType.card_upserted_v2 @@_card_upserted_v2 ||= EventType.new('card_upserted_v2') end |
.catalog_deleted ⇒ Object
14142 14143 14144 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14142 def EventType.catalog_deleted @@_catalog_deleted ||= EventType.new('catalog_deleted') end |
.catalog_item_deleted ⇒ Object
14158 14159 14160 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14158 def EventType.catalog_item_deleted @@_catalog_item_deleted ||= EventType.new('catalog_item_deleted') end |
.catalog_item_deleted_v2 ⇒ Object
14166 14167 14168 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14166 def EventType.catalog_item_deleted_v2 @@_catalog_item_deleted_v2 ||= EventType.new('catalog_item_deleted_v2') end |
.catalog_item_upserted ⇒ Object
14154 14155 14156 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14154 def EventType.catalog_item_upserted @@_catalog_item_upserted ||= EventType.new('catalog_item_upserted') end |
.catalog_item_upserted_v2 ⇒ Object
14162 14163 14164 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14162 def EventType.catalog_item_upserted_v2 @@_catalog_item_upserted_v2 ||= EventType.new('catalog_item_upserted_v2') end |
.catalog_upserted ⇒ Object
14138 14139 14140 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14138 def EventType.catalog_upserted @@_catalog_upserted ||= EventType.new('catalog_upserted') end |
.center_deleted ⇒ Object
14398 14399 14400 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14398 def EventType.center_deleted @@_center_deleted ||= EventType.new('center_deleted') end |
.center_upserted ⇒ Object
14394 14395 14396 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14394 def EventType.center_upserted @@_center_upserted ||= EventType.new('center_upserted') end |
.checkout_optin_responses_deleted ⇒ Object
14530 14531 14532 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14530 def EventType.checkout_optin_responses_deleted @@_checkout_optin_responses_deleted ||= EventType.new('checkout_optin_responses_deleted') end |
.checkout_optin_responses_upserted ⇒ Object
14526 14527 14528 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14526 def EventType.checkout_optin_responses_upserted @@_checkout_optin_responses_upserted ||= EventType.new('checkout_optin_responses_upserted') end |
.consumer_invoice_deleted ⇒ Object
14198 14199 14200 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14198 def EventType.consumer_invoice_deleted @@_consumer_invoice_deleted ||= EventType.new('consumer_invoice_deleted') end |
.consumer_invoice_upserted ⇒ Object
14194 14195 14196 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14194 def EventType.consumer_invoice_upserted @@_consumer_invoice_upserted ||= EventType.new('consumer_invoice_upserted') end |
.credit_memo_deleted ⇒ Object
14206 14207 14208 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14206 def EventType.credit_memo_deleted @@_credit_memo_deleted ||= EventType.new('credit_memo_deleted') end |
.credit_memo_upserted ⇒ Object
14202 14203 14204 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14202 def EventType.credit_memo_upserted @@_credit_memo_upserted ||= EventType.new('credit_memo_upserted') end |
.crossdock_shipment_upserted ⇒ Object
14210 14211 14212 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14210 def EventType.crossdock_shipment_upserted @@_crossdock_shipment_upserted ||= EventType.new('crossdock_shipment_upserted') end |
.currency_format_deleted ⇒ Object
14278 14279 14280 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14278 def EventType.currency_format_deleted @@_currency_format_deleted ||= EventType.new('currency_format_deleted') end |
.currency_format_upserted ⇒ Object
14282 14283 14284 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14282 def EventType.currency_format_upserted @@_currency_format_upserted ||= EventType.new('currency_format_upserted') end |
.customer_address_book_contact_deleted ⇒ Object
14242 14243 14244 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14242 def EventType.customer_address_book_contact_deleted @@_customer_address_book_contact_deleted ||= EventType.new('customer_address_book_contact_deleted') end |
.customer_address_book_contact_upserted ⇒ Object
14238 14239 14240 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14238 def EventType.customer_address_book_contact_upserted @@_customer_address_book_contact_upserted ||= EventType.new('customer_address_book_contact_upserted') end |
.customer_deleted ⇒ Object
14234 14235 14236 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14234 def EventType.customer_deleted @@_customer_deleted ||= EventType.new('customer_deleted') end |
.customer_upserted ⇒ Object
14230 14231 14232 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14230 def EventType.customer_upserted @@_customer_upserted ||= EventType.new('customer_upserted') end |
.ecommerce_platform_deleted ⇒ Object
14598 14599 14600 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14598 def EventType.ecommerce_platform_deleted @@_ecommerce_platform_deleted ||= EventType.new('ecommerce_platform_deleted') end |
.ecommerce_platform_upserted ⇒ Object
14594 14595 14596 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14594 def EventType.ecommerce_platform_upserted @@_ecommerce_platform_upserted ||= EventType.new('ecommerce_platform_upserted') end |
.email_notification_deleted ⇒ Object
14250 14251 14252 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14250 def EventType.email_notification_deleted @@_email_notification_deleted ||= EventType.new('email_notification_deleted') end |
.email_notification_upserted ⇒ Object
14246 14247 14248 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14246 def EventType.email_notification_upserted @@_email_notification_upserted ||= EventType.new('email_notification_upserted') end |
.experience_deleted ⇒ Object
14286 14287 14288 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14286 def EventType.experience_deleted @@_experience_deleted ||= EventType.new('experience_deleted') end |
.experience_deleted_v2 ⇒ Object
14294 14295 14296 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14294 def EventType.experience_deleted_v2 @@_experience_deleted_v2 ||= EventType.new('experience_deleted_v2') end |
.experience_logistics_settings_deleted ⇒ Object
14314 14315 14316 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14314 def EventType.experience_logistics_settings_deleted @@_experience_logistics_settings_deleted ||= EventType.new('experience_logistics_settings_deleted') end |
.experience_logistics_settings_upserted ⇒ Object
14310 14311 14312 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14310 def EventType.experience_logistics_settings_upserted @@_experience_logistics_settings_upserted ||= EventType.new('experience_logistics_settings_upserted') end |
.experience_price_book_mapping_deleted ⇒ Object
14302 14303 14304 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14302 def EventType.experience_price_book_mapping_deleted @@_experience_price_book_mapping_deleted ||= EventType.new('experience_price_book_mapping_deleted') end |
.experience_price_book_mapping_upserted ⇒ Object
14306 14307 14308 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14306 def EventType.experience_price_book_mapping_upserted @@_experience_price_book_mapping_upserted ||= EventType.new('experience_price_book_mapping_upserted') end |
.experience_upserted ⇒ Object
14290 14291 14292 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14290 def EventType.experience_upserted @@_experience_upserted ||= EventType.new('experience_upserted') end |
.experience_upserted_v2 ⇒ Object
14298 14299 14300 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14298 def EventType.experience_upserted_v2 @@_experience_upserted_v2 ||= EventType.new('experience_upserted_v2') end |
.fraud_status_changed ⇒ Object
14390 14391 14392 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14390 def EventType.fraud_status_changed @@_fraud_status_changed ||= EventType.new('fraud_status_changed') end |
.from_string(value) ⇒ Object
Returns the instance of EventType for this value, or nil if not found
14113 14114 14115 14116 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14113 def EventType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) EventType.ALL.find { |v| v.value == value } end |
.fully_harmonized_item_upserted ⇒ Object
14470 14471 14472 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14470 def EventType.fully_harmonized_item_upserted @@_fully_harmonized_item_upserted ||= EventType.new('fully_harmonized_item_upserted') end |
.harmonized_landed_cost_upserted ⇒ Object
14466 14467 14468 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14466 def EventType.harmonized_landed_cost_upserted @@_harmonized_landed_cost_upserted ||= EventType.new('harmonized_landed_cost_upserted') end |
.hs10_code_deleted ⇒ Object
14454 14455 14456 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14454 def EventType.hs10_code_deleted @@_hs10_code_deleted ||= EventType.new('hs10_code_deleted') end |
.hs10_code_upserted ⇒ Object
14450 14451 14452 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14450 def EventType.hs10_code_upserted @@_hs10_code_upserted ||= EventType.new('hs10_code_upserted') end |
.hs6_code_deleted ⇒ Object
14446 14447 14448 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14446 def EventType.hs6_code_deleted @@_hs6_code_deleted ||= EventType.new('hs6_code_deleted') end |
.hs6_code_upserted ⇒ Object
14442 14443 14444 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14442 def EventType.hs6_code_upserted @@_hs6_code_upserted ||= EventType.new('hs6_code_upserted') end |
.item_margin_deleted ⇒ Object
14318 14319 14320 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14318 def EventType.item_margin_deleted @@_item_margin_deleted ||= EventType.new('item_margin_deleted') end |
.item_margin_upserted ⇒ Object
14322 14323 14324 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14322 def EventType.item_margin_upserted @@_item_margin_upserted ||= EventType.new('item_margin_upserted') end |
.item_origin_deleted ⇒ Object
14462 14463 14464 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14462 def EventType.item_origin_deleted @@_item_origin_deleted ||= EventType.new('item_origin_deleted') end |
.item_origin_upserted ⇒ Object
14458 14459 14460 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14458 def EventType.item_origin_upserted @@_item_origin_upserted ||= EventType.new('item_origin_upserted') end |
.item_sales_margin_deleted ⇒ Object
14326 14327 14328 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14326 def EventType.item_sales_margin_deleted @@_item_sales_margin_deleted ||= EventType.new('item_sales_margin_deleted') end |
.item_sales_margin_upserted ⇒ Object
14330 14331 14332 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14330 def EventType.item_sales_margin_upserted @@_item_sales_margin_upserted ||= EventType.new('item_sales_margin_upserted') end |
.label_format_deleted ⇒ Object
14334 14335 14336 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14334 def EventType.label_format_deleted @@_label_format_deleted ||= EventType.new('label_format_deleted') end |
.label_format_upserted ⇒ Object
14338 14339 14340 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14338 def EventType.label_format_upserted @@_label_format_upserted ||= EventType.new('label_format_upserted') end |
.label_upserted ⇒ Object
14498 14499 14500 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14498 def EventType.label_upserted @@_label_upserted ||= EventType.new('label_upserted') end |
.local_item_deleted ⇒ Object
14522 14523 14524 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14522 def EventType.local_item_deleted @@_local_item_deleted ||= EventType.new('local_item_deleted') end |
.local_item_upserted ⇒ Object
14518 14519 14520 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14518 def EventType.local_item_upserted @@_local_item_upserted ||= EventType.new('local_item_upserted') end |
.manifested_label_deleted ⇒ Object
14514 14515 14516 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14514 def EventType.manifested_label_deleted @@_manifested_label_deleted ||= EventType.new('manifested_label_deleted') end |
.manifested_label_upserted ⇒ Object
14510 14511 14512 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14510 def EventType.manifested_label_upserted @@_manifested_label_upserted ||= EventType.new('manifested_label_upserted') end |
.membership_deleted_v2 ⇒ Object
14558 14559 14560 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14558 def EventType.membership_deleted_v2 @@_membership_deleted_v2 ||= EventType.new('membership_deleted_v2') end |
.membership_upserted_v2 ⇒ Object
14554 14555 14556 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14554 def EventType.membership_upserted_v2 @@_membership_upserted_v2 ||= EventType.new('membership_upserted_v2') end |
.notification_deleted ⇒ Object
14506 14507 14508 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14506 def EventType.notification_deleted @@_notification_deleted ||= EventType.new('notification_deleted') end |
.notification_upserted ⇒ Object
14502 14503 14504 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14502 def EventType.notification_upserted @@_notification_upserted ||= EventType.new('notification_upserted') end |
.online_authorization_deleted_v2 ⇒ Object
14622 14623 14624 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14622 def EventType. ||= EventType.new('online_authorization_deleted_v2') end |
.online_authorization_upserted_v2 ⇒ Object
14618 14619 14620 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14618 def EventType. ||= EventType.new('online_authorization_upserted_v2') end |
.order_deleted ⇒ Object
14342 14343 14344 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14342 def EventType.order_deleted @@_order_deleted ||= EventType.new('order_deleted') end |
.order_deleted_v2 ⇒ Object
14350 14351 14352 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14350 def EventType.order_deleted_v2 @@_order_deleted_v2 ||= EventType.new('order_deleted_v2') end |
.order_identifier_deleted ⇒ Object
14358 14359 14360 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14358 def EventType.order_identifier_deleted @@_order_identifier_deleted ||= EventType.new('order_identifier_deleted') end |
.order_identifier_deleted_v2 ⇒ Object
14366 14367 14368 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14366 def EventType.order_identifier_deleted_v2 @@_order_identifier_deleted_v2 ||= EventType.new('order_identifier_deleted_v2') end |
.order_identifier_upserted ⇒ Object
14362 14363 14364 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14362 def EventType.order_identifier_upserted @@_order_identifier_upserted ||= EventType.new('order_identifier_upserted') end |
.order_identifier_upserted_v2 ⇒ Object
14370 14371 14372 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14370 def EventType.order_identifier_upserted_v2 @@_order_identifier_upserted_v2 ||= EventType.new('order_identifier_upserted_v2') end |
.order_identifier_upserted_v3 ⇒ Object
14374 14375 14376 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14374 def EventType.order_identifier_upserted_v3 @@_order_identifier_upserted_v3 ||= EventType.new('order_identifier_upserted_v3') end |
.order_placed ⇒ Object
14542 14543 14544 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14542 def EventType.order_placed @@_order_placed ||= EventType.new('order_placed') end |
.order_placed_v2 ⇒ Object
14546 14547 14548 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14546 def EventType.order_placed_v2 @@_order_placed_v2 ||= EventType.new('order_placed_v2') end |
.order_service_change_request ⇒ Object
14386 14387 14388 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14386 def EventType.order_service_change_request @@_order_service_change_request ||= EventType.new('order_service_change_request') end |
.order_upserted ⇒ Object
14346 14347 14348 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14346 def EventType.order_upserted @@_order_upserted ||= EventType.new('order_upserted') end |
.order_upserted_v2 ⇒ Object
14354 14355 14356 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14354 def EventType.order_upserted_v2 @@_order_upserted_v2 ||= EventType.new('order_upserted_v2') end |
.organization_default_configurations_deleted ⇒ Object
14590 14591 14592 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14590 def EventType.organization_default_configurations_deleted @@_organization_default_configurations_deleted ||= EventType.new('organization_default_configurations_deleted') end |
.organization_default_configurations_upserted ⇒ Object
14586 14587 14588 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14586 def EventType.organization_default_configurations_upserted @@_organization_default_configurations_upserted ||= EventType.new('organization_default_configurations_upserted') end |
.organization_deleted ⇒ Object
14566 14567 14568 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14566 def EventType.organization_deleted @@_organization_deleted ||= EventType.new('organization_deleted') end |
.organization_deleted_v2 ⇒ Object
14574 14575 14576 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14574 def EventType.organization_deleted_v2 @@_organization_deleted_v2 ||= EventType.new('organization_deleted_v2') end |
.organization_rates_published ⇒ Object
14718 14719 14720 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14718 def EventType.organization_rates_published @@_organization_rates_published ||= EventType.new('organization_rates_published') end |
.organization_short_id_deleted ⇒ Object
14582 14583 14584 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14582 def EventType.organization_short_id_deleted @@_organization_short_id_deleted ||= EventType.new('organization_short_id_deleted') end |
.organization_short_id_upserted ⇒ Object
14578 14579 14580 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14578 def EventType.organization_short_id_upserted @@_organization_short_id_upserted ||= EventType.new('organization_short_id_upserted') end |
.organization_upserted ⇒ Object
14562 14563 14564 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14562 def EventType.organization_upserted @@_organization_upserted ||= EventType.new('organization_upserted') end |
.organization_upserted_v2 ⇒ Object
14570 14571 14572 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14570 def EventType.organization_upserted_v2 @@_organization_upserted_v2 ||= EventType.new('organization_upserted_v2') end |
.payment_deleted ⇒ Object
14646 14647 14648 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14646 def EventType.payment_deleted @@_payment_deleted ||= EventType.new('payment_deleted') end |
.payment_upserted ⇒ Object
14642 14643 14644 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14642 def EventType.payment_upserted @@_payment_upserted ||= EventType.new('payment_upserted') end |
.price_book_deleted ⇒ Object
14706 14707 14708 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14706 def EventType.price_book_deleted @@_price_book_deleted ||= EventType.new('price_book_deleted') end |
.price_book_item_deleted ⇒ Object
14714 14715 14716 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14714 def EventType.price_book_item_deleted @@_price_book_item_deleted ||= EventType.new('price_book_item_deleted') end |
.price_book_item_upserted ⇒ Object
14710 14711 14712 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14710 def EventType.price_book_item_upserted @@_price_book_item_upserted ||= EventType.new('price_book_item_upserted') end |
.price_book_upserted ⇒ Object
14702 14703 14704 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14702 def EventType.price_book_upserted @@_price_book_upserted ||= EventType.new('price_book_upserted') end |
.pricing_deleted ⇒ Object
14378 14379 14380 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14378 def EventType.pricing_deleted @@_pricing_deleted ||= EventType.new('pricing_deleted') end |
.pricing_upserted ⇒ Object
14382 14383 14384 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14382 def EventType.pricing_upserted @@_pricing_upserted ||= EventType.new('pricing_upserted') end |
.rate_deleted ⇒ Object
14214 14215 14216 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14214 def EventType.rate_deleted @@_rate_deleted ||= EventType.new('rate_deleted') end |
.rate_deleted_v3 ⇒ Object
14222 14223 14224 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14222 def EventType.rate_deleted_v3 @@_rate_deleted_v3 ||= EventType.new('rate_deleted_v3') end |
.rate_upserted ⇒ Object
14218 14219 14220 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14218 def EventType.rate_upserted @@_rate_upserted ||= EventType.new('rate_upserted') end |
.rate_upserted_v3 ⇒ Object
14226 14227 14228 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14226 def EventType.rate_upserted_v3 @@_rate_upserted_v3 ||= EventType.new('rate_upserted_v3') end |
.ratecard_deleted ⇒ Object
14734 14735 14736 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14734 def EventType.ratecard_deleted @@_ratecard_deleted ||= EventType.new('ratecard_deleted') end |
.ratecard_lane_deleted ⇒ Object
14726 14727 14728 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14726 def EventType.ratecard_lane_deleted @@_ratecard_lane_deleted ||= EventType.new('ratecard_lane_deleted') end |
.ratecard_lane_upserted ⇒ Object
14722 14723 14724 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14722 def EventType.ratecard_lane_upserted @@_ratecard_lane_upserted ||= EventType.new('ratecard_lane_upserted') end |
.ratecard_upserted ⇒ Object
14730 14731 14732 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14730 def EventType.ratecard_upserted @@_ratecard_upserted ||= EventType.new('ratecard_upserted') end |
.ready_to_fulfill ⇒ Object
14550 14551 14552 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14550 def EventType.ready_to_fulfill @@_ready_to_fulfill ||= EventType.new('ready_to_fulfill') end |
.refund_capture_upserted_v2 ⇒ Object
14658 14659 14660 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14658 def EventType.refund_capture_upserted_v2 @@_refund_capture_upserted_v2 ||= EventType.new('refund_capture_upserted_v2') end |
.refund_deleted_v2 ⇒ Object
14654 14655 14656 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14654 def EventType.refund_deleted_v2 @@_refund_deleted_v2 ||= EventType.new('refund_deleted_v2') end |
.refund_identifier_deleted ⇒ Object
14682 14683 14684 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14682 def EventType.refund_identifier_deleted @@_refund_identifier_deleted ||= EventType.new('refund_identifier_deleted') end |
.refund_identifier_upserted ⇒ Object
14678 14679 14680 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14678 def EventType.refund_identifier_upserted @@_refund_identifier_upserted ||= EventType.new('refund_identifier_upserted') end |
.refund_upserted_v2 ⇒ Object
14650 14651 14652 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14650 def EventType.refund_upserted_v2 @@_refund_upserted_v2 ||= EventType.new('refund_upserted_v2') end |
.return_deleted ⇒ Object
14742 14743 14744 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14742 def EventType.return_deleted @@_return_deleted ||= EventType.new('return_deleted') end |
.return_upserted ⇒ Object
14738 14739 14740 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14738 def EventType.return_upserted @@_return_upserted ||= EventType.new('return_upserted') end |
.reversal_deleted ⇒ Object
14666 14667 14668 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14666 def EventType.reversal_deleted @@_reversal_deleted ||= EventType.new('reversal_deleted') end |
.reversal_upserted ⇒ Object
14662 14663 14664 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14662 def EventType.reversal_upserted @@_reversal_upserted ||= EventType.new('reversal_upserted') end |
.rule_deleted ⇒ Object
14478 14479 14480 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14478 def EventType.rule_deleted @@_rule_deleted ||= EventType.new('rule_deleted') end |
.rule_upserted ⇒ Object
14474 14475 14476 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14474 def EventType.rule_upserted @@_rule_upserted ||= EventType.new('rule_upserted') end |
.serial_deleted ⇒ Object
14486 14487 14488 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14486 def EventType.serial_deleted @@_serial_deleted ||= EventType.new('serial_deleted') end |
.serial_upserted ⇒ Object
14482 14483 14484 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14482 def EventType.serial_upserted @@_serial_upserted ||= EventType.new('serial_upserted') end |
.shipping_configuration_deleted ⇒ Object
14406 14407 14408 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14406 def EventType.shipping_configuration_deleted @@_shipping_configuration_deleted ||= EventType.new('shipping_configuration_deleted') end |
.shipping_configuration_item_availability_deleted ⇒ Object
14430 14431 14432 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14430 def EventType.shipping_configuration_item_availability_deleted @@_shipping_configuration_item_availability_deleted ||= EventType.new('shipping_configuration_item_availability_deleted') end |
.shipping_configuration_item_availability_upserted ⇒ Object
14426 14427 14428 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14426 def EventType.shipping_configuration_item_availability_upserted @@_shipping_configuration_item_availability_upserted ||= EventType.new('shipping_configuration_item_availability_upserted') end |
.shipping_configuration_item_shipping_pricing_deleted ⇒ Object
14438 14439 14440 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14438 def EventType.shipping_configuration_item_shipping_pricing_deleted @@_shipping_configuration_item_shipping_pricing_deleted ||= EventType.new('shipping_configuration_item_shipping_pricing_deleted') end |
.shipping_configuration_item_shipping_pricing_upserted ⇒ Object
14434 14435 14436 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14434 def EventType.shipping_configuration_item_shipping_pricing_upserted @@_shipping_configuration_item_shipping_pricing_upserted ||= EventType.new('shipping_configuration_item_shipping_pricing_upserted') end |
.shipping_configuration_upserted ⇒ Object
14402 14403 14404 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14402 def EventType.shipping_configuration_upserted @@_shipping_configuration_upserted ||= EventType.new('shipping_configuration_upserted') end |
.shipping_lane_deleted ⇒ Object
14422 14423 14424 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14422 def EventType.shipping_lane_deleted @@_shipping_lane_deleted ||= EventType.new('shipping_lane_deleted') end |
.shipping_lane_upserted ⇒ Object
14418 14419 14420 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14418 def EventType.shipping_lane_upserted @@_shipping_lane_upserted ||= EventType.new('shipping_lane_upserted') end |
.shopify_localization_setting_deleted ⇒ Object
14750 14751 14752 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14750 def EventType.shopify_localization_setting_deleted @@_shopify_localization_setting_deleted ||= EventType.new('shopify_localization_setting_deleted') end |
.shopify_localization_setting_upserted ⇒ Object
14746 14747 14748 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14746 def EventType.shopify_localization_setting_upserted @@_shopify_localization_setting_upserted ||= EventType.new('shopify_localization_setting_upserted') end |
.snapshot_deleted ⇒ Object
14494 14495 14496 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14494 def EventType.snapshot_deleted @@_snapshot_deleted ||= EventType.new('snapshot_deleted') end |
.snapshot_upserted ⇒ Object
14490 14491 14492 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14490 def EventType.snapshot_upserted @@_snapshot_upserted ||= EventType.new('snapshot_upserted') end |
.subcatalog_deleted ⇒ Object
14150 14151 14152 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14150 def EventType.subcatalog_deleted @@_subcatalog_deleted ||= EventType.new('subcatalog_deleted') end |
.subcatalog_item_deleted ⇒ Object
14174 14175 14176 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14174 def EventType.subcatalog_item_deleted @@_subcatalog_item_deleted ||= EventType.new('subcatalog_item_deleted') end |
.subcatalog_item_upserted ⇒ Object
14170 14171 14172 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14170 def EventType.subcatalog_item_upserted @@_subcatalog_item_upserted ||= EventType.new('subcatalog_item_upserted') end |
.subcatalog_upserted ⇒ Object
14146 14147 14148 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14146 def EventType.subcatalog_upserted @@_subcatalog_upserted ||= EventType.new('subcatalog_upserted') end |
.targeting_item_deleted ⇒ Object
14762 14763 14764 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14762 def EventType.targeting_item_deleted @@_targeting_item_deleted ||= EventType.new('targeting_item_deleted') end |
.targeting_item_deleted_v3 ⇒ Object
14766 14767 14768 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14766 def EventType.targeting_item_deleted_v3 @@_targeting_item_deleted_v3 ||= EventType.new('targeting_item_deleted_v3') end |
.targeting_item_upserted ⇒ Object
14754 14755 14756 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14754 def EventType.targeting_item_upserted @@_targeting_item_upserted ||= EventType.new('targeting_item_upserted') end |
.targeting_item_upserted_v2 ⇒ Object
14758 14759 14760 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14758 def EventType.targeting_item_upserted_v2 @@_targeting_item_upserted_v2 ||= EventType.new('targeting_item_upserted_v2') end |
.tier_deleted_v2 ⇒ Object
14414 14415 14416 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14414 def EventType.tier_deleted_v2 @@_tier_deleted_v2 ||= EventType.new('tier_deleted_v2') end |
.tier_upserted_v2 ⇒ Object
14410 14411 14412 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14410 def EventType.tier_upserted_v2 @@_tier_upserted_v2 ||= EventType.new('tier_upserted_v2') end |
.tracking_label_event_upserted ⇒ Object
14770 14771 14772 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14770 def EventType.tracking_label_event_upserted @@_tracking_label_event_upserted ||= EventType.new('tracking_label_event_upserted') end |
.virtual_card_capture_deleted ⇒ Object
14690 14691 14692 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14690 def EventType.virtual_card_capture_deleted @@_virtual_card_capture_deleted ||= EventType.new('virtual_card_capture_deleted') end |
.virtual_card_capture_upserted ⇒ Object
14686 14687 14688 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14686 def EventType.virtual_card_capture_upserted @@_virtual_card_capture_upserted ||= EventType.new('virtual_card_capture_upserted') end |
.virtual_card_refund_deleted ⇒ Object
14698 14699 14700 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14698 def EventType.virtual_card_refund_deleted @@_virtual_card_refund_deleted ||= EventType.new('virtual_card_refund_deleted') end |
.virtual_card_refund_upserted ⇒ Object
14694 14695 14696 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14694 def EventType.virtual_card_refund_upserted @@_virtual_card_refund_upserted ||= EventType.new('virtual_card_refund_upserted') end |
Instance Method Details
#to_hash ⇒ Object
14774 14775 14776 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14774 def to_hash value end |