Class: Io::Flow::V0::Models::ExportStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ ExportStatus

Returns a new instance of ExportStatus.



12714
12715
12716
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12714

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



12712
12713
12714
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12712

def value
  @value
end

Class Method Details

.ALLObject



12734
12735
12736
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12734

def ExportStatus.ALL
  @@all ||= [ExportStatus.created, ExportStatus.processing, ExportStatus.completed, ExportStatus.failed]
end

.apply(value) ⇒ Object

Returns the instance of ExportStatus for this value, creating a new instance for an unknown value



12719
12720
12721
12722
12723
12724
12725
12726
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12719

def ExportStatus.apply(value)
  if value.instance_of?(ExportStatus)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || ExportStatus.new(value))
  end
end

.completedObject



12746
12747
12748
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12746

def ExportStatus.completed
  @@_completed ||= ExportStatus.new('completed')
end

.createdObject



12738
12739
12740
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12738

def ExportStatus.created
  @@_created ||= ExportStatus.new('created')
end

.failedObject



12750
12751
12752
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12750

def ExportStatus.failed
  @@_failed ||= ExportStatus.new('failed')
end

.from_string(value) ⇒ Object

Returns the instance of ExportStatus for this value, or nil if not found



12729
12730
12731
12732
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12729

def ExportStatus.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  ExportStatus.ALL.find { |v| v.value == value }
end

.processingObject



12742
12743
12744
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12742

def ExportStatus.processing
  @@_processing ||= ExportStatus.new('processing')
end

Instance Method Details

#to_hashObject



12754
12755
12756
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 12754

def to_hash
  value
end