Class: Io::Flow::V0::Models::FlowAddonRole
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Attributes inherited from FlowRole
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of FlowAddonRole for this value, creating a new instance for an unknown value.
-
.consumer_data_viewer ⇒ Object
Can view consumer's private data.
-
.from_string(value) ⇒ Object
Returns the instance of FlowAddonRole for this value, or nil if not found.
-
.membership_manager ⇒ Object
Can invite new users to the org.
Instance Method Summary collapse
-
#initialize(value) ⇒ FlowAddonRole
constructor
A new instance of FlowAddonRole.
- #subtype_to_hash ⇒ Object
Methods inherited from FlowRole
Constructor Details
#initialize(value) ⇒ FlowAddonRole
Returns a new instance of FlowAddonRole.
15065 15066 15067 15068 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15065 def initialize(value) super(:name => FlowRole::Types::FLOW_ADDON_ROLE, :__discriminator__ => 'flow_addon_role') @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
15063 15064 15065 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15063 def value @value end |
Class Method Details
.ALL ⇒ Object
15086 15087 15088 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15086 def FlowAddonRole.ALL @@all ||= [FlowAddonRole.consumer_data_viewer, FlowAddonRole.membership_manager] end |
.apply(value) ⇒ Object
Returns the instance of FlowAddonRole for this value, creating a new instance for an unknown value
15071 15072 15073 15074 15075 15076 15077 15078 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15071 def FlowAddonRole.apply(value) if value.instance_of?(FlowAddonRole) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || FlowAddonRole.new(value)) end end |
.consumer_data_viewer ⇒ Object
Can view consumer's private data
15091 15092 15093 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15091 def FlowAddonRole.consumer_data_viewer @@_consumer_data_viewer ||= FlowAddonRole.new('consumer_data_viewer') end |
.from_string(value) ⇒ Object
Returns the instance of FlowAddonRole for this value, or nil if not found
15081 15082 15083 15084 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15081 def FlowAddonRole.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) FlowAddonRole.ALL.find { |v| v.value == value } end |
.membership_manager ⇒ Object
Can invite new users to the org.
15096 15097 15098 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15096 def FlowAddonRole.membership_manager @@_membership_manager ||= FlowAddonRole.new('membership_manager') end |
Instance Method Details
#subtype_to_hash ⇒ Object
15100 15101 15102 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15100 def subtype_to_hash value end |