Class: Io::Flow::V0::Models::FtpOrganizationSettings
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::FtpOrganizationSettings
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
The FTP Organization Settings allows you to enable an FTP Drop Point for an organization, creating the standard set of FTP Folders, credentials, and associated webhooks.
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
Returns the value of attribute account.
-
#emails ⇒ Object
readonly
Returns the value of attribute emails.
-
#enabled ⇒ Object
readonly
Returns the value of attribute enabled.
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ FtpOrganizationSettings
constructor
A new instance of FtpOrganizationSettings.
- #to_hash ⇒ Object
- #to_json ⇒ Object
Constructor Details
#initialize(incoming = {}) ⇒ FtpOrganizationSettings
Returns a new instance of FtpOrganizationSettings.
30926 30927 30928 30929 30930 30931 30932 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 30926 def initialize(incoming={}) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:enabled, :emails], 'FtpOrganizationSettings') @enabled = HttpClient::Preconditions.assert_boolean('enabled', opts.delete(:enabled)) @emails = HttpClient::Preconditions.assert_class('emails', opts.delete(:emails), Array).map { |v| HttpClient::Preconditions.assert_class('emails', v, String) } @account = (x = opts.delete(:account); x.nil? ? nil : (x = x; x.is_a?(::Io::Flow::V0::Models::FtpAccount) ? x : ::Io::Flow::V0::Models::FtpAccount.new(x))) end |
Instance Attribute Details
#account ⇒ Object (readonly)
Returns the value of attribute account.
30924 30925 30926 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 30924 def account @account end |
#emails ⇒ Object (readonly)
Returns the value of attribute emails.
30924 30925 30926 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 30924 def emails @emails end |
#enabled ⇒ Object (readonly)
Returns the value of attribute enabled.
30924 30925 30926 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 30924 def enabled @enabled end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
30938 30939 30940 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 30938 def copy(incoming={}) FtpOrganizationSettings.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#to_hash ⇒ Object
30942 30943 30944 30945 30946 30947 30948 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 30942 def to_hash { :enabled => enabled, :emails => emails, :account => account.nil? ? nil : account.to_hash } end |
#to_json ⇒ Object
30934 30935 30936 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 30934 def to_json JSON.dump(to_hash) end |