Class: Io::Flow::V0::Models::ImportForm

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Import forms create imports. The import type defines both the type of the import (e.g. the CSV File format) and the URL at which the source data are available. If you do not have a URL readily available, you can first upload a file via the Flow API - see the resource named 'Upload'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ ImportForm

Returns a new instance of ImportForm.



13922
13923
13924
13925
13926
13927
13928
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13922

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:type, :source_url], 'ImportForm')
  @type = (x = opts.delete(:type); x.is_a?(::Io::Flow::V0::Models::ImportType) ? x : ::Io::Flow::V0::Models::ImportType.apply(x))
  @source_url = HttpClient::Preconditions.assert_class('source_url', opts.delete(:source_url), String)
  @emails = (x = opts.delete(:emails); x.nil? ? nil : HttpClient::Preconditions.assert_class('emails', x, Array).map { |v| HttpClient::Preconditions.assert_class('emails', v, String) })
end

Instance Attribute Details

#emails ⇒ Object (readonly)

Returns the value of attribute emails.



13920
13921
13922
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13920

def emails
  @emails
end

#source_url ⇒ Object (readonly)

Returns the value of attribute source_url.



13920
13921
13922
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13920

def source_url
  @source_url
end

#type ⇒ Object (readonly)

Returns the value of attribute type.



13920
13921
13922
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13920

def type
  @type
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



13934
13935
13936
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13934

def copy(incoming={})
  ImportForm.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hash ⇒ Object



13938
13939
13940
13941
13942
13943
13944
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13938

def to_hash
  {
    :type => type.value,
    :source_url => source_url,
    :emails => emails.nil? ? nil : emails
  }
end

#to_json ⇒ Object



13930
13931
13932
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 13930

def to_json
  JSON.dump(to_hash)
end