Class: Io::Flow::V0::Models::IncludedLevyKey
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::IncludedLevyKey
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of IncludedLevyKey for this value, creating a new instance for an unknown value.
- .duty ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of IncludedLevyKey for this value, or nil if not found.
- .none ⇒ Object
- .vat ⇒ Object
- .vat_and_duty ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ IncludedLevyKey
constructor
A new instance of IncludedLevyKey.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ IncludedLevyKey
Returns a new instance of IncludedLevyKey.
19844 19845 19846 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19844 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
19842 19843 19844 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19842 def value @value end |
Class Method Details
.ALL ⇒ Object
19864 19865 19866 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19864 def IncludedLevyKey.ALL @@all ||= [IncludedLevyKey.duty, IncludedLevyKey.vat, IncludedLevyKey.vat_and_duty, IncludedLevyKey.none] end |
.apply(value) ⇒ Object
Returns the instance of IncludedLevyKey for this value, creating a new instance for an unknown value
19849 19850 19851 19852 19853 19854 19855 19856 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19849 def IncludedLevyKey.apply(value) if value.instance_of?(IncludedLevyKey) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || IncludedLevyKey.new(value)) end end |
.duty ⇒ Object
19868 19869 19870 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19868 def IncludedLevyKey.duty @@_duty ||= IncludedLevyKey.new('duty') end |
.from_string(value) ⇒ Object
Returns the instance of IncludedLevyKey for this value, or nil if not found
19859 19860 19861 19862 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19859 def IncludedLevyKey.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) IncludedLevyKey.ALL.find { |v| v.value == value } end |
.none ⇒ Object
19880 19881 19882 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19880 def IncludedLevyKey.none @@_none ||= IncludedLevyKey.new('none') end |
.vat ⇒ Object
19872 19873 19874 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19872 def IncludedLevyKey.vat @@_vat ||= IncludedLevyKey.new('vat') end |
.vat_and_duty ⇒ Object
19876 19877 19878 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19876 def IncludedLevyKey.vat_and_duty @@_vat_and_duty ||= IncludedLevyKey.new('vat_and_duty') end |
Instance Method Details
#to_hash ⇒ Object
19884 19885 19886 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19884 def to_hash value end |