Class: Io::Flow::V0::Models::IncludedLevyKey
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::IncludedLevyKey
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of IncludedLevyKey for this value, creating a new instance for an unknown value.
- .duty ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of IncludedLevyKey for this value, or nil if not found.
- .none ⇒ Object
- .vat ⇒ Object
- .vat_and_duty ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ IncludedLevyKey
constructor
A new instance of IncludedLevyKey.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ IncludedLevyKey
Returns a new instance of IncludedLevyKey.
15821 15822 15823 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15821 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
15819 15820 15821 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15819 def value @value end |
Class Method Details
.ALL ⇒ Object
15841 15842 15843 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15841 def IncludedLevyKey.ALL @@all ||= [IncludedLevyKey.duty, IncludedLevyKey.vat, IncludedLevyKey.vat_and_duty, IncludedLevyKey.none] end |
.apply(value) ⇒ Object
Returns the instance of IncludedLevyKey for this value, creating a new instance for an unknown value
15826 15827 15828 15829 15830 15831 15832 15833 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15826 def IncludedLevyKey.apply(value) if value.instance_of?(IncludedLevyKey) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || IncludedLevyKey.new(value)) end end |
.duty ⇒ Object
15845 15846 15847 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15845 def IncludedLevyKey.duty @@_duty ||= IncludedLevyKey.new('duty') end |
.from_string(value) ⇒ Object
Returns the instance of IncludedLevyKey for this value, or nil if not found
15836 15837 15838 15839 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15836 def IncludedLevyKey.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) IncludedLevyKey.ALL.find { |v| v.value == value } end |
.none ⇒ Object
15857 15858 15859 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15857 def IncludedLevyKey.none @@_none ||= IncludedLevyKey.new('none') end |
.vat ⇒ Object
15849 15850 15851 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15849 def IncludedLevyKey.vat @@_vat ||= IncludedLevyKey.new('vat') end |
.vat_and_duty ⇒ Object
15853 15854 15855 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15853 def IncludedLevyKey.vat_and_duty @@_vat_and_duty ||= IncludedLevyKey.new('vat_and_duty') end |
Instance Method Details
#to_hash ⇒ Object
15861 15862 15863 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15861 def to_hash value end |