Class: Io::Flow::V0::Models::IncludedLevyKey

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ IncludedLevyKey

Returns a new instance of IncludedLevyKey.



9252
9253
9254
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9252

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



9250
9251
9252
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9250

def value
  @value
end

Class Method Details

.ALLObject



9272
9273
9274
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9272

def IncludedLevyKey.ALL
  @@all ||= [IncludedLevyKey.duty, IncludedLevyKey.vat, IncludedLevyKey.vat_and_duty]
end

.apply(value) ⇒ Object

Returns the instance of IncludedLevyKey for this value, creating a new instance for an unknown value



9257
9258
9259
9260
9261
9262
9263
9264
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9257

def IncludedLevyKey.apply(value)
  if value.instance_of?(IncludedLevyKey)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || IncludedLevyKey.new(value))
  end
end

.dutyObject



9276
9277
9278
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9276

def IncludedLevyKey.duty
  @@_duty ||= IncludedLevyKey.new('duty')
end

.from_string(value) ⇒ Object

Returns the instance of IncludedLevyKey for this value, or nil if not found



9267
9268
9269
9270
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9267

def IncludedLevyKey.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  IncludedLevyKey.ALL.find { |v| v.value == value }
end

.vatObject



9280
9281
9282
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9280

def IncludedLevyKey.vat
  @@_vat ||= IncludedLevyKey.new('vat')
end

.vat_and_dutyObject



9284
9285
9286
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9284

def IncludedLevyKey.vat_and_duty
  @@_vat_and_duty ||= IncludedLevyKey.new('vat_and_duty')
end

Instance Method Details

#to_hashObject



9288
9289
9290
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 9288

def to_hash
  value
end