Class: Io::Flow::V0::Models::InstallmentPlanPaymentErrorCode
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::InstallmentPlanPaymentErrorCode
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of InstallmentPlanPaymentErrorCode for this value, creating a new instance for an unknown value.
-
.from_string(value) ⇒ Object
Returns the instance of InstallmentPlanPaymentErrorCode for this value, or nil if not found.
-
.invalid_authorization ⇒ Object
Indicates the specified authorization key does not exist.
-
.invalid_authorization_amount ⇒ Object
Indicates the specified authorization amount does not match the first installment in the plan.
-
.invalid_installment_plan ⇒ Object
Indicates the specified installment plan does not exist.
Instance Method Summary collapse
-
#initialize(value) ⇒ InstallmentPlanPaymentErrorCode
constructor
A new instance of InstallmentPlanPaymentErrorCode.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ InstallmentPlanPaymentErrorCode
Returns a new instance of InstallmentPlanPaymentErrorCode.
16022 16023 16024 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16022 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
16020 16021 16022 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16020 def value @value end |
Class Method Details
.ALL ⇒ Object
16042 16043 16044 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16042 def InstallmentPlanPaymentErrorCode.ALL @@all ||= [InstallmentPlanPaymentErrorCode., InstallmentPlanPaymentErrorCode., InstallmentPlanPaymentErrorCode.invalid_installment_plan] end |
.apply(value) ⇒ Object
Returns the instance of InstallmentPlanPaymentErrorCode for this value, creating a new instance for an unknown value
16027 16028 16029 16030 16031 16032 16033 16034 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16027 def InstallmentPlanPaymentErrorCode.apply(value) if value.instance_of?(InstallmentPlanPaymentErrorCode) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || InstallmentPlanPaymentErrorCode.new(value)) end end |
.from_string(value) ⇒ Object
Returns the instance of InstallmentPlanPaymentErrorCode for this value, or nil if not found
16037 16038 16039 16040 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16037 def InstallmentPlanPaymentErrorCode.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) InstallmentPlanPaymentErrorCode.ALL.find { |v| v.value == value } end |
.invalid_authorization ⇒ Object
Indicates the specified authorization key does not exist
16047 16048 16049 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16047 def InstallmentPlanPaymentErrorCode. @@_invalid_authorization ||= InstallmentPlanPaymentErrorCode.new('invalid_authorization') end |
.invalid_authorization_amount ⇒ Object
Indicates the specified authorization amount does not match the first installment in the plan
16053 16054 16055 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16053 def InstallmentPlanPaymentErrorCode. @@_invalid_authorization_amount ||= InstallmentPlanPaymentErrorCode.new('invalid_authorization_amount') end |
.invalid_installment_plan ⇒ Object
Indicates the specified installment plan does not exist
16058 16059 16060 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16058 def InstallmentPlanPaymentErrorCode.invalid_installment_plan @@_invalid_installment_plan ||= InstallmentPlanPaymentErrorCode.new('invalid_installment_plan') end |
Instance Method Details
#to_hash ⇒ Object
16062 16063 16064 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16062 def to_hash value end |