Class: Io::Flow::V0::Models::InventoryStock
- Inherits:
-
InventoryStrategy
- Object
- InventoryStrategy
- Io::Flow::V0::Models::InventoryStock
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
Treats inventory as available as long as the actual inventory quantity is > the specified quantity. A common use case is to set quantity to zero to indicate availability as long as there is at least 1 unit available.
Instance Attribute Summary collapse
-
#quantity ⇒ Object
readonly
Returns the value of attribute quantity.
Attributes inherited from InventoryStrategy
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ InventoryStock
constructor
A new instance of InventoryStock.
- #subtype_to_hash ⇒ Object
- #to_json ⇒ Object
Methods inherited from InventoryStrategy
Constructor Details
#initialize(incoming = {}) ⇒ InventoryStock
Returns a new instance of InventoryStock.
33429 33430 33431 33432 33433 33434 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 33429 def initialize(incoming={}) super(:discriminator => InventoryStrategy::Types::INVENTORY_STOCK) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:quantity], 'InventoryStock') @quantity = HttpClient::Preconditions.assert_class('quantity', opts.delete(:quantity), Integer) end |
Instance Attribute Details
#quantity ⇒ Object (readonly)
Returns the value of attribute quantity.
33427 33428 33429 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 33427 def quantity @quantity end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
33440 33441 33442 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 33440 def copy(incoming={}) InventoryStock.new(subtype_to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#subtype_to_hash ⇒ Object
33444 33445 33446 33447 33448 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 33444 def subtype_to_hash { :quantity => quantity } end |
#to_json ⇒ Object
33436 33437 33438 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 33436 def to_json JSON.dump(to_hash) end |