Class: Io::Flow::V0::Models::InventoryStock

Inherits:
InventoryStrategy show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Treats inventory as available as long as the actual inventory quantity is > the specified quantity. A common use case is to set quantity to zero to indicate availability as long as there is at least 1 unit available.

Instance Attribute Summary collapse

Attributes inherited from InventoryStrategy

#discriminator

Instance Method Summary collapse

Methods inherited from InventoryStrategy

#to_hash

Constructor Details

#initialize(incoming = {}) ⇒ InventoryStock

Returns a new instance of InventoryStock.



14291
14292
14293
14294
14295
14296
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14291

def initialize(incoming={})
  super(:discriminator => InventoryStrategy::Types::INVENTORY_STOCK)
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:quantity], 'InventoryStock')
  @quantity = HttpClient::Preconditions.assert_class('quantity', opts.delete(:quantity), Integer)
end

Instance Attribute Details

#quantity ⇒ Object (readonly)

Returns the value of attribute quantity.



14289
14290
14291
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14289

def quantity
  @quantity
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



14302
14303
14304
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14302

def copy(incoming={})
  InventoryStock.new(subtype_to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#subtype_to_hash ⇒ Object



14306
14307
14308
14309
14310
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14306

def subtype_to_hash
  {
    :quantity => quantity
  }
end

#to_json ⇒ Object



14298
14299
14300
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14298

def to_json
  JSON.dump(to_hash)
end