Class: Io::Flow::V0::Models::ItemAvailabilityStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ ItemAvailabilityStatus

Returns a new instance of ItemAvailabilityStatus.



16156
16157
16158
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16156

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



16154
16155
16156
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16154

def value
  @value
end

Class Method Details

.ALLObject



16176
16177
16178
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16176

def ItemAvailabilityStatus.ALL
  @@all ||= [ItemAvailabilityStatus.available, ItemAvailabilityStatus.low, ItemAvailabilityStatus.out_of_stock]
end

.apply(value) ⇒ Object

Returns the instance of ItemAvailabilityStatus for this value, creating a new instance for an unknown value



16161
16162
16163
16164
16165
16166
16167
16168
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16161

def ItemAvailabilityStatus.apply(value)
  if value.instance_of?(ItemAvailabilityStatus)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || ItemAvailabilityStatus.new(value))
  end
end

.availableObject

Inventory is generally available for purchase



16181
16182
16183
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16181

def ItemAvailabilityStatus.available
  @@_available ||= ItemAvailabilityStatus.new('available')
end

.from_string(value) ⇒ Object

Returns the instance of ItemAvailabilityStatus for this value, or nil if not found



16171
16172
16173
16174
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16171

def ItemAvailabilityStatus.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  ItemAvailabilityStatus.ALL.find { |v| v.value == value }
end

.lowObject

Inventory is low and may soon become unavailable for purchase (# inventory items <= 5). Unless there is a specific use case for low inventory, it can be treated the same as 'available'



16188
16189
16190
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16188

def ItemAvailabilityStatus.low
  @@_low ||= ItemAvailabilityStatus.new('low')
end

.out_of_stockObject

There is no inventory available and is not available for purchase. Sample actions that can be taken are hiding the item or marking as sold out on the frontend



16195
16196
16197
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16195

def ItemAvailabilityStatus.out_of_stock
  @@_out_of_stock ||= ItemAvailabilityStatus.new('out_of_stock')
end

Instance Method Details

#to_hashObject



16199
16200
16201
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16199

def to_hash
  value
end