Class: Io::Flow::V0::Models::ItemFunctionPutForm
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::ItemFunctionPutForm
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
Item Functions are javascript code used to calculate the localized price of an additional item. Each function can be associated with an optional query identifying the products to which the function applies. Flow selects the first function matching an item, then uses that function to calculate local prices whenever any data relevant to the item changes (e.g. on update in master catalog, on change in relevant exchange rate, etc.). Item functions are immutable once created.
Instance Attribute Summary collapse
-
#code ⇒ Object
readonly
Returns the value of attribute code.
-
#description ⇒ Object
readonly
Returns the value of attribute description.
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ ItemFunctionPutForm
constructor
A new instance of ItemFunctionPutForm.
- #to_hash ⇒ Object
- #to_json ⇒ Object
Constructor Details
#initialize(incoming = {}) ⇒ ItemFunctionPutForm
Returns a new instance of ItemFunctionPutForm.
14764 14765 14766 14767 14768 14769 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14764 def initialize(incoming={}) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:description, :code], 'ItemFunctionPutForm') @description = HttpClient::Preconditions.assert_class('description', opts.delete(:description), String) @code = HttpClient::Preconditions.assert_class('code', opts.delete(:code), String) end |
Instance Attribute Details
#code ⇒ Object (readonly)
Returns the value of attribute code.
14762 14763 14764 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14762 def code @code end |
#description ⇒ Object (readonly)
Returns the value of attribute description.
14762 14763 14764 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14762 def description @description end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
14775 14776 14777 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14775 def copy(incoming={}) ItemFunctionPutForm.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#to_hash ⇒ Object
14779 14780 14781 14782 14783 14784 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14779 def to_hash { :description => description, :code => code } end |
#to_json ⇒ Object
14771 14772 14773 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 14771 def to_json JSON.dump(to_hash) end |