Class: Io::Flow::V0::Models::ItemOriginUpserted

Inherits:
Event
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Event raised whenever an item is assigned a country of origin. Note that one item may have multiple countries of origin.

Instance Attribute Summary collapse

Attributes inherited from Event

#discriminator

Instance Method Summary collapse

Methods inherited from Event

#to_hash

Constructor Details

#initialize(incoming = {}) ⇒ ItemOriginUpserted

Returns a new instance of ItemOriginUpserted.



15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15111

def initialize(incoming={})
  super(:discriminator => Event::Types::ITEM_ORIGIN_UPSERTED)
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:event_id, :timestamp, :organization, :number, :origin], 'ItemOriginUpserted')
  @event_id = HttpClient::Preconditions.assert_class('event_id', opts.delete(:event_id), String)
  @timestamp = HttpClient::Preconditions.assert_class('timestamp', HttpClient::Helper.to_date_time_iso8601(opts.delete(:timestamp)), DateTime)
  @organization = HttpClient::Preconditions.assert_class('organization', opts.delete(:organization), String)
  @number = HttpClient::Preconditions.assert_class('number', opts.delete(:number), String)
  @origin = HttpClient::Preconditions.assert_class('origin', opts.delete(:origin), String)
end

Instance Attribute Details

#event_id ⇒ Object (readonly)

Returns the value of attribute event_id.



15109
15110
15111
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15109

def event_id
  @event_id
end

#number ⇒ Object (readonly)

Returns the value of attribute number.



15109
15110
15111
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15109

def number
  @number
end

#organization ⇒ Object (readonly)

Returns the value of attribute organization.



15109
15110
15111
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15109

def organization
  @organization
end

#origin ⇒ Object (readonly)

Returns the value of attribute origin.



15109
15110
15111
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15109

def origin
  @origin
end

#timestamp ⇒ Object (readonly)

Returns the value of attribute timestamp.



15109
15110
15111
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15109

def timestamp
  @timestamp
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



15126
15127
15128
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15126

def copy(incoming={})
  ItemOriginUpserted.new(subtype_to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#subtype_to_hash ⇒ Object



15130
15131
15132
15133
15134
15135
15136
15137
15138
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15130

def subtype_to_hash
  {
    :event_id => event_id,
    :timestamp => timestamp,
    :organization => organization,
    :number => number,
    :origin => origin
  }
end

#to_json ⇒ Object



15122
15123
15124
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 15122

def to_json
  JSON.dump(to_hash)
end