Class: Io::Flow::V0::Models::LevyStrategy
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::LevyStrategy
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of LevyStrategy for this value, creating a new instance for an unknown value.
- .average ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of LevyStrategy for this value, or nil if not found.
- .maximum ⇒ Object
- .minimum ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ LevyStrategy
constructor
A new instance of LevyStrategy.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ LevyStrategy
16406 16407 16408 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16406 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
16404 16405 16406 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16404 def value @value end |
Class Method Details
.ALL ⇒ Object
16426 16427 16428 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16426 def LevyStrategy.ALL @@all ||= [LevyStrategy.minimum, LevyStrategy.average, LevyStrategy.maximum] end |
.apply(value) ⇒ Object
Returns the instance of LevyStrategy for this value, creating a new instance for an unknown value
16411 16412 16413 16414 16415 16416 16417 16418 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16411 def LevyStrategy.apply(value) if value.instance_of?(LevyStrategy) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || LevyStrategy.new(value)) end end |
.average ⇒ Object
16434 16435 16436 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16434 def LevyStrategy.average @@_average ||= LevyStrategy.new('average') end |
.from_string(value) ⇒ Object
Returns the instance of LevyStrategy for this value, or nil if not found
16421 16422 16423 16424 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16421 def LevyStrategy.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) LevyStrategy.ALL.find { |v| v.value == value } end |
.maximum ⇒ Object
16438 16439 16440 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16438 def LevyStrategy.maximum @@_maximum ||= LevyStrategy.new('maximum') end |
.minimum ⇒ Object
16430 16431 16432 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16430 def LevyStrategy.minimum @@_minimum ||= LevyStrategy.new('minimum') end |
Instance Method Details
#to_hash ⇒ Object
16442 16443 16444 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16442 def to_hash value end |