Class: Io::Flow::V0::Models::Membership

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Represents the users that are part of this organization. Primary purpose is to manage which users have access to the organization's data and to provide a simple user interface to assign roles and permissions to each member of the organization

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ Membership

Returns a new instance of Membership.



16095
16096
16097
16098
16099
16100
16101
16102
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16095

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:id, :organization, :user, :role], 'Membership')
  @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String)
  @organization = (x = opts.delete(:organization); x.is_a?(::Io::Flow::V0::Models::ExpandableOrganization) ? x : ::Io::Flow::V0::Models::ExpandableOrganization.from_json(x))
  @user = (x = opts.delete(:user); x.is_a?(::Io::Flow::V0::Models::ExpandableUser) ? x : ::Io::Flow::V0::Models::ExpandableUser.from_json(x))
  @role = (x = opts.delete(:role); x.is_a?(::Io::Flow::V0::Models::Role) ? x : ::Io::Flow::V0::Models::Role.apply(x))
end

Instance Attribute Details

#id ⇒ Object (readonly)

Returns the value of attribute id.



16093
16094
16095
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16093

def id
  @id
end

#organization ⇒ Object (readonly)

Returns the value of attribute organization.



16093
16094
16095
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16093

def organization
  @organization
end

#role ⇒ Object (readonly)

Returns the value of attribute role.



16093
16094
16095
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16093

def role
  @role
end

#user ⇒ Object (readonly)

Returns the value of attribute user.



16093
16094
16095
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16093

def user
  @user
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



16108
16109
16110
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16108

def copy(incoming={})
  Membership.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hash ⇒ Object



16112
16113
16114
16115
16116
16117
16118
16119
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16112

def to_hash
  {
    :id => id,
    :organization => organization.to_hash,
    :user => user.to_hash,
    :role => role.value
  }
end

#to_json ⇒ Object



16104
16105
16106
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 16104

def to_json
  JSON.dump(to_hash)
end