Class: Io::Flow::V0::Models::OrderPlacedV2
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
Sent when an order is submitted, allocations are generated and the total value of the order is accounted for by discounts, subsidies, credits and authorized payments -- but may not ready to fulfill (e.g. pending assignment of a DC or fraud review). Intended to fuel customer feedback and alert merchants that an order is coming.
Instance Attribute Summary collapse
-
#event_id ⇒ Object
readonly
Returns the value of attribute event_id.
-
#order_placed ⇒ Object
readonly
Returns the value of attribute order_placed.
-
#organization ⇒ Object
readonly
Returns the value of attribute organization.
-
#timestamp ⇒ Object
readonly
Returns the value of attribute timestamp.
Attributes inherited from Event
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ OrderPlacedV2
constructor
A new instance of OrderPlacedV2.
- #subtype_to_hash ⇒ Object
- #to_json ⇒ Object
Methods inherited from Event
Constructor Details
#initialize(incoming = {}) ⇒ OrderPlacedV2
Returns a new instance of OrderPlacedV2.
38459 38460 38461 38462 38463 38464 38465 38466 38467 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38459 def initialize(incoming={}) super(:discriminator => Event::Types::ORDER_PLACED_V2) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:event_id, :timestamp, :organization, :order_placed], 'OrderPlacedV2') @event_id = HttpClient::Preconditions.assert_class('event_id', opts.delete(:event_id), String) @timestamp = HttpClient::Preconditions.assert_class('timestamp', HttpClient::Helper.to_date_time_iso8601(opts.delete(:timestamp)), DateTime) @organization = HttpClient::Preconditions.assert_class('organization', opts.delete(:organization), String) @order_placed = (x = opts.delete(:order_placed); x.is_a?(::Io::Flow::V0::Models::OrderPlacedDetails) ? x : ::Io::Flow::V0::Models::OrderPlacedDetails.new(x)) end |
Instance Attribute Details
#event_id ⇒ Object (readonly)
Returns the value of attribute event_id.
38457 38458 38459 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38457 def event_id @event_id end |
#order_placed ⇒ Object (readonly)
Returns the value of attribute order_placed.
38457 38458 38459 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38457 def order_placed @order_placed end |
#organization ⇒ Object (readonly)
Returns the value of attribute organization.
38457 38458 38459 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38457 def organization @organization end |
#timestamp ⇒ Object (readonly)
Returns the value of attribute timestamp.
38457 38458 38459 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38457 def @timestamp end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
38473 38474 38475 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38473 def copy(incoming={}) OrderPlacedV2.new(subtype_to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#subtype_to_hash ⇒ Object
38477 38478 38479 38480 38481 38482 38483 38484 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38477 def subtype_to_hash { :event_id => event_id, :timestamp => , :organization => organization, :order_placed => order_placed.to_hash } end |
#to_json ⇒ Object
38469 38470 38471 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38469 def to_json JSON.dump(to_hash) end |