Class: Io::Flow::V0::Models::OrderPriceDetailKey

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ OrderPriceDetailKey

Returns a new instance of OrderPriceDetailKey.



17235
17236
17237
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17235

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



17233
17234
17235
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17233

def value
  @value
end

Class Method Details

.adjustmentObject

The details of any adjustments made to the order.



17260
17261
17262
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17260

def OrderPriceDetailKey.adjustment
  @@_adjustment ||= OrderPriceDetailKey.new('adjustment')
end

.ALLObject



17255
17256
17257
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17255

def OrderPriceDetailKey.ALL
  @@all ||= [OrderPriceDetailKey.adjustment, OrderPriceDetailKey.subtotal, OrderPriceDetailKey.vat, OrderPriceDetailKey.duty, OrderPriceDetailKey.shipping, OrderPriceDetailKey.insurance, OrderPriceDetailKey.discount, OrderPriceDetailKey.surcharges]
end

.apply(value) ⇒ Object

Returns the instance of OrderPriceDetailKey for this value, creating a new instance for an unknown value



17240
17241
17242
17243
17244
17245
17246
17247
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17240

def OrderPriceDetailKey.apply(value)
  if value.instance_of?(OrderPriceDetailKey)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || OrderPriceDetailKey.new(value))
  end
end

.discountObject

The details of any discount applied to the order.



17291
17292
17293
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17291

def OrderPriceDetailKey.discount
  @@_discount ||= OrderPriceDetailKey.new('discount')
end

.dutyObject

The details of any duties owed on the order.



17276
17277
17278
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17276

def OrderPriceDetailKey.duty
  @@_duty ||= OrderPriceDetailKey.new('duty')
end

.from_string(value) ⇒ Object

Returns the instance of OrderPriceDetailKey for this value, or nil if not found



17250
17251
17252
17253
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17250

def OrderPriceDetailKey.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  OrderPriceDetailKey.ALL.find { |v| v.value == value }
end

.insuranceObject

The details of insurance costs for the order.



17286
17287
17288
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17286

def OrderPriceDetailKey.insurance
  @@_insurance ||= OrderPriceDetailKey.new('insurance')
end

.shippingObject

The details of shipping costs for the order.



17281
17282
17283
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17281

def OrderPriceDetailKey.shipping
  @@_shipping ||= OrderPriceDetailKey.new('shipping')
end

.subtotalObject

The details of the subtotal for the order, including item prices, margins, and rounding.



17266
17267
17268
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17266

def OrderPriceDetailKey.subtotal
  @@_subtotal ||= OrderPriceDetailKey.new('subtotal')
end

.surchargesObject

Additional fees and levies applied to the order



17296
17297
17298
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17296

def OrderPriceDetailKey.surcharges
  @@_surcharges ||= OrderPriceDetailKey.new('surcharges')
end

.vatObject

The details of any VAT owed on the order.



17271
17272
17273
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17271

def OrderPriceDetailKey.vat
  @@_vat ||= OrderPriceDetailKey.new('vat')
end

Instance Method Details

#to_hashObject



17300
17301
17302
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17300

def to_hash
  value
end