Class: Io::Flow::V0::Models::OrderServiceChange
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::OrderServiceChange
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
Manual change for a shipping method used for an order. Currently only available to orders with a single calculated delivery.
Instance Attribute Summary collapse
-
#from ⇒ Object
readonly
Returns the value of attribute from.
-
#id ⇒ Object
readonly
Returns the value of attribute id.
-
#to ⇒ Object
readonly
Returns the value of attribute to.
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ OrderServiceChange
constructor
A new instance of OrderServiceChange.
- #to_hash ⇒ Object
- #to_json ⇒ Object
Constructor Details
#initialize(incoming = {}) ⇒ OrderServiceChange
Returns a new instance of OrderServiceChange.
38728 38729 38730 38731 38732 38733 38734 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38728 def initialize(incoming={}) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:id, :from, :to], 'OrderServiceChange') @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String) @from = (x = opts.delete(:from); x.is_a?(::Io::Flow::V0::Models::CarrierService) ? x : ::Io::Flow::V0::Models::CarrierService.new(x)) @to = (x = opts.delete(:to); x.is_a?(::Io::Flow::V0::Models::CarrierService) ? x : ::Io::Flow::V0::Models::CarrierService.new(x)) end |
Instance Attribute Details
#from ⇒ Object (readonly)
Returns the value of attribute from.
38726 38727 38728 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38726 def from @from end |
#id ⇒ Object (readonly)
Returns the value of attribute id.
38726 38727 38728 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38726 def id @id end |
#to ⇒ Object (readonly)
Returns the value of attribute to.
38726 38727 38728 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38726 def to @to end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
38740 38741 38742 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38740 def copy(incoming={}) OrderServiceChange.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#to_hash ⇒ Object
38744 38745 38746 38747 38748 38749 38750 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38744 def to_hash { :id => id, :from => from.to_hash, :to => to.to_hash } end |
#to_json ⇒ Object
38736 38737 38738 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 38736 def to_json JSON.dump(to_hash) end |