Class: Io::Flow::V0::Models::OrderStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ OrderStatus

Returns a new instance of OrderStatus.



17310
17311
17312
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17310

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



17308
17309
17310
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17308

def value
  @value
end

Class Method Details

.ALLObject



17330
17331
17332
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17330

def OrderStatus.ALL
  @@all ||= [OrderStatus.open, OrderStatus.]
end

.apply(value) ⇒ Object

Returns the instance of OrderStatus for this value, creating a new instance for an unknown value



17315
17316
17317
17318
17319
17320
17321
17322
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17315

def OrderStatus.apply(value)
  if value.instance_of?(OrderStatus)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || OrderStatus.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of OrderStatus for this value, or nil if not found



17325
17326
17327
17328
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17325

def OrderStatus.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  OrderStatus.ALL.find { |v| v.value == value }
end

.openObject



17334
17335
17336
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17334

def OrderStatus.open
  @@_open ||= OrderStatus.new('open')
end

.submittedObject



17338
17339
17340
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17338

def OrderStatus.
   ||= OrderStatus.new('submitted')
end

Instance Method Details

#to_hashObject



17342
17343
17344
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17342

def to_hash
  value
end