Class: Io::Flow::V0::Models::PaymentErrorCode
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::PaymentErrorCode
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of PaymentErrorCode for this value, creating a new instance for an unknown value.
- .duplicate ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of PaymentErrorCode for this value, or nil if not found.
-
.invalid_amount ⇒ Object
Amount is not valid (e.g. for merchant of record payments, the amount specified must match the order).
-
.invalid_currency ⇒ Object
Currency is either not known or invalid (e.g. for merchant of record payments, the currency specified must match the order).
-
.invalid_customer ⇒ Object
Customer information is invalid (e.g. email specified but not a valid email).
-
.invalid_destination ⇒ Object
Destination/shipping address is not valid.
-
.invalid_method ⇒ Object
Invalid payment method.
-
.invalid_order ⇒ Object
The specified order number was not found.
-
.unknown ⇒ Object
Failed due to another reason (details not known).
Instance Method Summary collapse
-
#initialize(value) ⇒ PaymentErrorCode
constructor
A new instance of PaymentErrorCode.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ PaymentErrorCode
Returns a new instance of PaymentErrorCode.
17392 17393 17394 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17392 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
17390 17391 17392 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17390 def value @value end |
Class Method Details
.ALL ⇒ Object
17412 17413 17414 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17412 def PaymentErrorCode.ALL @@all ||= [PaymentErrorCode.duplicate, PaymentErrorCode.invalid_amount, PaymentErrorCode.invalid_currency, PaymentErrorCode.invalid_method, PaymentErrorCode.invalid_order, PaymentErrorCode.invalid_customer, PaymentErrorCode.invalid_destination, PaymentErrorCode.unknown] end |
.apply(value) ⇒ Object
Returns the instance of PaymentErrorCode for this value, creating a new instance for an unknown value
17397 17398 17399 17400 17401 17402 17403 17404 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17397 def PaymentErrorCode.apply(value) if value.instance_of?(PaymentErrorCode) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || PaymentErrorCode.new(value)) end end |
.duplicate ⇒ Object
17416 17417 17418 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17416 def PaymentErrorCode.duplicate @@_duplicate ||= PaymentErrorCode.new('duplicate') end |
.from_string(value) ⇒ Object
Returns the instance of PaymentErrorCode for this value, or nil if not found
17407 17408 17409 17410 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17407 def PaymentErrorCode.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) PaymentErrorCode.ALL.find { |v| v.value == value } end |
.invalid_amount ⇒ Object
Amount is not valid (e.g. for merchant of record payments, the amount specified must match the order). This typically is handled by refreshing the order amount and reconfirming with the user as something has changed.
17423 17424 17425 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17423 def PaymentErrorCode.invalid_amount @@_invalid_amount ||= PaymentErrorCode.new('invalid_amount') end |
.invalid_currency ⇒ Object
Currency is either not known or invalid (e.g. for merchant of record payments, the currency specified must match the order).
17429 17430 17431 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17429 def PaymentErrorCode.invalid_currency @@_invalid_currency ||= PaymentErrorCode.new('invalid_currency') end |
.invalid_customer ⇒ Object
Customer information is invalid (e.g. email specified but not a valid email)
17444 17445 17446 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17444 def PaymentErrorCode.invalid_customer @@_invalid_customer ||= PaymentErrorCode.new('invalid_customer') end |
.invalid_destination ⇒ Object
Destination/shipping address is not valid
17449 17450 17451 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17449 def PaymentErrorCode.invalid_destination @@_invalid_destination ||= PaymentErrorCode.new('invalid_destination') end |
.invalid_method ⇒ Object
Invalid payment method
17434 17435 17436 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17434 def PaymentErrorCode.invalid_method @@_invalid_method ||= PaymentErrorCode.new('invalid_method') end |
.invalid_order ⇒ Object
The specified order number was not found
17439 17440 17441 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17439 def PaymentErrorCode.invalid_order @@_invalid_order ||= PaymentErrorCode.new('invalid_order') end |
.unknown ⇒ Object
Failed due to another reason (details not known)
17454 17455 17456 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17454 def PaymentErrorCode.unknown @@_unknown ||= PaymentErrorCode.new('unknown') end |
Instance Method Details
#to_hash ⇒ Object
17458 17459 17460 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17458 def to_hash value end |