Class: Io::Flow::V0::Models::PaymentMethodType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::PaymentMethodType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of PaymentMethodType for this value, creating a new instance for an unknown value.
-
.card ⇒ Object
Represents all form of card payment (e.g. credit, debit, etc.).
-
.from_string(value) ⇒ Object
Returns the instance of PaymentMethodType for this value, or nil if not found.
-
.offline ⇒ Object
Offline payment method types represent payments like Cash On Delivery which require offline collection.
-
.online ⇒ Object
Represents the most common form of alternative payment methods which require some degree of integration online (e.g. a redirect) to complete payment.
Instance Method Summary collapse
-
#initialize(value) ⇒ PaymentMethodType
constructor
A new instance of PaymentMethodType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ PaymentMethodType
Returns a new instance of PaymentMethodType.
17506 17507 17508 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17506 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
17504 17505 17506 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17504 def value @value end |
Class Method Details
.ALL ⇒ Object
17526 17527 17528 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17526 def PaymentMethodType.ALL @@all ||= [PaymentMethodType.card, PaymentMethodType.online, PaymentMethodType.offline] end |
.apply(value) ⇒ Object
Returns the instance of PaymentMethodType for this value, creating a new instance for an unknown value
17511 17512 17513 17514 17515 17516 17517 17518 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17511 def PaymentMethodType.apply(value) if value.instance_of?(PaymentMethodType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || PaymentMethodType.new(value)) end end |
.card ⇒ Object
Represents all form of card payment (e.g. credit, debit, etc.)
17531 17532 17533 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17531 def PaymentMethodType.card @@_card ||= PaymentMethodType.new('card') end |
.from_string(value) ⇒ Object
Returns the instance of PaymentMethodType for this value, or nil if not found
17521 17522 17523 17524 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17521 def PaymentMethodType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) PaymentMethodType.ALL.find { |v| v.value == value } end |
.offline ⇒ Object
Offline payment method types represent payments like Cash On Delivery which require offline collection
17543 17544 17545 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17543 def PaymentMethodType.offline @@_offline ||= PaymentMethodType.new('offline') end |
.online ⇒ Object
Represents the most common form of alternative payment methods which require some degree of integration online (e.g. a redirect) to complete payment.
17537 17538 17539 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17537 def PaymentMethodType.online @@_online ||= PaymentMethodType.new('online') end |
Instance Method Details
#to_hash ⇒ Object
17547 17548 17549 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17547 def to_hash value end |