Class: Io::Flow::V0::Models::PriceBookStatus
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::PriceBookStatus
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of PriceBookStatus for this value, creating a new instance for an unknown value.
- .archived ⇒ Object
- .draft ⇒ Object
-
.from_string(value) ⇒ Object
Returns the instance of PriceBookStatus for this value, or nil if not found.
- .published ⇒ Object
Instance Method Summary collapse
-
#initialize(value) ⇒ PriceBookStatus
constructor
A new instance of PriceBookStatus.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ PriceBookStatus
Returns a new instance of PriceBookStatus.
17749 17750 17751 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17749 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
17747 17748 17749 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17747 def value @value end |
Class Method Details
.ALL ⇒ Object
17769 17770 17771 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17769 def PriceBookStatus.ALL @@all ||= [PriceBookStatus.draft, PriceBookStatus.published, PriceBookStatus.archived] end |
.apply(value) ⇒ Object
Returns the instance of PriceBookStatus for this value, creating a new instance for an unknown value
17754 17755 17756 17757 17758 17759 17760 17761 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17754 def PriceBookStatus.apply(value) if value.instance_of?(PriceBookStatus) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || PriceBookStatus.new(value)) end end |
.archived ⇒ Object
17781 17782 17783 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17781 def PriceBookStatus.archived @@_archived ||= PriceBookStatus.new('archived') end |
.draft ⇒ Object
17773 17774 17775 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17773 def PriceBookStatus.draft @@_draft ||= PriceBookStatus.new('draft') end |
.from_string(value) ⇒ Object
Returns the instance of PriceBookStatus for this value, or nil if not found
17764 17765 17766 17767 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17764 def PriceBookStatus.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) PriceBookStatus.ALL.find { |v| v.value == value } end |
.published ⇒ Object
17777 17778 17779 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17777 def PriceBookStatus.published @@_published ||= PriceBookStatus.new('published') end |
Instance Method Details
#to_hash ⇒ Object
17785 17786 17787 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 17785 def to_hash value end |