Class: Io::Flow::V0::Models::PublicKey
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::PublicKey
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Overview
A public key is used to encrypt cards client side prior to submitting to the Flow vault.
Instance Attribute Summary collapse
-
#id ⇒ Object
readonly
Returns the value of attribute id.
Instance Method Summary collapse
- #copy(incoming = {}) ⇒ Object
-
#initialize(incoming = {}) ⇒ PublicKey
constructor
A new instance of PublicKey.
- #to_hash ⇒ Object
- #to_json ⇒ Object
Constructor Details
#initialize(incoming = {}) ⇒ PublicKey
Returns a new instance of PublicKey.
18581 18582 18583 18584 18585 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18581 def initialize(incoming={}) opts = HttpClient::Helper.symbolize_keys(incoming) HttpClient::Preconditions.require_keys(opts, [:id], 'PublicKey') @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String) end |
Instance Attribute Details
#id ⇒ Object (readonly)
Returns the value of attribute id.
18579 18580 18581 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18579 def id @id end |
Instance Method Details
#copy(incoming = {}) ⇒ Object
18591 18592 18593 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18591 def copy(incoming={}) PublicKey.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming))) end |
#to_hash ⇒ Object
18595 18596 18597 18598 18599 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18595 def to_hash { :id => id } end |
#to_json ⇒ Object
18587 18588 18589 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18587 def to_json JSON.dump(to_hash) end |