Class: Io::Flow::V0::Models::QuoteErrorCode

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ QuoteErrorCode

Returns a new instance of QuoteErrorCode.



18230
18231
18232
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18230

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



18228
18229
18230
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18228

def value
  @value
end

Class Method Details

.ALLObject



18250
18251
18252
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18250

def QuoteErrorCode.ALL
  @@all ||= [QuoteErrorCode.generic_error, QuoteErrorCode.items_not_available, QuoteErrorCode.shipping_unavailable]
end

.apply(value) ⇒ Object

Returns the instance of QuoteErrorCode for this value, creating a new instance for an unknown value



18235
18236
18237
18238
18239
18240
18241
18242
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18235

def QuoteErrorCode.apply(value)
  if value.instance_of?(QuoteErrorCode)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || QuoteErrorCode.new(value))
  end
end

.from_string(value) ⇒ Object

Returns the instance of QuoteErrorCode for this value, or nil if not found



18245
18246
18247
18248
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18245

def QuoteErrorCode.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  QuoteErrorCode.ALL.find { |v| v.value == value }
end

.generic_errorObject



18254
18255
18256
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18254

def QuoteErrorCode.generic_error
  @@_generic_error ||= QuoteErrorCode.new('generic_error')
end

.items_not_availableObject

Item numbers are not available in inventory



18259
18260
18261
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18259

def QuoteErrorCode.items_not_available
  @@_items_not_available ||= QuoteErrorCode.new('items_not_available')
end

.shipping_unavailableObject

Indicates that an order was created for a destination country to which you have no shipping lanes.



18265
18266
18267
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18265

def QuoteErrorCode.shipping_unavailable
  @@_shipping_unavailable ||= QuoteErrorCode.new('shipping_unavailable')
end

Instance Method Details

#to_hashObject



18269
18270
18271
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18269

def to_hash
  value
end