Class: Io::Flow::V0::Models::Refund

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Refunds can be created against either a specific capture or an authorization (in which case we will select 1 or more specific captures against which to execute the refund).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ Refund

Returns a new instance of Refund.



19025
19026
19027
19028
19029
19030
19031
19032
19033
19034
19035
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19025

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:id, :key, :authorization, :amount, :currency, :captures, :created_at], 'Refund')
  @id = HttpClient::Preconditions.assert_class('id', opts.delete(:id), String)
  @key = HttpClient::Preconditions.assert_class('key', opts.delete(:key), String)
  @authorization = (x = opts.delete(:authorization); x.is_a?(::Io::Flow::V0::Models::AuthorizationReference) ? x : ::Io::Flow::V0::Models::AuthorizationReference.new(x))
  @amount = HttpClient::Preconditions.assert_class('amount', HttpClient::Helper.to_big_decimal(opts.delete(:amount)), BigDecimal)
  @currency = HttpClient::Preconditions.assert_class('currency', opts.delete(:currency), String)
  @captures = HttpClient::Preconditions.assert_class('captures', opts.delete(:captures), Array).map { |v| (x = v; x.is_a?(::Io::Flow::V0::Models::RefundCapture) ? x : ::Io::Flow::V0::Models::RefundCapture.new(x)) }
  @created_at = HttpClient::Preconditions.assert_class('created_at', HttpClient::Helper.to_date_time_iso8601(opts.delete(:created_at)), DateTime)
end

Instance Attribute Details

#amount ⇒ Object (readonly)

Returns the value of attribute amount.



19023
19024
19025
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19023

def amount
  @amount
end

#authorization ⇒ Object (readonly)

Returns the value of attribute authorization.



19023
19024
19025
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19023

def authorization
  @authorization
end

#captures ⇒ Object (readonly)

Returns the value of attribute captures.



19023
19024
19025
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19023

def captures
  @captures
end

#created_at ⇒ Object (readonly)

Returns the value of attribute created_at.



19023
19024
19025
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19023

def created_at
  @created_at
end

#currency ⇒ Object (readonly)

Returns the value of attribute currency.



19023
19024
19025
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19023

def currency
  @currency
end

#id ⇒ Object (readonly)

Returns the value of attribute id.



19023
19024
19025
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19023

def id
  @id
end

#key ⇒ Object (readonly)

Returns the value of attribute key.



19023
19024
19025
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19023

def key
  @key
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



19041
19042
19043
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19041

def copy(incoming={})
  Refund.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hash ⇒ Object



19045
19046
19047
19048
19049
19050
19051
19052
19053
19054
19055
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19045

def to_hash
  {
    :id => id,
    :key => key,
    :authorization => authorization.to_hash,
    :amount => amount,
    :currency => currency,
    :captures => captures.map { |o| o.to_hash },
    :created_at => created_at
  }
end

#to_json ⇒ Object



19037
19038
19039
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 19037

def to_json
  JSON.dump(to_hash)
end