Class: Io::Flow::V0::Models::ReversalErrorCode

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ ReversalErrorCode

Returns a new instance of ReversalErrorCode.



18510
18511
18512
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18510

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



18508
18509
18510
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18508

def value
  @value
end

Class Method Details

.ALLObject



18530
18531
18532
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18530

def ReversalErrorCode.ALL
  @@all ||= [ReversalErrorCode.amount_exceeds_balance, ReversalErrorCode.authorization_declined, ReversalErrorCode.authorization_expired, ReversalErrorCode.invalid_authorization, ReversalErrorCode.invalid_key, ReversalErrorCode.invalid_amount, ReversalErrorCode.invalid_currency, ReversalErrorCode.no_remaining_balance, ReversalErrorCode.partial_reversal_not_supported, ReversalErrorCode.unknown]
end

.amount_exceeds_balanceObject

Amount specified exceeds the remaining authorization balance.



18535
18536
18537
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18535

def ReversalErrorCode.amount_exceeds_balance
  @@_amount_exceeds_balance ||= ReversalErrorCode.new('amount_exceeds_balance')
end

.apply(value) ⇒ Object

Returns the instance of ReversalErrorCode for this value, creating a new instance for an unknown value



18515
18516
18517
18518
18519
18520
18521
18522
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18515

def ReversalErrorCode.apply(value)
  if value.instance_of?(ReversalErrorCode)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || ReversalErrorCode.new(value))
  end
end

.authorization_declinedObject

The authorization was initially declined; there is nothing to reverse.



18540
18541
18542
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18540

def ReversalErrorCode.authorization_declined
  @@_authorization_declined ||= ReversalErrorCode.new('authorization_declined')
end

.authorization_expiredObject

The authorization has expired and can no longer be reversed.



18545
18546
18547
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18545

def ReversalErrorCode.authorization_expired
  @@_authorization_expired ||= ReversalErrorCode.new('authorization_expired')
end

.from_string(value) ⇒ Object

Returns the instance of ReversalErrorCode for this value, or nil if not found



18525
18526
18527
18528
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18525

def ReversalErrorCode.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  ReversalErrorCode.ALL.find { |v| v.value == value }
end

.invalid_amountObject

Amount is not valid - usually because amount was <= 0



18560
18561
18562
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18560

def ReversalErrorCode.invalid_amount
  @@_invalid_amount ||= ReversalErrorCode.new('invalid_amount')
end

.invalid_authorizationObject

The authorization was not found.



18550
18551
18552
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18550

def ReversalErrorCode.invalid_authorization
  @@_invalid_authorization ||= ReversalErrorCode.new('invalid_authorization')
end

.invalid_currencyObject

Currency is either not known or invalid



18565
18566
18567
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18565

def ReversalErrorCode.invalid_currency
  @@_invalid_currency ||= ReversalErrorCode.new('invalid_currency')
end

.invalid_keyObject

Invalid key



18555
18556
18557
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18555

def ReversalErrorCode.invalid_key
  @@_invalid_key ||= ReversalErrorCode.new('invalid_key')
end

.no_remaining_balanceObject

The authorization has already been fully captured and/or reversed - there are no additional funds to reverse.



18571
18572
18573
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18571

def ReversalErrorCode.no_remaining_balance
  @@_no_remaining_balance ||= ReversalErrorCode.new('no_remaining_balance')
end

.partial_reversal_not_supportedObject

Indicates a request for a partial reversal when the underlying processor does not support it



18577
18578
18579
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18577

def ReversalErrorCode.partial_reversal_not_supported
  @@_partial_reversal_not_supported ||= ReversalErrorCode.new('partial_reversal_not_supported')
end

.unknownObject

Unknown or other



18582
18583
18584
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18582

def ReversalErrorCode.unknown
  @@_unknown ||= ReversalErrorCode.new('unknown')
end

Instance Method Details

#to_hashObject



18586
18587
18588
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18586

def to_hash
  value
end