Class: Io::Flow::V0::Models::ReversalErrorCode
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::ReversalErrorCode
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.amount_exceeds_balance ⇒ Object
Amount specified exceeds the remaining authorization balance.
-
.apply(value) ⇒ Object
Returns the instance of ReversalErrorCode for this value, creating a new instance for an unknown value.
-
.authorization_declined ⇒ Object
The authorization was initially declined; there is nothing to reverse.
-
.authorization_expired ⇒ Object
The authorization has expired and can no longer be reversed.
-
.from_string(value) ⇒ Object
Returns the instance of ReversalErrorCode for this value, or nil if not found.
-
.invalid_amount ⇒ Object
Amount is not valid - usually because amount was <= 0.
-
.invalid_authorization ⇒ Object
The authorization was not found.
-
.invalid_currency ⇒ Object
Currency is either not known or invalid.
-
.invalid_key ⇒ Object
Invalid key.
-
.no_remaining_balance ⇒ Object
The authorization has already been fully captured and/or reversed - there are no additional funds to reverse.
-
.partial_reversal_not_supported ⇒ Object
Indicates a request for a partial reversal when the underlying processor does not support it.
-
.unknown ⇒ Object
Unknown or other.
Instance Method Summary collapse
-
#initialize(value) ⇒ ReversalErrorCode
constructor
A new instance of ReversalErrorCode.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ ReversalErrorCode
Returns a new instance of ReversalErrorCode.
18510 18511 18512 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18510 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
18508 18509 18510 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18508 def value @value end |
Class Method Details
.ALL ⇒ Object
18530 18531 18532 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18530 def ReversalErrorCode.ALL @@all ||= [ReversalErrorCode.amount_exceeds_balance, ReversalErrorCode., ReversalErrorCode., ReversalErrorCode., ReversalErrorCode.invalid_key, ReversalErrorCode.invalid_amount, ReversalErrorCode.invalid_currency, ReversalErrorCode.no_remaining_balance, ReversalErrorCode.partial_reversal_not_supported, ReversalErrorCode.unknown] end |
.amount_exceeds_balance ⇒ Object
Amount specified exceeds the remaining authorization balance.
18535 18536 18537 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18535 def ReversalErrorCode.amount_exceeds_balance @@_amount_exceeds_balance ||= ReversalErrorCode.new('amount_exceeds_balance') end |
.apply(value) ⇒ Object
Returns the instance of ReversalErrorCode for this value, creating a new instance for an unknown value
18515 18516 18517 18518 18519 18520 18521 18522 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18515 def ReversalErrorCode.apply(value) if value.instance_of?(ReversalErrorCode) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || ReversalErrorCode.new(value)) end end |
.authorization_declined ⇒ Object
The authorization was initially declined; there is nothing to reverse.
18540 18541 18542 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18540 def ReversalErrorCode. ||= ReversalErrorCode.new('authorization_declined') end |
.authorization_expired ⇒ Object
The authorization has expired and can no longer be reversed.
18545 18546 18547 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18545 def ReversalErrorCode. ||= ReversalErrorCode.new('authorization_expired') end |
.from_string(value) ⇒ Object
Returns the instance of ReversalErrorCode for this value, or nil if not found
18525 18526 18527 18528 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18525 def ReversalErrorCode.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) ReversalErrorCode.ALL.find { |v| v.value == value } end |
.invalid_amount ⇒ Object
Amount is not valid - usually because amount was <= 0
18560 18561 18562 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18560 def ReversalErrorCode.invalid_amount @@_invalid_amount ||= ReversalErrorCode.new('invalid_amount') end |
.invalid_authorization ⇒ Object
The authorization was not found.
18550 18551 18552 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18550 def ReversalErrorCode. ||= ReversalErrorCode.new('invalid_authorization') end |
.invalid_currency ⇒ Object
Currency is either not known or invalid
18565 18566 18567 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18565 def ReversalErrorCode.invalid_currency @@_invalid_currency ||= ReversalErrorCode.new('invalid_currency') end |
.invalid_key ⇒ Object
Invalid key
18555 18556 18557 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18555 def ReversalErrorCode.invalid_key @@_invalid_key ||= ReversalErrorCode.new('invalid_key') end |
.no_remaining_balance ⇒ Object
The authorization has already been fully captured and/or reversed - there are no additional funds to reverse.
18571 18572 18573 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18571 def ReversalErrorCode.no_remaining_balance @@_no_remaining_balance ||= ReversalErrorCode.new('no_remaining_balance') end |
.partial_reversal_not_supported ⇒ Object
Indicates a request for a partial reversal when the underlying processor does not support it
18577 18578 18579 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18577 def ReversalErrorCode.partial_reversal_not_supported @@_partial_reversal_not_supported ||= ReversalErrorCode.new('partial_reversal_not_supported') end |
.unknown ⇒ Object
Unknown or other
18582 18583 18584 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18582 def ReversalErrorCode.unknown @@_unknown ||= ReversalErrorCode.new('unknown') end |
Instance Method Details
#to_hash ⇒ Object
18586 18587 18588 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18586 def to_hash value end |