Class: Io::Flow::V0::Models::RoundingMethod

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value) ⇒ RoundingMethod

Returns a new instance of RoundingMethod.



18687
18688
18689
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18687

def initialize(value)
  @value = HttpClient::Preconditions.assert_class('value', value, String)
end

Instance Attribute Details

#valueObject (readonly)

Returns the value of attribute value.



18685
18686
18687
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18685

def value
  @value
end

Class Method Details

.ALLObject



18707
18708
18709
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18707

def RoundingMethod.ALL
  @@all ||= [RoundingMethod.up, RoundingMethod.down, RoundingMethod.nearest]
end

.apply(value) ⇒ Object

Returns the instance of RoundingMethod for this value, creating a new instance for an unknown value



18692
18693
18694
18695
18696
18697
18698
18699
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18692

def RoundingMethod.apply(value)
  if value.instance_of?(RoundingMethod)
    value
  else
    HttpClient::Preconditions.assert_class_or_nil('value', value, String)
    value.nil? ? nil : (from_string(value) || RoundingMethod.new(value))
  end
end

.downObject

Round down to the specified rounding.value



18717
18718
18719
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18717

def RoundingMethod.down
  @@_down ||= RoundingMethod.new('down')
end

.from_string(value) ⇒ Object

Returns the instance of RoundingMethod for this value, or nil if not found



18702
18703
18704
18705
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18702

def RoundingMethod.from_string(value)
  HttpClient::Preconditions.assert_class('value', value, String)
  RoundingMethod.ALL.find { |v| v.value == value }
end

.nearestObject

Round to the nearest specified rounding.value. If equidistant, will round up.



18722
18723
18724
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18722

def RoundingMethod.nearest
  @@_nearest ||= RoundingMethod.new('nearest')
end

.upObject

Round up to the specified rounding.value



18712
18713
18714
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18712

def RoundingMethod.up
  @@_up ||= RoundingMethod.new('up')
end

Instance Method Details

#to_hashObject



18726
18727
18728
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 18726

def to_hash
  value
end