Class: Io::Flow::V0::Models::ShippingNotificationForm

Inherits:
Object
  • Object
show all
Defined in:
lib/flow_commerce/flow_api_v0_client.rb

Overview

Form for information about a client-facilitated shipment where the shipping label and fulfillment was not handled by Flow. For merchant-of-record and tracking purposes, clients doing their own shipping will need to notify Flow of shipped packages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(incoming = {}) ⇒ ShippingNotificationForm

Returns a new instance of ShippingNotificationForm.



20306
20307
20308
20309
20310
20311
20312
20313
20314
20315
20316
20317
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20306

def initialize(incoming={})
  opts = HttpClient::Helper.symbolize_keys(incoming)
  HttpClient::Preconditions.require_keys(opts, [:carrier_tracking_number, :destination, :order_number, :origin, :package, :service], 'ShippingNotificationForm')
  @key = (x = opts.delete(:key); x.nil? ? nil : HttpClient::Preconditions.assert_class('key', x, String))
  @attributes = (x = opts.delete(:attributes); x.nil? ? nil : HttpClient::Preconditions.assert_class('attributes', x, Hash).inject({}) { |h, d| h[d[0]] = HttpClient::Preconditions.assert_class('attributes', d[1], String); h })
  @carrier_tracking_number = HttpClient::Preconditions.assert_class('carrier_tracking_number', opts.delete(:carrier_tracking_number), String)
  @destination = (x = opts.delete(:destination); x.is_a?(::Io::Flow::V0::Models::ShippingAddress) ? x : ::Io::Flow::V0::Models::ShippingAddress.new(x))
  @order_number = HttpClient::Preconditions.assert_class('order_number', opts.delete(:order_number), String)
  @origin = (x = opts.delete(:origin); x.is_a?(::Io::Flow::V0::Models::ShippingAddress) ? x : ::Io::Flow::V0::Models::ShippingAddress.new(x))
  @package = (x = opts.delete(:package); x.is_a?(::Io::Flow::V0::Models::ShippingLabelPackage) ? x : ::Io::Flow::V0::Models::ShippingLabelPackage.new(x))
  @service = HttpClient::Preconditions.assert_class('service', opts.delete(:service), String)
end

Instance Attribute Details

#attributes ⇒ Object (readonly)

Returns the value of attribute attributes.



20304
20305
20306
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20304

def attributes
  @attributes
end

#carrier_tracking_number ⇒ Object (readonly)

Returns the value of attribute carrier_tracking_number.



20304
20305
20306
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20304

def carrier_tracking_number
  @carrier_tracking_number
end

#destination ⇒ Object (readonly)

Returns the value of attribute destination.



20304
20305
20306
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20304

def destination
  @destination
end

#key ⇒ Object (readonly)

Returns the value of attribute key.



20304
20305
20306
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20304

def key
  @key
end

#order_number ⇒ Object (readonly)

Returns the value of attribute order_number.



20304
20305
20306
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20304

def order_number
  @order_number
end

#origin ⇒ Object (readonly)

Returns the value of attribute origin.



20304
20305
20306
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20304

def origin
  @origin
end

#package ⇒ Object (readonly)

Returns the value of attribute package.



20304
20305
20306
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20304

def package
  @package
end

#service ⇒ Object (readonly)

Returns the value of attribute service.



20304
20305
20306
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20304

def service
  @service
end

Instance Method Details

#copy(incoming = {}) ⇒ Object



20323
20324
20325
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20323

def copy(incoming={})
  ShippingNotificationForm.new(to_hash.merge(HttpClient::Helper.symbolize_keys(incoming)))
end

#to_hash ⇒ Object



20327
20328
20329
20330
20331
20332
20333
20334
20335
20336
20337
20338
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20327

def to_hash
  {
    :key => key,
    :attributes => attributes.nil? ? nil : attributes,
    :carrier_tracking_number => carrier_tracking_number,
    :destination => destination.to_hash,
    :order_number => order_number,
    :origin => origin.to_hash,
    :package => package.to_hash,
    :service => service
  }
end

#to_json ⇒ Object



20319
20320
20321
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20319

def to_json
  JSON.dump(to_hash)
end