Module: Io::Flow::V0::Models::TierRuleOutcome::Types
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Constant Summary collapse
- AMOUNT_MARGIN =
Add a certain amount on the actual base cost
'amount_margin'- AT_COST =
'at_cost'- FLAT_RATE =
'flat_rate'- PERCENT_MARGIN =
Add a certain percentage of the actual base cost
'percent_margin'