Class: Io::Flow::V0::Models::UpdateType
- Inherits:
-
Object
- Object
- Io::Flow::V0::Models::UpdateType
- Defined in:
- lib/flow_commerce/flow_api_v0_client.rb
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
Returns the value of attribute value.
Class Method Summary collapse
- .ALL ⇒ Object
-
.apply(value) ⇒ Object
Returns the instance of UpdateType for this value, creating a new instance for an unknown value.
-
.change ⇒ Object
Long value to increment or decrement.
-
.from_string(value) ⇒ Object
Returns the instance of UpdateType for this value, or nil if not found.
-
.set ⇒ Object
Set absolute quantity to new value with no regard for previous updates.
Instance Method Summary collapse
-
#initialize(value) ⇒ UpdateType
constructor
A new instance of UpdateType.
- #to_hash ⇒ Object
Constructor Details
#initialize(value) ⇒ UpdateType
Returns a new instance of UpdateType.
20010 20011 20012 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20010 def initialize(value) @value = HttpClient::Preconditions.assert_class('value', value, String) end |
Instance Attribute Details
#value ⇒ Object (readonly)
Returns the value of attribute value.
20008 20009 20010 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20008 def value @value end |
Class Method Details
.ALL ⇒ Object
20030 20031 20032 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20030 def UpdateType.ALL @@all ||= [UpdateType.change, UpdateType.set] end |
.apply(value) ⇒ Object
Returns the instance of UpdateType for this value, creating a new instance for an unknown value
20015 20016 20017 20018 20019 20020 20021 20022 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20015 def UpdateType.apply(value) if value.instance_of?(UpdateType) value else HttpClient::Preconditions.assert_class_or_nil('value', value, String) value.nil? ? nil : (from_string(value) || UpdateType.new(value)) end end |
.change ⇒ Object
Long value to increment or decrement. Positive quantities are added to inventory while negative quantities are decrement from inventory.
20036 20037 20038 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20036 def UpdateType.change @@_change ||= UpdateType.new('change') end |
.from_string(value) ⇒ Object
Returns the instance of UpdateType for this value, or nil if not found
20025 20026 20027 20028 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20025 def UpdateType.from_string(value) HttpClient::Preconditions.assert_class('value', value, String) UpdateType.ALL.find { |v| v.value == value } end |
.set ⇒ Object
Set absolute quantity to new value with no regard for previous updates
20041 20042 20043 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20041 def UpdateType.set @@_set ||= UpdateType.new('set') end |
Instance Method Details
#to_hash ⇒ Object
20045 20046 20047 |
# File 'lib/flow_commerce/flow_api_v0_client.rb', line 20045 def to_hash value end |